// The Module object: Our interface to the outside world. We import
// and export values on it, and do the work to get that through
// closure compiler if necessary. There are various ways Module can be used:
// 1. Not defined. We create it here
// 2. A function parameter, function(Module) { ..generated code.. }
// 3. pre-run appended it, var Module = {}; ..generated code..
// 4. External script tag defines var Module.
// We need to do an eval in order to handle the closure compiler
// case, where this code here is minified but Module was defined
// elsewhere (e.g. case 4 above). We also need to check if Module
// already exists (e.g. case 3 above).
// Note that if you want to run closure, and also to use Module
// after the generated code, you will need to define   var Module = {};
// before the code. Then that object will be used in the code, and you
// can continue to use Module afterwards as well.
var Module;
if (!Module) Module = (typeof Module !== 'undefined' ? Module : null) || {};

// Sometimes an existing Module object exists with properties
// meant to overwrite the default module functionality. Here
// we collect those properties and reapply _after_ we configure
// the current environment's defaults to avoid having to be so
// defensive during initialization.
var moduleOverrides = {};
for (var key in Module) {
  if (Module.hasOwnProperty(key)) {
    moduleOverrides[key] = Module[key];
  }
}

// The environment setup code below is customized to use Module.
// *** Environment setup code ***
var ENVIRONMENT_IS_WEB = typeof window === 'object';
var ENVIRONMENT_IS_NODE = typeof process === 'object' && typeof require === 'function' && !ENVIRONMENT_IS_WEB;
// Three configurations we can be running in:
// 1) We could be the application main() thread running in the main JS UI thread. (ENVIRONMENT_IS_WORKER == false and ENVIRONMENT_IS_PTHREAD == false)
// 2) We could be the application main() thread proxied to worker. (with Emscripten -s PROXY_TO_WORKER=1) (ENVIRONMENT_IS_WORKER == true, ENVIRONMENT_IS_PTHREAD == false)
// 3) We could be an application pthread running in a worker. (ENVIRONMENT_IS_WORKER == true and ENVIRONMENT_IS_PTHREAD == true)
var ENVIRONMENT_IS_WORKER = typeof importScripts === 'function';
var ENVIRONMENT_IS_SHELL = !ENVIRONMENT_IS_WEB && !ENVIRONMENT_IS_NODE && !ENVIRONMENT_IS_WORKER;

if (ENVIRONMENT_IS_NODE) {
  // Expose functionality in the same simple way that the shells work
  // Note that we pollute the global namespace here, otherwise we break in node
  if (!Module['print']) Module['print'] = function print(x) {
    process['stdout'].write(x + '\n');
  };
  if (!Module['printErr']) Module['printErr'] = function printErr(x) {
    process['stderr'].write(x + '\n');
  };

  var nodeFS = require('fs');
  var nodePath = require('path');

  Module['read'] = function read(filename, binary) {
    filename = nodePath['normalize'](filename);
    var ret = nodeFS['readFileSync'](filename);
    // The path is absolute if the normalized version is the same as the resolved.
    if (!ret && filename != nodePath['resolve'](filename)) {
      filename = path.join(__dirname, '..', 'src', filename);
      ret = nodeFS['readFileSync'](filename);
    }
    if (ret && !binary) ret = ret.toString();
    return ret;
  };

  Module['readBinary'] = function readBinary(filename) { return Module['read'](filename, true) };

  Module['load'] = function load(f) {
    globalEval(read(f));
  };

  if (!Module['thisProgram']) {
    if (process['argv'].length > 1) {
      Module['thisProgram'] = process['argv'][1].replace(/\\/g, '/');
    } else {
      Module['thisProgram'] = 'unknown-program';
    }
  }

  Module['arguments'] = process['argv'].slice(2);

  if (typeof module !== 'undefined') {
    module['exports'] = Module;
  }

  process['on']('uncaughtException', function(ex) {
    // suppress ExitStatus exceptions from showing an error
    if (!(ex instanceof ExitStatus)) {
      throw ex;
    }
  });

  Module['inspect'] = function () { return '[Emscripten Module object]'; };
}
else if (ENVIRONMENT_IS_SHELL) {
  if (!Module['print']) Module['print'] = print;
  if (typeof printErr != 'undefined') Module['printErr'] = printErr; // not present in v8 or older sm

  if (typeof read != 'undefined') {
    Module['read'] = read;
  } else {
    Module['read'] = function read() { throw 'no read() available (jsc?)' };
  }

  Module['readBinary'] = function readBinary(f) {
    if (typeof readbuffer === 'function') {
      return new Uint8Array(readbuffer(f));
    }
    var data = read(f, 'binary');
    assert(typeof data === 'object');
    return data;
  };

  if (typeof scriptArgs != 'undefined') {
    Module['arguments'] = scriptArgs;
  } else if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

}
else if (ENVIRONMENT_IS_WEB || ENVIRONMENT_IS_WORKER) {
  Module['read'] = function read(url) {
    var xhr = new XMLHttpRequest();
    xhr.open('GET', url, false);
    xhr.send(null);
    return xhr.responseText;
  };

  if (typeof arguments != 'undefined') {
    Module['arguments'] = arguments;
  }

  if (typeof console !== 'undefined') {
    if (!Module['print']) Module['print'] = function print(x) {
      console.log(x);
    };
    if (!Module['printErr']) Module['printErr'] = function printErr(x) {
      console.log(x);
    };
  } else {
    // Probably a worker, and without console.log. We can do very little here...
    var TRY_USE_DUMP = false;
    if (!Module['print']) Module['print'] = (TRY_USE_DUMP && (typeof(dump) !== "undefined") ? (function(x) {
      dump(x);
    }) : (function(x) {
      // self.postMessage(x); // enable this if you want stdout to be sent as messages
    }));
  }

  if (ENVIRONMENT_IS_WORKER) {
    Module['load'] = importScripts;
  }

  if (typeof Module['setWindowTitle'] === 'undefined') {
    Module['setWindowTitle'] = function(title) { document.title = title };
  }
}
else {
  // Unreachable because SHELL is dependant on the others
  throw 'Unknown runtime environment. Where are we?';
}

function globalEval(x) {
  eval.call(null, x);
}
if (!Module['load'] && Module['read']) {
  Module['load'] = function load(f) {
    globalEval(Module['read'](f));
  };
}
if (!Module['print']) {
  Module['print'] = function(){};
}
if (!Module['printErr']) {
  Module['printErr'] = Module['print'];
}
if (!Module['arguments']) {
  Module['arguments'] = [];
}
if (!Module['thisProgram']) {
  Module['thisProgram'] = './this.program';
}

// *** Environment setup code ***

// Closure helpers
Module.print = Module['print'];
Module.printErr = Module['printErr'];

// Callbacks
Module['preRun'] = [];
Module['postRun'] = [];

// Merge back in the overrides
for (var key in moduleOverrides) {
  if (moduleOverrides.hasOwnProperty(key)) {
    Module[key] = moduleOverrides[key];
  }
}



// === Preamble library stuff ===

// Documentation for the public APIs defined in this file must be updated in: 
//    site/source/docs/api_reference/preamble.js.rst
// A prebuilt local version of the documentation is available at: 
//    site/build/text/docs/api_reference/preamble.js.txt
// You can also build docs locally as HTML or other formats in site/
// An online HTML version (which may be of a different version of Emscripten)
//    is up at http://kripken.github.io/emscripten-site/docs/api_reference/preamble.js.html

//========================================
// Runtime code shared with compiler
//========================================

var Runtime = {
  setTempRet0: function (value) {
    tempRet0 = value;
  },
  getTempRet0: function () {
    return tempRet0;
  },
  stackSave: function () {
    return STACKTOP;
  },
  stackRestore: function (stackTop) {
    STACKTOP = stackTop;
  },
  getNativeTypeSize: function (type) {
    switch (type) {
      case 'i1': case 'i8': return 1;
      case 'i16': return 2;
      case 'i32': return 4;
      case 'i64': return 8;
      case 'float': return 4;
      case 'double': return 8;
      default: {
        if (type[type.length-1] === '*') {
          return Runtime.QUANTUM_SIZE; // A pointer
        } else if (type[0] === 'i') {
          var bits = parseInt(type.substr(1));
          assert(bits % 8 === 0);
          return bits/8;
        } else {
          return 0;
        }
      }
    }
  },
  getNativeFieldSize: function (type) {
    return Math.max(Runtime.getNativeTypeSize(type), Runtime.QUANTUM_SIZE);
  },
  STACK_ALIGN: 16,
  prepVararg: function (ptr, type) {
    if (type === 'double' || type === 'i64') {
      // move so the load is aligned
      if (ptr & 7) {
        assert((ptr & 7) === 4);
        ptr += 4;
      }
    } else {
      assert((ptr & 3) === 0);
    }
    return ptr;
  },
  getAlignSize: function (type, size, vararg) {
    // we align i64s and doubles on 64-bit boundaries, unlike x86
    if (!vararg && (type == 'i64' || type == 'double')) return 8;
    if (!type) return Math.min(size, 8); // align structures internally to 64 bits
    return Math.min(size || (type ? Runtime.getNativeFieldSize(type) : 0), Runtime.QUANTUM_SIZE);
  },
  dynCall: function (sig, ptr, args) {
    if (args && args.length) {
      assert(args.length == sig.length-1);
      if (!args.splice) args = Array.prototype.slice.call(args);
      args.splice(0, 0, ptr);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].apply(null, args);
    } else {
      assert(sig.length == 1);
      assert(('dynCall_' + sig) in Module, 'bad function pointer type - no table for sig \'' + sig + '\'');
      return Module['dynCall_' + sig].call(null, ptr);
    }
  },
  functionPointers: [],
  addFunction: function (func) {
    for (var i = 0; i < Runtime.functionPointers.length; i++) {
      if (!Runtime.functionPointers[i]) {
        Runtime.functionPointers[i] = func;
        return 2*(1 + i);
      }
    }
    throw 'Finished up all reserved function pointers. Use a higher value for RESERVED_FUNCTION_POINTERS.';
  },
  removeFunction: function (index) {
    Runtime.functionPointers[(index-2)/2] = null;
  },
  warnOnce: function (text) {
    if (!Runtime.warnOnce.shown) Runtime.warnOnce.shown = {};
    if (!Runtime.warnOnce.shown[text]) {
      Runtime.warnOnce.shown[text] = 1;
      Module.printErr(text);
    }
  },
  funcWrappers: {},
  getFuncWrapper: function (func, sig) {
    assert(sig);
    if (!Runtime.funcWrappers[sig]) {
      Runtime.funcWrappers[sig] = {};
    }
    var sigCache = Runtime.funcWrappers[sig];
    if (!sigCache[func]) {
      sigCache[func] = function dynCall_wrapper() {
        return Runtime.dynCall(sig, func, arguments);
      };
    }
    return sigCache[func];
  },
  getCompilerSetting: function (name) {
    throw 'You must build with -s RETAIN_COMPILER_SETTINGS=1 for Runtime.getCompilerSetting or emscripten_get_compiler_setting to work';
  },
  stackAlloc: function (size) { var ret = STACKTOP;STACKTOP = (STACKTOP + size)|0;STACKTOP = (((STACKTOP)+15)&-16);(assert((((STACKTOP|0) < (STACK_MAX|0))|0))|0); return ret; },
  staticAlloc: function (size) { var ret = STATICTOP;STATICTOP = (STATICTOP + (assert(!staticSealed),size))|0;STATICTOP = (((STATICTOP)+15)&-16); return ret; },
  dynamicAlloc: function (size) { var ret = DYNAMICTOP;DYNAMICTOP = (DYNAMICTOP + (assert(DYNAMICTOP > 0),size))|0;DYNAMICTOP = (((DYNAMICTOP)+15)&-16); if (DYNAMICTOP >= TOTAL_MEMORY) { var success = enlargeMemory(); if (!success) { DYNAMICTOP = ret; return 0; } }; return ret; },
  alignMemory: function (size,quantum) { var ret = size = Math.ceil((size)/(quantum ? quantum : 16))*(quantum ? quantum : 16); return ret; },
  makeBigInt: function (low,high,unsigned) { var ret = (unsigned ? ((+((low>>>0)))+((+((high>>>0)))*4294967296.0)) : ((+((low>>>0)))+((+((high|0)))*4294967296.0))); return ret; },
  GLOBAL_BASE: 8,
  QUANTUM_SIZE: 4,
  __dummy__: 0
}


Module['Runtime'] = Runtime;



//========================================
// Runtime essentials
//========================================

var __THREW__ = 0; // Used in checking for thrown exceptions.

var ABORT = false; // whether we are quitting the application. no code should run after this. set in exit() and abort()
var EXITSTATUS = 0;

var undef = 0;
// tempInt is used for 32-bit signed values or smaller. tempBigInt is used
// for 32-bit unsigned values or more than 32 bits. TODO: audit all uses of tempInt
var tempValue, tempInt, tempBigInt, tempInt2, tempBigInt2, tempPair, tempBigIntI, tempBigIntR, tempBigIntS, tempBigIntP, tempBigIntD, tempDouble, tempFloat;
var tempI64, tempI64b;
var tempRet0, tempRet1, tempRet2, tempRet3, tempRet4, tempRet5, tempRet6, tempRet7, tempRet8, tempRet9;

function assert(condition, text) {
  if (!condition) {
    abort('Assertion failed: ' + text);
  }
}

var globalScope = this;

// Returns the C function with a specified identifier (for C++, you need to do manual name mangling)
function getCFunc(ident) {
  var func = Module['_' + ident]; // closure exported function
  if (!func) {
    try {
      func = eval('_' + ident); // explicit lookup
    } catch(e) {}
  }
  assert(func, 'Cannot call unknown function ' + ident + ' (perhaps LLVM optimizations or closure removed it?)');
  return func;
}

var cwrap, ccall;
(function(){
  var JSfuncs = {
    // Helpers for cwrap -- it can't refer to Runtime directly because it might
    // be renamed by closure, instead it calls JSfuncs['stackSave'].body to find
    // out what the minified function name is.
    'stackSave': function() {
      Runtime.stackSave()
    },
    'stackRestore': function() {
      Runtime.stackRestore()
    },
    // type conversion from js to c
    'arrayToC' : function(arr) {
      var ret = Runtime.stackAlloc(arr.length);
      writeArrayToMemory(arr, ret);
      return ret;
    },
    'stringToC' : function(str) {
      var ret = 0;
      if (str !== null && str !== undefined && str !== 0) { // null string
        // at most 4 bytes per UTF-8 code point, +1 for the trailing '\0'
        ret = Runtime.stackAlloc((str.length << 2) + 1);
        writeStringToMemory(str, ret);
      }
      return ret;
    }
  };
  // For fast lookup of conversion functions
  var toC = {'string' : JSfuncs['stringToC'], 'array' : JSfuncs['arrayToC']};

  // C calling interface. 
  ccall = function ccallFunc(ident, returnType, argTypes, args, opts) {
    var func = getCFunc(ident);
    var cArgs = [];
    var stack = 0;
    assert(returnType !== 'array', 'Return type should not be "array".');
    if (args) {
      for (var i = 0; i < args.length; i++) {
        var converter = toC[argTypes[i]];
        if (converter) {
          if (stack === 0) stack = Runtime.stackSave();
          cArgs[i] = converter(args[i]);
        } else {
          cArgs[i] = args[i];
        }
      }
    }
    var ret = func.apply(null, cArgs);
    if ((!opts || !opts.async) && typeof EmterpreterAsync === 'object') {
      assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling ccall');
    }
    if (opts && opts.async) assert(!returnType, 'async ccalls cannot return values');
    if (returnType === 'string') ret = Pointer_stringify(ret);
    if (stack !== 0) {
      if (opts && opts.async) {
        EmterpreterAsync.asyncFinalizers.push(function() {
          Runtime.stackRestore(stack);
        });
        return;
      }
      Runtime.stackRestore(stack);
    }
    return ret;
  }

  var sourceRegex = /^function\s*\(([^)]*)\)\s*{\s*([^*]*?)[\s;]*(?:return\s*(.*?)[;\s]*)?}$/;
  function parseJSFunc(jsfunc) {
    // Match the body and the return value of a javascript function source
    var parsed = jsfunc.toString().match(sourceRegex).slice(1);
    return {arguments : parsed[0], body : parsed[1], returnValue: parsed[2]}
  }
  var JSsource = {};
  for (var fun in JSfuncs) {
    if (JSfuncs.hasOwnProperty(fun)) {
      // Elements of toCsource are arrays of three items:
      // the code, and the return value
      JSsource[fun] = parseJSFunc(JSfuncs[fun]);
    }
  }

  
  cwrap = function cwrap(ident, returnType, argTypes) {
    argTypes = argTypes || [];
    var cfunc = getCFunc(ident);
    // When the function takes numbers and returns a number, we can just return
    // the original function
    var numericArgs = argTypes.every(function(type){ return type === 'number'});
    var numericRet = (returnType !== 'string');
    if ( numericRet && numericArgs) {
      return cfunc;
    }
    // Creation of the arguments list (["$1","$2",...,"$nargs"])
    var argNames = argTypes.map(function(x,i){return '$'+i});
    var funcstr = "(function(" + argNames.join(',') + ") {";
    var nargs = argTypes.length;
    if (!numericArgs) {
      // Generate the code needed to convert the arguments from javascript
      // values to pointers
      funcstr += 'var stack = ' + JSsource['stackSave'].body + ';';
      for (var i = 0; i < nargs; i++) {
        var arg = argNames[i], type = argTypes[i];
        if (type === 'number') continue;
        var convertCode = JSsource[type + 'ToC']; // [code, return]
        funcstr += 'var ' + convertCode.arguments + ' = ' + arg + ';';
        funcstr += convertCode.body + ';';
        funcstr += arg + '=' + convertCode.returnValue + ';';
      }
    }

    // When the code is compressed, the name of cfunc is not literally 'cfunc' anymore
    var cfuncname = parseJSFunc(function(){return cfunc}).returnValue;
    // Call the function
    funcstr += 'var ret = ' + cfuncname + '(' + argNames.join(',') + ');';
    if (!numericRet) { // Return type can only by 'string' or 'number'
      // Convert the result to a string
      var strgfy = parseJSFunc(function(){return Pointer_stringify}).returnValue;
      funcstr += 'ret = ' + strgfy + '(ret);';
    }
    funcstr += "if (typeof EmterpreterAsync === 'object') { assert(!EmterpreterAsync.state, 'cannot start async op with normal JS calling cwrap') }";
    if (!numericArgs) {
      // If we had a stack, restore it
      funcstr += JSsource['stackRestore'].body.replace('()', '(stack)') + ';';
    }
    funcstr += 'return ret})';
    return eval(funcstr);
  };
})();
Module["cwrap"] = cwrap;
Module["ccall"] = ccall;


function setValue(ptr, value, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': HEAP8[((ptr)>>0)]=value; break;
      case 'i8': HEAP8[((ptr)>>0)]=value; break;
      case 'i16': HEAP16[((ptr)>>1)]=value; break;
      case 'i32': HEAP32[((ptr)>>2)]=value; break;
      case 'i64': (tempI64 = [value>>>0,(tempDouble=value,(+(Math_abs(tempDouble))) >= 1.0 ? (tempDouble > 0.0 ? ((Math_min((+(Math_floor((tempDouble)/4294967296.0))), 4294967295.0))|0)>>>0 : (~~((+(Math_ceil((tempDouble - +(((~~(tempDouble)))>>>0))/4294967296.0)))))>>>0) : 0)],HEAP32[((ptr)>>2)]=tempI64[0],HEAP32[(((ptr)+(4))>>2)]=tempI64[1]); break;
      case 'float': HEAPF32[((ptr)>>2)]=value; break;
      case 'double': HEAPF64[((ptr)>>3)]=value; break;
      default: abort('invalid type for setValue: ' + type);
    }
}
Module['setValue'] = setValue;


function getValue(ptr, type, noSafe) {
  type = type || 'i8';
  if (type.charAt(type.length-1) === '*') type = 'i32'; // pointers are 32-bit
    switch(type) {
      case 'i1': return HEAP8[((ptr)>>0)];
      case 'i8': return HEAP8[((ptr)>>0)];
      case 'i16': return HEAP16[((ptr)>>1)];
      case 'i32': return HEAP32[((ptr)>>2)];
      case 'i64': return HEAP32[((ptr)>>2)];
      case 'float': return HEAPF32[((ptr)>>2)];
      case 'double': return HEAPF64[((ptr)>>3)];
      default: abort('invalid type for setValue: ' + type);
    }
  return null;
}
Module['getValue'] = getValue;

var ALLOC_NORMAL = 0; // Tries to use _malloc()
var ALLOC_STACK = 1; // Lives for the duration of the current function call
var ALLOC_STATIC = 2; // Cannot be freed
var ALLOC_DYNAMIC = 3; // Cannot be freed except through sbrk
var ALLOC_NONE = 4; // Do not allocate
Module['ALLOC_NORMAL'] = ALLOC_NORMAL;
Module['ALLOC_STACK'] = ALLOC_STACK;
Module['ALLOC_STATIC'] = ALLOC_STATIC;
Module['ALLOC_DYNAMIC'] = ALLOC_DYNAMIC;
Module['ALLOC_NONE'] = ALLOC_NONE;

// allocate(): This is for internal use. You can use it yourself as well, but the interface
//             is a little tricky (see docs right below). The reason is that it is optimized
//             for multiple syntaxes to save space in generated code. So you should
//             normally not use allocate(), and instead allocate memory using _malloc(),
//             initialize it with setValue(), and so forth.
// @slab: An array of data, or a number. If a number, then the size of the block to allocate,
//        in *bytes* (note that this is sometimes confusing: the next parameter does not
//        affect this!)
// @types: Either an array of types, one for each byte (or 0 if no type at that position),
//         or a single type which is used for the entire block. This only matters if there
//         is initial data - if @slab is a number, then this does not matter at all and is
//         ignored.
// @allocator: How to allocate memory, see ALLOC_*
function allocate(slab, types, allocator, ptr) {
  var zeroinit, size;
  if (typeof slab === 'number') {
    zeroinit = true;
    size = slab;
  } else {
    zeroinit = false;
    size = slab.length;
  }

  var singleType = typeof types === 'string' ? types : null;

  var ret;
  if (allocator == ALLOC_NONE) {
    ret = ptr;
  } else {
    ret = [_malloc, Runtime.stackAlloc, Runtime.staticAlloc, Runtime.dynamicAlloc][allocator === undefined ? ALLOC_STATIC : allocator](Math.max(size, singleType ? 1 : types.length));
  }

  if (zeroinit) {
    var ptr = ret, stop;
    assert((ret & 3) == 0);
    stop = ret + (size & ~3);
    for (; ptr < stop; ptr += 4) {
      HEAP32[((ptr)>>2)]=0;
    }
    stop = ret + size;
    while (ptr < stop) {
      HEAP8[((ptr++)>>0)]=0;
    }
    return ret;
  }

  if (singleType === 'i8') {
    if (slab.subarray || slab.slice) {
      HEAPU8.set(slab, ret);
    } else {
      HEAPU8.set(new Uint8Array(slab), ret);
    }
    return ret;
  }

  var i = 0, type, typeSize, previousType;
  while (i < size) {
    var curr = slab[i];

    if (typeof curr === 'function') {
      curr = Runtime.getFunctionIndex(curr);
    }

    type = singleType || types[i];
    if (type === 0) {
      i++;
      continue;
    }
    assert(type, 'Must know what type to store in allocate!');

    if (type == 'i64') type = 'i32'; // special case: we have one i32 here, and one i32 later

    setValue(ret+i, curr, type);

    // no need to look up size unless type changes, so cache it
    if (previousType !== type) {
      typeSize = Runtime.getNativeTypeSize(type);
      previousType = type;
    }
    i += typeSize;
  }

  return ret;
}
Module['allocate'] = allocate;

// Allocate memory during any stage of startup - static memory early on, dynamic memory later, malloc when ready
function getMemory(size) {
  if (!staticSealed) return Runtime.staticAlloc(size);
  if ((typeof _sbrk !== 'undefined' && !_sbrk.called) || !runtimeInitialized) return Runtime.dynamicAlloc(size);
  return _malloc(size);
}
Module['getMemory'] = getMemory;

function Pointer_stringify(ptr, /* optional */ length) {
  if (length === 0 || !ptr) return '';
  // TODO: use TextDecoder
  // Find the length, and check for UTF while doing so
  var hasUtf = 0;
  var t;
  var i = 0;
  while (1) {
    assert(ptr + i < TOTAL_MEMORY);
    t = HEAPU8[(((ptr)+(i))>>0)];
    hasUtf |= t;
    if (t == 0 && !length) break;
    i++;
    if (length && i == length) break;
  }
  if (!length) length = i;

  var ret = '';

  if (hasUtf < 128) {
    var MAX_CHUNK = 1024; // split up into chunks, because .apply on a huge string can overflow the stack
    var curr;
    while (length > 0) {
      curr = String.fromCharCode.apply(String, HEAPU8.subarray(ptr, ptr + Math.min(length, MAX_CHUNK)));
      ret = ret ? ret + curr : curr;
      ptr += MAX_CHUNK;
      length -= MAX_CHUNK;
    }
    return ret;
  }
  return Module['UTF8ToString'](ptr);
}
Module['Pointer_stringify'] = Pointer_stringify;

// Given a pointer 'ptr' to a null-terminated ASCII-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function AsciiToString(ptr) {
  var str = '';
  while (1) {
    var ch = HEAP8[((ptr++)>>0)];
    if (!ch) return str;
    str += String.fromCharCode(ch);
  }
}
Module['AsciiToString'] = AsciiToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in ASCII form. The copy will require at most str.length+1 bytes of space in the HEAP.

function stringToAscii(str, outPtr) {
  return writeAsciiToMemory(str, outPtr, false);
}
Module['stringToAscii'] = stringToAscii;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the given array that contains uint8 values, returns
// a copy of that string as a Javascript String object.

function UTF8ArrayToString(u8Array, idx) {
  var u0, u1, u2, u3, u4, u5;

  var str = '';
  while (1) {
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    u0 = u8Array[idx++];
    if (!u0) return str;
    if (!(u0 & 0x80)) { str += String.fromCharCode(u0); continue; }
    u1 = u8Array[idx++] & 63;
    if ((u0 & 0xE0) == 0xC0) { str += String.fromCharCode(((u0 & 31) << 6) | u1); continue; }
    u2 = u8Array[idx++] & 63;
    if ((u0 & 0xF0) == 0xE0) {
      u0 = ((u0 & 15) << 12) | (u1 << 6) | u2;
    } else {
      u3 = u8Array[idx++] & 63;
      if ((u0 & 0xF8) == 0xF0) {
        u0 = ((u0 & 7) << 18) | (u1 << 12) | (u2 << 6) | u3;
      } else {
        u4 = u8Array[idx++] & 63;
        if ((u0 & 0xFC) == 0xF8) {
          u0 = ((u0 & 3) << 24) | (u1 << 18) | (u2 << 12) | (u3 << 6) | u4;
        } else {
          u5 = u8Array[idx++] & 63;
          u0 = ((u0 & 1) << 30) | (u1 << 24) | (u2 << 18) | (u3 << 12) | (u4 << 6) | u5;
        }
      }
    }
    if (u0 < 0x10000) {
      str += String.fromCharCode(u0);
    } else {
      var ch = u0 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    }
  }
}
Module['UTF8ArrayToString'] = UTF8ArrayToString;

// Given a pointer 'ptr' to a null-terminated UTF8-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF8ToString(ptr) {
  return UTF8ArrayToString(HEAPU8, ptr);
}
Module['UTF8ToString'] = UTF8ToString;

// Copies the given Javascript String object 'str' to the given byte array at address 'outIdx',
// encoded in UTF8 form and null-terminated. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outU8Array: the array to copy to. Each index in this array is assumed to be one 8-byte element.
//   outIdx: The starting offset in the array to begin the copying.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=1, only the null terminator will be written and nothing else.
//                    maxBytesToWrite=0 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8Array(str, outU8Array, outIdx, maxBytesToWrite) {
  if (!(maxBytesToWrite > 0)) // Parameter maxBytesToWrite is not optional. Negative values, 0, null, undefined and false each don't write out any bytes.
    return 0;

  var startIdx = outIdx;
  var endIdx = outIdx + maxBytesToWrite - 1; // -1 for string null terminator.
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    // For UTF8 byte structure, see http://en.wikipedia.org/wiki/UTF-8#Description and https://www.ietf.org/rfc/rfc2279.txt and https://tools.ietf.org/html/rfc3629
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      if (outIdx >= endIdx) break;
      outU8Array[outIdx++] = u;
    } else if (u <= 0x7FF) {
      if (outIdx + 1 >= endIdx) break;
      outU8Array[outIdx++] = 0xC0 | (u >> 6);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0xFFFF) {
      if (outIdx + 2 >= endIdx) break;
      outU8Array[outIdx++] = 0xE0 | (u >> 12);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x1FFFFF) {
      if (outIdx + 3 >= endIdx) break;
      outU8Array[outIdx++] = 0xF0 | (u >> 18);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else if (u <= 0x3FFFFFF) {
      if (outIdx + 4 >= endIdx) break;
      outU8Array[outIdx++] = 0xF8 | (u >> 24);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    } else {
      if (outIdx + 5 >= endIdx) break;
      outU8Array[outIdx++] = 0xFC | (u >> 30);
      outU8Array[outIdx++] = 0x80 | ((u >> 24) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 18) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 12) & 63);
      outU8Array[outIdx++] = 0x80 | ((u >> 6) & 63);
      outU8Array[outIdx++] = 0x80 | (u & 63);
    }
  }
  // Null-terminate the pointer to the buffer.
  outU8Array[outIdx] = 0;
  return outIdx - startIdx;
}
Module['stringToUTF8Array'] = stringToUTF8Array;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF8 form. The copy will require at most str.length*4+1 bytes of space in the HEAP.
// Use the function lengthBytesUTF8() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF8(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF8(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  return stringToUTF8Array(str, HEAPU8, outPtr, maxBytesToWrite);
}
Module['stringToUTF8'] = stringToUTF8;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF8 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF8(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! So decode UTF16->UTF32->UTF8.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var u = str.charCodeAt(i); // possibly a lead surrogate
    if (u >= 0xD800 && u <= 0xDFFF) u = 0x10000 + ((u & 0x3FF) << 10) | (str.charCodeAt(++i) & 0x3FF);
    if (u <= 0x7F) {
      ++len;
    } else if (u <= 0x7FF) {
      len += 2;
    } else if (u <= 0xFFFF) {
      len += 3;
    } else if (u <= 0x1FFFFF) {
      len += 4;
    } else if (u <= 0x3FFFFFF) {
      len += 5;
    } else {
      len += 6;
    }
  }
  return len;
}
Module['lengthBytesUTF8'] = lengthBytesUTF8;

// Given a pointer 'ptr' to a null-terminated UTF16LE-encoded string in the emscripten HEAP, returns
// a copy of that string as a Javascript String object.

function UTF16ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var codeUnit = HEAP16[(((ptr)+(i*2))>>1)];
    if (codeUnit == 0)
      return str;
    ++i;
    // fromCharCode constructs a character from a UTF-16 code unit, so we can pass the UTF16 string right through.
    str += String.fromCharCode(codeUnit);
  }
}
Module['UTF16ToString'] = UTF16ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF16 form. The copy will require at most str.length*4+2 bytes of space in the HEAP.
// Use the function lengthBytesUTF16() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=2, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<2 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF16(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF16(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 2) return 0;
  maxBytesToWrite -= 2; // Null terminator.
  var startPtr = outPtr;
  var numCharsToWrite = (maxBytesToWrite < str.length*2) ? (maxBytesToWrite / 2) : str.length;
  for (var i = 0; i < numCharsToWrite; ++i) {
    // charCodeAt returns a UTF-16 encoded code unit, so it can be directly written to the HEAP.
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    HEAP16[((outPtr)>>1)]=codeUnit;
    outPtr += 2;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP16[((outPtr)>>1)]=0;
  return outPtr - startPtr;
}
Module['stringToUTF16'] = stringToUTF16;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF16(str) {
  return str.length*2;
}
Module['lengthBytesUTF16'] = lengthBytesUTF16;

function UTF32ToString(ptr) {
  var i = 0;

  var str = '';
  while (1) {
    var utf32 = HEAP32[(((ptr)+(i*4))>>2)];
    if (utf32 == 0)
      return str;
    ++i;
    // Gotcha: fromCharCode constructs a character from a UTF-16 encoded code (pair), not from a Unicode code point! So encode the code point to UTF-16 for constructing.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    if (utf32 >= 0x10000) {
      var ch = utf32 - 0x10000;
      str += String.fromCharCode(0xD800 | (ch >> 10), 0xDC00 | (ch & 0x3FF));
    } else {
      str += String.fromCharCode(utf32);
    }
  }
}
Module['UTF32ToString'] = UTF32ToString;

// Copies the given Javascript String object 'str' to the emscripten HEAP at address 'outPtr',
// null-terminated and encoded in UTF32 form. The copy will require at most str.length*4+4 bytes of space in the HEAP.
// Use the function lengthBytesUTF32() to compute the exact number of bytes (excluding null terminator) that this function will write.
// Parameters:
//   str: the Javascript string to copy.
//   outPtr: Byte address in Emscripten HEAP where to write the string to.
//   maxBytesToWrite: The maximum number of bytes this function can write to the array. This count should include the null 
//                    terminator, i.e. if maxBytesToWrite=4, only the null terminator will be written and nothing else.
//                    maxBytesToWrite<4 does not write any bytes to the output, not even the null terminator.
// Returns the number of bytes written, EXCLUDING the null terminator.

function stringToUTF32(str, outPtr, maxBytesToWrite) {
  assert(typeof maxBytesToWrite == 'number', 'stringToUTF32(str, outPtr, maxBytesToWrite) is missing the third parameter that specifies the length of the output buffer!');
  // Backwards compatibility: if max bytes is not specified, assume unsafe unbounded write is allowed.
  if (maxBytesToWrite === undefined) {
    maxBytesToWrite = 0x7FFFFFFF;
  }
  if (maxBytesToWrite < 4) return 0;
  var startPtr = outPtr;
  var endPtr = startPtr + maxBytesToWrite - 4;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i); // possibly a lead surrogate
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) {
      var trailSurrogate = str.charCodeAt(++i);
      codeUnit = 0x10000 + ((codeUnit & 0x3FF) << 10) | (trailSurrogate & 0x3FF);
    }
    HEAP32[((outPtr)>>2)]=codeUnit;
    outPtr += 4;
    if (outPtr + 4 > endPtr) break;
  }
  // Null-terminate the pointer to the HEAP.
  HEAP32[((outPtr)>>2)]=0;
  return outPtr - startPtr;
}
Module['stringToUTF32'] = stringToUTF32;

// Returns the number of bytes the given Javascript string takes if encoded as a UTF16 byte array, EXCLUDING the null terminator byte.

function lengthBytesUTF32(str) {
  var len = 0;
  for (var i = 0; i < str.length; ++i) {
    // Gotcha: charCodeAt returns a 16-bit word that is a UTF-16 encoded code unit, not a Unicode code point of the character! We must decode the string to UTF-32 to the heap.
    // See http://unicode.org/faq/utf_bom.html#utf16-3
    var codeUnit = str.charCodeAt(i);
    if (codeUnit >= 0xD800 && codeUnit <= 0xDFFF) ++i; // possibly a lead surrogate, so skip over the tail surrogate.
    len += 4;
  }

  return len;
}
Module['lengthBytesUTF32'] = lengthBytesUTF32;

function demangle(func) {
  var hasLibcxxabi = !!Module['___cxa_demangle'];
  if (hasLibcxxabi) {
    try {
      var buf = _malloc(func.length);
      writeStringToMemory(func.substr(1), buf);
      var status = _malloc(4);
      var ret = Module['___cxa_demangle'](buf, 0, 0, status);
      if (getValue(status, 'i32') === 0 && ret) {
        return Pointer_stringify(ret);
      }
      // otherwise, libcxxabi failed, we can try ours which may return a partial result
    } catch(e) {
      // failure when using libcxxabi, we can try ours which may return a partial result
    } finally {
      if (buf) _free(buf);
      if (status) _free(status);
      if (ret) _free(ret);
    }
  }
  var i = 3;
  // params, etc.
  var basicTypes = {
    'v': 'void',
    'b': 'bool',
    'c': 'char',
    's': 'short',
    'i': 'int',
    'l': 'long',
    'f': 'float',
    'd': 'double',
    'w': 'wchar_t',
    'a': 'signed char',
    'h': 'unsigned char',
    't': 'unsigned short',
    'j': 'unsigned int',
    'm': 'unsigned long',
    'x': 'long long',
    'y': 'unsigned long long',
    'z': '...'
  };
  var subs = [];
  var first = true;
  function dump(x) {
    //return;
    if (x) Module.print(x);
    Module.print(func);
    var pre = '';
    for (var a = 0; a < i; a++) pre += ' ';
    Module.print (pre + '^');
  }
  function parseNested() {
    i++;
    if (func[i] === 'K') i++; // ignore const
    var parts = [];
    while (func[i] !== 'E') {
      if (func[i] === 'S') { // substitution
        i++;
        var next = func.indexOf('_', i);
        var num = func.substring(i, next) || 0;
        parts.push(subs[num] || '?');
        i = next+1;
        continue;
      }
      if (func[i] === 'C') { // constructor
        parts.push(parts[parts.length-1]);
        i += 2;
        continue;
      }
      var size = parseInt(func.substr(i));
      var pre = size.toString().length;
      if (!size || !pre) { i--; break; } // counter i++ below us
      var curr = func.substr(i + pre, size);
      parts.push(curr);
      subs.push(curr);
      i += pre + size;
    }
    i++; // skip E
    return parts;
  }
  function parse(rawList, limit, allowVoid) { // main parser
    limit = limit || Infinity;
    var ret = '', list = [];
    function flushList() {
      return '(' + list.join(', ') + ')';
    }
    var name;
    if (func[i] === 'N') {
      // namespaced N-E
      name = parseNested().join('::');
      limit--;
      if (limit === 0) return rawList ? [name] : name;
    } else {
      // not namespaced
      if (func[i] === 'K' || (first && func[i] === 'L')) i++; // ignore const and first 'L'
      var size = parseInt(func.substr(i));
      if (size) {
        var pre = size.toString().length;
        name = func.substr(i + pre, size);
        i += pre + size;
      }
    }
    first = false;
    if (func[i] === 'I') {
      i++;
      var iList = parse(true);
      var iRet = parse(true, 1, true);
      ret += iRet[0] + ' ' + name + '<' + iList.join(', ') + '>';
    } else {
      ret = name;
    }
    paramLoop: while (i < func.length && limit-- > 0) {
      //dump('paramLoop');
      var c = func[i++];
      if (c in basicTypes) {
        list.push(basicTypes[c]);
      } else {
        switch (c) {
          case 'P': list.push(parse(true, 1, true)[0] + '*'); break; // pointer
          case 'R': list.push(parse(true, 1, true)[0] + '&'); break; // reference
          case 'L': { // literal
            i++; // skip basic type
            var end = func.indexOf('E', i);
            var size = end - i;
            list.push(func.substr(i, size));
            i += size + 2; // size + 'EE'
            break;
          }
          case 'A': { // array
            var size = parseInt(func.substr(i));
            i += size.toString().length;
            if (func[i] !== '_') throw '?';
            i++; // skip _
            list.push(parse(true, 1, true)[0] + ' [' + size + ']');
            break;
          }
          case 'E': break paramLoop;
          default: ret += '?' + c; break paramLoop;
        }
      }
    }
    if (!allowVoid && list.length === 1 && list[0] === 'void') list = []; // avoid (void)
    if (rawList) {
      if (ret) {
        list.push(ret + '?');
      }
      return list;
    } else {
      return ret + flushList();
    }
  }
  var parsed = func;
  try {
    // Special-case the entry point, since its name differs from other name mangling.
    if (func == 'Object._main' || func == '_main') {
      return 'main()';
    }
    if (typeof func === 'number') func = Pointer_stringify(func);
    if (func[0] !== '_') return func;
    if (func[1] !== '_') return func; // C function
    if (func[2] !== 'Z') return func;
    switch (func[3]) {
      case 'n': return 'operator new()';
      case 'd': return 'operator delete()';
    }
    parsed = parse();
  } catch(e) {
    parsed += '?';
  }
  if (parsed.indexOf('?') >= 0 && !hasLibcxxabi) {
    Runtime.warnOnce('warning: a problem occurred in builtin C++ name demangling; build with  -s DEMANGLE_SUPPORT=1  to link in libcxxabi demangling');
  }
  return parsed;
}

function demangleAll(text) {
  return text.replace(/__Z[\w\d_]+/g, function(x) { var y = demangle(x); return x === y ? x : (x + ' [' + y + ']') });
}

function jsStackTrace() {
  var err = new Error();
  if (!err.stack) {
    // IE10+ special cases: It does have callstack info, but it is only populated if an Error object is thrown,
    // so try that as a special-case.
    try {
      throw new Error(0);
    } catch(e) {
      err = e;
    }
    if (!err.stack) {
      return '(no stack trace available)';
    }
  }
  return err.stack.toString();
}

function stackTrace() {
  return demangleAll(jsStackTrace());
}
Module['stackTrace'] = stackTrace;

// Memory management

var PAGE_SIZE = 4096;

function alignMemoryPage(x) {
  if (x % 4096 > 0) {
    x += (4096 - (x % 4096));
  }
  return x;
}

var HEAP;
var HEAP8, HEAPU8, HEAP16, HEAPU16, HEAP32, HEAPU32, HEAPF32, HEAPF64;

var STATIC_BASE = 0, STATICTOP = 0, staticSealed = false; // static area
var STACK_BASE = 0, STACKTOP = 0, STACK_MAX = 0; // stack area
var DYNAMIC_BASE = 0, DYNAMICTOP = 0; // dynamic area handled by sbrk


function enlargeMemory() {
  abort('Cannot enlarge memory arrays. Either (1) compile with -s TOTAL_MEMORY=X with X higher than the current value ' + TOTAL_MEMORY + ', (2) compile with ALLOW_MEMORY_GROWTH which adjusts the size at runtime but prevents some optimizations, or (3) set Module.TOTAL_MEMORY before the program runs.');
}


var TOTAL_STACK = Module['TOTAL_STACK'] || 5242880;
var TOTAL_MEMORY = Module['TOTAL_MEMORY'] || 16777216;

var totalMemory = 64*1024;
while (totalMemory < TOTAL_MEMORY || totalMemory < 2*TOTAL_STACK) {
  if (totalMemory < 16*1024*1024) {
    totalMemory *= 2;
  } else {
    totalMemory += 16*1024*1024
  }
}
if (totalMemory !== TOTAL_MEMORY) {
  Module.printErr('increasing TOTAL_MEMORY to ' + totalMemory + ' to be compliant with the asm.js spec (and given that TOTAL_STACK=' + TOTAL_STACK + ')');
  TOTAL_MEMORY = totalMemory;
}

// Initialize the runtime's memory
// check for full engine support (use string 'subarray' to avoid closure compiler confusion)
assert(typeof Int32Array !== 'undefined' && typeof Float64Array !== 'undefined' && !!(new Int32Array(1)['subarray']) && !!(new Int32Array(1)['set']),
       'JS engine does not provide full typed array support');

var buffer;
buffer = new ArrayBuffer(TOTAL_MEMORY);
HEAP8 = new Int8Array(buffer);
HEAP16 = new Int16Array(buffer);
HEAP32 = new Int32Array(buffer);
HEAPU8 = new Uint8Array(buffer);
HEAPU16 = new Uint16Array(buffer);
HEAPU32 = new Uint32Array(buffer);
HEAPF32 = new Float32Array(buffer);
HEAPF64 = new Float64Array(buffer);

// Endianness check (note: assumes compiler arch was little-endian)
HEAP32[0] = 255;
assert(HEAPU8[0] === 255 && HEAPU8[3] === 0, 'Typed arrays 2 must be run on a little-endian system');

Module['HEAP'] = HEAP;
Module['buffer'] = buffer;
Module['HEAP8'] = HEAP8;
Module['HEAP16'] = HEAP16;
Module['HEAP32'] = HEAP32;
Module['HEAPU8'] = HEAPU8;
Module['HEAPU16'] = HEAPU16;
Module['HEAPU32'] = HEAPU32;
Module['HEAPF32'] = HEAPF32;
Module['HEAPF64'] = HEAPF64;

function callRuntimeCallbacks(callbacks) {
  while(callbacks.length > 0) {
    var callback = callbacks.shift();
    if (typeof callback == 'function') {
      callback();
      continue;
    }
    var func = callback.func;
    if (typeof func === 'number') {
      if (callback.arg === undefined) {
        Runtime.dynCall('v', func);
      } else {
        Runtime.dynCall('vi', func, [callback.arg]);
      }
    } else {
      func(callback.arg === undefined ? null : callback.arg);
    }
  }
}

var __ATPRERUN__  = []; // functions called before the runtime is initialized
var __ATINIT__    = []; // functions called during startup
var __ATMAIN__    = []; // functions called when main() is to be run
var __ATEXIT__    = []; // functions called during shutdown
var __ATPOSTRUN__ = []; // functions called after the runtime has exited

var runtimeInitialized = false;
var runtimeExited = false;


function preRun() {
  // compatibility - merge in anything from Module['preRun'] at this time
  if (Module['preRun']) {
    if (typeof Module['preRun'] == 'function') Module['preRun'] = [Module['preRun']];
    while (Module['preRun'].length) {
      addOnPreRun(Module['preRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPRERUN__);
}

function ensureInitRuntime() {
  if (runtimeInitialized) return;
  runtimeInitialized = true;
  callRuntimeCallbacks(__ATINIT__);
}

function preMain() {
  callRuntimeCallbacks(__ATMAIN__);
}

function exitRuntime() {
  callRuntimeCallbacks(__ATEXIT__);
  runtimeExited = true;
}

function postRun() {
  // compatibility - merge in anything from Module['postRun'] at this time
  if (Module['postRun']) {
    if (typeof Module['postRun'] == 'function') Module['postRun'] = [Module['postRun']];
    while (Module['postRun'].length) {
      addOnPostRun(Module['postRun'].shift());
    }
  }
  callRuntimeCallbacks(__ATPOSTRUN__);
}

function addOnPreRun(cb) {
  __ATPRERUN__.unshift(cb);
}
Module['addOnPreRun'] = Module.addOnPreRun = addOnPreRun;

function addOnInit(cb) {
  __ATINIT__.unshift(cb);
}
Module['addOnInit'] = Module.addOnInit = addOnInit;

function addOnPreMain(cb) {
  __ATMAIN__.unshift(cb);
}
Module['addOnPreMain'] = Module.addOnPreMain = addOnPreMain;

function addOnExit(cb) {
  __ATEXIT__.unshift(cb);
}
Module['addOnExit'] = Module.addOnExit = addOnExit;

function addOnPostRun(cb) {
  __ATPOSTRUN__.unshift(cb);
}
Module['addOnPostRun'] = Module.addOnPostRun = addOnPostRun;

// Tools


function intArrayFromString(stringy, dontAddNull, length /* optional */) {
  var len = length > 0 ? length : lengthBytesUTF8(stringy)+1;
  var u8array = new Array(len);
  var numBytesWritten = stringToUTF8Array(stringy, u8array, 0, u8array.length);
  if (dontAddNull) u8array.length = numBytesWritten;
  return u8array;
}
Module['intArrayFromString'] = intArrayFromString;

function intArrayToString(array) {
  var ret = [];
  for (var i = 0; i < array.length; i++) {
    var chr = array[i];
    if (chr > 0xFF) {
        assert(false, 'Character code ' + chr + ' (' + String.fromCharCode(chr) + ')  at offset ' + i + ' not in 0x00-0xFF.');
      chr &= 0xFF;
    }
    ret.push(String.fromCharCode(chr));
  }
  return ret.join('');
}
Module['intArrayToString'] = intArrayToString;

function writeStringToMemory(string, buffer, dontAddNull) {
  var array = intArrayFromString(string, dontAddNull);
  var i = 0;
  while (i < array.length) {
    var chr = array[i];
    HEAP8[(((buffer)+(i))>>0)]=chr;
    i = i + 1;
  }
}
Module['writeStringToMemory'] = writeStringToMemory;

function writeArrayToMemory(array, buffer) {
  for (var i = 0; i < array.length; i++) {
    HEAP8[((buffer++)>>0)]=array[i];
  }
}
Module['writeArrayToMemory'] = writeArrayToMemory;

function writeAsciiToMemory(str, buffer, dontAddNull) {
  for (var i = 0; i < str.length; ++i) {
    assert(str.charCodeAt(i) === str.charCodeAt(i)&0xff);
    HEAP8[((buffer++)>>0)]=str.charCodeAt(i);
  }
  // Null-terminate the pointer to the HEAP.
  if (!dontAddNull) HEAP8[((buffer)>>0)]=0;
}
Module['writeAsciiToMemory'] = writeAsciiToMemory;

function unSign(value, bits, ignore) {
  if (value >= 0) {
    return value;
  }
  return bits <= 32 ? 2*Math.abs(1 << (bits-1)) + value // Need some trickery, since if bits == 32, we are right at the limit of the bits JS uses in bitshifts
                    : Math.pow(2, bits)         + value;
}
function reSign(value, bits, ignore) {
  if (value <= 0) {
    return value;
  }
  var half = bits <= 32 ? Math.abs(1 << (bits-1)) // abs is needed if bits == 32
                        : Math.pow(2, bits-1);
  if (value >= half && (bits <= 32 || value > half)) { // for huge values, we can hit the precision limit and always get true here. so don't do that
                                                       // but, in general there is no perfect solution here. With 64-bit ints, we get rounding and errors
                                                       // TODO: In i64 mode 1, resign the two parts separately and safely
    value = -2*half + value; // Cannot bitshift half, as it may be at the limit of the bits JS uses in bitshifts
  }
  return value;
}


// check for imul support, and also for correctness ( https://bugs.webkit.org/show_bug.cgi?id=126345 )
if (!Math['imul'] || Math['imul'](0xffffffff, 5) !== -5) Math['imul'] = function imul(a, b) {
  var ah  = a >>> 16;
  var al = a & 0xffff;
  var bh  = b >>> 16;
  var bl = b & 0xffff;
  return (al*bl + ((ah*bl + al*bh) << 16))|0;
};
Math.imul = Math['imul'];


if (!Math['clz32']) Math['clz32'] = function(x) {
  x = x >>> 0;
  for (var i = 0; i < 32; i++) {
    if (x & (1 << (31 - i))) return i;
  }
  return 32;
};
Math.clz32 = Math['clz32']

var Math_abs = Math.abs;
var Math_cos = Math.cos;
var Math_sin = Math.sin;
var Math_tan = Math.tan;
var Math_acos = Math.acos;
var Math_asin = Math.asin;
var Math_atan = Math.atan;
var Math_atan2 = Math.atan2;
var Math_exp = Math.exp;
var Math_log = Math.log;
var Math_sqrt = Math.sqrt;
var Math_ceil = Math.ceil;
var Math_floor = Math.floor;
var Math_pow = Math.pow;
var Math_imul = Math.imul;
var Math_fround = Math.fround;
var Math_min = Math.min;
var Math_clz32 = Math.clz32;

// A counter of dependencies for calling run(). If we need to
// do asynchronous work before running, increment this and
// decrement it. Incrementing must happen in a place like
// PRE_RUN_ADDITIONS (used by emcc to add file preloading).
// Note that you can add dependencies in preRun, even though
// it happens right before run - run will be postponed until
// the dependencies are met.
var runDependencies = 0;
var runDependencyWatcher = null;
var dependenciesFulfilled = null; // overridden to take different actions when all run dependencies are fulfilled
var runDependencyTracking = {};

function getUniqueRunDependency(id) {
  var orig = id;
  while (1) {
    if (!runDependencyTracking[id]) return id;
    id = orig + Math.random();
  }
  return id;
}

function addRunDependency(id) {
  runDependencies++;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(!runDependencyTracking[id]);
    runDependencyTracking[id] = 1;
    if (runDependencyWatcher === null && typeof setInterval !== 'undefined') {
      // Check for missing dependencies every few seconds
      runDependencyWatcher = setInterval(function() {
        if (ABORT) {
          clearInterval(runDependencyWatcher);
          runDependencyWatcher = null;
          return;
        }
        var shown = false;
        for (var dep in runDependencyTracking) {
          if (!shown) {
            shown = true;
            Module.printErr('still waiting on run dependencies:');
          }
          Module.printErr('dependency: ' + dep);
        }
        if (shown) {
          Module.printErr('(end of list)');
        }
      }, 10000);
    }
  } else {
    Module.printErr('warning: run dependency added without ID');
  }
}
Module['addRunDependency'] = addRunDependency;
function removeRunDependency(id) {
  runDependencies--;
  if (Module['monitorRunDependencies']) {
    Module['monitorRunDependencies'](runDependencies);
  }
  if (id) {
    assert(runDependencyTracking[id]);
    delete runDependencyTracking[id];
  } else {
    Module.printErr('warning: run dependency removed without ID');
  }
  if (runDependencies == 0) {
    if (runDependencyWatcher !== null) {
      clearInterval(runDependencyWatcher);
      runDependencyWatcher = null;
    }
    if (dependenciesFulfilled) {
      var callback = dependenciesFulfilled;
      dependenciesFulfilled = null;
      callback(); // can add another dependenciesFulfilled
    }
  }
}
Module['removeRunDependency'] = removeRunDependency;

Module["preloadedImages"] = {}; // maps url to image data
Module["preloadedAudios"] = {}; // maps url to audio data



var memoryInitializer = null;



// === Body ===

var ASM_CONSTS = [];




STATIC_BASE = 8;

STATICTOP = STATIC_BASE + 73680;
  /* global initializers */  __ATINIT__.push();
  

/* memory initializer */ allocate([37,115,58,32,0,0,0,0,99,97,110,110,111,116,32,99,114,101,97,116,101,32,115,116,97,116,101,58,32,110,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,0,0,64,0,0,0,0,0,0,0,108,117,97,0,0,0,0,0,39,37,115,39,32,110,101,101,100,115,32,97,114,103,117,109,101,110,116,10,0,0,0,0,117,110,114,101,99,111,103,110,105,122,101,100,32,111,112,116,105,111,110,32,39,37,115,39,10,0,0,0,0,0,0,0,117,115,97,103,101,58,32,37,115,32,91,111,112,116,105,111,110,115,93,32,91,115,99,114,105,112,116,32,91,97,114,103,115,93,93,10,65,118,97,105,108,97,98,108,101,32,111,112,116,105,111,110,115,32,97,114,101,58,10,32,32,45,101,32,115,116,97,116,32,32,101,120,101,99,117,116,101,32,115,116,114,105,110,103,32,39,115,116,97,116,39,10,32,32,45,105,32,32,32,32,32,32,32,101,110,116,101,114,32,105,110,116,101,114,97,99,116,105,118,101,32,109,111,100,101,32,97,102,116,101,114,32,101,120,101,99,117,116,105,110,103,32,39,115,99,114,105,112,116,39,10,32,32,45,108,32,110,97,109,101,32,32,114,101,113,117,105,114,101,32,108,105,98,114,97,114,121,32,39,110,97,109,101,39,10,32,32,45,118,32,32,32,32,32,32,32,115,104,111,119,32,118,101,114,115,105,111,110,32,105,110,102,111,114,109,97,116,105,111,110,10,32,32,45,69,32,32,32,32,32,32,32,105,103,110,111,114,101,32,101,110,118,105,114,111,110,109,101,110,116,32,118,97,114,105,97,98,108,101,115,10,32,32,45,45,32,32,32,32,32,32,32,115,116,111,112,32,104,97,110,100,108,105,110,103,32,111,112,116,105,111,110,115,10,32,32,45,32,32,32,32,32,32,32,32,115,116,111,112,32,104,97,110,100,108,105,110,103,32,111,112,116,105,111,110,115,32,97,110,100,32,101,120,101,99,117,116,101,32,115,116,100,105,110,10,0,0,0,0,0,0,0,76,117,97,32,53,46,51,46,48,32,32,67,111,112,121,114,105,103,104,116,32,40,67,41,32,49,57,57,52,45,50,48,49,53,32,76,117,97,46,111,114,103,44,32,80,85,67,45,82,105,111,0,0,0,0,0,97,114,103,0,0,0,0,0,61,76,85,65,95,73,78,73,84,95,53,95,51,0,0,0,61,76,85,65,95,73,78,73,84,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,61,40,99,111,109,109,97,110,100,32,108,105,110,101,41,0,45,0,0,0,0,0,0,0,45,45,0,0,0,0,0,0,39,97,114,103,39,32,105,115,32,110,111,116,32,97,32,116,97,98,108,101,0,0,0,0,116,111,111,32,109,97,110,121,32,97,114,103,117,109,101,110,116,115,32,116,111,32,115,99,114,105,112,116,0,0,0,0,114,101,116,117,114,110,32,0,116,111,111,32,109,97,110,121,32,114,101,115,117,108,116,115,32,116,111,32,112,114,105,110,116,0,0,0,0,0,0,0,101,114,114,111,114,32,99,97,108,108,105,110,103,32,39,112,114,105,110,116,39,32,40,37,115,41,0,0,0,0,0,0,95,80,82,79,77,80,84,0,95,80,82,79,77,80,84,50,0,0,0,0,0,0,0,0,62,32,0,0,0,0,0,0,62,62,32,0,0,0,0,0,114,101,116,117,114,110,32,37,115,0,0,0,0,0,0,0,105,110,116,101,114,114,117,112,116,101,100,33,0,0,0,0,40,101,114,114,111,114,32,111,98,106,101,99,116,32,105,115,32,97,32,37,115,32,118,97,108,117,101,41,0,0,0,0,0,0,0,0,0,112,127,64,40,42,110,111,32,110,97,109,101,41,0,0,0,0,0,0,40,42,116,101,109,112,111,114,97,114,121,41,0,0,0,0,40,42,118,97,114,97,114,103,41,0,0,0,0,0,0,0,61,91,67,93,0,0,0,0,61,63,0,0,0,0,0,0,109,97,105,110,0,0,0,0,76,117,97,0,0,0,0,0,67,0,0,0,0,0,0,0,102,111,114,32,105,116,101,114,97,116,111,114,0,0,0,0,109,101,116,97,109,101,116,104,111,100,0,0,0,0,0,0,104,111,111,107,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,37,115,32,97,32,37,115,32,118,97,108,117,101,37,115,0,0,0,0,0,0,99,111,110,99,97,116,101,110,97,116,101,0,0,0,0,0,110,117,109,98,101,114,37,115,32,104,97,115,32,110,111,32,105,110,116,101,103,101,114,32,114,101,112,114,101,115,101,110,116,97,116,105,111,110,0,0,97,116,116,101,109,112,116,32,116,111,32,99,111,109,112,97,114,101,32,116,119,111,32,37,115,32,118,97,108,117,101,115,0,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,99,111,109,112,97,114,101,32,37,115,32,119,105,116,104,32,37,115,0,0,0,117,112,118,97,108,117,101,0,32,40,37,115,32,39,37,115,39,41,0,0,0,0,0,0,103,108,111,98,97,108,0,0,102,105,101,108,100,0,0,0,99,111,110,115,116,97,110,116,0,0,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,101,114,114,111,114,32,104,97,110,100,108,105,110,103,0,67,32,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,121,105,101,108,100,32,97,99,114,111,115,115,32,97,32,67,45,99,97,108,108,32,98,111,117,110,100,97,114,121,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,121,105,101,108,100,32,102,114,111,109,32,111,117,116,115,105,100,101,32,97,32,99,111,114,111,117,116,105,110,101,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,108,111,97,100,32,97,32,37,115,32,99,104,117,110,107,32,40,109,111,100,101,32,105,115,32,39,37,115,39,41,0,0,0,0,0,0,0,98,105,110,97,114,121,0,0,116,101,120,116,0,0,0,0,99,97,110,110,111,116,32,114,101,115,117,109,101,32,110,111,110,45,115,117,115,112,101,110,100,101,100,32,99,111,114,111,117,116,105,110,101,0,0,0,110,111,32,109,101,115,115,97,103,101,0,0,0,0,0,0,101,114,114,111,114,32,105,110,32,95,95,103,99,32,109,101,116,97,109,101,116,104,111,100,32,40,37,115,41,0,0,0,116,111,111,32,109,97,110,121,32,37,115,32,40,108,105,109,105,116,32,105,115,32,37,100,41,0,0,0,0,0,0,0,109,101,109,111,114,121,32,97,108,108,111,99,97,116,105,111,110,32,101,114,114,111,114,58,32,98,108,111,99,107,32,116,111,111,32,98,105,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,2,2,3,3,3,3,4,4,4,4,4,4,4,4,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,6,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,7,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,8,110,78,0,0,0,0,0,0,45,48,49,50,51,52,53,54,55,56,57,0,0,0,0,0,60,92,37,100,62,0,0,0,37,112,0,0,0,0,0,0,37,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,111,112,116,105,111,110,32,39,37,37,37,99,39,32,116,111,32,39,108,117,97,95,112,117,115,104,102,115,116,114,105,110,103,39,0,0,0,0,0,0,91,115,116,114,105,110,103,32,34,0,0,0,0,0,0,0,34,93,0,0,0,0,0,0,96,113,65,84,80,80,92,108,60,16,60,84,108,124,124,124,124,124,124,124,124,124,124,124,124,96,96,96,96,104,34,188,188,188,132,228,84,84,16,98,98,4,98,20,81,80,23,0,108,97,98,101,108,115,47,103,111,116,111,115,0,0,0,0,60,37,115,62,32,97,116,32,108,105,110,101,32,37,100,32,110,111,116,32,105,110,115,105,100,101,32,97,32,108,111,111,112,0,0,0,0,0,0,0,110,111,32,118,105,115,105,98,108,101,32,108,97,98,101,108,32,39,37,115,39,32,102,111,114,32,60,103,111,116,111,62,32,97,116,32,108,105,110,101,32,37,100,0,0,0,0,0,60,103,111,116,111,32,37,115,62,32,97,116,32,108,105,110,101,32,37,100,32,106,117,109,112,115,32,105,110,116,111,32,116,104,101,32,115,99,111,112,101,32,111,102,32,108,111,99,97,108,32,39,37,115,39,0,37,115,32,101,120,112,101,99,116,101,100,0,0,0,0,0,102,117,110,99,116,105,111,110,32,97,116,32,108,105,110,101,32,37,100,0,0,0,0,0,109,97,105,110,32,102,117,110,99,116,105,111,110,0,0,0,116,111,111,32,109,97,110,121,32,37,115,32,40,108,105,109,105,116,32,105,115,32,37,100,41,32,105,110,32,37,115,0,67,32,108,101,118,101,108,115,0,0,0,0,0,0,0,0,37,115,32,101,120,112,101,99,116,101,100,32,40,116,111,32,99,108,111,115,101,32,37,115,32,97,116,32,108,105,110,101,32,37,100,41,0,0,0,0,40,102,111,114,32,105,110,100,101,120,41,0,0,0,0,0,40,102,111,114,32,108,105,109,105,116,41,0,0,0,0,0,40,102,111,114,32,115,116,101,112,41,0,0,0,0,0,0,40,102,111,114,32,103,101,110,101,114,97,116,111,114,41,0,40,102,111,114,32,115,116,97,116,101,41,0,0,0,0,0,40,102,111,114,32,99,111,110,116,114,111,108,41,0,0,0,39,61,39,32,111,114,32,39,105,110,39,32,101,120,112,101,99,116,101,100,0,0,0,0,108,97,98,101,108,32,39,37,115,39,32,97,108,114,101,97,100,121,32,100,101,102,105,110,101,100,32,111,110,32,108,105,110,101,32,37,100,0,0,0,115,121,110,116,97,120,32,101,114,114,111,114,0,0,0,0,117,110,101,120,112,101,99,116,101,100,32,115,121,109,98,111,108,0,0,0,0,0,0,0,102,117,110,99,116,105,111,110,32,97,114,103,117,109,101,110,116,115,32,101,120,112,101,99,116,101,100,0,0,0,0,0,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,0,115,101,108,102,0,0,0,0,60,110,97,109,101,62,32,111,114,32,39,46,46,46,39,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,0,0,108,111,99,97,108,32,118,97,114,105,97,98,108,101,115,0,99,97,110,110,111,116,32,117,115,101,32,39,46,46,46,39,32,111,117,116,115,105,100,101,32,97,32,118,97,114,97,114,103,32,102,117,110,99,116,105,111,110,0,0,0,0,0,0,10,10,10,10,11,11,11,11,14,13,11,11,11,11,6,6,4,4,5,5,7,7,7,7,9,8,3,3,3,3,3,3,3,3,3,3,3,3,2,2,1,1,0,0,0,0,0,0,117,112,118,97,108,117,101,115,0,0,0,0,0,0,0,0,110,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,107,101,121,32,116,111,32,39,110,101,120,116,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,116,97,98,108,101,32,111,118,101,114,102,108,111,119,0,0,116,97,98,108,101,32,105,110,100,101,120,32,105,115,32,110,105,108,0,0,0,0,0,0,116,97,98,108,101,32,105,110,100,101,120,32,105,115,32,78,97,78,0,0,0,0,0,0,48,45,0,0,152,22,0,0,0,12,0,0,8,12,0,0,24,12,0,0,232,21,0,0,96,18,0,0,112,22,0,0,8,12,0,0,32,12,0,0,40,12,0,0,0,0,0,0,152,46,0,0,160,46,0,0,240,48,0,0,192,30,0,0,48,12,0,0,56,12,0,0,64,12,0,0,72,12,0,0,80,12,0,0,88,12,0,0,96,12,0,0,104,12,0,0,112,12,0,0,120,12,0,0,128,12,0,0,136,12,0,0,144,12,0,0,152,12,0,0,160,12,0,0,168,12,0,0,176,12,0,0,184,12,0,0,192,12,0,0,208,12,0,0,112,101,114,102,111,114,109,32,98,105,116,119,105,115,101,32,111,112,101,114,97,116,105,111,110,32,111,110,0,0,0,0,112,101,114,102,111,114,109,32,97,114,105,116,104,109,101,116,105,99,32,111,110,0,0,0,98,111,111,108,101,97,110,0,117,115,101,114,100,97,116,97,0,0,0,0,0,0,0,0,110,117,109,98,101,114,0,0,116,104,114,101,97,100,0,0,112,114,111,116,111,0,0,0,95,95,108,101,110,0,0,0,95,95,101,113,0,0,0,0,95,95,97,100,100,0,0,0,95,95,115,117,98,0,0,0,95,95,109,117,108,0,0,0,95,95,109,111,100,0,0,0,95,95,112,111,119,0,0,0,95,95,100,105,118,0,0,0,95,95,105,100,105,118,0,0,95,95,98,97,110,100,0,0,95,95,98,111,114,0,0,0,95,95,98,120,111,114,0,0,95,95,115,104,108,0,0,0,95,95,115,104,114,0,0,0,95,95,117,110,109,0,0,0,95,95,98,110,111,116,0,0,95,95,108,116,0,0,0,0,95,95,108,101,0,0,0,0,95,95,99,111,110,99,97,116,0,0,0,0,0,0,0,0,95,95,99,97,108,108,0,0,98,105,110,97,114,121,32,115,116,114,105,110,103,0,0,0,116,114,117,110,99,97,116,101,100,0,0,0,0,0,0,0,27,76,117,97,0,0,0,0,110,111,116,32,97,0,0,0,118,101,114,115,105,111,110,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,0,25,147,13,10,26,10,0,0,99,111,114,114,117,112,116,101,100,0,0,0,0,0,0,0,37,115,32,115,105,122,101,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,105,110,116,0,0,0,0,0,115,105,122,101,95,116,0,0,73,110,115,116,114,117,99,116,105,111,110,0,0,0,0,0,108,117,97,95,73,110,116,101,103,101,114,0,0,0,0,0,108,117,97,95,78,117,109,98,101,114,0,0,0,0,0,0,101,110,100,105,97,110,110,101,115,115,32,109,105,115,109,97,116,99,104,32,105,110,0,0,102,108,111,97,116,32,102,111,114,109,97,116,32,109,105,115,109,97,116,99,104,32,105,110,0,0,0,0,0,0,0,0,37,115,58,32,37,115,32,112,114,101,99,111,109,112,105,108,101,100,32,99,104,117,110,107,0,0,0,0,0,0,0,0,105,110,100,101,120,0,0,0,103,101,116,116,97,98,108,101,32,99,104,97,105,110,32,116,111,111,32,108,111,110,103,59,32,112,111,115,115,105,98,108,101,32,108,111,111,112,0,0,115,101,116,116,97,98,108,101,32,99,104,97,105,110,32,116,111,111,32,108,111,110,103,59,32,112,111,115,115,105,98,108,101,32,108,111,111,112,0,0,115,116,114,105,110,103,32,108,101,110,103,116,104,32,111,118,101,114,102,108,111,119,0,0,103,101,116,32,108,101,110,103,116,104,32,111,102,0,0,0,97,116,116,101,109,112,116,32,116,111,32,100,105,118,105,100,101,32,98,121,32,122,101,114,111,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,112,101,114,102,111,114,109,32,39,110,37,37,48,39,0,0,0,0,0,0,0,39,102,111,114,39,32,108,105,109,105,116,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,39,102,111,114,39,32,115,116,101,112,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,0,39,102,111,114,39,32,105,110,105,116,105,97,108,32,118,97,108,117,101,32,109,117,115,116,32,98,101,32,97,32,110,117,109,98,101,114,0,0,0,0,115,116,97,99,107,32,116,114,97,99,101,98,97,99,107,58,0,0,0,0,0,0,0,0,10,9,46,46,46,0,0,0,83,108,110,116,0,0,0,0,10,9,37,115,58,0,0,0,37,100,58,0,0,0,0,0,32,105,110,32,0,0,0,0,102,117,110,99,116,105,111,110,32,39,37,115,39,0,0,0,37,115,32,39,37,115,39,0,109,97,105,110,32,99,104,117,110,107,0,0,0,0,0,0,102,117,110,99,116,105,111,110,32,60,37,115,58,37,100,62,0,0,0,0,0,0,0,0,10,9,40,46,46,46,116,97,105,108,32,99,97,108,108,115,46,46,46,41,0,0,0,0,98,97,100,32,97,114,103,117,109,101,110,116,32,35,37,100,32,40,37,115,41,0,0,0,109,101,116,104,111,100,0,0,99,97,108,108,105,110,103,32,39,37,115,39,32,111,110,32,98,97,100,32,115,101,108,102,32,40,37,115,41,0,0,0,98,97,100,32,97,114,103,117,109,101,110,116,32,35,37,100,32,116,111,32,39,37,115,39,32,40,37,115,41,0,0,0,83,108,0,0,0,0,0,0,37,115,58,37,100,58,32,0,37,115,58,32,37,115,0,0,95,95,110,97,109,101,0,0,105,110,118,97,108,105,100,32,111,112,116,105,111,110,32,39,37,115,39,0,0,0,0,0,115,116,97,99,107,32,111,118,101,114,102,108,111,119,32,40,37,115,41,0,0,0,0,0,115,116,97,99,107,32,111,118,101,114,102,108,111,119,0,0,110,117,109,98,101,114,32,104,97,115,32,110,111,32,105,110,116,101,103,101,114,32,114,101,112,114,101,115,101,110,116,97,116,105,111,110,0,0,0,0,98,117,102,102,101,114,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,61,115,116,100,105,110,0,0,64,37,115,0,0,0,0,0,99,97,110,110,111,116,32,37,115,32,37,115,58,32,37,115,0,0,0,0,0,0,0,0,114,98,0,0,0,0,0,0,114,101,111,112,101,110,0,0,111,98,106,101,99,116,32,108,101,110,103,116,104,32,105,115,32,110,111,116,32,97,110,32,105,110,116,101,103,101,114,0,37,73,0,0,0,0,0,0,37,102,0,0,0,0,0,0,37,115,58,32,37,112,0,0,116,111,111,32,109,97,110,121,32,117,112,118,97,108,117,101,115,0,0,0,0,0,0,0,99,111,114,101,32,97,110,100,32,108,105,98,114,97,114,121,32,104,97,118,101,32,105,110,99,111,109,112,97,116,105,98,108,101,32,110,117,109,101,114,105,99,32,116,121,112,101,115,0,0,0,0,0,0,0,0,109,117,108,116,105,112,108,101,32,76,117,97,32,86,77,115,32,100,101,116,101,99,116,101,100,0,0,0,0,0,0,0,118,101,114,115,105,111,110,32,109,105,115,109,97,116,99,104,58,32,97,112,112,46,32,110,101,101,100,115,32,37,102,44,32,76,117,97,32,99,111,114,101,32,112,114,111,118,105,100,101,115,32,37,102,0,0,0,80,65,78,73,67,58,32,117,110,112,114,111,116,101,99,116,101,100,32,101,114,114,111,114,32,105,110,32,99,97,108,108,32,116,111,32,76,117,97,32,65,80,73,32,40,37,115,41,10,0,0,0,0,0,0,0,108,105,103,104,116,32,117,115,101,114,100,97,116,97,0,0,37,115,32,101,120,112,101,99,116,101,100,44,32,103,111,116,32,37,115,0,0,0,0,0,102,0,0,0,0,0,0,0,95,71,46,0,0,0,0,0,112,97,99,107,97,103,101,0,99,111,114,111,117,116,105,110,101,0,0,0,0,0,0,0,116,97,98,108,101,0,0,0,105,111,0,0,0,0,0,0,111,115,0,0,0,0,0,0,109,97,116,104,0,0,0,0,98,105,116,51,50,0,0,0,99,111,110,116,114,111,108,32,115,116,114,117,99,116,117,114,101,32,116,111,111,32,108,111,110,103,0,0,0,0,0,0,102,117,110,99,116,105,111,110,32,111,114,32,101,120,112,114,101,115,115,105,111,110,32,116,111,111,32,99,111,109,112,108,101,120,0,0,0,0,0,0,99,111,110,115,116,114,117,99,116,111,114,32,116,111,111,32,108,111,110,103,0,0,0,0,99,111,110,115,116,97,110,116,115,0,0,0,0,0,0,0,111,112,99,111,100,101,115,0,0,0,0,0,0,0,0,0,0,0,8,8,8,8,8,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,4,4,4,4,4,4,4,4,4,4,4,4,4,4,4,22,22,22,22,22,22,22,22,22,22,4,4,4,4,4,4,4,21,21,21,21,21,21,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,5,4,21,21,21,21,21,21,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,5,4,4,4,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,69,78,86,0,0,0,0,72,22,0,0,80,22,0,0,208,144,0,0,136,116,0,0,88,22,0,0,112,34,0,0,96,22,0,0,104,22,0,0,112,22,0,0,128,22,0,0,8,116,0,0,136,22,0,0,144,22,0,0,152,22,0,0,160,22,0,0,192,144,0,0,168,22,0,0,232,30,0,0,176,22,0,0,184,22,0,0,192,22,0,0,200,22,0,0,144,115,0,0,208,22,0,0,216,22,0,0,224,22,0,0,232,22,0,0,240,22,0,0,248,22,0,0,0,23,0,0,8,23,0,0,16,23,0,0,24,23,0,0,32,23,0,0,48,23,0,0,64,23,0,0,72,23,0,0,0,0,0,0,39,37,99,39,0,0,0,0,39,37,115,39,0,0,0,0,99,104,117,110,107,32,104,97,115,32,116,111,111,32,109,97,110,121,32,108,105,110,101,115,0,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,108,111,110,103,32,115,116,114,105,110,103,32,100,101,108,105,109,105,116,101,114,0,0,0,108,101,120,105,99,97,108,32,101,108,101,109,101,110,116,32,116,111,111,32,108,111,110,103,0,0,0,0,0,0,0,0,117,110,102,105,110,105,115,104,101,100,32,115,116,114,105,110,103,0,0,0,0,0,0,0,104,101,120,97,100,101,99,105,109,97,108,32,100,105,103,105,116,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,109,105,115,115,105,110,103,32,39,123,39,0,0,0,0,0,85,84,70,45,56,32,118,97,108,117,101,32,116,111,111,32,108,97,114,103,101,0,0,0,109,105,115,115,105,110,103,32,39,125,39,0,0,0,0,0,105,110,118,97,108,105,100,32,101,115,99,97,112,101,32,115,101,113,117,101,110,99,101,0,100,101,99,105,109,97,108,32,101,115,99,97,112,101,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,0,0,69,101,0,0,0,0,0,0,80,112,0,0,0,0,0,0,109,97,108,102,111,114,109,101,100,32,110,117,109,98,101,114,0,0,0,0,0,0,0,0,115,116,114,105,110,103,0,0,99,111,109,109,101,110,116,0,117,110,102,105,110,105,115,104,101,100,32,108,111,110,103,32,37,115,32,40,115,116,97,114,116,105,110,103,32,97,116,32,108,105,110,101,32,37,100,41,0,0,0,0,0,0,0,0,37,115,58,37,100,58,32,37,115,0,0,0,0,0,0,0,37,115,32,110,101,97,114,32,37,115,0,0,0,0,0,0,97,110,100,0,0,0,0,0,98,114,101,97,107,0,0,0,101,108,115,101,105,102,0,0,102,97,108,115,101,0,0,0,102,111,114,0,0,0,0,0,102,117,110,99,116,105,111,110,0,0,0,0,0,0,0,0,103,111,116,111,0,0,0,0,105,110,0,0,0,0,0,0,108,111,99,97,108,0,0,0,110,105,108,0,0,0,0,0,110,111,116,0,0,0,0,0,114,101,112,101,97,116,0,0,116,104,101,110,0,0,0,0,116,114,117,101,0,0,0,0,117,110,116,105,108,0,0,0,119,104,105,108,101,0,0,0,46,46,0,0,0,0,0,0,46,46,46,0,0,0,0,0,61,61,0,0,0,0,0,0,62,61,0,0,0,0,0,0,60,61,0,0,0,0,0,0,126,61,0,0,0,0,0,0,60,60,0,0,0,0,0,0,62,62,0,0,0,0,0,0,58,58,0,0,0,0,0,0,60,101,111,102,62,0,0,0,60,110,117,109,98,101,114,62,0,0,0,0,0,0,0,0,60,105,110,116,101,103,101,114,62,0,0,0,0,0,0,0,60,110,97,109,101,62,0,0,60,115,116,114,105,110,103,62,0,0,0,0,0,0,0,0,64,24,0,0,1,0,0,0,72,24,0,0,2,0,0,0,88,24,0,0,3,0,0,0,96,24,0,0,4,0,0,0,232,29,0,0,5,0,0,0,104,24,0,0,6,0,0,0,112,24,0,0,7,0,0,0,128,24,0,0,8,0,0,0,136,24,0,0,9,0,0,0,144,24,0,0,10,0,0,0,152,24,0,0,11,0,0,0,160,24,0,0,12,0,0,0,168,24,0,0,13,0,0,0,184,24,0,0,14,0,0,0,192,24,0,0,15,0,0,0,200,24,0,0,16,0,0,0,208,24,0,0,17,0,0,0,80,30,0,0,18,0,0,0,216,24,0,0,19,0,0,0,232,24,0,0,20,0,0,0,248,24,0,0,21,0,0,0,128,37,0,0,0,0,0,0,32,24,0,0,0,0,0,0,48,24,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,71,0,0,0,0,0,0,76,117,97,32,53,46,51,0,95,86,69,82,83,73,79,78,0,0,0,0,0,0,0,0,97,115,115,101,114,116,0,0,99,111,108,108,101,99,116,103,97,114,98,97,103,101,0,0,100,111,102,105,108,101,0,0,101,114,114,111,114,0,0,0,105,112,97,105,114,115,0,0,108,111,97,100,102,105,108,101,0,0,0,0,0,0,0,0,108,111,97,100,0,0,0,0,110,101,120,116,0,0,0,0,112,97,105,114,115,0,0,0,112,99,97,108,108,0,0,0,112,114,105,110,116,0,0,0,114,97,119,101,113,117,97,108,0,0,0,0,0,0,0,0,114,97,119,108,101,110,0,0,114,97,119,103,101,116,0,0,114,97,119,115,101,116,0,0,115,101,108,101,99,116,0,0,116,111,110,117,109,98,101,114,0,0,0,0,0,0,0,0,116,111,115,116,114,105,110,103,0,0,0,0,0,0,0,0,120,112,99,97,108,108,0,0,98,97,115,101,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,0,0,0,32,12,10,13,9,11,0,0,95,95,109,101,116,97,116,97,98,108,101,0,0,0,0,0,99,97,110,110,111,116,32,99,104,97,110,103,101,32,97,32,112,114,111,116,101,99,116,101,100,32,109,101,116,97,116,97,98,108,101,0,0,0,0,0,105,110,100,101,120,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,0,0,116,97,98,108,101,32,111,114,32,115,116,114,105,110,103,32,101,120,112,101,99,116,101,100,0,0,0,0,0,0,0,0,39,116,111,115,116,114,105,110,103,39,32,109,117,115,116,32,114,101,116,117,114,110,32,97,32,115,116,114,105,110,103,32,116,111,32,39,112,114,105,110,116,39,0,0,0,0,0,0,95,95,112,97,105,114,115,0,98,116,0,0,0,0,0,0,61,40,108,111,97,100,41,0,116,111,111,32,109,97,110,121,32,110,101,115,116,101,100,32,102,117,110,99,116,105,111,110,115,0,0,0,0,0,0,0,114,101,97,100,101,114,32,102,117,110,99,116,105,111,110,32,109,117,115,116,32,114,101,116,117,114,110,32,97,32,115,116,114,105,110,103,0,0,0,0,95,95,105,112,97,105,114,115,0,0,0,0,0,0,0,0,99,111,108,108,101,99,116,0,128,26,0,0,136,26,0,0,48,26,0,0,240,30,0,0,144,26,0,0,152,26,0,0,168,26,0,0,184,26,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,2,0,0,0,3,0,0,0,5,0,0,0,6,0,0,0,7,0,0,0,9,0,0,0,115,116,111,112,0,0,0,0,114,101,115,116,97,114,116,0,115,116,101,112,0,0,0,0,115,101,116,112,97,117,115,101,0,0,0,0,0,0,0,0,115,101,116,115,116,101,112,109,117,108,0,0,0,0,0,0,105,115,114,117,110,110,105,110,103,0,0,0,0,0,0,0,97,115,115,101,114,116,105,111,110,32,102,97,105,108,101,100,33,0,0,0,0,0,0,0,72,27,0,0,22,0,0,0,80,27,0,0,23,0,0,0,88,27,0,0,24,0,0,0,96,27,0,0,25,0,0,0,104,27,0,0,26,0,0,0,112,27,0,0,27,0,0,0,120,27,0,0,28,0,0,0,128,27,0,0,29,0,0,0,136,27,0,0,30,0,0,0,144,27,0,0,31,0,0,0,152,27,0,0,32,0,0,0,160,27,0,0,33,0,0,0,0,0,0,0,0,0,0,0,97,114,115,104,105,102,116,0,98,97,110,100,0,0,0,0,98,110,111,116,0,0,0,0,98,111,114,0,0,0,0,0,98,120,111,114,0,0,0,0,98,116,101,115,116,0,0,0,101,120,116,114,97,99,116,0,108,114,111,116,97,116,101,0,108,115,104,105,102,116,0,0,114,101,112,108,97,99,101,0,114,114,111,116,97,116,101,0,114,115,104,105,102,116,0,0,102,105,101,108,100,32,99,97,110,110,111,116,32,98,101,32,110,101,103,97,116,105,118,101,0,0,0,0,0,0,0,0,119,105,100,116,104,32,109,117,115,116,32,98,101,32,112,111,115,105,116,105,118,101,0,0,116,114,121,105,110,103,32,116,111,32,97,99,99,101,115,115,32,110,111,110,45,101,120,105,115,116,101,110,116,32,98,105,116,115,0,0,0,0,0,0,72,28,0,0,34,0,0,0,80,28,0,0,35,0,0,0,88,28,0,0,36,0,0,0,96,28,0,0,37,0,0,0,104,28,0,0,38,0,0,0,112,28,0,0,39,0,0,0,120,28,0,0,40,0,0,0,0,0,0,0,0,0,0,0,99,114,101,97,116,101,0,0,114,101,115,117,109,101,0,0,114,117,110,110,105,110,103,0,115,116,97,116,117,115,0,0,119,114,97,112,0,0,0,0,121,105,101,108,100,0,0,0,105,115,121,105,101,108,100,97,98,108,101,0,0,0,0,0,116,111,111,32,109,97,110,121,32,97,114,103,117,109,101,110,116,115,32,116,111,32,114,101,115,117,109,101,0,0,0,0,99,97,110,110,111,116,32,114,101,115,117,109,101,32,100,101,97,100,32,99,111,114,111,117,116,105,110,101,0,0,0,0,116,111,111,32,109,97,110,121,32,114,101,115,117,108,116,115,32,116,111,32,114,101,115,117,109,101,0,0,0,0,0,0,116,104,114,101,97,100,32,101,120,112,101,99,116,101,100,0,115,117,115,112,101,110,100,101,100,0,0,0,0,0,0,0,110,111,114,109,97,108,0,0,100,101,97,100,0,0,0,0,160,29,0,0,41,0,0,0,168,29,0,0,42,0,0,0,184,29,0,0,43,0,0,0,192,29,0,0,44,0,0,0,200,29,0,0,45,0,0,0,216,29,0,0,46,0,0,0,232,29,0,0,47,0,0,0,248,29,0,0,48,0,0,0,8,30,0,0,49,0,0,0,24,30,0,0,50,0,0,0,40,30,0,0,51,0,0,0,56,30,0,0,52,0,0,0,64,30,0,0,53,0,0,0,80,30,0,0,54,0,0,0,96,30,0,0,55,0,0,0,112,30,0,0,56,0,0,0,0,0,0,0,0,0,0,0,100,101,98,117,103,0,0,0,103,101,116,117,115,101,114,118,97,108,117,101,0,0,0,0,103,101,116,104,111,111,107,0,103,101,116,105,110,102,111,0,103,101,116,108,111,99,97,108,0,0,0,0,0,0,0,0,103,101,116,114,101,103,105,115,116,114,121,0,0,0,0,0,103,101,116,109,101,116,97,116,97,98,108,101,0,0,0,0,103,101,116,117,112,118,97,108,117,101,0,0,0,0,0,0,117,112,118,97,108,117,101,106,111,105,110,0,0,0,0,0,117,112,118,97,108,117,101,105,100,0,0,0,0,0,0,0,115,101,116,117,115,101,114,118,97,108,117,101,0,0,0,0,115,101,116,104,111,111,107,0,115,101,116,108,111,99,97,108,0,0,0,0,0,0,0,0,115,101,116,109,101,116,97,116,97,98,108,101,0,0,0,0,115,101,116,117,112,118,97,108,117,101,0,0,0,0,0,0,116,114,97,99,101,98,97,99,107,0,0,0,0,0,0,0,110,105,108,32,111,114,32,116,97,98,108,101,32,101,120,112,101,99,116,101,100,0,0,0,108,101,118,101,108,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,107,0,0,0,0,0,0,0,95,95,109,111,100,101,0,0,224,30,0,0,232,30,0,0,32,34,0,0,240,30,0,0,248,30,0,0,0,0,0,0,99,97,108,108,0,0,0,0,114,101,116,117,114,110,0,0,99,111,117,110,116,0,0,0,116,97,105,108,32,99,97,108,108,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,117,112,118,97,108,117,101,32,105,110,100,101,120,0,0,0,76,117,97,32,102,117,110,99,116,105,111,110,32,101,120,112,101,99,116,101,100,0,0,0,102,108,110,83,116,117,0,0,62,37,115,0,0,0,0,0,105,110,118,97,108,105,100,32,111,112,116,105,111,110,0,0,115,111,117,114,99,101,0,0,115,104,111,114,116,95,115,114,99,0,0,0,0,0,0,0,108,105,110,101,100,101,102,105,110,101,100,0,0,0,0,0,108,97,115,116,108,105,110,101,100,101,102,105,110,101,100,0,119,104,97,116,0,0,0,0,99,117,114,114,101,110,116,108,105,110,101,0,0,0,0,0,110,117,112,115,0,0,0,0,110,112,97,114,97,109,115,0,105,115,118,97,114,97,114,103,0,0,0,0,0,0,0,0,110,97,109,101,0,0,0,0,110,97,109,101,119,104,97,116,0,0,0,0,0,0,0,0,105,115,116,97,105,108,99,97,108,108,0,0,0,0,0,0,97,99,116,105,118,101,108,105,110,101,115,0,0,0,0,0,102,117,110,99,0,0,0,0,101,120,116,101,114,110,97,108,32,104,111,111,107,0,0,0,108,117,97,95,100,101,98,117,103,62,32,0,0,0,0,0,99,111,110,116,10,0,0,0,61,40,100,101,98,117,103,32,99,111,109,109,97,110,100,41,0,0,0,0,0,0,0,0,37,115,10,0,0,0,0,0,96,33,0,0,57,0,0,0,104,33,0,0,58,0,0,0,200,34,0,0,59,0,0,0,112,33,0,0,60,0,0,0,208,34,0,0,61,0,0,0,216,34,0,0,62,0,0,0,224,34,0,0,63,0,0,0,120,33,0,0,64,0,0,0,232,34,0,0,65,0,0,0,128,37,0,0,66,0,0,0,144,33,0,0,67,0,0,0,0,0,0,0,0,0,0,0,70,73,76,69,42,0,0,0,96,33,0,0,57,0,0,0,104,33,0,0,68,0,0,0,112,33,0,0,69,0,0,0,120,33,0,0,70,0,0,0,128,33,0,0,71,0,0,0,136,33,0,0,72,0,0,0,144,33,0,0,73,0,0,0,240,48,0,0,74,0,0,0,152,33,0,0,75,0,0,0,0,0,0,0,0,0,0,0,95,73,79,95,105,110,112,117,116,0,0,0,0,0,0,0,115,116,100,105,110,0,0,0,95,73,79,95,111,117,116,112,117,116,0,0,0,0,0,0,115,116,100,111,117,116,0,0,115,116,100,101,114,114,0,0,99,97,110,110,111,116,32,99,108,111,115,101,32,115,116,97,110,100,97,114,100,32,102,105,108,101,0,0,0,0,0,0,99,108,111,115,101,0,0,0,102,108,117,115,104,0,0,0,108,105,110,101,115,0,0,0,114,101,97,100,0,0,0,0,115,101,101,107,0,0,0,0,115,101,116,118,98,117,102,0,119,114,105,116,101,0,0,0,95,95,116,111,115,116,114,105,110,103,0,0,0,0,0,0,102,105,108,101,32,40,99,108,111,115,101,100,41,0,0,0,102,105,108,101,32,40,37,112,41,0,0,0,0,0,0,0,97,116,116,101,109,112,116,32,116,111,32,117,115,101,32,97,32,99,108,111,115,101,100,32,102,105,108,101,0,0,0,0,37,108,108,100,0,0,0,0,37,46,49,52,103,0,0,0,120,144,0,0,24,34,0,0,32,34,0,0,0,0,0,0,2,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,102,117,108,108,0,0,0,0,108,105,110,101,0,0,0,0,99,117,114,0,0,0,0,0,192,116,0,0,40,34,0,0,112,34,0,0,0,0,0,0,110,111,116,32,97,110,32,105,110,116,101,103,101,114,32,105,110,32,112,114,111,112,101,114,32,114,97,110,103,101,0,0,0,0,0,0,1,0,0,0,2,0,0,0,0,0,0,0,101,110,100,0,0,0,0,0,116,111,111,32,109,97,110,121,32,97,114,103,117,109,101,110,116,115,0,0,0,0,0,0,112,80,0,0,0,0,0,0,101,69,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,111,114,109,97,116,0,0,102,105,108,101,32,105,115,32,97,108,114,101,97,100,121,32,99,108,111,115,101,100,0,0,105,110,112,117,116,0,0,0,111,112,101,110,0,0,0,0,111,117,116,112,117,116,0,0,112,111,112,101,110,0,0,0,116,109,112,102,105,108,101,0,115,116,97,110,100,97,114,100,32,37,115,32,102,105,108,101,32,105,115,32,99,108,111,115,101,100,0,0,0,0,0,0,99,108,111,115,101,100,32,102,105,108,101,0,0,0,0,0,102,105,108,101,0,0,0,0,39,112,111,112,101,110,39,32,110,111,116,32,115,117,112,112,111,114,116,101,100,0,0,0,119,0,0,0,0,0,0,0,99,97,110,110,111,116,32,111,112,101,110,32,102,105,108,101,32,39,37,115,39,32,40,37,115,41,0,0,0,0,0,0,114,119,97,0,0,0,0,0,105,110,118,97,108,105,100,32,109,111,100,101,0,0,0,0,200,36,0,0,76,0,0,0,208,36,0,0,77,0,0,0,216,36,0,0,78,0,0,0,224,36,0,0,79,0,0,0,232,36,0,0,80,0,0,0,240,36,0,0,81,0,0,0,248,36,0,0,82,0,0,0,0,37,0,0,83,0,0,0,8,37,0,0,84,0,0,0,24,37,0,0,85,0,0,0,32,37,0,0,86,0,0,0,40,37,0,0,87,0,0,0,48,37,0,0,88,0,0,0,56,37,0,0,89,0,0,0,48,39,0,0,90,0,0,0,64,37,0,0,91,0,0,0,72,37,0,0,92,0,0,0,80,37,0,0,93,0,0,0,88,37,0,0,94,0,0,0,104,37,0,0,95,0,0,0,112,37,0,0,96,0,0,0,120,37,0,0,97,0,0,0,128,37,0,0,98,0,0,0,136,37,0,0,79,0,0,0,144,37,0,0,99,0,0,0,152,37,0,0,100,0,0,0,160,37,0,0,101,0,0,0,168,37,0,0,102,0,0,0,176,37,0,0,103,0,0,0,184,37,0,0,104,0,0,0,192,37,0,0,105,0,0,0,152,144,0,0,0,0,0,0,160,36,0,0,0,0,0,0,168,36,0,0,0,0,0,0,184,36,0,0,0,0,0,0,0,0,0,0,0,0,0,0,104,117,103,101,0,0,0,0,109,97,120,105,110,116,101,103,101,114,0,0,0,0,0,0,109,105,110,105,110,116,101,103,101,114,0,0,0,0,0,0,97,98,115,0,0,0,0,0,97,99,111,115,0,0,0,0,97,115,105,110,0,0,0,0,97,116,97,110,0,0,0,0,99,101,105,108,0,0,0,0,99,111,115,0,0,0,0,0,100,101,103,0,0,0,0,0,101,120,112,0,0,0,0,0,116,111,105,110,116,101,103,101,114,0,0,0,0,0,0,0,102,108,111,111,114,0,0,0,102,109,111,100,0,0,0,0,117,108,116,0,0,0,0,0,108,111,103,0,0,0,0,0,109,97,120,0,0,0,0,0,109,111,100,102,0,0,0,0,114,97,100,0,0,0,0,0,114,97,110,100,111,109,0,0,114,97,110,100,111,109,115,101,101,100,0,0,0,0,0,0,115,105,110,0,0,0,0,0,115,113,114,116,0,0,0,0,116,97,110,0,0,0,0,0,116,121,112,101,0,0,0,0,97,116,97,110,50,0,0,0,99,111,115,104,0,0,0,0,115,105,110,104,0,0,0,0,116,97,110,104,0,0,0,0,112,111,119,0,0,0,0,0,102,114,101,120,112,0,0,0,108,100,101,120,112,0,0,0,108,111,103,49,48,0,0,0,105,110,116,101,103,101,114,0,102,108,111,97,116,0,0,0,119,114,111,110,103,32,110,117,109,98,101,114,32,111,102,32,97,114,103,117,109,101,110,116,115,0,0,0,0,0,0,0,105,110,116,101,114,118,97,108,32,105,115,32,101,109,112,116,121,0,0,0,0,0,0,0,105,110,116,101,114,118,97,108,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,118,97,108,117,101,32,101,120,112,101,99,116,101,100,0,0,122,101,114,111,0,0,0,0,160,38,0,0,106,0,0,0,168,38,0,0,107,0,0,0,176,38,0,0,108,0,0,0,192,38,0,0,109,0,0,0,200,38,0,0,110,0,0,0,208,38,0,0,111,0,0,0,88,46,0,0,112,0,0,0,216,38,0,0,113,0,0,0,224,38,0,0,114,0,0,0,240,38,0,0,115,0,0,0,248,38,0,0,116,0,0,0,0,0,0,0,0,0,0,0,99,108,111,99,107,0,0,0,100,97,116,101,0,0,0,0,100,105,102,102,116,105,109,101,0,0,0,0,0,0,0,0,101,120,101,99,117,116,101,0,101,120,105,116,0,0,0,0,103,101,116,101,110,118,0,0,114,101,110,97,109,101,0,0,115,101,116,108,111,99,97,108,101,0,0,0,0,0,0,0,116,105,109,101,0,0,0,0,116,109,112,110,97,109,101,0,117,110,97,98,108,101,32,116,111,32,103,101,110,101,114,97,116,101,32,97,32,117,110,105,113,117,101,32,102,105,108,101,110,97,109,101,0,0,0,0,115,101,99,0,0,0,0,0,109,105,110,0,0,0,0,0,104,111,117,114,0,0,0,0,100,97,121,0,0,0,0,0,102,105,101,108,100,32,39,37,115,39,32,109,105,115,115,105,110,103,32,105,110,32,100,97,116,101,32,116,97,98,108,101,0,0,0,0,0,0,0,0,109,111,110,116,104,0,0,0,121,101,97,114,0,0,0,0,105,115,100,115,116,0,0,0,97,108,108,0,0,0,0,0,136,39,0,0,200,39,0,0,208,39,0,0,216,39,0,0,232,39,0,0,240,38,0,0,0,0,0,0,0,0,0,0,6,0,0,0,3,0,0,0,0,0,0,0,4,0,0,0,1,0,0,0,2,0,0,0,99,111,108,108,97,116,101,0,99,116,121,112,101,0,0,0,109,111,110,101,116,97,114,121,0,0,0,0,0,0,0,0,110,117,109,101,114,105,99,0,37,99,0,0,0,0,0,0,42,116,0,0,0,0,0,0,119,100,97,121], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE);
/* memory initializer */ allocate([121,100,97,121,0,0,0,0,97,65,98,66,99,67,100,68,101,70,103,71,104,72,73,106,109,77,110,112,114,82,83,116,84,117,85,86,119,87,120,88,121,89,122,90,37,0,0,0,69,0,0,0,0,0,0,0,99,67,120,88,121,89,0,0,79,0,0,0,0,0,0,0,100,101,72,73,109,77,83,117,85,86,119,87,121,0,0,0,105,110,118,97,108,105,100,32,99,111,110,118,101,114,115,105,111,110,32,115,112,101,99,105,102,105,101,114,32,39,37,37,37,115,39,0,0,0,0,0,24,41,0,0,117,0,0,0,232,47,0,0,118,0,0,0,32,41,0,0,119,0,0,0,40,41,0,0,120,0,0,0,48,41,0,0,121,0,0,0,56,41,0,0,122,0,0,0,64,41,0,0,123,0,0,0,240,47,0,0,124,0,0,0,72,41,0,0,125,0,0,0,80,41,0,0,126,0,0,0,88,41,0,0,127,0,0,0,96,41,0,0,128,0,0,0,104,41,0,0,129,0,0,0,112,41,0,0,130,0,0,0,72,46,0,0,131,0,0,0,120,41,0,0,132,0,0,0,80,46,0,0,133,0,0,0,0,0,0,0,0,0,0,0,98,121,116,101,0,0,0,0,100,117,109,112,0,0,0,0,102,105,110,100,0,0,0,0,102,111,114,109,97,116,0,0,103,109,97,116,99,104,0,0,103,115,117,98,0,0,0,0,108,111,119,101,114,0,0,0,109,97,116,99,104,0,0,0,114,101,112,0,0,0,0,0,114,101,118,101,114,115,101,0,115,117,98,0,0,0,0,0,117,112,112,101,114,0,0,0,112,97,99,107,115,105,122,101,0,0,0,0,0,0,0,0,100,97,116,97,32,115,116,114,105,110,103,32,116,111,111,32,115,104,111,114,116,0,0,0,116,111,111,32,109,97,110,121,32,114,101,115,117,108,116,115,0,0,0,0,0,0,0,0,37,100,45,98,121,116,101,32,105,110,116,101,103,101,114,32,100,111,101,115,32,110,111,116,32,102,105,116,32,105,110,116,111,32,76,117,97,32,73,110,116,101,103,101,114,0,0,0,105,110,118,97,108,105,100,32,110,101,120,116,32,111,112,116,105,111,110,32,102,111,114,32,111,112,116,105,111,110,32,39,88,39,0,0,0,0,0,0,102,111,114,109,97,116,32,97,115,107,115,32,102,111,114,32,97,108,105,103,110,109,101,110,116,32,110,111,116,32,112,111,119,101,114,32,111,102,32,50,0,0,0,0,0,0,0,0,105,110,116,101,103,114,97,108,32,115,105,122,101,32,40,37,100,41,32,111,117,116,32,111,102,32,108,105,109,105,116,115,32,91,49,44,37,100,93,0,109,105,115,115,105,110,103,32,115,105,122,101,32,102,111,114,32,102,111,114,109,97,116,32,111,112,116,105,111,110,32,39,99,39,0,0,0,0,0,0,105,110,118,97,108,105,100,32,102,111,114,109,97,116,32,111,112,116,105,111,110,32,39,37,99,39,0,0,0,0,0,0,102,111,114,109,97,116,32,114,101,115,117,108,116,32,116,111,111,32,108,97,114,103,101,0,118,97,114,105,97,98,108,101,45,108,101,110,103,116,104,32,102,111,114,109,97,116,0,0,105,110,116,101,103,101,114,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,0,117,110,115,105,103,110,101,100,32,111,118,101,114,102,108,111,119,0,0,0,0,0,0,0,119,114,111,110,103,32,108,101,110,103,116,104,0,0,0,0,115,116,114,105,110,103,32,108,101,110,103,116,104,32,100,111,101,115,32,110,111,116,32,102,105,116,32,105,110,32,103,105,118,101,110,32,115,105,122,101,0,0,0,0,0,0,0,0,115,116,114,105,110,103,32,99,111,110,116,97,105,110,115,32,122,101,114,111,115,0,0,0,114,101,115,117,108,116,105,110,103,32,115,116,114,105,110,103,32,116,111,111,32,108,97,114,103,101,0,0,0,0,0,0,94,36,42,43,63,46,40,91,37,45,0,0,0,0,0,0,116,111,111,32,109,97,110,121,32,99,97,112,116,117,114,101,115,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,99,97,112,116,117,114,101,32,105,110,100,101,120,32,37,37,37,100,0,0,0,0,0,0,117,110,102,105,110,105,115,104,101,100,32,99,97,112,116,117,114,101,0,0,0,0,0,0,112,97,116,116,101,114,110,32,116,111,111,32,99,111,109,112,108,101,120,0,0,0,0,0,105,110,118,97,108,105,100,32,112,97,116,116,101,114,110,32,99,97,112,116,117,114,101,0,109,97,108,102,111,114,109,101,100,32,112,97,116,116,101,114,110,32,40,109,105,115,115,105,110,103,32,97,114,103,117,109,101,110,116,115,32,116,111,32,39,37,37,98,39,41,0,0,109,105,115,115,105,110,103,32,39,91,39,32,97,102,116,101,114,32,39,37,37,102,39,32,105,110,32,112,97,116,116,101,114,110,0,0,0,0,0,0,109,97,108,102,111,114,109,101,100,32,112,97,116,116,101,114,110,32,40,101,110,100,115,32,119,105,116,104,32,39,37,37,39,41,0,0,0,0,0,0,109,97,108,102,111,114,109,101,100,32,112,97,116,116,101,114,110,32,40,109,105,115,115,105,110,103,32,39,93,39,41,0,115,116,114,105,110,103,47,102,117,110,99,116,105,111,110,47,116,97,98,108,101,32,101,120,112,101,99,116,101,100,0,0,105,110,118,97,108,105,100,32,117,115,101,32,111,102,32,39,37,99,39,32,105,110,32,114,101,112,108,97,99,101,109,101,110,116,32,115,116,114,105,110,103,0,0,0,0,0,0,0,105,110,118,97,108,105,100,32,114,101,112,108,97,99,101,109,101,110,116,32,118,97,108,117,101,32,40,97,32,37,115,41,0,0,0,0,0,0,0,0,110,111,32,118,97,108,117,101,0,0,0,0,0,0,0,0,45,43,32,35,48,0,0,0,105,110,118,97,108,105,100,32,102,111,114,109,97,116,32,40,114,101,112,101,97,116,101,100,32,102,108,97,103,115,41,0,105,110,118,97,108,105,100,32,102,111,114,109,97,116,32,40,119,105,100,116,104,32,111,114,32,112,114,101,99,105,115,105,111,110,32,116,111,111,32,108,111,110,103,41,0,0,0,0,108,108,0,0,0,0,0,0,92,37,100,0,0,0,0,0,92,37,48,51,100,0,0,0,105,110,118,97,108,105,100,32,111,112,116,105,111,110,32,39,37,37,37,99,39,32,116,111,32,39,102,111,114,109,97,116,39,0,0,0,0,0,0,0,117,110,97,98,108,101,32,116,111,32,100,117,109,112,32,103,105,118,101,110,32,102,117,110,99,116,105,111,110,0,0,0,56,46,0,0,134,0,0,0,64,46,0,0,135,0,0,0,72,46,0,0,136,0,0,0,80,46,0,0,137,0,0,0,88,46,0,0,138,0,0,0,96,46,0,0,139,0,0,0,104,46,0,0,140,0,0,0,0,0,0,0,0,0,0,0,99,111,110,99,97,116,0,0,105,110,115,101,114,116,0,0,112,97,99,107,0,0,0,0,117,110,112,97,99,107,0,0,114,101,109,111,118,101,0,0,109,111,118,101,0,0,0,0,115,111,114,116,0,0,0,0,105,110,118,97,108,105,100,32,111,114,100,101,114,32,102,117,110,99,116,105,111,110,32,102,111,114,32,115,111,114,116,105,110,103,0,0,0,0,0,0,95,95,105,110,100,101,120,0,95,95,110,101,119,105,110,100,101,120,0,0,0,0,0,0,105,110,105,116,105,97,108,32,112,111,115,105,116,105,111,110,32,109,117,115,116,32,98,101,32,112,111,115,105,116,105,118,101,0,0,0,0,0,0,0,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,98,111,117,110,100,115,0,0,116,111,111,32,109,97,110,121,32,114,101,115,117,108,116,115,32,116,111,32,117,110,112,97,99,107,0,0,0,0,0,0,110,0,0,0,0,0,0,0,119,114,111,110,103,32,110,117,109,98,101,114,32,111,102,32,97,114,103,117,109,101,110,116,115,32,116,111,32,39,105,110,115,101,114,116,39,0,0,0,105,110,118,97,108,105,100,32,118,97,108,117,101,32,40,37,115,41,32,97,116,32,105,110,100,101,120,32,37,100,32,105,110,32,116,97,98,108,101,32,102,111,114,32,39,99,111,110,99,97,116,39,0,0,0,0,208,47,0,0,141,0,0,0,216,47,0,0,142,0,0,0,232,47,0,0,143,0,0,0,240,47,0,0,144,0,0,0,248,47,0,0,145,0,0,0,192,47,0,0,0,0,0,0,0,0,0,0,0,0,0,0,91,0,45,127,194,45,244,93,91,128,45,191,93,42,0,0,99,104,97,114,112,97,116,116,101,114,110,0,0,0,0,0,111,102,102,115,101,116,0,0,99,111,100,101,112,111,105,110,116,0,0,0,0,0,0,0,99,104,97,114,0,0,0,0,108,101,110,0,0,0,0,0,99,111,100,101,115,0,0,0,255,0,0,0,127,0,0,0,255,7,0,0,255,255,0,0,105,110,118,97,108,105,100,32,85,84,70,45,56,32,99,111,100,101,0,0,0,0,0,0,105,110,105,116,105,97,108,32,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,115,116,114,105,110,103,0,0,102,105,110,97,108,32,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,115,116,114,105,110,103,0,0,0,0,118,97,108,117,101,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,0,0,37,85,0,0,0,0,0,0,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,0,115,116,114,105,110,103,32,115,108,105,99,101,32,116,111,111,32,108,111,110,103,0,0,0,112,111,115,105,116,105,111,110,32,111,117,116,32,111,102,32,114,97,110,103,101,0,0,0,105,110,105,116,105,97,108,32,112,111,115,105,116,105,111,110,32,105,115,32,97,32,99,111,110,116,105,110,117,97,116,105,111,110,32,98,121,116,101,0,95,95,103,99,0,0,0,0,0,0,0,0,0,0,0,0,80,52,0,0,146,0,0,0,88,52,0,0,147,0,0,0,184,50,0,0,0,0,0,0,16,50,0,0,0,0,0,0,80,49,0,0,0,0,0,0,64,49,0,0,0,0,0,0,160,50,0,0,0,0,0,0,0,0,0,0,0,0,0,0,115,101,97,114,99,104,101,114,115,0,0,0,0,0,0,0,112,97,116,104,0,0,0,0,76,85,65,95,80,65,84,72,95,53,95,51,0,0,0,0,76,85,65,95,80,65,84,72,0,0,0,0,0,0,0,0,47,117,115,114,47,108,111,99,97,108,47,115,104,97,114,101,47,108,117,97,47,53,46,51,47,63,46,108,117,97,59,47,117,115,114,47,108,111,99,97,108,47,115,104,97,114,101,47,108,117,97,47,53,46,51,47,63,47,105,110,105,116,46,108,117,97,59,47,117,115,114,47,108,111,99,97,108,47,108,105,98,47,108,117,97,47,53,46,51,47,63,46,108,117,97,59,47,117,115,114,47,108,111,99,97,108,47,108,105,98,47,108,117,97,47,53,46,51,47,63,47,105,110,105,116,46,108,117,97,59,46,47,63,46,108,117,97,59,46,47,63,47,105,110,105,116,46,108,117,97,0,0,99,112,97,116,104,0,0,0,76,85,65,95,67,80,65,84,72,95,53,95,51,0,0,0,76,85,65,95,67,80,65,84,72,0,0,0,0,0,0,0,47,117,115,114,47,108,111,99,97,108,47,108,105,98,47,108,117,97,47,53,46,51,47,63,46,115,111,59,47,117,115,114,47,108,111,99,97,108,47,108,105,98,47,108,117,97,47,53,46,51,47,108,111,97,100,97,108,108,46,115,111,59,46,47,63,46,115,111,0,0,0,0,47,10,59,10,63,10,33,10,45,10,0,0,0,0,0,0,99,111,110,102,105,103,0,0,95,76,79,65,68,69,68,0,108,111,97,100,101,100,0,0,95,80,82,69,76,79,65,68,0,0,0,0,0,0,0,0,112,114,101,108,111,97,100,0,208,50,0,0,148,0,0,0,0,0,0,0,0,0,0,0,114,101,113,117,105,114,101,0,39,112,97,99,107,97,103,101,46,115,101,97,114,99,104,101,114,115,39,32,109,117,115,116,32,98,101,32,97,32,116,97,98,108,101,0,0,0,0,0,109,111,100,117,108,101,32,39,37,115,39,32,110,111,116,32,102,111,117,110,100,58,37,115,0,0,0,0,0,0,0,0,76,85,65,95,78,79,69,78,86,0,0,0,0,0,0,0,59,59,0,0,0,0,0,0,59,1,59,0,0,0,0,0,1,0,0,0,0,0,0,0,39,112,97,99,107,97,103,101,46,37,115,39,32,109,117,115,116,32,98,101,32,97,32,115,116,114,105,110,103,0,0,0,101,114,114,111,114,32,108,111,97,100,105,110,103,32,109,111,100,117,108,101,32,39,37,115,39,32,102,114,111,109,32,102,105,108,101,32,39,37,115,39,58,10,9,37,115,0,0,0,10,9,110,111,32,109,111,100,117,108,101,32,39,37,115,39,32,105,110,32,102,105,108,101,32,39,37,115,39,0,0,0,95,0,0,0,0,0,0,0,108,117,97,111,112,101,110,95,37,115,0,0,0,0,0,0,100,121,110,97,109,105,99,32,108,105,98,114,97,114,105,101,115,32,110,111,116,32,101,110,97,98,108,101,100,59,32,99,104,101,99,107,32,121,111,117,114,32,76,117,97,32,105,110,115,116,97,108,108,97,116,105,111,110,0,0,0,0,0,0,114,0,0,0,0,0,0,0,10,9,110,111,32,102,105,108,101,32,39,37,115,39,0,0,10,9,110,111,32,102,105,101,108,100,32,112,97,99,107,97,103,101,46,112,114,101,108,111,97,100,91,39,37,115,39,93,0,0,0,0,0,0,0,0,108,111,97,100,108,105,98,0,115,101,97,114,99,104,112,97,116,104,0,0,0,0,0,0,97,98,115,101,110,116,0,0,105,110,105,116,0,0,0,0,80,87,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,27,91,65,0,0,0,0,0,27,91,66,0,0,0,0,0,27,91,67,0,0,0,0,0,27,91,68,0,0,0,0,0,27,91,72,0,0,0,0,0,27,91,70,0,0,0,0,0,27,79,65,0,0,0,0,0,27,79,66,0,0,0,0,0,27,79,67,0,0,0,0,0,27,79,68,0,0,0,0,0,27,79,72,0,0,0,0,0,27,79,70,0,0,0,0,0,105,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,95,42,92,65,97,73,105,67,99,68,100,80,112,89,121,82,114,83,115,88,120,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,108,124,104,94,48,98,66,70,84,96,0,0,0,0,0,32,108,124,104,119,87,94,48,98,66,70,84,96,0,0,0,32,108,124,104,94,48,37,98,66,70,84,96,0,0,0,0,118,105,100,111,109,111,118,101,95,100,105,115,112,97,116,99,104,58,32,117,110,107,110,111,119,110,32,111,112,101,114,97,116,111,114,32,37,100,0,0,32,104,108,94,36,48,102,116,70,84,59,44,37,119,98,101,87,66,69,124,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,61,0,0,149,0,0,0,24,61,0,0,150,0,0,0,40,61,0,0,151,0,0,0,64,61,0,0,152,0,0,0,80,61,0,0,153,0,0,0,96,61,0,0,154,0,0,0,120,61,0,0,155,0,0,0,144,61,0,0,156,0,0,0,168,61,0,0,157,0,0,0,184,61,0,0,158,0,0,0,208,61,0,0,159,0,0,0,232,61,0,0,160,0,0,0,0,62,0,0,161,0,0,0,16,62,0,0,162,0,0,0,40,62,0,0,163,0,0,0,72,62,0,0,164,0,0,0,88,62,0,0,165,0,0,0,104,62,0,0,166,0,0,0,128,62,0,0,167,0,0,0,152,62,0,0,168,0,0,0,176,62,0,0,169,0,0,0,192,62,0,0,170,0,0,0,216,62,0,0,171,0,0,0,240,62,0,0,172,0,0,0,0,63,0,0,173,0,0,0,24,63,0,0,174,0,0,0,40,63,0,0,175,0,0,0,56,63,0,0,176,0,0,0,72,63,0,0,177,0,0,0,88,63,0,0,178,0,0,0,112,63,0,0,179,0,0,0,128,63,0,0,180,0,0,0,144,63,0,0,181,0,0,0,160,63,0,0,182,0,0,0,184,63,0,0,183,0,0,0,216,63,0,0,184,0,0,0,232,63,0,0,185,0,0,0,248,63,0,0,186,0,0,0,16,64,0,0,187,0,0,0,32,64,0,0,188,0,0,0,56,64,0,0,189,0,0,0,80,64,0,0,190,0,0,0,120,64,0,0,191,0,0,0,160,64,0,0,192,0,0,0,176,64,0,0,193,0,0,0,200,64,0,0,194,0,0,0,216,64,0,0,195,0,0,0,232,64,0,0,196,0,0,0,248,64,0,0,197,0,0,0,8,65,0,0,198,0,0,0,24,65,0,0,199,0,0,0,48,65,0,0,200,0,0,0,64,65,0,0,201,0,0,0,104,65,0,0,202,0,0,0,144,65,0,0,203,0,0,0,192,65,0,0,204,0,0,0,240,65,0,0,205,0,0,0,8,66,0,0,206,0,0,0,24,66,0,0,207,0,0,0,48,66,0,0,208,0,0,0,72,66,0,0,209,0,0,0,96,66,0,0,210,0,0,0,112,66,0,0,211,0,0,0,136,66,0,0,212,0,0,0,160,66,0,0,213,0,0,0,184,66,0,0,214,0,0,0,200,66,0,0,215,0,0,0,216,66,0,0,216,0,0,0,232,66,0,0,217,0,0,0,0,67,0,0,218,0,0,0,16,67,0,0,219,0,0,0,32,67,0,0,220,0,0,0,48,67,0,0,221,0,0,0,64,67,0,0,222,0,0,0,80,67,0,0,223,0,0,0,96,67,0,0,224,0,0,0,104,67,0,0,225,0,0,0,128,67,0,0,226,0,0,0,152,67,0,0,227,0,0,0,176,67,0,0,228,0,0,0,200,67,0,0,229,0,0,0,216,67,0,0,230,0,0,0,224,67,0,0,231,0,0,0,240,67,0,0,232,0,0,0,0,68,0,0,233,0,0,0,16,68,0,0,234,0,0,0,32,68,0,0,235,0,0,0,48,68,0,0,236,0,0,0,64,68,0,0,237,0,0,0,88,68,0,0,238,0,0,0,112,68,0,0,239,0,0,0,136,68,0,0,238,0,0,0,152,68,0,0,239,0,0,0,168,68,0,0,240,0,0,0,184,68,0,0,241,0,0,0,200,68,0,0,242,0,0,0,216,68,0,0,243,0,0,0,232,68,0,0,244,0,0,0,248,68,0,0,245,0,0,0,8,69,0,0,246,0,0,0,24,69,0,0,247,0,0,0,40,69,0,0,248,0,0,0,56,69,0,0,249,0,0,0,72,69,0,0,248,0,0,0,88,69,0,0,250,0,0,0,104,69,0,0,251,0,0,0,120,69,0,0,252,0,0,0,136,69,0,0,253,0,0,0,152,69,0,0,254,0,0,0,176,69,0,0,255,0,0,0,192,69,0,0,253,0,0,0,216,69,0,0,0,1,0,0,232,69,0,0,0,1,0,0,248,69,0,0,1,1,0,0,8,70,0,0,2,1,0,0,24,70,0,0,3,1,0,0,48,70,0,0,4,1,0,0,64,70,0,0,5,1,0,0,88,70,0,0,6,1,0,0,104,70,0,0,7,1,0,0,120,70,0,0,8,1,0,0,144,70,0,0,9,1,0,0,160,70,0,0,10,1,0,0,168,70,0,0,11,1,0,0,176,70,0,0,12,1,0,0,192,70,0,0,13,1,0,0,208,70,0,0,14,1,0,0,224,70,0,0,15,1,0,0,240,70,0,0,16,1,0,0,0,71,0,0,17,1,0,0,16,71,0,0,18,1,0,0,32,71,0,0,19,1,0,0,48,71,0,0,20,1,0,0,0,0,0,0,0,0,0,0,97,98,111,114,116,0,0,0,97,99,99,101,112,116,45,108,105,110,101,0,0,0,0,0,97,114,114,111,119,45,107,101,121,45,112,114,101,102,105,120,0,0,0,0,0,0,0,0,98,97,99,107,119,97,114,100,45,98,121,116,101,0,0,0,98,97,99,107,119,97,114,100,45,99,104,97,114,0,0,0,98,97,99,107,119,97,114,100,45,100,101,108,101,116,101,45,99,104,97,114,0,0,0,0,98,97,99,107,119,97,114,100,45,107,105,108,108,45,108,105,110,101,0,0,0,0,0,0,98,97,99,107,119,97,114,100,45,107,105,108,108,45,119,111,114,100,0,0,0,0,0,0,98,97,99,107,119,97,114,100,45,119,111,114,100,0,0,0,98,101,103,105,110,110,105,110,103,45,111,102,45,104,105,115,116,111,114,121,0,0,0,0,98,101,103,105,110,110,105,110,103,45,111,102,45,108,105,110,101,0,0,0,0,0,0,0,99,97,108,108,45,108,97,115,116,45,107,98,100,45,109,97,99,114,111,0,0,0,0,0,99,97,112,105,116,97,108,105,122,101,45,119,111,114,100,0,99,104,97,114,97,99,116,101,114,45,115,101,97,114,99,104,0,0,0,0,0,0,0,0,99,104,97,114,97,99,116,101,114,45,115,101,97,114,99,104,45,98,97,99,107,119,97,114,100,0,0,0,0,0,0,0,99,108,101,97,114,45,115,99,114,101,101,110,0,0,0,0,99,111,109,112,108,101,116,101,0,0,0,0,0,0,0,0,99,111,112,121,45,98,97,99,107,119,97,114,100,45,119,111,114,100,0,0,0,0,0,0,99,111,112,121,45,102,111,114,119,97,114,100,45,119,111,114,100,0,0,0,0,0,0,0,99,111,112,121,45,114,101,103,105,111,110,45,97,115,45,107,105,108,108,0,0,0,0,0,100,101,108,101,116,101,45,99,104,97,114,0,0,0,0,0,100,101,108,101,116,101,45,99,104,97,114,45,111,114,45,108,105,115,116,0,0,0,0,0,100,101,108,101,116,101,45,104,111,114,105,122,111,110,116,97,108,45,115,112,97,99,101,0,100,105,103,105,116,45,97,114,103,117,109,101,110,116,0,0,100,111,45,108,111,119,101,114,99,97,115,101,45,118,101,114,115,105,111,110,0,0,0,0,100,111,119,110,99,97,115,101,45,119,111,114,100,0,0,0,100,117,109,112,45,102,117,110,99,116,105,111,110,115,0,0,100,117,109,112,45,109,97,99,114,111,115,0,0,0,0,0,100,117,109,112,45,118,97,114,105,97,98,108,101,115,0,0,101,109,97,99,115,45,101,100,105,116,105,110,103,45,109,111,100,101,0,0,0,0,0,0,101,110,100,45,107,98,100,45,109,97,99,114,111,0,0,0,101,110,100,45,111,102,45,104,105,115,116,111,114,121,0,0,101,110,100,45,111,102,45,108,105,110,101,0,0,0,0,0,101,120,99,104,97,110,103,101,45,112,111,105,110,116,45,97,110,100,45,109,97,114,107,0,102,111,114,119,97,114,100,45,98,97,99,107,119,97,114,100,45,100,101,108,101,116,101,45,99,104,97,114,0,0,0,0,102,111,114,119,97,114,100,45,98,121,116,101,0,0,0,0,102,111,114,119,97,114,100,45,99,104,97,114,0,0,0,0,102,111,114,119,97,114,100,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,0,0,102,111,114,119,97,114,100,45,119,111,114,100,0,0,0,0,104,105,115,116,111,114,121,45,115,101,97,114,99,104,45,98,97,99,107,119,97,114,100,0,104,105,115,116,111,114,121,45,115,101,97,114,99,104,45,102,111,114,119,97,114,100,0,0,104,105,115,116,111,114,121,45,115,117,98,115,116,114,105,110,103,45,115,101,97,114,99,104,45,98,97,99,107,119,97,114,100,0,0,0,0,0,0,0,104,105,115,116,111,114,121,45,115,117,98,115,116,114,105,110,103,45,115,101,97,114,99,104,45,102,111,114,119,97,114,100,0,0,0,0,0,0,0,0,105,110,115,101,114,116,45,99,111,109,109,101,110,116,0,0,105,110,115,101,114,116,45,99,111,109,112,108,101,116,105,111,110,115,0,0,0,0,0,0,107,105,108,108,45,119,104,111,108,101,45,108,105,110,101,0,107,105,108,108,45,108,105,110,101,0,0,0,0,0,0,0,107,105,108,108,45,114,101,103,105,111,110,0,0,0,0,0,107,105,108,108,45,119,111,114,100,0,0,0,0,0,0,0,109,101,110,117,45,99,111,109,112,108,101,116,101,0,0,0,109,101,110,117,45,99,111,109,112,108,101,116,101,45,98,97,99,107,119,97,114,100,0,0,110,101,120,116,45,104,105,115,116,111,114,121,0,0,0,0,110,111,110,45,105,110,99,114,101,109,101,110,116,97,108,45,102,111,114,119,97,114,100,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,0,0,110,111,110,45,105,110,99,114,101,109,101,110,116,97,108,45,114,101,118,101,114,115,101,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,0,0,110,111,110,45,105,110,99,114,101,109,101,110,116,97,108,45,102,111,114,119,97,114,100,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,45,97,103,97,105,110,0,0,0,0,110,111,110,45,105,110,99,114,101,109,101,110,116,97,108,45,114,101,118,101,114,115,101,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,45,97,103,97,105,110,0,0,0,0,111,108,100,45,109,101,110,117,45,99,111,109,112,108,101,116,101,0,0,0,0,0,0,0,111,118,101,114,119,114,105,116,101,45,109,111,100,101,0,0,112,111,115,115,105,98,108,101,45,99,111,109,112,108,101,116,105,111,110,115,0,0,0,0,112,114,101,118,105,111,117,115,45,104,105,115,116,111,114,121,0,0,0,0,0,0,0,0,112,114,105,110,116,45,108,97,115,116,45,107,98,100,45,109,97,99,114,111,0,0,0,0,113,117,111,116,101,100,45,105,110,115,101,114,116,0,0,0,114,101,45,114,101,97,100,45,105,110,105,116,45,102,105,108,101,0,0,0,0,0,0,0,114,101,100,114,97,119,45,99,117,114,114,101,110,116,45,108,105,110,101,0,0,0,0,0,114,101,118,101,114,115,101,45,115,101,97,114,99,104,45,104,105,115,116,111,114,121,0,0,114,101,118,101,114,116,45,108,105,110,101,0,0,0,0,0,115,101,108,102,45,105,110,115,101,114,116,0,0,0,0,0,115,101,116,45,109,97,114,107,0,0,0,0,0,0,0,0,115,107,105,112,45,99,115,105,45,115,101,113,117,101,110,99,101,0,0,0,0,0,0,0,115,116,97,114,116,45,107,98,100,45,109,97,99,114,111,0,116,97,98,45,105,110,115,101,114,116,0,0,0,0,0,0,116,105,108,100,101,45,101,120,112,97,110,100,0,0,0,0,116,114,97,110,115,112,111,115,101,45,99,104,97,114,115,0,116,114,97,110,115,112,111,115,101,45,119,111,114,100,115,0,116,116,121,45,115,116,97,116,117,115,0,0,0,0,0,0,117,110,100,111,0,0,0,0,117,110,105,118,101,114,115,97,108,45,97,114,103,117,109,101,110,116,0,0,0,0,0,0,117,110,105,120,45,102,105,108,101,110,97,109,101,45,114,117,98,111,117,116,0,0,0,0,117,110,105,120,45,108,105,110,101,45,100,105,115,99,97,114,100,0,0,0,0,0,0,0,117,110,105,120,45,119,111,114,100,45,114,117,98,111,117,116,0,0,0,0,0,0,0,0,117,112,99,97,115,101,45,119,111,114,100,0,0,0,0,0,121,97,110,107,0,0,0,0,121,97,110,107,45,108,97,115,116,45,97,114,103,0,0,0,121,97,110,107,45,110,116,104,45,97,114,103,0,0,0,0,121,97,110,107,45,112,111,112,0,0,0,0,0,0,0,0,118,105,45,97,112,112,101,110,100,45,101,111,108,0,0,0,118,105,45,97,112,112,101,110,100,45,109,111,100,101,0,0,118,105,45,97,114,103,45,100,105,103,105,116,0,0,0,0,118,105,45,98,97,99,107,45,116,111,45,105,110,100,101,110,116,0,0,0,0,0,0,0,118,105,45,98,97,99,107,119,97,114,100,45,98,105,103,119,111,114,100,0,0,0,0,0,118,105,45,98,97,99,107,119,97,114,100,45,119,111,114,100,0,0,0,0,0,0,0,0,118,105,45,98,87,111,114,100,0,0,0,0,0,0,0,0,118,105,45,98,119,111,114,100,0,0,0,0,0,0,0,0,118,105,45,99,104,97,110,103,101,45,99,97,115,101,0,0,118,105,45,99,104,97,110,103,101,45,99,104,97,114,0,0,118,105,45,99,104,97,110,103,101,45,116,111,0,0,0,0,118,105,45,99,104,97,114,45,115,101,97,114,99,104,0,0,118,105,45,99,111,108,117,109,110,0,0,0,0,0,0,0,118,105,45,99,111,109,112,108,101,116,101,0,0,0,0,0,118,105,45,100,101,108,101,116,101,0,0,0,0,0,0,0,118,105,45,100,101,108,101,116,101,45,116,111,0,0,0,0,118,105,45,101,87,111,114,100,0,0,0,0,0,0,0,0,118,105,45,101,100,105,116,105,110,103,45,109,111,100,101,0,118,105,45,101,110,100,45,98,105,103,119,111,114,100,0,0,118,105,45,101,110,100,45,119,111,114,100,0,0,0,0,0,118,105,45,101,111,102,45,109,97,121,98,101,0,0,0,0,118,105,45,101,119,111,114,100,0,0,0,0,0,0,0,0,118,105,45,102,87,111,114,100,0,0,0,0,0,0,0,0,118,105,45,102,101,116,99,104,45,104,105,115,116,111,114,121,0,0,0,0,0,0,0,0,118,105,45,102,105,114,115,116,45,112,114,105,110,116,0,0,118,105,45,102,111,114,119,97,114,100,45,98,105,103,119,111,114,100,0,0,0,0,0,0,118,105,45,102,111,114,119,97,114,100,45,119,111,114,100,0,118,105,45,102,119,111,114,100,0,0,0,0,0,0,0,0,118,105,45,103,111,116,111,45,109,97,114,107,0,0,0,0,118,105,45,105,110,115,101,114,116,45,98,101,103,0,0,0,118,105,45,105,110,115,101,114,116,105,111,110,45,109,111,100,101,0,0,0,0,0,0,0,118,105,45,109,97,116,99,104,0,0,0,0,0,0,0,0,118,105,45,109,111,118,101,109,101,110,116,45,109,111,100,101,0,0,0,0,0,0,0,0,118,105,45,110,101,120,116,45,119,111,114,100,0,0,0,0,118,105,45,111,118,101,114,115,116,114,105,107,101,0,0,0,118,105,45,111,118,101,114,115,116,114,105,107,101,45,100,101,108,101,116,101,0,0,0,0,118,105,45,112,114,101,118,45,119,111,114,100,0,0,0,0,118,105,45,112,117,116,0,0,118,105,45,114,101,100,111,0,118,105,45,114,101,112,108,97,99,101,0,0,0,0,0,0,118,105,45,114,117,98,111,117,116,0,0,0,0,0,0,0,118,105,45,115,101,97,114,99,104,0,0,0,0,0,0,0,118,105,45,115,101,97,114,99,104,45,97,103,97,105,110,0,118,105,45,115,101,116,45,109,97,114,107,0,0,0,0,0,118,105,45,115,117,98,115,116,0,0,0,0,0,0,0,0,118,105,45,116,105,108,100,101,45,101,120,112,97,110,100,0,118,105,45,121,97,110,107,45,97,114,103,0,0,0,0,0,118,105,45,121,97,110,107,45,116,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,211,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,182,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,218,0,0,0,0,0,0,0,179,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,155], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+10240);
/* memory initializer */ allocate([149,0,0,0,0,0,0,0,156,0,0,0,0,0,0,0,219,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,165,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,163,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,193,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,231,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,172,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,158,0,0,0,0,0,0,0,207,0,0,0,0,0,0,0,180,0,0,0,0,0,0,0,207,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,173,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,171,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,231,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,157,0,0,0,0,0,0,0,161,0,0,0,0,0,0,0,197,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,187,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,174,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,201,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,202,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,222,0,0,0,0,0,0,0,229,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,233,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,220,0,0,0,0,0,0,0,156], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+20348);
/* memory initializer */ allocate([216,0,0,0,0,0,0,0,159,0,0,0,0,0,0,0,153,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,169,0,0,0,0,0,0,0,181,0,0,0,0,0,0,0,185,0,0,0,0,0,0,0,149,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,165,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,195,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,213,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,221,0,0,0,0,0,0,0,227,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,228,0,0,0,1,0,0,0,64,71,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,72,79,0,0,0,0,0,0,0,0,0,0,0,0,0,0,162,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,251,0,0,0,0,0,0,0,178,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,149,0,0,0,0,0,0,0,153,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,195,0,0,0,0,0,0,0,164,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,213,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,221,0,0,0,0,0,0,0,227,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,228,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,21,1,0,0,0,0,0,0,185,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,0,0,0,0,0,0,0,181,0,0,0,0,0,0,0,4,1,0,0,0,0,0,0,18,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,0,0,0,0,0,0,0,200,0,0,0,0,0,0,0,243,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,11,1,0,0,0,0,0,0,14,1,0,0,0,0,0,0,159,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,236,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,243,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,234,0,0,0,0,0,0,0,9,1,0,0,0,0,0,0,242,0,0,0,0,0,0,0,247,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,243,0,0,0,0,0,0,0,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,1,0,0,0,0,0,0,17,1,0,0,0,0,0,0,243,0,0,0,0,0,0,0,214,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,13,1,0,0,0,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,0,0,0,0,0,0,0,19,1,0,0,0,0,0,0,1,1,0,0,0,0,0,0,235,0,0,0,0,0,0,0,9,1,0,0,0,0,0,0,242,0,0,0,0,0,0,0,247,0,0,0,0,0,0,0,250,0,0,0,0,0,0,0,243,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,153,0,0,0,0,0,0,0,22,1,0,0,0,0,0,0,200,0,0,0,0,0,0,0,208,0,0,0,0,0,0,0,185,0,0,0,0,0,0,0,16,1,0,0,0,0,0,0,15,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,10,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,241,0,0,0,0,0,0,0,17,1,0,0,0,0,0,0,243,0,0,0,0,0,0,0,21,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,6,1,0,0,0,0,0,0,246,0,0,0,0,0,0,0,20,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+22348);
/* memory initializer */ allocate([215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,251,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,165,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,150,0,0,0,0,0,0,0,198,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,199,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,213,0,0,0,0,0,0,0,186,0,0,0,0,0,0,0,221,0,0,0,0,0,0,0,227,0,0,0,0,0,0,0,210,0,0,0,0,0,0,0,228,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,230,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,5,1,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,21,1,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,154,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,215,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,23,1,0,0,0,0,0,0,24,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,119,97,114,110,105,110,103,58,32,116,117,114,110,105,110,103,32,111,102,102,32,111,117,116,112,117,116,32,102,108,117,115,104,105,110,103,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,104,115,0,0,0,0,0,0,128,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,25,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,97,100,32,118,97,108,117,101,32,37,100,32,102,111,114,32,119,104,97,116,95,116,111,95,100,111,32,105,110,32,114,108,95,99,111,109,112,108,101,116,101,0,0,0,0,0,0,45,45,77,111,114,101,45,45,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,9,10,34,92,39,96,64,36,62,60,61,59,124,38,123,40,0,0,0,0,0,0,0,34,39,0,0,0,0,0,0,47,0,0,0,0,0,0,0,47,47,0,0,0,0,0,0,68,105,115,112,108,97,121,32,97,108,108,32,37,100,32,112,111,115,115,105,98,105,108,105,116,105,101,115,63,32,40,121,32,111,114,32,110,41,0,0,0,0,0,0,0,0,0,0,184,121,0,0,0,0,0,0,67,45,92,77,45,0,0,0,0,0,0,0,0,0,0,0,73,78,80,85,84,82,67,0,126,47,46,105,110,112,117,116,114,99,0,0,0,0,0,0,47,101,116,99,47,105,110,112,117,116,114,99,0,0,0,0,105,102,0,0,0,0,0,0,8,116,0,0,26,1,0,0,56,116,0,0,27,1,0,0,136,116,0,0,28,1,0,0,144,116,0,0,29,1,0,0,0,0,0,0,0,0,0,0,101,110,100,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,115,58,32,108,105,110,101,32,37,100,58,32,37,115,10,0,0,0,0,0,0,0,0,117,110,107,110,111,119,110,32,112,97,114,115,101,114,32,100,105,114,101,99,116,105,118,101,0,0,0,0,0,0,0,0,101,108,115,101,0,0,0,0,105,110,99,108,117,100,101,0,0,0,0,0,0,0,0,0,110,111,32,99,108,111,115,105,110,103,32,96,34,39,32,105,110,32,107,101,121,32,98,105,110,100,105,110,103,0,0,0,115,101,116,0,0,0,0,0,120,121,0,0,136,53,0,0,0,0,0,0,72,119,0,0,80,145,0,0,1,0,0,0,232,122,0,0,144,141,0,0,0,0,0,0,248,122,0,0,48,113,0,0,0,0,0,0,8,123,0,0,0,113,0,0,0,0,0,0,32,123,0,0,8,113,0,0,0,0,0,0,56,123,0,0,120,53,0,0,0,0,0,0,72,123,0,0,64,114,0,0,0,0,0,0,96,123,0,0,152,53,0,0,0,0,0,0,120,123,0,0,168,137,0,0,0,0,0,0,136,123,0,0,32,137,0,0,0,0,0,0,152,123,0,0,104,113,0,0,0,0,0,0,168,123,0,0,192,140,0,0,0,0,0,0,192,123,0,0,32,53,0,0,0,0,0,0,216,123,0,0,168,53,0,0,0,0,0,0,232,123,0,0,240,112,0,0,0,0,0,0,0,124,0,0,40,53,0,0,0,0,0,0,24,124,0,0,248,112,0,0,0,0,0,0,56,124,0,0,16,113,0,0,0,0,0,0,80,124,0,0,64,113,0,0,0,0,0,0,112,124,0,0,168,53,0,0,0,0,0,0,128,124,0,0,128,53,0,0,0,0,0,0,144,124,0,0,160,113,0,0,0,0,0,0,96,119,0,0,120,119,0,0,1,0,0,0,168,124,0,0,88,114,0,0,0,0,0,0,200,124,0,0,144,53,0,0,0,0,0,0,224,124,0,0,224,112,0,0,0,0,0,0,248,124,0,0,232,112,0,0,0,0,0,0,128,119,0,0,160,53,0,0,0,0,0,0,16,125,0,0,56,113,0,0,0,0,0,0,40,125,0,0,40,113,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,68,69,76,0,0,0,0,0,72,118,0,0,127,0,0,0,176,118,0,0,27,0,0,0,184,118,0,0,27,0,0,0,192,118,0,0,10,0,0,0,200,118,0,0,10,0,0,0,208,118,0,0,13,0,0,0,216,118,0,0,13,0,0,0,224,118,0,0,127,0,0,0,232,118,0,0,32,0,0,0,240,118,0,0,32,0,0,0,248,118,0,0,9,0,0,0,0,0,0,0,0,0,0,0,69,83,67,0,0,0,0,0,69,115,99,97,112,101,0,0,76,70,68,0,0,0,0,0,78,101,119,108,105,110,101,0,82,69,84,0,0,0,0,0,82,101,116,117,114,110,0,0,82,117,98,111,117,116,0,0,83,80,67,0,0,0,0,0,83,112,97,99,101,0,0,0,84,97,98,0,0,0,0,0,67,111,110,116,114,111,108,45,0,0,0,0,0,0,0,0,67,45,0,0,0,0,0,0,77,101,116,97,0,0,0,0,77,45,0,0,0,0,0,0,112,114,101,102,105,120,45,109,101,116,97,0,0,0,0,0,67,84,82,76,45,0,0,0,111,110,0,0,0,0,0,0,98,108,105,110,107,45,109,97,116,99,104,105,110,103,45,112,97,114,101,110,0,0,0,0,112,114,101,102,101,114,45,118,105,115,105,98,108,101,45,98,101,108,108,0,0,0,0,0,1,0,0,0,0,0,0,0,115,104,111,119,45,109,111,100,101,45,105,110,45,112,114,111,109,112,116,0,0,0,0,0,232,121,0,0,1,0,0,0,30,1,0,0,8,122,0,0,1,0,0,0,31,1,0,0,24,122,0,0,2,0,0,0,32,1,0,0,88,122,0,0,2,0,0,0,33,1,0,0,128,122,0,0,2,0,0,0,34,1,0,0,152,122,0,0,1,0,0,0,35,1,0,0,168,122,0,0,2,0,0,0,36,1,0,0,184,122,0,0,1,0,0,0,37,1,0,0,208,122,0,0,1,0,0,0,38,1,0,0,216,122,0,0,2,0,0,0,39,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,111,102,102,0,0,0,0,0,101,109,97,99,115,0,0,0,40,120,0,0,80,87,0,0,120,120,0,0,80,87,0,0,136,120,0,0,72,79,0,0,152,120,0,0,64,71,0,0,168,120,0,0,88,95,0,0,176,120,0,0,88,95,0,0,184,120,0,0,88,95,0,0,200,120,0,0,96,103,0,0,0,0,0,0,0,0,0,0,101,109,97,99,115,45,115,116,97,110,100,97,114,100,0,0,101,109,97,99,115,45,109,101,116,97,0,0,0,0,0,0,101,109,97,99,115,45,99,116,108,120,0,0,0,0,0,0,118,105,0,0,0,0,0,0,118,105,45,109,111,118,101,0,118,105,45,99,111,109,109,97,110,100,0,0,0,0,0,0,118,105,45,105,110,115,101,114,116,0,0,0,0,0,0,0,92,101,0,0,0,0,0,0,92,67,45,37,99,0,0,0,92,67,45,63,0,0,0,0,35,32,37,115,32,40,110,111,116,32,98,111,117,110,100,41,10,0,0,0,0,0,0,0,34,37,115,34,58,32,37,115,10,0,0,0,0,0,0,0,37,115,32,105,115,32,110,111,116,32,98,111,117,110,100,32,116,111,32,97,110,121,32,107,101,121,115,10,0,0,0,0,37,115,32,99,97,110,32,98,101,32,102,111,117,110,100,32,111,110,32,0,0,0,0,0,44,32,0,0,0,0,0,0,46,10,0,0,0,0,0,0,34,37,115,34,37,115,0,0,46,46,46,10,0,0,0,0,13,10,0,0,0,0,0,0,98,105,110,100,45,116,116,121,45,115,112,101,99,105,97,108,45,99,104,97,114,115,0,0,115,101,116,32,37,115,32,37,115,10,0,0,0,0,0,0,37,115,32,105,115,32,115,101,116,32,116,111,32,96,37,115,39,10,0,0,0,0,0,0,111,116,104,101,114,0,0,0,34,37,115,37,115,34,58,32,34,37,115,34,10,0,0,0,37,115,37,115,32,111,117,116,112,117,116,115,32,37,115,10,0,0,0,0,0,0,0,0,98,101,108,108,45,115,116,121,108,101,0,0,0,0,0,0,118,105,115,105,98,108,101,0,97,117,100,105,98,108,101,0,99,111,109,109,101,110,116,45,98,101,103,105,110,0,0,0,99,111,109,112,108,101,116,105,111,110,45,100,105,115,112,108,97,121,45,119,105,100,116,104,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,111,109,112,108,101,116,105,111,110,45,112,114,101,102,105,120,45,100,105,115,112,108,97,121,45,108,101,110,103,116,104,0,0,0,0,0,0,0,0,99,111,109,112,108,101,116,105,111,110,45,113,117,101,114,121,45,105,116,101,109,115,0,0,101,100,105,116,105,110,103,45,109,111,100,101,0,0,0,0,104,105,115,116,111,114,121,45,115,105,122,101,0,0,0,0,105,115,101,97,114,99,104,45,116,101,114,109,105,110,97,116,111,114,115,0,0,0,0,0,107,101,121,109,97,112,0,0,107,101,121,115,101,113,45,116,105,109,101,111,117,116,0,0,98,121,116,101,45,111,114,105,101,110,116,101,100,0,0,0,99,111,108,111,114,101,100,45,115,116,97,116,115,0,0,0,99,111,109,112,108,101,116,105,111,110,45,105,103,110,111,114,101,45,99,97,115,101,0,0,99,111,109,112,108,101,116,105,111,110,45,109,97,112,45,99,97,115,101,0,0,0,0,0,99,111,110,118,101,114,116,45,109,101,116,97,0,0,0,0,100,105,115,97,98,108,101,45,99,111,109,112,108,101,116,105,111,110,0,0,0,0,0,0,101,99,104,111,45,99,111,110,116,114,111,108,45,99,104,97,114,97,99,116,101,114,115,0,101,110,97,98,108,101,45,107,101,121,112,97,100,0,0,0,101,110,97,98,108,101,45,109,101,116,97,45,107,101,121,0,101,120,112,97,110,100,45,116,105,108,100,101,0,0,0,0,104,105,115,116,111,114,121,45,112,114,101,115,101,114,118,101,45,112,111,105,110,116,0,0,104,111,114,105,122,111,110,116,97,108,45,115,99,114,111,108,108,45,109,111,100,101,0,0,105,110,112,117,116,45,109,101,116,97,0,0,0,0,0,0,109,97,114,107,45,100,105,114,101,99,116,111,114,105,101,115,0,0,0,0,0,0,0,0,109,97,114,107,45,109,111,100,105,102,105,101,100,45,108,105,110,101,115,0,0,0,0,0,109,97,114,107,45,115,121,109,108,105,110,107,101,100,45,100,105,114,101,99,116,111,114,105,101,115,0,0,0,0,0,0,109,97,116,99,104,45,104,105,100,100,101,110,45,102,105,108,101,115,0,0,0,0,0,0,109,101,110,117,45,99,111,109,112,108,101,116,101,45,100,105,115,112,108,97,121,45,112,114,101,102,105,120,0,0,0,0,109,101,116,97,45,102,108,97,103,0,0,0,0,0,0,0,111,117,116,112,117,116,45,109,101,116,97,0,0,0,0,0,112,97,103,101,45,99,111,109,112,108,101,116,105,111,110,115,0,0,0,0,0,0,0,0,112,114,105,110,116,45,99,111,109,112,108,101,116,105,111,110,115,45,104,111,114,105,122,111,110,116,97,108,108,121,0,0,114,101,118,101,114,116,45,97,108,108,45,97,116,45,110,101,119,108,105,110,101,0,0,0,115,104,111,119,45,97,108,108,45,105,102,45,97,109,98,105,103,117,111,117,115,0,0,0,115,104,111,119,45,97,108,108,45,105,102,45,117,110,109,111,100,105,102,105,101,100,0,0,115,107,105,112,45,99,111,109,112,108,101,116,101,100,45,116,101,120,116,0,0,0,0,0,118,105,115,105,98,108,101,45,115,116,97,116,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,36,101,108,115,101,32,102,111,117,110,100,32,119,105,116,104,111,117,116,32,109,97,116,99,104,105,110,103,32,36,105,102,0,0,0,0,0,0,0,0,36,101,110,100,105,102,32,119,105,116,104,111,117,116,32,109,97,116,99,104,105,110,103,32,36,105,102,0,0,0,0,0,0,0,0,0,0,0,0,0,116,101,114,109,61,0,0,0,109,111,100,101,61,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,114,101,118,101,114,115,101,45,0,0,0,0,0,0,0,0,105,45,115,101,97,114,99,104,41,96,0,0,0,0,0,0,27,10,0,0,0,0,0,0,40,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,100,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,4,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,92,37,111,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,42,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+26468);
/* memory initializer */ allocate([47,45,95,61,126,46,35,36,0,0,0,0,0,0,0,0,126,0,0,0,0,0,0,0,114,101,97,100,108,105,110,101,58,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,37,115,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,41,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,134,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,99,111,0,0,0,0,0,0,108,105,0,0,0,0,0,0,100,117,109,98,0,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,139,0,0,40,138,0,0,128,139,0,0,120,137,0,0,136,139,0,0,88,137,0,0,144,139,0,0,64,137,0,0,16,145,0,0,80,137,0,0,152,139,0,0,72,137,0,0,160,139,0,0,128,137,0,0,168,139,0,0,104,137,0,0,176,139,0,0,96,137,0,0,184,139,0,0,112,137,0,0,192,139,0,0,8,138,0,0,200,139,0,0,24,138,0,0,208,139,0,0,16,138,0,0,216,139,0,0,248,137,0,0,224,139,0,0,48,138,0,0,232,139,0,0,32,138,0,0,240,139,0,0,240,137,0,0,248,139,0,0,232,137,0,0,0,140,0,0,56,138,0,0,8,140,0,0,0,138,0,0,16,140,0,0,152,137,0,0,24,140,0,0,72,138,0,0,32,140,0,0,64,138,0,0,40,140,0,0,144,137,0,0,48,140,0,0,160,137,0,0,56,140,0,0,136,137,0,0,64,140,0,0,224,137,0,0,72,140,0,0,80,138,0,0,80,140,0,0,88,138,0,0,0,0,0,0,0,0,0,0,97,109,0,0,0,0,0,0,120,110,0,0,0,0,0,0,107,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,55,0,0,0,0,0,0,68,67,0,0,0,0,0,0,73,67,0,0,0,0,0,0,99,101,0,0,0,0,0,0,99,114,0,0,0,0,0,0,100,99,0,0,0,0,0,0,101,105,0,0,0,0,0,0,105,99,0,0,0,0,0,0,105,109,0,0,0,0,0,0,107,68,0,0,0,0,0,0,107,72,0,0,0,0,0,0,107,73,0,0,0,0,0,0,107,100,0,0,0,0,0,0,107,101,0,0,0,0,0,0,107,104,0,0,0,0,0,0,107,108,0,0,0,0,0,0,107,114,0,0,0,0,0,0,107,115,0,0,0,0,0,0,107,117,0,0,0,0,0,0,108,101,0,0,0,0,0,0,109,109,0,0,0,0,0,0,109,111,0,0,0,0,0,0,110,100,0,0,0,0,0,0,112,99,0,0,0,0,0,0,117,112,0,0,0,0,0,0,118,98,0,0,0,0,0,0,118,115,0,0,0,0,0,0,118,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,35,0,0,0,0,0,0,0,76,67,95,65,76,76,0,0,76,67,95,67,84,89,80,69,0,0,0,0,0,0,0,0,76,65,78,71,0,0,0,0,85,84,70,45,56,0,0,0,117,116,102,56,0,0,0,0,80,79,83,73,88,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,97,114,103,58,32,37,100,41,32,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,88,37,108,117,0,0,0,0,0,0,0,0,0,0,0,0,72,141,0,0,0,0,0,0,32,9,10,59,38,40,41,124,60,62,0,0,0,0,0,0,40,41,10,0,0,0,0,0,60,62,59,38,124,36,0,0,33,64,63,43,42,0,0,0,34,39,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,141,0,0,0,0,0,0,216,141,0,0,0,0,0,0,72,79,77,69,0,0,0,0,240,141,0,0,248,141,0,0,0,0,0,0,0,0,0,0,232,141,0,0,120,145,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,0,0,32,126,0,0,0,0,0,0,9,126,0,0,0,0,0,0,0,0,0,0,0,0,0,0,48,48,0,0,0,0,0,0,2,0,0,0,224,143,0,0,1,0,0,0,232,143,0,0,0,0,0,0,0,0,0,0,1,0,0,0,240,143,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,248,143,0,0,5,0,0,0,0,144,0,0,2,0,0,0,8,144,0,0,5,0,0,0,16,144,0,0,5,0,0,0,24,144,0,0,5,0,0,0,24,144,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,5,0,0,0,32,144,0,0,5,0,0,0,16,144,0,0,5,0,0,0,40,144,0,0,5,0,0,0,48,144,0,0,5,0,0,0,56,144,0,0,5,0,0,0,64,144,0,0,5,0,0,0,72,144,0,0,5,0,0,0,80,144,0,0,0,0,0,0,0,0,0,0,3,0,0,0,88,144,0,0,76,83,95,67,79,76,79,82,83,0,0,0,0,0,0,0,63,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,108,99,0,0,0,0,0,0,240,142,0,0,96,144,0,0,104,144,0,0,112,144,0,0,120,144,0,0,128,144,0,0,136,144,0,0,144,144,0,0,152,144,0,0,160,144,0,0,168,144,0,0,176,144,0,0,184,144,0,0,192,144,0,0,200,144,0,0,208,144,0,0,216,144,0,0,224,144,0,0,232,144,0,0,240,144,0,0,248,144,0,0,0,145,0,0,8,145,0,0,16,145,0,0,0,0,0,0,0,0,0,0,76,83,95,67,79,76,79,82,83,58,32,117,110,114,101,99,111,103,110,105,122,101,100,32,112,114,101,102,105,120,58,32,37,115,0,0,0,0,0,0,76,83,95,67,79,76,79,82,83,58,32,115,121,110,116,97,120,32,101,114,114,111,114,58,32,37,115,0,0,0,0,0,117,110,112,97,114,115,97,98,108,101,32,118,97,108,117,101,32,102,111,114,32,76,83,95,67,79,76,79,82,83,32,101,110,118,105,114,111,110,109,101,110,116,32,118,97,114,105,97,98,108,101,0,0,0,0,0,27,91,0,0,0,0,0,0,109,0,0,0,0,0,0,0,48,0,0,0,0,0,0,0,48,49,59,51,52,0,0,0,48,49,59,51,54,0,0,0,51,51,0,0,0,0,0,0,48,49,59,51,53,0,0,0,48,49,59,51,51,0,0,0,48,49,59,51,50,0,0,0,51,55,59,52,49,0,0,0,51,48,59,52,51,0,0,0,51,55,59,52,52,0,0,0,51,52,59,52,50,0,0,0,51,48,59,52,50,0,0,0,51,48,59,52,49,0,0,0,27,91,75,0,0,0,0,0,114,99,0,0,0,0,0,0,101,99,0,0,0,0,0,0,114,115,0,0,0,0,0,0,110,111,0,0,0,0,0,0,102,105,0,0,0,0,0,0,100,105,0,0,0,0,0,0,108,110,0,0,0,0,0,0,112,105,0,0,0,0,0,0,115,111,0,0,0,0,0,0,98,100,0,0,0,0,0,0,99,100,0,0,0,0,0,0,109,105,0,0,0,0,0,0,111,114,0,0,0,0,0,0,101,120,0,0,0,0,0,0,100,111,0,0,0,0,0,0,115,117,0,0,0,0,0,0,115,103,0,0,0,0,0,0,115,116,0,0,0,0,0,0,111,119,0,0,0,0,0,0,116,119,0,0,0,0,0,0,99,97,0,0,0,0,0,0,109,104,0,0,0,0,0,0,99,108,0,0,0,0,0,0,120,109,97,108,108,111,99,0,120,114,101,97,108,108,111,99,0,0,0,0,0,0,0,0,37,115,58,32,111,117,116,32,111,102,32,118,105,114,116,117,97,108,32,109,101,109,111,114,121,10,0,0,0,0,0,0,1,0,0,0,0,0,0,0,32,161,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,79,117,116,32,111,102,32,109,101,109,111,114,121,0,0,0,0,0,0,0,0,0,0,0,37,100,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,78,67,85,82,83,69,83,95,78,79,95,80,65,68,68,73,78,71,0,0,0,0,0,0,42,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,63,0,0,0,0,0,0,0,34,37,115,34,0,0,0,0,44,32,108,105,110,101,32,37,100,0,0,0,0,0,0,0,44,32,99,111,108,32,37,100,0,0,0,0,0,0,0,0,44,32,116,101,114,109,105,110,97,108,32,39,37,115,39,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,50,0,0,0,2,0,0,0,75,0,0,0,3,0,0,0,110,0,0,0,4,0,0,0,134,0,0,0,5,0,0,0,150,0,0,0,6,0,0,0,200,0,0,0,7,0,0,0,44,1,0,0,8,0,0,0,88,2,0,0,9,0,0,0,176,4,0,0,10,0,0,0,8,7,0,0,11,0,0,0,96,9,0,0,12,0,0,0,192,18,0,0,13,0,0,0,128,37,0,0,14,0,0,0,0,75,0,0,15,0,0,0,0,150,0,0,1,16,0,0,0,225,0,0,2,16,0,0,0,194,1,0,3,16,0,0,0,132,3,0,4,16,0,0,0,8,7,0,7,16,0,0,0,16,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,149,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,110,111,110,101,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,0,0,0,0,0,0,0,76,73,78,69,83,0,0,0,67,79,76,85,77,78,83,0,67,67,0,0,0,0,0,0,84,69,82,77,0,0,0,0,84,69,82,77,32,101,110,118,105,114,111,110,109,101,110,116,32,118,97,114,105,97,98,108,101,32,110,111,116,32,115,101,116,46,10,0,0,0,0,0,84,69,82,77,32,101,110,118,105,114,111,110,109,101,110,116,32,109,117,115,116,32,98,101,32,60,61,32,37,100,32,99,104,97,114,97,99,116,101,114,115,46,10,0,0,0,0,0,78,111,116,32,101,110,111,117,103,104,32,109,101,109,111,114,121,32,116,111,32,99,114,101,97,116,101,32,116,101,114,109,105,110,97,108,32,115,116,114,117,99,116,117,114,101,46,10,0,0,0,0,0,0,0,0,39,37,115,39,58,32,117,110,107,110,111,119,110,32,116,101,114,109,105,110,97,108,32,116,121,112,101,46,10,0,0,0,39,37,115,39,58,32,73,32,110,101,101,100,32,115,111,109,101,116,104,105,110,103,32,109,111,114,101,32,115,112,101,99,105,102,105,99,46,10,0,0,39,37,115,39,58,32,73,32,99,97,110,39,116,32,104,97,110,100,108,101,32,104,97,114,100,99,111,112,121,32,116,101,114,109,105,110,97,108,115,46,10,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,98,119,0,97,109,0,120,98,0,120,115,0,120,110,0,101,111,0,103,110,0,104,99,0,107,109,0,104,115,0,105,110,0,100,97,0,100,98,0,109,105,0,109,115,0,111,115,0,101,115,0,120,116,0,104,122,0,117,108,0,120,111,0,110,120,0,53,105,0,72,67,0,78,82,0,78,80,0,78,68,0,99,99,0,117,116,0,104,108,0,89,65,0,89,66,0,89,67,0,89,68,0,89,69,0,89,70,0,89,71,0,99,111,0,105,116,0,108,105,0,108,109,0,115,103,0,112,98,0,118,116,0,119,115,0,78,108,0,108,104,0,108,119,0,109,97,0,77,87,0,67,111,0,112,97,0,78,67,0,89,97,0,89,98,0,89,99,0,89,100,0,89,101,0,89,102,0,89,103,0,89,104,0,89,105,0,89,106,0,89,107,0,89,108,0,89,109,0,89,110,0,66,84,0,89,111,0,89,112,0,98,116,0,98,108,0,99,114,0,99,115,0,99,116,0,99,108,0,99,101,0,99,100,0,99,104,0,67,67,0,99,109,0,100,111,0,104,111,0,118,105,0,108,101,0,67,77,0,118,101,0,110,100,0,108,108,0,117,112,0,118,115,0,100,99,0,100,108,0,100,115,0,104,100,0,97,115,0,109,98,0,109,100,0,116,105,0,100,109,0,109,104,0,105,109,0,109,107,0,109,112,0,109,114,0,115,111,0,117,115,0,101,99,0,97,101,0,109,101,0,116,101,0,101,100,0,101,105,0,115,101,0,117,101,0,118,98,0,102,102,0,102,115,0,105,49,0,105,115,0,105,51,0,105,102,0,105,99,0,97,108,0,105,112,0,107,98,0,107,97,0,107,67,0,107,116,0,107,68,0,107,76,0,107,100,0,107,77,0,107,69,0,107,83,0,107,48,0,107,49,0,107,59,0,107,50,0,107,51,0,107,52,0,107,53,0,107,54,0,107,55,0,107,56,0,107,57,0,107,104,0,107,73,0,107,65,0,107,108,0,107,72,0,107,78,0,107,80,0,107,114,0,107,70,0,107,82,0,107,84,0,107,117,0,107,101,0,107,115,0,108,48,0,108,49,0,108,97,0,108,50,0,108,51,0,108,52,0,108,53,0,108,54,0,108,55,0,108,56,0,108,57,0,109,111,0,109,109,0,110,119,0,112,99,0,68,67,0,68,76,0,68,79,0,73,67,0,83,70,0,65,76,0,76,69,0,82,73,0,83,82,0,85,80,0,112,107,0,112,108,0,112,120,0,112,115,0,112,102,0,112,111,0,114,112,0,114,49,0,114,50,0,114,51,0,114,102,0,114,99,0,99,118,0,115,99,0,115,102,0,115,114,0,115,97,0,115,116,0,119,105,0,116,97,0,116,115,0,117,99,0,104,117,0,105,80,0,75,49,0,75,51,0,75,50,0,75,52,0,75,53,0,112,79,0,114,80,0,97,99,0,112,110,0,107,66,0,83,88,0,82,88,0,83,65,0,82,65,0,88,78,0,88,70,0,101,65,0,76,79,0,76,70,0,64,49,0,64,50,0,64,51,0,64,52,0,64,53,0,64,54,0,64,55,0,64,56,0,64,57,0,64,48,0,37,49,0,37,50,0,37,51,0,37,52,0,37,53,0,37,54,0,37,55,0,37,56,0,37,57,0,37,48,0,38,49,0,38,50,0,38,51,0,38,52,0,38,53,0,38,54,0,38,55,0,38,56,0,38,57,0,38,48,0,42,49,0,42,50,0,42,51,0,42,52,0,42,53,0,42,54,0,42,55,0,42,56,0,42,57,0,42,48,0,35,49,0,35,50,0,35,51,0,35,52,0,37,97,0,37,98,0,37,99,0,37,100,0,37,101,0,37,102,0,37,103,0,37,104,0,37,105,0,37,106,0,33,49,0,33,50,0,33,51,0,82,70,0,70,49,0,70,50,0,70,51,0,70,52,0,70,53,0,70,54,0,70,55,0,70,56,0,70,57,0,70,65,0,70,66,0,70,67,0,70,68,0,70,69,0,70,70,0,70,71,0,70,72,0,70,73,0,70,74,0,70,75,0,70,76,0,70,77,0,70,78,0,70,79,0,70,80,0,70,81,0,70,82,0,70,83,0,70,84,0,70,85,0,70,86,0,70,87,0,70,88,0,70,89,0,70,90,0,70,97,0,70,98,0,70,99,0,70,100,0,70,101,0,70,102,0,70,103,0,70,104,0,70,105,0,70,106,0,70,107,0,70,108,0,70,109,0,70,110,0,70,111,0,70,112,0,70,113,0,70,114,0,99,98,0,77,67,0,77,76,0,77,82,0,76,102,0,83,67,0,68,75,0,82,67,0,67,87,0,87,71,0,72,85,0,68,73,0,81,68,0,84,79,0,80,85,0,102,104,0,80,65,0,87,65,0,117,48,0,117,49,0,117,50,0,117,51,0,117,52,0,117,53,0,117,54,0,117,55,0,117,56,0,117,57,0,111,112,0,111,99,0,73,99,0,73,112,0,115,112,0,83,102,0,83,98,0,90,65,0,90,66,0,90,67,0,90,68,0,90,69,0,90,70,0,90,71,0,90,72,0,90,73,0,90,74,0,90,75,0,90,76,0,90,77,0,90,78,0,90,79,0,90,80,0,90,81,0,90,82,0,90,83,0,90,84,0,90,85,0,90,86,0,90,87,0,90,88,0,90,89,0,90,90,0,90,97,0,90,98,0,90,99,0,90,100,0,90,101,0,90,102,0,90,103,0,90,104,0,90,105,0,90,106,0,90,107,0,90,108,0,90,109,0,90,110,0,90,111,0,90,112,0,90,113,0,90,114,0,90,115,0,90,116,0,90,117,0,90,118,0,90,119,0,90,120,0,90,121,0,75,109,0,77,105,0,82,81,0,71,109,0,65,70,0,65,66,0,120,108,0,100,118,0,99,105,0,115,48,0,115,49,0,115,50,0,115,51,0,77,76,0,77,84,0,88,121,0,90,122,0,89,118,0,89,119,0,89,120,0,89,121,0,89,122,0,89,90,0,83,49,0,83,50,0,83,51,0,83,52,0,83,53,0,83,54,0,83,55,0,83,56,0,88,104,0,88,108,0,88,111,0,88,114,0,88,116,0,88,118,0,115,65,0,115,76,0,105,50,0,114,115,0,117,103,0,98,115,0,110,115,0,110,99,0,100,67,0,100,78,0,110,108,0,98,99,0,77,84,0,78,76,0,100,66,0,100,84,0,107,110,0,107,111,0,109,97,0,112,116,0,120,114,0,71,50,0,71,51,0,71,49,0,71,52,0,71,82,0,71,76,0,71,85,0,71,68,0,71,72,0,71,86,0,71,67,0,109,108,0,109,117,0,98,120,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,3,0,0,0,0,0,0,0,1,0,255,255,6,0,0,0,0,0,0,0,2,0,255,255,9,0,0,0,0,0,0,0,3,0,255,255,12,0,0,0,0,0,0,0,4,0,255,255,15,0,0,0,0,0,0,0,5,0,255,255,18,0,0,0,0,0,0,0,6,0,255,255,21,0,0,0,0,0,0,0,7,0,255,255,24,0,0,0,0,0,0,0,8,0,255,255,27,0,0,0,0,0,0,0,9,0,255,255,30,0,0,0,0,0,0,0,10,0,255,255,33,0,0,0,0,0,0,0,11,0,255,255,36,0,0,0,0,0,0,0,12,0,255,255,39,0,0,0,0,0,0,0,13,0,255,255,42,0,0,0,0,0,0,0,14,0,255,255,45,0,0,0,0,0,0,0,15,0,255,255,48,0,0,0,0,0,0,0,16,0,255,255,51,0,0,0,0,0,0,0,17,0,255,255,54,0,0,0,0,0,0,0,18,0,255,255,57,0,0,0,0,0,0,0,19,0,255,255,60,0,0,0,0,0,0,0,20,0,255,255,63,0,0,0,0,0,0,0,21,0,255,255,66,0,0,0,0,0,0,0,22,0,255,255,69,0,0,0,0,0,0,0,23,0,255,255,72,0,0,0,0,0,0,0,24,0,1,0,75,0,0,0,0,0,0,0,25,0,255,255,78,0,0,0,0,0,0,0,26,0,255,255,81,0,0,0,0,0,0,0,27,0,255,255,84,0,0,0,0,0,0,0,28,0,255,255,87,0,0,0,0,0,0,0,29,0,255,255,90,0,0,0,0,0,0,0,30,0,255,255,93,0,0,0,0,0,0,0,31,0,255,255,96,0,0,0,0,0,0,0,32,0,255,255,99,0,0,0,0,0,0,0,33,0,255,255,102,0,0,0,0,0,0,0,34,0,255,255,105,0,0,0,0,0,0,0,35,0,255,255,108,0,0,0,0,0,0,0,36,0,255,255,111,0,0,0,1,0,0,0,0,0,255,255,114,0,0,0,1,0,0,0,1,0,255,255,117,0,0,0,1,0,0,0,2,0,255,255,120,0,0,0,1,0,0,0,3,0,255,255,123,0,0,0,1,0,0,0,4,0,255,255,126,0,0,0,1,0,0,0,5,0,255,255,129,0,0,0,1,0,0,0,6,0,255,255,132,0,0,0,1,0,0,0,7,0,255,255,135,0,0,0,1,0,0,0,8,0,255,255,138,0,0,0,1,0,0,0,9,0,255,255,141,0,0,0,1,0,0,0,10,0,255,255,144,0,0,0,1,0,0,0,11,0,255,255,147,0,0,0,1,0,0,0,12,0,255,255,150,0,0,0,1,0,0,0,13,0,255,255,153,0,0,0,1,0,0,0,14,0,255,255,156,0,0,0,1,0,0,0,15,0,255,255,159,0,0,0,1,0,0,0,16,0,255,255,162,0,0,0,1,0,0,0,17,0,255,255,165,0,0,0,1,0,0,0,18,0,255,255,168,0,0,0,1,0,0,0,19,0,255,255,171,0,0,0,1,0,0,0,20,0,255,255,174,0,0,0,1,0,0,0,21,0,255,255,177,0,0,0,1,0,0,0,22,0,255,255,180,0,0,0,1,0,0,0,23,0,255,255,183,0,0,0,1,0,0,0,24,0,255,255,186,0,0,0,1,0,0,0,25,0,255,255,189,0,0,0,1,0,0,0,26,0,255,255,192,0,0,0,1,0,0,0,27,0,255,255,195,0,0,0,1,0,0,0,28,0,255,255,198,0,0,0,1,0,0,0,29,0,255,255,201,0,0,0,1,0,0,0,30,0,255,255,204,0,0,0,1,0,0,0,31,0,255,255,207,0,0,0,1,0,0,0,32,0,255,255,210,0,0,0,2,0,0,0,0,0,255,255,213,0,0,0,2,0,0,0,1,0,255,255,216,0,0,0,2,0,0,0,2,0,255,255,219,0,0,0,2,0,0,0,3,0,255,255,222,0,0,0,2,0,0,0,4,0,255,255,225,0,0,0,2,0,0,0,5,0,255,255,228,0,0,0,2,0,0,0,6,0,255,255,231,0,0,0,2,0,0,0,7,0,255,255,234,0,0,0,2,0,0,0,8,0,255,255,237,0,0,0,2,0,0,0,9,0,255,255,240,0,0,0,2,0,0,0,10,0,255,255,243,0,0,0,2,0,0,0,11,0,255,255,246,0,0,0,2,0,0,0,12,0,255,255,249,0,0,0,2,0,0,0,13,0,255,255,252,0,0,0,2,0,0,0,14,0,255,255,255,0,0,0,2,0,0,0,15,0,255,255,2,1,0,0,2,0,0,0,16,0,255,255,5,1,0,0,2,0,0,0,17,0,255,255,8,1,0,0,2,0,0,0,18,0,255,255,11,1,0,0,2,0,0,0,19,0,255,255,14,1,0,0,2,0,0,0,20,0,255,255,17,1,0,0,2,0,0,0,21,0,255,255,20,1,0,0,2,0,0,0,22,0,255,255,23,1,0,0,2,0,0,0,23,0,255,255,26,1,0,0,2,0,0,0,24,0,255,255,29,1,0,0,2,0,0,0,25,0,255,255,32,1,0,0,2,0,0,0,26,0,255,255,35,1,0,0,2,0,0,0,27,0,255,255,38,1,0,0,2,0,0,0,28,0,255,255,41,1,0,0,2,0,0,0,29,0,255,255,44,1,0,0,2,0,0,0,30,0,255,255,47,1,0,0,2,0,0,0,31,0,255,255,50,1,0,0,2,0,0,0,32,0,255,255,53,1,0,0,2,0,0,0,33,0,255,255,56,1,0,0,2,0,0,0,34,0,255,255,59,1,0,0,2,0,0,0,35,0,255,255,62,1,0,0,2,0,0,0,36,0,255,255,65,1,0,0,2,0,0,0,37,0,255,255,68,1,0,0,2,0,0,0,38,0,255,255,71,1,0,0,2,0,0,0,39,0,255,255,74,1,0,0,2,0,0,0,40,0,255,255,77,1,0,0,2,0,0,0,41,0,255,255,80,1,0,0,2,0,0,0,42,0,255,255,83,1,0,0,2,0,0,0,43,0,255,255,86,1,0,0,2,0,0,0,44,0,255,255,89,1,0,0,2,0,0,0,45,0,255,255,92,1,0,0,2,0,0,0,46,0,255,255,95,1,0,0,2,0,0,0,47,0,255,255,98,1,0,0,2,0,0,0,48,0,102,0,101,1,0,0,2,0,0,0,49,0,255,255,104,1,0,0,2,0,0,0,50,0,255,255,107,1,0,0,2,0,0,0,51,0,255,255,110,1,0,0,2,0,0,0,52,0,255,255,113,1,0,0,2,0,0,0,53,0,255,255,116,1,0,0,2,0,0,0,54,0,255,255,119,1,0,0,2,0,0,0,55,0,255,255,122,1,0,0,2,0,0,0,56,0,255,255,125,1,0,0,2,0,0,0,57,0,255,255,128,1,0,0,2,0,0,0,58,0,255,255,131,1,0,0,2,0,0,0,59,0,255,255,134,1,0,0,2,0,0,0,60,0,255,255,137,1,0,0,2,0,0,0,61,0,255,255,140,1,0,0,2,0,0,0,62,0,255,255,143,1,0,0,2,0,0,0,63,0,255,255,146,1,0,0,2,0,0,0,64,0,255,255,149,1,0,0,2,0,0,0,65,0,255,255,152,1,0,0,2,0,0,0,66,0,255,255,155,1,0,0,2,0,0,0,67,0,255,255,158,1,0,0,2,0,0,0,68,0,255,255,161,1,0,0,2,0,0,0,69,0,255,255,164,1,0,0,2,0,0,0,70,0,255,255,167,1,0,0,2,0,0,0,71,0,255,255,170,1,0,0,2,0,0,0,72,0,255,255,173,1,0,0,2,0,0,0,73,0,255,255,176,1,0,0,2,0,0,0,74,0,255,255,179,1,0,0,2,0,0,0,75,0,15,0,182,1,0,0,2,0,0,0,76,0,255,255,185,1,0,0,2,0,0,0,77,0,255,255,188,1,0,0,2,0,0,0,78,0,255,255,191,1,0,0,2,0,0,0,79,0,255,255,194,1,0,0,2,0,0,0,80,0,255,255,197,1,0,0,2,0,0,0,81,0,255,255,200,1,0,0,2,0,0,0,82,0,255,255,203,1,0,0,2,0,0,0,83,0,255,255,206,1,0,0,2,0,0,0,84,0,255,255,209,1,0,0,2,0,0,0,85,0,255,255,212,1,0,0,2,0,0,0,86,0,255,255,215,1,0,0,2,0,0,0,87,0,255,255,218,1,0,0,2,0,0,0,88,0,255,255,221,1,0,0,2,0,0,0,89,0,255,255,224,1,0,0,2,0,0,0,90,0,255,255,227,1,0,0,2,0,0,0,91,0,255,255,230,1,0,0,2,0,0,0,92,0,35,0,233,1,0,0,2,0,0,0,93,0,255,255,236,1,0,0,2,0,0,0,94,0,255,255,239,1,0,0,2,0,0,0,95,0,255,255,242,1,0,0,2,0,0,0,96,0,255,255,245,1,0,0,2,0,0,0,97,0,255,255,248,1,0,0,2,0,0,0,98,0,255,255,251,1,0,0,2,0,0,0,99,0,255,255,254,1,0,0,2,0,0,0,100,0,255,255,1,2,0,0,2,0,0,0,101,0,255,255,4,2,0,0,2,0,0,0,102,0,120,0,7,2,0,0,2,0,0,0,103,0,255,255,10,2,0,0,2,0,0,0,104,0,255,255,13,2,0,0,2,0,0,0,105,0,255,255,16,2,0,0,2,0,0,0,106,0,255,255,19,2,0,0,2,0,0,0,107,0,255,255,22,2,0,0,2,0,0,0,108,0,255,255,25,2,0,0,2,0,0,0,109,0,255,255,28,2,0,0,2,0,0,0,110,0,255,255,31,2,0,0,2,0,0,0,111,0,255,255,34,2,0,0,2,0,0,0,112,0,111,0,37,2,0,0,2,0,0,0,113,0,255,255,40,2,0,0,2,0,0,0,114,0,255,255,43,2,0,0,2,0,0,0,115,0,161,0,46,2,0,0,2,0,0,0,116,0,163,0,49,2,0,0,2,0,0,0,117,0,255,255,52,2,0,0,2,0,0,0,118,0,170,0,55,2,0,0,2,0,0,0,119,0,255,255,58,2,0,0,2,0,0,0,120,0,166,0,61,2,0,0,2,0,0,0,121,0,255,255,64,2,0,0,2,0,0,0,122,0,255,255,67,2,0,0,2,0,0,0,123,0,255,255,70,2,0,0,2,0,0,0,124,0,255,255,73,2,0,0,2,0,0,0,125,0,255,255,76,2,0,0,2,0,0,0,126,0,255,255,79,2,0,0,2,0,0,0,127,0,255,255,82,2,0,0,2,0,0,0,128,0,255,255,85,2,0,0,2,0,0,0,129,0,255,255,88,2,0,0,2,0,0,0,130,0,255,255,91,2,0,0,2,0,0,0,131,0,255,255,94,2,0,0,2,0,0,0,132,0,255,255,97,2,0,0,2,0,0,0,133,0,255,255,100,2,0,0,2,0,0,0,134,0,255,255,103,2,0,0,2,0,0,0,135,0,255,255,106,2,0,0,2,0,0,0,136,0,255,255,109,2,0,0,2,0,0,0,137,0,255,255,112,2,0,0,2,0,0,0,138,0,255,255,115,2,0,0,2,0,0,0,139,0,255,255,118,2,0,0,2,0,0,0,140,0,255,255,121,2,0,0,2,0,0,0,141,0,255,255,124,2,0,0,2,0,0,0,142,0,255,255,127,2,0,0,2,0,0,0,143,0,255,255,130,2,0,0,2,0,0,0,144,0,255,255,133,2,0,0,2,0,0,0,145,0,37,0,136,2,0,0,2,0,0,0,146,0,255,255,139,2,0,0,2,0,0,0,147,0,165,0,142,2,0,0,2,0,0,0,148,0,255,255,145,2,0,0,2,0,0,0,149,0,117,0,148,2,0,0,2,0,0,0,150,0,16,0,151,2,0,0,2,0,0,0,151,0,255,255,154,2,0,0,2,0,0,0,152,0,255,255,157,2,0,0,2,0,0,0,153,0,255,255,160,2,0,0,2,0,0,0,154,0,126,0,163,2,0,0,2,0,0,0,155,0,255,255,166,2,0,0,2,0,0,0,156,0,255,255,169,2,0,0,2,0,0,0,157,0,255,255,172,2,0,0,2,0,0,0,158,0,255,255,175,2,0,0,2,0,0,0,159,0,255,255,178,2,0,0,2,0,0,0,160,0,255,255,181,2,0,0,2,0,0,0,161,0,255,255,184,2,0,0,2,0,0,0,162,0,255,255,187,2,0,0,2,0,0,0,163,0,255,255,190,2,0,0,2,0,0,0,164,0,183,0,193,2,0,0,2,0,0,0,165,0,255,255,196,2,0,0,2,0,0,0,166,0,255,255,199,2,0,0,2,0,0,0,167,0,116,0,202,2,0,0,2,0,0,0,168,0,255,255,205,2,0,0,2,0,0,0,169,0,97,0,208,2,0,0,2,0,0,0,170,0,109,0,211,2,0,0,2,0,0,0,171,0,255,255,214,2,0,0,2,0,0,0,172,0,255,255,217,2,0,0,2,0,0,0,173,0,100,0,220,2,0,0,2,0,0,0,174,0,13,0,223,2,0,0,2,0,0,0,175,0,255,255,226,2,0,0,2,0,0,0,176,0,118,0,229,2,0,0,2,0,0,0,177,0,96,0,232,2,0,0,2,0,0,0,178,0,255,255,235,2,0,0,2,0,0,0,179,0,87,0,238,2,0,0,2,0,0,0,180,0,255,255,241,2,0,0,2,0,0,0,181,0,255,255,244,2,0,0,2,0,0,0,182,0,255,255,247,2,0,0,2,0,0,0,183,0,255,255,250,2,0,0,2,0,0,0,184,0,255,255,253,2,0,0,2,0,0,0,185,0,255,255,0,3,0,0,2,0,0,0,186,0,255,255,3,3,0,0,2,0,0,0,187,0,255,255,6,3,0,0,2,0,0,0,188,0,196,0,9,3,0,0,2,0,0,0,189,0,255,255,12,3,0,0,2,0,0,0,190,0,255,255,15,3,0,0,2,0,0,0,191,0,195,0,18,3,0,0,2,0,0,0,192,0,255,255,21,3,0,0,2,0,0,0,193,0,255,255,24,3,0,0,2,0,0,0,194,0,255,255,27,3,0,0,2,0,0,0,195,0,255,255,30,3,0,0,2,0,0,0,196,0,255,255,33,3,0,0,2,0,0,0,197,0,255,255,36,3,0,0,2,0,0,0,198,0,255,255,39,3,0,0,2,0,0,0,199,0,131,0,42,3,0,0,2,0,0,0,200,0,158,0,45,3,0,0,2,0,0,0,201,0,255,255,48,3,0,0,2,0,0,0,202,0,255,255,51,3,0,0,2,0,0,0,203,0,255,255,54,3,0,0,2,0,0,0,204,0,255,255,57,3,0,0,2,0,0,0,205,0,255,255,60,3,0,0,2,0,0,0,206,0,255,255,63,3,0,0,2,0,0,0,207,0,255,255,66,3,0,0,2,0,0,0,208,0,255,255,69,3,0,0,2,0,0,0,209,0,255,255,72,3,0,0,2,0,0,0,210,0,255,255,75,3,0,0,2,0,0,0,211,0,255,255,78,3,0,0,2,0,0,0,212,0,122,0,81,3,0,0,2,0,0,0,213,0,255,255,84,3,0,0,2,0,0,0,214,0,255,255,87,3,0,0,2,0,0,0,215,0,255,255,90,3,0,0,2,0,0,0,216,0,255,255,93,3,0,0,2,0,0,0,217,0,46,0,96,3,0,0,2,0,0,0,218,0,39,0,99,3,0,0,2,0,0,0,219,0,255,255,102,3,0,0,2,0,0,0,220,0,255,255,105,3,0,0,2,0,0,0,221,0,88,0,108,3,0,0,2,0,0,0,222,0,40,0,111,3,0,0,2,0,0,0,223,0,255,255,114,3,0,0,2,0,0,0,224,0,255,255,117,3,0,0,2,0,0,0,225,0,47,0,120,3,0,0,2,0,0,0,226,0,255,255,123,3,0,0,2,0,0,0,227,0,255,255,126,3,0,0,2,0,0,0,228,0,255,255,129,3,0,0,2,0,0,0,229,0,255,255,132,3,0,0,2,0,0,0,230,0,53,0,135,3,0,0,2,0,0,0,231,0,54,0,138,3,0,0,2,0,0,0,232,0,55,0,141,3,0,0,2,0,0,0,233,0,56,0,144,3,0,0,2,0,0,0,234,0,57,0,147,3,0,0,2,0,0,0,235,0,58,0,150,3,0,0,2,0,0,0,236,0,59,0,153,3,0,0,2,0,0,0,237,0,60,0,156,3,0,0,2,0,0,0,238,0,61,0,159,3,0,0,2,0,0,0,239,0,62,0,162,3,0,0,2,0,0,0,240,0,63,0,165,3,0,0,2,0,0,0,241,0,64,0,168,3,0,0,2,0,0,0,242,0,65,0,171,3,0,0,2,0,0,0,243,0,66,0,174,3,0,0,2,0,0,0,244,0,68,0,177,3,0,0,2,0,0,0,245,0,69,0,180,3,0,0,2,0,0,0,246,0,255,255,183,3,0,0,2,0,0,0,247,0,255,255,186,3,0,0,2,0,0,0,248,0,255,255,189,3,0,0,2,0,0,0,249,0,255,255,192,3,0,0,2,0,0,0,250,0,255,255,195,3,0,0,2,0,0,0,251,0,255,255,198,3,0,0,2,0,0,0,252,0,255,255,201,3,0,0,2,0,0,0,253,0,255,255,204,3,0,0,2,0,0,0,254,0,255,255,207,3,0,0,2,0,0,0,255,0,255,255,210,3,0,0,2,0,0,0,0,1,255,255,213,3,0,0,2,0,0,0,1,1,7,0,216,3,0,0,2,0,0,0,2,1,94,0,219,3,0,0,2,0,0,0,3,1,255,255,222,3,0,0,2,0,0,0,4,1,255,255,225,3,0,0,2,0,0,0,5,1,255,255,228,3,0,0,2,0,0,0,6,1,255,255,231,3,0,0,2,0,0,0,7,1,255,255,234,3,0,0,2,0,0,0,8,1,255,255,237,3,0,0,2,0,0,0,9,1,184,0,240,3,0,0,2,0,0,0,10,1,29,0,243,3,0,0,2,0,0,0,11,1,255,255,246,3,0,0,2,0,0,0,12,1,255,255,249,3,0,0,2,0,0,0,13,1,255,255,252,3,0,0,2,0,0,0,14,1,255,255,255,3,0,0,2,0,0,0,15,1,255,255,2,4,0,0,2,0,0,0,16,1,255,255,5,4,0,0,2,0,0,0,17,1,1,1,8,4,0,0,2,0,0,0,18,1,255,255,11,4,0,0,2,0,0,0,19,1,255,255,14,4,0,0,2,0,0,0,20,1,255,255,17,4,0,0,2,0,0,0,21,1,4], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+34296);
/* memory initializer */ allocate([20,4,0,0,2,0,0,0,22,1,255,255,23,4,0,0,2,0,0,0,23,1,255,255,26,4,0,0,2,0,0,0,24,1,255,255,29,4,0,0,2,0,0,0,25,1,255,255,32,4,0,0,2,0,0,0,26,1,255,255,35,4,0,0,2,0,0,0,27,1,255,255,38,4,0,0,2,0,0,0,28,1,229,0,41,4,0,0,2,0,0,0,29,1,255,255,44,4,0,0,2,0,0,0,30,1,255,255,47,4,0,0,2,0,0,0,31,1,255,255,50,4,0,0,2,0,0,0,32,1,255,255,53,4,0,0,2,0,0,0,33,1,255,255,56,4,0,0,2,0,0,0,34,1,255,255,59,4,0,0,2,0,0,0,35,1,255,255,62,4,0,0,2,0,0,0,36,1,255,255,65,4,0,0,2,0,0,0,37,1,255,255,68,4,0,0,2,0,0,0,38,1,255,255,71,4,0,0,2,0,0,0,39,1,255,255,74,4,0,0,2,0,0,0,40,1,255,255,77,4,0,0,2,0,0,0,41,1,142,0,80,4,0,0,2,0,0,0,42,1,255,255,83,4,0,0,2,0,0,0,43,1,255,255,86,4,0,0,2,0,0,0,44,1,149,0,89,4,0,0,2,0,0,0,45,1,255,255,92,4,0,0,2,0,0,0,46,1,255,255,95,4,0,0,2,0,0,0,47,1,255,255,98,4,0,0,2,0,0,0,48,1,255,255,101,4,0,0,2,0,0,0,49,1,255,255,104,4,0,0,2,0,0,0,50,1,255,255,107,4,0,0,2,0,0,0,51,1,255,255,110,4,0,0,2,0,0,0,52,1,255,255,113,4,0,0,2,0,0,0,53,1,48,0,116,4,0,0,2,0,0,0,54,1,247,0,119,4,0,0,2,0,0,0,55,1,238,0,122,4,0,0,2,0,0,0,56,1,239,0,125,4,0,0,2,0,0,0,57,1,240,0,128,4,0,0,2,0,0,0,58,1,241,0,131,4,0,0,2,0,0,0,59,1,242,0,134,4,0,0,2,0,0,0,60,1,243,0,137,4,0,0,2,0,0,0,61,1,244,0,140,4,0,0,2,0,0,0,62,1,245,0,143,4,0,0,2,0,0,0,63,1,246,0,146,4,0,0,2,0,0,0,64,1,255,255,149,4,0,0,2,0,0,0,65,1,172,0,152,4,0,0,2,0,0,0,66,1,255,255,155,4,0,0,2,0,0,0,67,1,171,0,158,4,0,0,2,0,0,0,68,1,103,0,161,4,0,0,2,0,0,0,69,1,255,255,164,4,0,0,2,0,0,0,70,1,104,0,167,4,0,0,2,0,0,0,71,1,14,0,170,4,0,0,2,0,0,0,72,1,255,255,173,4,0,0,2,0,0,0,73,1,255,255,176,4,0,0,2,0,0,0,74,1,255,255,179,4,0,0,2,0,0,0,75,1,255,255,182,4,0,0,2,0,0,0,76,1,255,255,185,4,0,0,2,0,0,0,77,1,255,255,188,4,0,0,2,0,0,0,78,1,255,255,191,4,0,0,2,0,0,0,79,1,255,255,194,4,0,0,2,0,0,0,80,1,255,255,197,4,0,0,2,0,0,0,81,1,255,255,200,4,0,0,2,0,0,0,82,1,255,255,203,4,0,0,2,0,0,0,83,1,255,255,206,4,0,0,2,0,0,0,84,1,255,255,209,4,0,0,2,0,0,0,85,1,255,255,212,4,0,0,2,0,0,0,86,1,255,255,215,4,0,0,2,0,0,0,87,1,255,255,218,4,0,0,2,0,0,0,88,1,208,0,221,4,0,0,2,0,0,0,89,1,255,255,224,4,0,0,2,0,0,0,90,1,255,255,227,4,0,0,2,0,0,0,91,1,255,255,230,4,0,0,2,0,0,0,92,1,255,255,233,4,0,0,2,0,0,0,93,1,255,255,236,4,0,0,2,0,0,0,94,1,255,255,239,4,0,0,2,0,0,0,95,1,255,255,242,4,0,0,2,0,0,0,96,1,255,255,245,4,0,0,2,0,0,0,97,1,16,1,248,4,0,0,2,0,0,0,98,1,17,1,251,4,0,0,2,0,0,0,99,1,131,1,254,4,0,0,2,0,0,0,100,1,255,255,1,5,0,0,2,0,0,0,101,1,255,255,4,5,0,0,2,0,0,0,102,1,255,255,7,5,0,0,2,0,0,0,103,1,255,255,10,5,0,0,2,0,0,0,104,1,255,255,13,5,0,0,2,0,0,0,105,1,255,255,16,5,0,0,2,0,0,0,106,1,255,255,19,5,0,0,2,0,0,0,107,1,255,255,22,5,0,0,2,0,0,0,108,1,255,255,25,5,0,0,2,0,0,0,109,1,67,0,28,5,0,0,2,0,0,0,110,1,255,255,31,5,0,0,2,0,0,0,111,1,255,255,34,5,0,0,2,0,0,0,112,1,85,1,37,5,0,0,2,0,0,0,113,1,255,255,40,5,0,0,2,0,0,0,114,1,255,255,43,5,0,0,2,0,0,0,115,1,18,1,46,5,0,0,2,0,0,0,116,1,255,255,49,5,0,0,2,0,0,0,117,1,255,255,52,5,0,0,2,0,0,0,118,1,255,255,55,5,0,0,2,0,0,0,119,1,255,255,58,5,0,0,2,0,0,0,120,1,255,255,61,5,0,0,2,0,0,0,121,1,255,255,64,5,0,0,2,0,0,0,122,1,255,255,67,5,0,0,2,0,0,0,123,1,255,255,70,5,0,0,2,0,0,0,124,1,255,255,73,5,0,0,2,0,0,0,125,1,101,1,76,5,0,0,2,0,0,0,126,1,102,1,79,5,0,0,2,0,0,0,127,1,103,1,82,5,0,0,2,0,0,0,128,1,104,1,85,5,0,0,2,0,0,0,129,1,105,1,88,5,0,0,2,0,0,0,130,1,255,255,91,5,0,0,2,0,0,0,131,1,255,255,94,5,0,0,2,0,0,0,132,1,255,255,97,5,0,0,2,0,0,0,133,1,255,255,100,5,0,0,2,0,0,0,134,1,255,255,103,5,0,0,2,0,0,0,135,1,255,255,106,5,0,0,2,0,0,0,136,1,255,255,109,5,0,0,2,0,0,0,137,1,255,255,112,5,0,0,2,0,0,0,138,1,134,1,115,5,0,0,2,0,0,0,139,1,255,255,118,5,0,0,1,0,0,0,33,0,255,255,121,5,0,0,0,0,0,0,37,0,255,255,124,5,0,0,0,0,0,0,38,0,255,255,127,5,0,0,0,0,0,0,39,0,248,0,130,5,0,0,1,0,0,0,34,0,255,255,133,5,0,0,1,0,0,0,35,0,203,0,136,5,0,0,2,0,0,0,140,1,255,255,139,5,0,0,2,0,0,0,141,1,255,255,142,5,0,0,0,0,0,0,40,0,183,1,145,5,0,0,0,0,0,0,41,0,255,255,148,5,0,0,1,0,0,0,36,0,255,255,151,5,0,0,1,0,0,0,37,0,255,255,154,5,0,0,1,0,0,0,38,0,255,255,157,5,0,0,2,0,0,0,142,1,255,255,160,5,0,0,2,0,0,0,143,1,123,1,163,5,0,0,0,0,0,0,42,0,255,255,166,5,0,0,0,0,0,0,43,0,255,255,169,5,0,0,2,0,0,0,144,1,130,1,172,5,0,0,2,0,0,0,145,1,169,1,175,5,0,0,2,0,0,0,146,1,129,1,178,5,0,0,2,0,0,0,147,1,132,1,181,5,0,0,2,0,0,0,148,1,156,1,184,5,0,0,2,0,0,0,149,1,150,1,187,5,0,0,2,0,0,0,150,1,159,1,190,5,0,0,2,0,0,0,151,1,255,255,193,5,0,0,2,0,0,0,152,1,146,1,196,5,0,0,2,0,0,0,153,1,160,1,199,5,0,0,2,0,0,0,154,1,255,255,202,5,0,0,2,0,0,0,155,1,208,1,205,5,0,0,2,0,0,0,156,1,143,1,208,5,0,0,2,0,0,0,157,1,255,255,0,0,0,0,0,0,0,0,0,0,0,0,98,119,0,97,109,0,120,115,98,0,120,104,112,0,120,101,110,108,0,101,111,0,103,110,0,104,99,0,107,109,0,104,115,0,105,110,0,100,97,0,100,98,0,109,105,114,0,109,115,103,114,0,111,115,0,101,115,108,111,107,0,120,116,0,104,122,0,117,108,0,120,111,110,0,110,120,111,110,0,109,99,53,105,0,99,104,116,115,0,110,114,114,109,99,0,110,112,99,0,110,100,115,99,114,0,99,99,99,0,98,99,101,0,104,108,115,0,120,104,112,97,0,99,114,120,109,0,100,97,105,115,121,0,120,118,112,97,0,115,97,109,0,99,112,105,120,0,108,112,105,120,0,99,111,108,115,0,105,116,0,108,105,110,101,115,0,108,109,0,120,109,99,0,112,98,0,118,116,0,119,115,108,0,110,108,97,98,0,108,104,0,108,119,0,109,97,0,119,110,117,109,0,99,111,108,111,114,115,0,112,97,105,114,115,0,110,99,118,0,98,117,102,115,122,0,115,112,105,110,118,0,115,112,105,110,104,0,109,97,100,100,114,0,109,106,117,109,112,0,109,99,115,0,109,108,115,0,110,112,105,110,115,0,111,114,99,0,111,114,108,0,111,114,104,105,0,111,114,118,105,0,99,112,115,0,119,105,100,99,115,0,98,116,110,115,0,98,105,116,119,105,110,0,98,105,116,121,112,101,0,99,98,116,0,98,101,108,0,99,114,0,99,115,114,0,116,98,99,0,99,108,101,97,114,0,101,108,0,101,100,0,104,112,97,0,99,109,100,99,104,0,99,117,112,0,99,117,100,49,0,104,111,109,101,0,99,105,118,105,115,0,99,117,98,49,0,109,114,99,117,112,0,99,110,111,114,109,0,99,117,102,49,0,108,108,0,99,117,117,49,0,99,118,118,105,115,0,100,99,104,49,0,100,108,49,0,100,115,108,0,104,100,0,115,109,97,99,115,0,98,108,105,110,107,0,98,111,108,100,0,115,109,99,117,112,0,115,109,100,99,0,100,105,109,0,115,109,105,114,0,105,110,118,105,115,0,112,114,111,116,0,114,101,118,0,115,109,115,111,0,115,109,117,108,0,101,99,104,0,114,109,97,99,115,0,115,103,114,48,0,114,109,99,117,112,0,114,109,100,99,0,114,109,105,114,0,114,109,115,111,0,114,109,117,108,0,102,108,97,115,104,0,102,102,0,102,115,108,0,105,115,49,0,105,115,50,0,105,115,51,0,105,102,0,105,99,104,49,0,105,108,49,0,105,112,0,107,98,115,0,107,116,98,99,0,107,99,108,114,0,107,99,116,97,98,0,107,100,99,104,49,0,107,100,108,49,0,107,99,117,100,49,0,107,114,109,105,114,0,107,101,108,0,107,101,100,0,107,102,48,0,107,102,49,0,107,102,49,48,0,107,102,50,0,107,102,51,0,107,102,52,0,107,102,53,0,107,102,54,0,107,102,55,0,107,102,56,0,107,102,57,0,107,104,111,109,101,0,107,105,99,104,49,0,107,105,108,49,0,107,99,117,98,49,0,107,108,108,0,107,110,112,0,107,112,112,0,107,99,117,102,49,0,107,105,110,100,0,107,114,105,0,107,104,116,115,0,107,99,117,117,49,0,114,109,107,120,0,115,109,107,120,0,108,102,48,0,108,102,49,0,108,102,49,48,0,108,102,50,0,108,102,51,0,108,102,52,0,108,102,53,0,108,102,54,0,108,102,55,0,108,102,56,0,108,102,57,0,114,109,109,0,115,109,109,0,110,101,108,0,112,97,100,0,100,99,104,0,100,108,0,99,117,100,0,105,99,104,0,105,110,100,110,0,105,108,0,99,117,98,0,99,117,102,0,114,105,110,0,99,117,117,0,112,102,107,101,121,0,112,102,108,111,99,0,112,102,120,0,109,99,48,0,109,99,52,0,109,99,53,0,114,101,112,0,114,115,49,0,114,115,50,0,114,115,51,0,114,102,0,114,99,0,118,112,97,0,115,99,0,105,110,100,0,114,105,0,115,103,114,0,104,116,115,0,119,105,110,100,0,104,116,0,116,115,108,0,117,99,0,104,117,0,105,112,114,111,103,0,107,97,49,0,107,97,51,0,107,98,50,0,107,99,49,0,107,99,51,0,109,99,53,112,0,114,109,112,0,97,99,115,99,0,112,108,110,0,107,99,98,116,0,115,109,120,111,110,0,114,109,120,111,110,0,115,109,97,109,0,114,109,97,109,0,120,111,110,99,0,120,111,102,102,99,0,101,110,97,99,115,0,115,109,108,110,0,114,109,108,110,0,107,98,101,103,0,107,99,97,110,0,107,99,108,111,0,107,99,109,100,0,107,99,112,121,0,107,99,114,116,0,107,101,110,100,0,107,101,110,116,0,107,101,120,116,0,107,102,110,100,0,107,104,108,112,0,107,109,114,107,0,107,109,115,103,0,107,109,111,118,0,107,110,120,116,0,107,111,112,110,0,107,111,112,116,0,107,112,114,118,0,107,112,114,116,0,107,114,100,111,0,107,114,101,102,0,107,114,102,114,0,107,114,112,108,0,107,114,115,116,0,107,114,101,115,0,107,115,97,118,0,107,115,112,100,0,107,117,110,100,0,107,66,69,71,0,107,67,65,78,0,107,67,77,68,0,107,67,80,89,0,107,67,82,84,0,107,68,67,0,107,68,76,0,107,115,108,116,0,107,69,78,68,0,107,69,79,76,0,107,69,88,84,0,107,70,78,68,0,107,72,76,80,0,107,72,79,77,0,107,73,67,0,107,76,70,84,0,107,77,83,71,0,107,77,79,86,0,107,78,88,84,0,107,79,80,84,0,107,80,82,86,0,107,80,82,84,0,107,82,68,79,0,107,82,80,76,0,107,82,73,84,0,107,82,69,83,0,107,83,65,86,0,107,83,80,68,0,107,85,78,68,0,114,102,105,0,107,102,49,49,0,107,102,49,50,0,107,102,49,51,0,107,102,49,52,0,107,102,49,53,0,107,102,49,54,0,107,102,49,55,0,107,102,49,56,0,107,102,49,57,0,107,102,50,48,0,107,102,50,49,0,107,102,50,50,0,107,102,50,51,0,107,102,50,52,0,107,102,50,53,0,107,102,50,54,0,107,102,50,55,0,107,102,50,56,0,107,102,50,57,0,107,102,51,48,0,107,102,51,49,0,107,102,51,50,0,107,102,51,51,0,107,102,51,52,0,107,102,51,53,0,107,102,51,54,0,107,102,51,55,0,107,102,51,56,0,107,102,51,57,0,107,102,52,48,0,107,102,52,49,0,107,102,52,50,0,107,102,52,51,0,107,102,52,52,0,107,102,52,53,0,107,102,52,54,0,107,102,52,55,0,107,102,52,56,0,107,102,52,57,0,107,102,53,48,0,107,102,53,49,0,107,102,53,50,0,107,102,53,51,0,107,102,53,52,0,107,102,53,53,0,107,102,53,54,0,107,102,53,55,0,107,102,53,56,0,107,102,53,57,0,107,102,54,48,0,107,102,54,49,0,107,102,54,50,0,107,102,54,51,0,101,108,49,0,109,103,99,0,115,109,103,108,0,115,109,103,114,0,102,108,110,0,115,99,108,107,0,100,99,108,107,0,114,109,99,108,107,0,99,119,105,110,0,119,105,110,103,111,0,104,117,112,0,100,105,97,108,0,113,100,105,97,108,0,116,111,110,101,0,112,117,108,115,101,0,104,111,111,107,0,112,97,117,115,101,0,119,97,105,116,0,117,48,0,117,49,0,117,50,0,117,51,0,117,52,0,117,53,0,117,54,0,117,55,0,117,56,0,117,57,0,111,112,0,111,99,0,105,110,105,116,99,0,105,110,105,116,112,0,115,99,112,0,115,101,116,102,0,115,101,116,98,0,99,112,105,0,108,112,105,0,99,104,114,0,99,118,114,0,100,101,102,99,0,115,119,105,100,109,0,115,100,114,102,113,0,115,105,116,109,0,115,108,109,0,115,109,105,99,109,0,115,110,108,113,0,115,110,114,109,113,0,115,115,104,109,0,115,115,117,98,109,0,115,115,117,112,109,0,115,117,109,0,114,119,105,100,109,0,114,105,116,109,0,114,108,109,0,114,109,105,99,109,0,114,115,104,109,0,114,115,117,98,109,0,114,115,117,112,109,0,114,117,109,0,109,104,112,97,0,109,99,117,100,49,0,109,99,117,98,49,0,109,99,117,102,49,0,109,118,112,97,0,109,99,117,117,49,0,112,111,114,100,101,114,0,109,99,117,100,0,109,99,117,98,0,109,99,117,102,0,109,99,117,117,0,115,99,115,0,115,109,103,98,0,115,109,103,98,112,0,115,109,103,108,112,0,115,109,103,114,112,0,115,109,103,116,0,115,109,103,116,112,0,115,98,105,109,0,115,99,115,100,0,114,98,105,109,0,114,99,115,100,0,115,117,98,99,115,0,115,117,112,99,115,0,100,111,99,114,0,122,101,114,111,109,0,99,115,110,109,0,107,109,111,117,115,0,109,105,110,102,111,0,114,101,113,109,112,0,103,101,116,109,0,115,101,116,97,102,0,115,101,116,97,98,0,112,102,120,108,0,100,101,118,116,0,99,115,105,110,0,115,48,100,115,0,115,49,100,115,0,115,50,100,115,0,115,51,100,115,0,115,109,103,108,114,0,115,109,103,116,98,0,98,105,114,101,112,0,98,105,110,101,108,0,98,105,99,114,0,99,111,108,111,114,110,109,0,100,101,102,98,105,0,101,110,100,98,105,0,115,101,116,99,111,108,111,114,0,115,108,105,110,101,115,0,100,105,115,112,99,0,115,109,112,99,104,0,114,109,112,99,104,0,115,109,115,99,0,114,109,115,99,0,112,99,116,114,109,0,115,99,101,115,99,0,115,99,101,115,97,0,101,104,104,108,109,0,101,108,104,108,109,0,101,108,111,104,108,109,0,101,114,104,108,109,0,101,116,104,108,109,0,101,118,104,108,109,0,115,103,114,49,0,115,108,101,110,103,116,104,0,79,84,105,50,0,79,84,114,115,0,79,84,117,103,0,79,84,98,115,0,79,84,110,115,0,79,84,110,99,0,79,84,100,67,0,79,84,100,78,0,79,84,110,108,0,79,84,98,99,0,79,84,77,84,0,79,84,78,76,0,79,84,100,66,0,79,84,100,84,0,79,84,107,110,0,79,84,107,111,0,79,84,109,97,0,79,84,112,116,0,79,84,120,114,0,79,84,71,50,0,79,84,71,51,0,79,84,71,49,0,79,84,71,52,0,79,84,71,82,0,79,84,71,76,0,79,84,71,85,0,79,84,71,68,0,79,84,71,72,0,79,84,71,86,0,79,84,71,67,0,109,101,109,108,0,109,101,109,117,0,98,111,120,49,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,3,0,0,0,0,0,0,0,1,0,255,255,6,0,0,0,0,0,0,0,2,0,255,255,10,0,0,0,0,0,0,0,3,0,255,255,14,0,0,0,0,0,0,0,4,0,255,255,19,0,0,0,0,0,0,0,5,0,255,255,22,0,0,0,0,0,0,0,6,0,255,255,25,0,0,0,0,0,0,0,7,0,255,255,28,0,0,0,0,0,0,0,8,0,255,255,31,0,0,0,0,0,0,0,9,0,255,255,34,0,0,0,0,0,0,0,10,0,255,255,37,0,0,0,0,0,0,0,11,0,255,255,40,0,0,0,0,0,0,0,12,0,255,255,43,0,0,0,0,0,0,0,13,0,255,255,47,0,0,0,0,0,0,0,14,0,255,255,52,0,0,0,0,0,0,0,15,0,255,255,55,0,0,0,0,0,0,0,16,0,255,255,61,0,0,0,0,0,0,0,17,0,255,255,64,0,0,0,0,0,0,0,18,0,255,255,67,0,0,0,0,0,0,0,19,0,255,255,70,0,0,0,0,0,0,0,20,0,255,255,74,0,0,0,0,0,0,0,21,0,255,255,79,0,0,0,0,0,0,0,22,0,255,255,84,0,0,0,0,0,0,0,23,0,255,255,89,0,0,0,0,0,0,0,24,0,255,255,95,0,0,0,0,0,0,0,25,0,255,255,99,0,0,0,0,0,0,0,26,0,255,255,105,0,0,0,0,0,0,0,27,0,255,255,109,0,0,0,0,0,0,0,28,0,255,255,113,0,0,0,0,0,0,0,29,0,255,255,117,0,0,0,0,0,0,0,30,0,255,255,122,0,0,0,0,0,0,0,31,0,255,255,127,0,0,0,0,0,0,0,32,0,255,255,133,0,0,0,0,0,0,0,33,0,255,255,138,0,0,0,0,0,0,0,34,0,255,255,142,0,0,0,0,0,0,0,35,0,255,255,147,0,0,0,0,0,0,0,36,0,255,255,152,0,0,0,1,0,0,0,0,0,255,255,157,0,0,0,1,0,0,0,1,0,255,255,160,0,0,0,1,0,0,0,2,0,6,0,166,0,0,0,1,0,0,0,3,0,255,255,169,0,0,0,1,0,0,0,4,0,255,255,173,0,0,0,1,0,0,0,5,0,255,255,176,0,0,0,1,0,0,0,6,0,255,255,179,0,0,0,1,0,0,0,7,0,255,255,183,0,0,0,1,0,0,0,8,0,255,255,188,0,0,0,1,0,0,0,9,0,255,255,191,0,0,0,1,0,0,0,10,0,255,255,194,0,0,0,1,0,0,0,11,0,255,255,197,0,0,0,1,0,0,0,12,0,255,255,202,0,0,0,1,0,0,0,13,0,255,255,209,0,0,0,1,0,0,0,14,0,255,255,215,0,0,0,1,0,0,0,15,0,255,255,219,0,0,0,1,0,0,0,16,0,46,0,225,0,0,0,1,0,0,0,17,0,255,255,231,0,0,0,1,0,0,0,18,0,255,255,237,0,0,0,1,0,0,0,19,0,255,255,243,0,0,0,1,0,0,0,20,0,255,255,249,0,0,0,1,0,0,0,21,0,255,255,253,0,0,0,1,0,0,0,22,0,255,255,1,1,0,0,1,0,0,0,23,0,255,255,7,1,0,0,1,0,0,0,24,0,255,255,11,1,0,0,1,0,0,0,25,0,255,255,15,1,0,0,1,0,0,0,26,0,255,255,20,1,0,0,1,0,0,0,27,0,255,255,25,1,0,0,1,0,0,0,28,0,255,255,29,1,0,0,1,0,0,0,29,0,255,255,35,1,0,0,1,0,0,0,30,0,255,255,40,1,0,0,1,0,0,0,31,0,255,255,47,1,0,0,1,0,0,0,32,0,68,0,54,1,0,0,2,0,0,0,0,0,255,255,58,1,0,0,2,0,0,0,1,0,255,255,62,1,0,0,2,0,0,0,2,0,255,255,65,1,0,0,2,0,0,0,3,0,255,255,69,1,0,0,2,0,0,0,4,0,255,255,73,1,0,0,2,0,0,0,5,0,255,255,79,1,0,0,2,0,0,0,6,0,255,255,82,1,0,0,2,0,0,0,7,0,255,255,85,1,0,0,2,0,0,0,8,0,255,255,89,1,0,0,2,0,0,0,9,0,255,255,95,1,0,0,2,0,0,0,10,0,73,0,99,1,0,0,2,0,0,0,11,0,255,255,104,1,0,0,2,0,0,0,12,0,255,255,109,1,0,0,2,0,0,0,13,0,255,255,115,1,0,0,2,0,0,0,14,0,255,255,120,1,0,0,2,0,0,0,15,0,255,255,126,1,0,0,2,0,0,0,16,0,255,255,132,1,0,0,2,0,0,0,17,0,255,255,137,1,0,0,2,0,0,0,18,0,255,255,140,1,0,0,2,0,0,0,19,0,255,255,145,1,0,0,2,0,0,0,20,0,255,255,151,1,0,0,2,0,0,0,21,0,255,255,156,1,0,0,2,0,0,0,22,0,255,255,160,1,0,0,2,0,0,0,23,0,255,255,164,1,0,0,2,0,0,0,24,0,255,255,167,1,0,0,2,0,0,0,25,0,255,255,173,1,0,0,2,0,0,0,26,0,255,255,179,1,0,0,2,0,0,0,27,0,255,255,184,1,0,0,2,0,0,0,28,0,255,255,190,1,0,0,2,0,0,0,29,0,255,255,195,1,0,0,2,0,0,0,30,0,255,255,199,1,0,0,2,0,0,0,31,0,255,255,204,1,0,0,2,0,0,0,32,0,255,255,210,1,0,0,2,0,0,0,33,0,255,255,215,1,0,0,2,0,0,0,34,0,255,255,219,1,0,0,2,0,0,0,35,0,255,255,224,1,0,0,2,0,0,0,36,0,255,255,229,1,0,0,2,0,0,0,37,0,255,255,233,1,0,0,2,0,0,0,38,0,255,255,239,1,0,0,2,0,0,0,39,0,255,255,244,1,0,0,2,0,0,0,40,0,255,255,250,1,0,0,2,0,0,0,41,0,255,255,255,1,0,0,2,0,0,0,42,0,255,255,4,2,0,0,2,0,0,0,43,0,255,255,9,2,0,0,2,0,0,0,44,0,255,255,14,2,0,0,2,0,0,0,45,0,255,255,20,2,0,0,2,0,0,0,46,0,255,255,23,2,0,0,2,0,0,0,47,0,255,255,27,2,0,0,2,0,0,0,48,0,255,255,31,2,0,0,2,0,0,0,49,0,59,0,35,2,0,0,2,0,0,0,50,0,76,0,39,2,0,0,2,0,0,0,51,0,255,255,42,2,0,0,2,0,0,0,52,0,20,0,47,2,0,0,2,0,0,0,53,0,255,255,51,2,0,0,2,0,0,0,54,0,255,255,54,2,0,0,2,0,0,0,55,0,255,255,58,2,0,0,2,0,0,0,56,0,255,255,63,2,0,0,2,0,0,0,57,0,98,0,68,2,0,0,2,0,0,0,58,0,255,255,74,2,0,0,2,0,0,0,59,0,255,255,80,2,0,0,2,0,0,0,60,0,255,255,85,2,0,0,2,0,0,0,61,0,255,255,91,2,0,0,2,0,0,0,62,0,255,255,97,2,0,0,2,0,0,0,63,0,255,255,101,2,0,0,2,0,0,0,64,0,255,255,105,2,0,0,2,0,0,0,65,0,255,255,109,2,0,0,2,0,0,0,66,0,255,255,113,2,0,0,2,0,0,0,67,0,255,255,118,2,0,0,2,0,0,0,68,0,255,255,122,2,0,0,2,0,0,0,69,0,255,255,126,2,0,0,2,0,0,0,70,0,255,255,130,2,0,0,2,0,0,0,71,0,61,0,134,2,0,0,2,0,0,0,72,0,255,255,138,2,0,0,2,0,0,0,73,0,255,255,142,2,0,0,2,0,0,0,74,0,255,255,146,2,0,0,2,0,0,0,75,0,255,255,150,2,0,0,2,0,0,0,76,0,255,255,156,2,0,0,2,0,0,0,77,0,255,255,162,2,0,0,2,0,0,0,78,0,255,255,167,2,0,0,2,0,0,0,79,0,255,255,173,2,0,0,2,0,0,0,80,0,255,255,177,2,0,0,2,0,0,0,81,0,255,255,181,2,0,0,2,0,0,0,82,0,255,255,185,2,0,0,2,0,0,0,83,0,255,255,191,2,0,0,2,0,0,0,84,0,55,0,196,2,0,0,2,0,0,0,85,0,105,0,200,2,0,0,2,0,0,0,86,0,255,255,205,2,0,0,2,0,0,0,87,0,81,0,211,2,0,0,2,0,0,0,88,0,255,255,216,2,0,0,2,0,0,0,89,0,255,255,221,2,0,0,2,0,0,0,90,0,255,255,225,2,0,0,2,0,0,0,91,0,255,255,229,2,0,0,2,0,0,0,92,0,255,255,234,2,0,0,2,0,0,0,93,0,255,255,238,2,0,0,2,0,0,0,94,0,33,0,242,2,0,0,2,0,0,0,95,0,255,255,246,2,0,0,2,0,0,0,96,0,255,255,250,2,0,0,2,0,0,0,97,0,255,255,254,2,0,0,2,0,0,0,98,0,7,0,2,3,0,0,2,0,0,0,99,0,94,0,6,3,0,0,2,0,0,0,100,0,255,255,10,3,0,0,2,0,0,0,101,0,131,0,14,3,0,0,2,0,0,0,102,0,255,255,18,3,0,0,2,0,0,0,103,0,255,255,22,3,0,0,2,0,0,0,104,0,30,0,26,3,0,0,2,0,0,0,105,0,255,255,30,3,0,0,2,0,0,0,106,0,255,255,33,3,0,0,2,0,0,0,107,0,255,255,37,3,0,0,2,0,0,0,108,0,255,255,41,3,0,0,2,0,0,0,109,0,255,255,46,3,0,0,2,0,0,0,110,0,255,255,49,3,0,0,2,0,0,0,111,0,255,255,53,3,0,0,2,0,0,0,112,0,156,0,57,3,0,0,2,0,0,0,113,0,255,255,61,3,0,0,2,0,0,0,114,0,255,255,65,3,0,0,2,0,0,0,115,0,51,0,71,3,0,0,2,0,0,0,116,0,255,255,77,3,0,0,2,0,0,0,117,0,255,255,81,3,0,0,2,0,0,0,118,0,255,255,85,3,0,0,2,0,0,0,119,0,255,255,89,3,0,0,2,0,0,0,120,0,255,255,93,3,0,0,2,0,0,0,121,0,255,255,97,3,0,0,2,0,0,0,122,0,255,255,101,3,0,0,2,0,0,0,123,0,255,255,105,3,0,0,2,0,0,0,124,0,126,0,109,3,0,0,2,0,0,0,125,0,255,255,112,3,0,0,2,0,0,0,126,0,255,255,115,3,0,0,2,0,0,0,127,0,255,255,119,3,0,0,2,0,0,0,128,0,255,255,122,3,0,0,2,0,0,0,129,0,255,255,126,3,0,0,2,0,0,0,130,0,255,255,129,3,0,0,2,0,0,0,131,0,255,255,133,3,0,0,2,0,0,0,132,0,255,255,137,3,0,0,2,0,0,0,133,0,255,255,142,3,0,0,2,0,0,0,134,0,255,255,145,3,0,0,2,0,0,0,135,0,255,255,149,3,0,0,2,0,0,0,136,0,23,0,152,3,0,0,2,0,0,0,137,0,255,255,155,3,0,0,2,0,0,0,138,0,255,255,161,3,0,0,2,0,0,0,139,0,255,255,165,3,0,0,2,0,0,0,140,0,255,255,169,3,0,0,2,0,0,0,141,0,210,0,173,3,0,0,2,0,0,0,142,0,211,0,177,3,0,0,2,0,0,0,143,0,135,0,181,3,0,0,2,0,0,0,144,0,255,255,186,3,0,0,2,0,0,0,145,0,255,255,190,3,0,0,2,0,0,0,146,0,176,0,195,3,0,0,2,0,0,0,147,0,255,255,199,3,0,0,2,0,0,0,148,0,194,0,204,3,0,0,2,0,0,0,149,0,255,255,210,3,0,0,2,0,0,0,150,0,255,255,216,3,0,0,2,0,0,0,151,0,137,0,221,3,0,0,2,0,0,0,152,0,255,255,226,3,0,0,2,0,0,0,153,0,255,255,231,3,0,0,2,0,0,0,154,0,255,255,237,3,0,0,2,0,0,0,155,0,255,255,243,3,0,0,2,0,0,0,156,0,255,255,248,3,0,0,2,0,0,0,157,0,255,255,253,3,0,0,2,0,0,0,158,0,255,255,2,4,0,0,2,0,0,0,159,0,255,255,7,4,0,0,2,0,0,0,160,0,255,255,12,4,0,0,2,0,0,0,161,0,255,255,17,4,0,0,2,0,0,0,162,0,255,255,22,4,0,0,2,0,0,0,163,0,54,0,27,4,0,0,2,0,0,0,164,0,192,0,32,4,0,0,2,0,0,0,165,0,255,255,37,4,0,0,2,0,0,0,166,0,255,255,42,4,0,0,2,0,0,0,167,0,193,0,47,4,0,0,2,0,0,0,168,0,255,255,52,4,0,0,2,0,0,0,169,0,70,0,57,4,0,0,2,0,0,0,170,0,235,0,62,4,0,0,2,0,0,0,171,0,255,255,67,4,0,0,2,0,0,0,172,0,255,255,72,4,0,0,2,0,0,0,173,0,177,0,77,4,0,0,2,0,0,0,174,0,255,255,82,4,0,0,2,0,0,0,175,0,255,255,87,4,0,0,2,0,0,0,176,0,255,255,92,4,0,0,2,0,0,0,177,0,255,255,97,4,0,0,2,0,0,0,178,0,255,255,102,4,0,0,2,0,0,0,179,0,239,0,107,4,0,0,2,0,0,0,180,0,219,0,112,4,0,0,2,0,0,0,181,0,80,0,117,4,0,0,2,0,0,0,182,0,249,0,122,4,0,0,2,0,0,0,183,0,252,0,127,4,0,0,2,0,0,0,184,0,240,0,132,4,0,0,2,0,0,0,185,0,254,0,137,4,0,0,2,0,0,0,186,0,255,255,142,4,0,0,2,0,0,0,187,0,255,255,147,4,0,0,2,0,0,0,188,0,101,0,152,4,0,0,2,0,0,0,189,0,255,255,157,4,0,0,2,0,0,0,190,0,255,255,162,4,0,0,2,0,0,0,191,0,255,255,166,4,0,0,2,0,0,0,192,0,255,255,170,4,0,0,2,0,0,0,193,0,244,0,175,4,0,0,2,0,0,0,194,0,255,255,180,4,0,0,2,0,0,0,195,0,152,0,185,4,0,0,2,0,0,0,196,0,255,255,190,4,0,0,2,0,0,0,197,0,150,0,195,4,0,0,2,0,0,0,198,0,255,255,200,4,0,0,2,0,0,0,199,0,12,1,205,4,0,0,2,0,0,0,200,0,255,255,209,4,0,0,2,0,0,0,201,0,72,0,214,4,0,0,2,0,0,0,202,0,255,255,219,4,0,0,2,0,0,0,203,0,255,255,224,4,0,0,2,0,0,0,204,0,255,255,229,4,0,0,2,0,0,0,205,0,255,255,234,4,0,0,2,0,0,0,206,0,255,255,239,4,0,0,2,0,0,0,207,0,196,0,244,4,0,0,2,0,0,0,208,0,255,255,249,4,0,0,2,0,0,0,209,0,255,255,254,4,0,0,2,0,0,0,210,0,255,255,3,5,0,0,2,0,0,0,211,0,255,255,8,5,0,0,2,0,0,0,212,0,25,1,13,5,0,0,2,0,0,0,213,0,16,1,18,5,0,0,2,0,0,0,214,0,27,1,23,5,0,0,2,0,0,0,215,0,255,255,27,5,0,0,2,0,0,0,216,0,255,255,32,5,0,0,2,0,0,0,217,0,134,0,37,5,0,0,2,0,0,0,218,0,255,255,42,5,0,0,2,0,0,0,219,0,255,255,47,5,0,0,2,0,0,0,220,0,255,255,52,5,0,0,2,0,0,0,221,0,43,0,57,5,0,0,2,0,0,0,222,0,0,1,62,5,0,0,2,0,0,0,223,0,255,255,67,5,0,0,2,0,0,0,224,0,255,255,72,5,0,0,2,0,0,0,225,0,30,1,77,5,0,0,2,0,0,0,226,0,31,1,82,5,0,0,2,0,0,0,227,0,32,1,87,5,0,0,2,0,0,0,228,0,33,1,92,5,0,0,2,0,0,0,229,0,34,1,97,5,0,0,2,0,0,0,230,0,35,1,102,5,0,0,2,0,0,0,231,0,36,1,107,5,0,0,2,0,0,0,232,0,37,1,112,5,0,0,2,0,0,0,233,0,38,1,117,5,0,0,2,0,0,0,234,0,133,0,122,5,0,0,2,0,0,0,235,0,40,1,127,5,0,0,2,0,0,0,236,0,41,1,132,5,0,0,2,0,0,0,237,0,42,1,137,5,0,0,2,0,0,0,238,0,43,1,142,5,0,0,2,0,0,0,239,0,44,1,147,5,0,0,2,0,0,0,240,0,45,1,152,5,0,0,2,0,0,0,241,0,46,1,157,5,0,0,2,0,0,0,242,0,47,1,162,5,0,0,2,0,0,0,243,0,48,1,167,5,0,0,2,0,0,0,244,0,1,1,172,5,0,0,2,0,0,0,245,0,50,1,177,5,0,0,2,0,0,0,246,0,51,1,182,5,0,0,2,0,0,0,247,0,52,1,187,5,0,0,2,0,0,0,248,0,53,1,192,5,0,0,2,0,0,0,249,0,54,1,197,5,0,0,2,0,0,0,250,0,55,1,202,5,0,0,2,0,0,0,251,0,56,1,207,5,0,0,2,0,0,0,252,0,57,1,212,5,0,0,2,0,0,0,253,0,58,1,217,5,0,0,2,0,0,0,254,0,226,0,222,5,0,0,2,0,0,0,255,0,60,1,227,5,0,0,2,0,0,0,0,1,61,1,232,5,0,0,2,0,0,0,1,1,62,1,237,5,0,0,2,0,0,0,2,1,63,1,242,5,0,0,2,0,0,0,3,1,64,1,247,5,0,0,2,0,0,0,4,1,65,1,252,5,0,0,2,0,0,0,5,1,66,1,1,6,0,0,2,0,0,0,6,1,67,1,6,6,0,0,2,0,0,0,7,1,68,1,11,6,0,0,2,0,0,0,8,1,2,1,16,6,0,0,2,0,0,0,9,1,70,1,21,6,0,0,2,0,0,0,10,1,71,1,26,6,0,0,2,0,0,0,11,1,72,1,31,6,0,0,2,0,0,0,12,1,73,1,36,6,0,0,2,0,0,0,13,1,255,255,40,6,0,0,2,0,0,0,14,1,255,255,44,6,0,0,2,0,0,0,15,1,79,1,49,6,0,0,2,0,0,0,16,1,76,1,54,6,0,0,2,0,0,0,17,1,255,255,58,6,0,0,2,0,0,0,18,1,255,255,63,6,0,0,2,0,0,0,19,1,255,255,68,6,0,0,2,0,0,0,20,1,255,255,74,6,0,0,2,0,0,0,21,1,37,0,79,6,0,0,2,0,0,0,22,1,255,255,85,6,0,0,2,0,0,0,23,1,255,255,89,6,0,0,2,0,0,0,24,1,255,255,94,6,0,0,2,0,0,0,25,1,255,255,100,6,0,0,2,0,0,0,26,1,255,255,105,6,0,0,2,0,0,0,27,1,255,255,111,6,0,0,2,0,0,0,28,1,255,255,116,6,0,0,2,0,0,0,29,1,8,0,122,6,0,0,2,0,0,0,30,1,6,1,127,6,0,0,2,0,0,0,31,1,255,255,130,6,0,0,2,0,0,0,32,1,255,255,133,6,0,0,2,0,0,0,33,1,255,255,136,6,0,0,2,0,0,0,34,1,255,255,139,6,0,0,2,0,0,0,35,1,255,255,142,6,0,0,2,0,0,0,36,1,255,255,145,6,0,0,2,0,0,0,37,1,255,255,148,6,0,0,2,0,0,0,38,1,255,255,151,6,0,0,2,0,0,0,39,1,255,255,154,6,0,0,2,0,0,0,40,1,255,255,157,6,0,0,2,0,0,0,41,1,255,255,160,6,0,0,2,0,0,0,42,1,255,255,163,6,0,0,2,0,0,0,43,1,255,255,169,6,0,0,2,0,0,0,44,1,255,255,175,6,0,0,2,0,0,0,45,1,255,255,179,6,0,0,2,0,0,0,46,1,69,1,184,6,0,0,2,0,0,0,47,1,221,0,189,6,0,0,2,0,0,0,48,1,243,0,193,6,0,0,2,0,0,0,49,1,255,255,197,6,0,0,2,0,0,0,50,1,250,0,201,6,0,0,2,0,0,0,51,1,255,255,205,6,0,0,2,0,0,0,52,1,141,0,210,6,0,0,2,0,0,0,53,1,248,0,216,6,0,0,2,0,0,0,54,1,218,0,222,6,0,0,2,0,0,0,55,1,255,255,227,6,0,0,2,0,0,0,56,1,201,0,231,6,0,0,2,0,0,0,57,1,229,0,237,6,0,0,2,0,0,0,58,1,8,1,242,6,0,0,2,0,0,0,59,1,253,0,248,6,0,0,2,0,0,0,60,1,78,1,253,6,0,0,2,0,0,0,61,1,255,255,3,7,0,0,2,0,0,0,62,1,236,0,9,7,0,0,2,0,0,0,63,1,185,0,13,7,0,0,2,0,0,0,64,1,255,255,19,7,0,0,2,0,0,0,65,1,255,255,24,7,0,0,2,0,0,0,66,1,255,255,28,7,0,0,2,0,0,0,67,1,255,255,34,7,0,0,2,0,0,0,68,1,112,0,39,7,0,0,2,0,0,0,69,1,255,255,45,7,0,0,2,0,0,0,70,1,255,255,51,7,0,0,2,0,0,0,71,1,255,255,55,7,0,0,2,0,0,0,72,1,255,255,60,7,0,0,2,0,0,0,73,1,255,255,66,7,0,0,2,0,0,0,74,1,255,255,72,7,0,0,2,0,0,0,75,1,53,0,78,7,0,0,2,0,0,0,76,1,255,255,83,7,0,0,2,0,0,0,77,1,47,0,89,7,0,0,2,0,0,0,78,1,155,0,96,7,0,0,2,0,0,0,79,1,255,255,101,7,0,0,2,0,0,0,80,1,255,255,106,7,0,0,2,0,0,0,81,1,255,255,111,7,0,0,2,0,0,0,82,1,255,255,116,7,0,0,2,0,0,0,83,1,255,255,120,7,0,0,2,0,0,0,84,1,255,255,125,7,0,0,2,0,0,0,85,1,127,1,131,7,0,0,2,0,0,0,86,1,255,255,137,7,0,0,2,0,0,0,87,1,255,255,143,7,0,0,2,0,0,0,88,1,130,1,148,7,0,0,2,0,0,0,89,1,238,0,154,7,0,0,2,0,0,0,90,1,255,255,159,7,0,0,2,0,0,0,91,1,88,1,164,7,0,0,2,0,0,0,92,1,31,0,169,7,0,0,2,0,0,0,93,1,255,255,174,7,0,0,2,0,0,0,94,1,124,1,180,7,0,0,2,0,0,0,95,1,255,0,186,7,0,0,2,0,0,0,96,1,255,255,191,7,0,0,2,0,0,0,97,1,255,255,197,7,0,0,2,0,0,0,98,1,91,1,202,7,0,0,2,0,0,0,99,1,255,255,208,7,0,0,2,0,0,0,100,1,255,255,214,7,0,0,2,0,0,0,101,1,255,255,220,7,0,0,2,0,0,0,102,1,87,0,225,7,0,0,2,0,0,0,103,1,255,255,231,7,0,0,2,0,0,0,104,1,255,255,237,7,0,0,2,0,0,0,105,1,255,255,242,7,0,0,2,0,0,0,106,1,255,255,247,7,0,0,2,0,0,0,107,1,255,255,252,7,0,0,2,0,0,0,108,1,255,255,1,8,0,0,2,0,0,0,109,1,212,0,6,8,0,0,2,0,0,0,110,1,109,0,11,8,0,0,2,0,0,0,111,1,213,0,16,8,0,0,2,0,0,0,112,1,230,0,22,8,0,0,2,0,0,0,113,1,255,255,28,8,0,0,2,0,0,0,114,1,255,255,34,8,0,0,2,0,0,0,115,1,255,255,40,8,0,0,2,0,0,0,116,1,255,255,45,8,0,0,2,0,0,0,117,1,255,255,53,8,0,0,2,0,0,0,118,1,255,255,59,8,0,0,2,0,0,0,119,1,255,255,65,8,0,0,2,0,0,0,120,1,255,255,74,8,0,0,2,0,0,0,121,1,116,0,81,8,0,0,2,0,0,0,122,1,255,255,87,8,0,0,2,0,0,0,123,1,231,0,93,8,0,0,2,0,0,0,124,1,255,255,99,8,0,0,2,0,0,0,125,1,82,1,104,8,0,0,2,0,0,0,126,1,255,255,109,8,0,0,2,0,0,0,127,1,255,255,115,8,0,0,2,0,0,0,128,1,197,0,121,8,0,0,2,0,0,0,129,1,174,1,127,8,0,0,2,0,0,0,130,1,255,255,133,8,0,0,2,0,0,0,131,1,255,255,139,8,0,0,2,0,0,0,132,1,255,255,146,8,0,0,2,0,0,0,133,1,255,255,152,8,0,0,2,0,0,0,134,1,255,255,158,8,0,0,2,0,0,0,135,1,255,255,164,8,0,0,2,0,0,0,136,1,181,1,169,8,0,0,2,0,0,0,137,1,255,255,177,8,0,0,2,0,0,0,138,1,255,255,182,8,0,0,2,0,0,0,139,1,255,255,187,8,0,0,1,0,0,0,33,0,255,255,192,8,0,0,0,0,0,0,37,0,255,255,197,8,0,0,0,0,0,0,38,0,255,255,202,8,0,0,0,0,0,0,39,0,255,255,207,8,0,0,1,0,0,0,34,0,255,255,212,8,0,0,1,0,0,0,35,0,255,255,217,8,0,0,2,0,0,0,140,1,255,255,222,8,0,0,2,0,0,0,141,1,13,0,227,8,0,0,0,0,0,0,40,0,255,255,232,8,0,0,0,0,0,0,41,0,190,1,237,8,0,0,1,0,0,0,36,0,255,255,242,8,0,0,1,0,0,0,37,0,255,255,247,8,0,0,1,0,0,0,38,0,255,255,252,8,0,0,2,0,0,0,142,1,216,1,1,9,0,0,2,0,0,0,143,1,255,255,6,9,0,0,0,0,0,0,42,0,255,255,11,9,0,0,0,0,0,0,43,0,255,255,16,9,0,0,2,0,0,0,144,1,255,255,21,9,0,0,2,0,0,0,145,1,255,255,26,9,0,0,2,0,0,0,146,1,255,255,31,9,0,0,2,0,0,0,147,1,255,255,36,9,0,0,2,0,0,0,148,1,255,255,41,9,0,0,2,0,0,0,149,1,255,255,46,9,0,0,2,0,0,0,150,1,255,255,51,9,0,0,2,0,0,0,151,1,255,255,56,9,0,0,2,0,0,0,152,1,26,0,61,9,0,0,2,0,0,0,153,1,60,0,66,9,0,0,2,0,0,0,154,1,121,0,71,9,0,0,2,0,0,0,155,1,151,1,76,9,0,0,2,0,0,0,156,1,146,1,81,9,0,0,2,0,0,0,157,1,255,255,0,0,0,0,253,0,255,255,45,0,211,0,7,1,255,255,255,255,255,255,255,255,255,255,255,255,193,1,201,1,55,1,155,1,255,255,132,0,255,255,255,255,255,255,255,255,123,0,71,0,75,0,92,0,171,1,233,0,255,255,80,1,255,255,255,255,114,1,35,1,238,1,216,1,138,0,186,0,255,255,255,255,255,255], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+44536);
/* memory initializer */ allocate([255,255,19,0,193,0,180,1,175,1,197,1,255,255,59,1,233,1,93,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,97,1,255,255,255,255,255,255,255,255,255,255,124,0,255,255,255,255,255,255,138,1,255,255,111,1,167,0,255,255,191,0,115,1,255,255,89,0,255,255,255,255,255,255,107,1,204,1,63,1,163,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,70,0,74,0,255,255,255,255,255,255,255,255,255,255,38,0,255,255,128,0,255,255,142,1,255,255,255,255,225,1,255,255,255,255,202,0,255,255,28,0,43,0,255,255,17,0,255,255,255,255,188,1,167,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,240,1,255,255,255,255,255,255,255,255,174,1,255,255,255,255,255,255,255,255,40,1,255,255,21,0,255,255,187,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,65,1,20,1,255,255,255,255,31,0,119,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,173,1,220,1,255,255,255,255,255,255,44,1,144,1,255,255,218,0,255,255,255,255,227,0,255,255,255,255,255,255,255,255,11,0,29,1,179,0,255,255,69,1,24,1,255,255,224,0,162,0,224,1,255,255,255,255,51,0,255,255,255,255,201,0,204,0,255,255,255,255,255,255,255,255,22,0,255,255,48,1,148,1,255,255,154,0,255,255,255,255,255,255,255,255,108,0,255,255,76,0,255,255,255,255,255,255,255,255,73,1,28,1,255,255,14,1,84,0,127,1,250,0,170,1,255,255,255,255,4,1,113,0,110,0,114,0,86,0,255,255,255,255,255,255,255,255,52,1,152,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,177,1,255,255,112,0,230,0,255,255,77,1,172,1,255,255,223,0,32,1,228,1,254,0,255,255,255,255,210,0,8,1,255,255,98,0,255,255,83,0,215,1,255,255,194,1,255,255,56,1,231,1,255,255,151,0,255,255,255,255,255,255,86,1,24,0,255,255,80,0,99,0,255,255,234,0,255,255,81,1,101,0,255,255,8,0,36,1,135,1,255,255,139,0,164,0,255,255,255,255,255,255,255,255,255,255,194,0,181,1,255,255,198,1,255,255,60,1,236,1,255,255,155,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,139,1,255,255,143,0,168,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,108,1,255,255,64,1,164,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,207,0,255,255,255,255,157,0,191,1,239,1,255,255,137,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,184,1,189,1,168,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,79,0,175,0,255,255,41,1,237,1,23,0,178,0,255,255,255,255,255,255,84,1,52,0,255,255,255,255,255,255,90,1,88,1,255,255,66,1,21,1,255,255,255,255,32,0,120,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,117,1,255,255,214,1,255,255,255,255,255,255,45,1,145,1,255,255,127,0,255,255,255,255,255,255,255,255,255,255,255,255,83,1,12,0,255,255,255,255,255,255,70,1,25,1,92,1,125,0,36,0,124,1,87,1,255,255,42,0,255,255,11,1,255,255,255,255,116,1,115,0,255,255,2,0,89,1,255,255,49,1,149,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,237,0,255,255,74,1,121,0,255,255,15,1,255,255,128,1,251,0,255,255,189,0,255,255,5,1,199,0,255,255,255,255,255,255,255,255,255,255,177,0,255,255,53,1,153,1,255,255,255,255,255,255,255,255,226,0,255,255,255,255,255,255,255,255,255,255,255,255,231,0,96,1,78,1,255,255,255,255,255,255,33,1,230,1,255,0,135,0,160,0,212,0,9,1,255,255,255,255,255,255,255,255,178,1,255,255,195,1,255,255,57,1,157,1,255,255,255,255,255,255,255,255,255,255,255,255,214,0,255,255,255,255,255,255,255,255,235,0,6,0,82,1,10,0,255,255,222,1,37,1,136,1,255,255,140,0,217,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,91,1,199,1,203,1,61,1,161,1,255,255,134,0,255,255,255,255,255,255,49,0,255,255,255,255,72,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,153,0,255,255,140,1,255,255,144,0,169,0,255,255,255,255,200,0,255,255,255,255,255,255,255,255,226,1,109,1,205,1,186,1,165,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,197,0,176,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,190,1,185,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,18,0,255,255,255,255,255,255,42,1,234,1,255,255,255,255,255,255,255,255,255,255,255,255,26,0,255,255,255,255,95,1,255,255,255,255,255,255,67,1,22,1,255,255,113,1,33,0,121,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,46,1,235,1,255,255,129,0,255,255,255,255,255,255,255,255,216,0,217,1,27,0,91,0,107,0,255,255,255,255,71,1,26,1,255,255,12,1,255,255,125,1,213,1,112,1,174,0,255,255,2,1,198,0,255,255,206,0,180,0,255,255,255,255,176,0,255,255,50,1,232,1,255,255,150,0,255,255,255,255,255,255,182,1,219,1,255,255,255,255,255,255,255,255,228,0,255,255,75,1,255,255,255,255,255,255,30,1,229,1,252,0,255,255,255,255,209,0,6,1,41,0,255,255,210,1,255,255,255,255,255,255,192,1,255,255,54,1,154,1,255,255,130,0,255,255,255,255,255,255,255,255,25,0,255,255,255,255,207,1,50,0,232,0,255,255,79,1,255,255,255,255,255,255,34,1,133,1,0,1,136,0,185,0,213,0,10,1,255,255,255,255,255,255,192,0,179,1,255,255,196,1,202,1,58,1,158,1,255,255,152,0,255,255,255,255,255,255,218,1,255,255,255,255,215,0,81,0,5,0,236,0,255,255,82,0,255,255,255,255,223,1,38,1,137,1,255,255,141,0,190,0,255,255,255,255,105,0,255,255,255,255,255,255,221,1,20,0,106,1,255,255,62,1,162,1,255,255,156,0,255,255,255,255,255,255,255,255,95,0,211,1,73,0,93,0,220,0,219,0,255,255,9,0,119,0,255,255,159,0,255,255,141,1,212,1,145,0,188,0,255,255,209,1,255,255,205,0,106,0,90,0,44,0,3,0,110,1,255,255,187,1,166,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,39,1,255,255,173,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,99,1,255,255,222,0,221,0,255,255,255,255,19,1,100,1,255,255,30,0,118,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,225,0,255,255,255,255,43,1,255,255,255,255,148,0,255,255,255,255,181,0,255,255,255,255,255,255,255,255,206,1,255,255,255,255,255,255,68,1,23,1,255,255,255,255,34,0,122,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,94,1,255,255,47,1,147,1,255,255,133,0,255,255,255,255,255,255,255,255,255,255,255,255,77,0,255,255,182,0,255,255,255,255,72,1,27,1,255,255,13,1,255,255,126,1,249,0,255,255,255,255,255,255,3,1,255,255,255,255,255,255,255,255,255,255,85,0,255,255,200,1,51,1,151,1,255,255,147,0,255,255,255,255,255,255,255,255,255,255,255,255,78,0,255,255,255,255,98,1,255,255,76,1,255,255,255,255,146,0,31,1,227,1,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,209,1,255,255,255,255,255,255,255,255,255,255,5,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,201,1,255,255,255,255,9,1,216,0,120,0,255,255,255,255,255,255,180,0,255,255,255,255,88,0,255,255,164,1,255,255,142,1,255,255,92,1,255,255,255,255,19,0,255,255,255,255,255,255,103,1,255,255,174,0,255,255,245,0,255,255,74,0,255,255,255,255,255,255,255,255,255,255,13,1,255,255,224,1,255,255,255,255,255,255,124,0,255,255,255,255,255,255,134,1,123,1,111,1,255,255,255,255,188,1,255,255,255,255,255,255,49,1,255,255,255,255,107,1,255,255,255,255,227,1,121,1,255,255,255,255,255,255,255,255,204,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,204,0,38,0,255,255,82,0,255,255,110,0,127,0,255,255,255,255,207,1,255,255,255,255,255,255,255,255,80,1,255,255,17,0,128,0,178,1,255,255,188,0,129,0,255,255,95,1,255,255,255,255,16,0,255,255,255,255,3,1,255,255,255,255,255,255,255,255,255,255,233,1,255,255,97,1,255,255,71,0,247,0,255,255,255,255,255,255,255,255,78,0,255,255,255,255,75,1,255,255,255,255,173,0,136,0,161,0,189,0,255,255,255,255,255,255,255,255,198,1,255,255,255,255,255,255,255,255,224,0,223,1,255,255,255,255,255,255,255,255,255,255,98,1,255,255,255,255,233,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,125,0,11,0,255,255,255,255,122,1,166,0,255,255,191,0,255,255,255,255,48,0,228,0,255,255,2,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,118,1,255,255,152,1,255,255,255,255,255,255,255,255,255,255,255,255,119,1,255,255,52,0,145,0,170,0,255,255,136,1,126,1,255,255,137,1,155,1,255,255,255,255,255,255,20,1,255,255,255,255,35,0,255,255,255,255,255,255,255,255,255,255,255,255,140,1,132,1,36,0,255,255,255,255,64,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,94,1,255,255,255,255,215,0,91,0,255,255,255,255,183,1,255,255,122,0,255,255,200,0,255,255,67,0,255,255,154,1,255,255,255,255,89,0,255,255,255,255,255,255,255,255,255,255,96,0,21,0,255,255,103,0,1,0,255,255,255,255,113,1,255,255,255,255,89,1,255,255,255,255,255,255,99,1,40,0,255,255,27,0,255,255,150,1,255,255,255,255,255,255,226,1,163,1,161,1,255,255,255,255,104,1,14,1,255,255,255,255,251,0,255,255,255,255,255,255,255,255,93,1,255,255,255,255,22,1,255,255,186,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,182,1,255,255,238,1,255,255,255,255,255,255,255,255,255,255,59,1,255,255,84,1,108,1,100,1,255,255,228,1,255,255,255,255,255,255,255,255,32,0,255,255,255,255,255,255,4,1,255,255,255,255,255,255,255,255,207,0,231,1,84,0,197,1,255,255,255,255,157,1,255,255,255,255,255,255,255,255,255,255,214,0,255,255,81,1,96,1,221,1,255,255,179,1,56,0,255,255,255,255,34,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,132,0,255,255,85,0,236,1,172,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,199,0,255,255,86,1,255,255,255,255,255,255,138,0,163,0,190,0,147,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,10,1,255,255,255,255,177,1,255,255,255,255,218,1,255,255,255,255,255,255,255,255,129,1,100,0,255,255,255,255,255,255,175,1,255,255,135,1,125,1,12,0,58,0,255,255,142,0,167,0,255,255,255,255,153,1,255,255,255,255,255,255,255,255,42,0,45,0,66,0,255,255,255,255,168,1,255,255,255,255,255,255,255,255,255,255,255,255,220,0,120,1,255,255,255,255,87,1,255,255,255,255,255,255,114,0,106,0,255,255,255,255,191,1,255,255,217,0,237,1,171,0,172,0,143,1,90,1,255,255,255,255,255,255,255,255,195,0,255,255,255,255,255,255,255,255,255,255,240,1,255,255,255,255,255,255,255,255,241,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,151,0,255,255,118,0,255,255,62,0,187,0,255,255,255,255,255,255,255,255,255,255,234,0,255,255,187,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,101,1,255,255,255,255,255,255,246,0,255,255,255,255,255,255,192,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,39,0,255,255,10,0,141,1,133,1,255,255,255,255,154,0,255,255,255,255,255,255,130,0,255,255,22,0,222,0,117,1,162,0,255,255,105,1,203,0,255,255,255,255,242,0,255,255,255,255,255,255,255,255,203,1,255,255,255,255,15,1,255,255,97,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,171,1,255,255,175,0,107,0,255,255,255,255,255,255,178,0,167,1,116,1,69,0,255,255,109,1,255,255,4,0,230,1,184,0,255,255,255,255,255,255,255,255,205,1,255,255,255,255,26,1,255,255,255,255,255,255,255,255,255,255,219,1,255,255,255,255,255,255,139,1,131,1,255,255,255,255,79,0,63,0,255,255,255,255,196,1,195,1,255,255,50,0,255,255,180,1,255,255,255,255,29,1,255,255,255,255,83,0,199,1,255,255,255,255,255,255,23,1,114,1,255,255,255,255,255,255,18,0,255,255,255,255,255,255,255,255,255,255,165,1,255,255,239,1,255,255,255,255,255,255,255,255,227,0,77,1,255,255,255,255,25,0,139,0,164,0,255,255,255,255,115,1,255,255,255,255,173,1,255,255,255,255,255,255,17,1,255,255,210,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,181,0,255,255,255,255,75,0,255,255,92,0,83,1,255,255,128,1,255,255,123,0,255,255,143,0,168,0,255,255,183,0,186,0,255,255,108,0,95,0,112,1,255,255,255,255,21,1,198,0,255,255,206,0,176,1,255,255,220,1,255,255,202,1,255,255,255,255,182,0,255,255,185,1,255,255,255,255,255,255,115,0,113,0,148,1,255,255,217,1,255,255,255,255,255,255,234,1,104,0,255,255,255,255,194,1,193,1,255,255,255,255,255,255,18,1,255,255,225,1,111,0,99,0,255,255,255,255,255,255,255,255,255,255,255,255,7,1,93,0,255,255,117,0,255,255,29,0,255,255,255,255,255,255,255,255,119,0,255,255,255,255,170,1,235,1,255,255,255,255,205,0,255,255,237,0,44,0,255,255,255,255,255,255,255,255,255,255,162,1,160,1,255,255,255,255,102,1,255,255,255,255,255,255,65,0,255,255,184,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,5,0,255,255,255,255,255,255,232,1,255,255,255,255,255,255,28,0,156,1,255,255,149,1,255,255,255,255,255,255,255,255,255,255,39,1,255,255,215,1,106,1,255,255,255,255,229,1,255,255,255,255,255,255,255,255,255,255,202,0,255,255,255,255,28,1,255,255,213,1,255,255,255,255,9,0,24,0,255,255,255,255,179,0,255,255,255,255,15,0,255,255,255,255,148,0,255,255,255,255,255,255,85,1,255,255,255,255,110,1,209,0,223,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,255,255,208,0,211,1,255,255,166,1,255,255,208,1,157,0,255,255,147,1,255,255,159,1,255,255,255,255,255,255,255,255,189,1,255,255,255,255,74,1,255,255,255,255,255,255,206,1,160,0,255,255,255,255,255,255,255,255,86,0,255,255,255,255,41,0,255,255,24,1,255,255,222,1,255,255,255,255,57,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,138,1,158,1,255,255,255,255,255,255,140,0,165,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,19,1,102,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,232,0,255,255,14,0,255,255,255,255,225,0,255,255,255,255,11,1,255,255,77,0,255,255,144,0,169,0,255,255,149,0,255,255,144,1,255,255,255,255,255,255,3,0,255,255,255,255,255,255,212,1,169,1,255,255,255,255,214,1,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,200,1,255,255,158,0,159,0,255,255,255,255,146,0,49,0,255,255,255,255,153,0,255,255,145,1,90,0,0,0,0,0,226,3,0,0,120,221,0,0,43,1,0,0,44,1,0,0,226,3,0,0,176,213,0,0,45,1,0,0,46,1,0,0,120,116,101,114,109,45,50,53,54,99,111,108,111,114,124,120,116,101,114,109,32,119,105,116,104,32,50,53,54,32,99,111,108,111,114,115,0,0,0,0,124,0,0,0,0,0,0,0,118,116,49,48,48,124,118,116,49,48,48,45,97,109,124,100,101,99,32,118,116,49,48,48,32,40,119,47,97,100,118,97,110,99,101,100,32,118,105,100,101,111,41,0,0,0,0,0,96,229,0,0,0,0,0,0,16,230,0,0,64,230,0,0,144,230,0,0,0,0,0,0,0,0,0,0,44,0,39,0,158,1,0,0,0,0,0,0,144,229,0,0,0,0,0,0,8,237,0,0,56,237,0,0,136,237,0,0,0,0,0,0,0,0,0,0,44,0,39,0,158,1,0,0,0,0,0,0,0,1,0,0,1,0,0,0,1,0,0,0,0,1,1,0,0,0,0,0,0,0,1,0,0,1,0,1,1,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,80,0,8,0,24,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,80,247,0,0,88,247,0,0,96,247,0,0,104,247,0,0,128,247,0,0,136,247,0,0,144,247,0,0,152,247,0,0,160,247,0,0,0,0,0,0,176,247,0,0,200,247,0,0,208,247,0,0,216,247,0,0,224,247,0,0,0,0,0,0,232,247,0,0,248,247,0,0,0,0,0,0,0,248,0,0,8,248,0,0,24,248,0,0,32,248,0,0,0,0,0,0,0,0,0,0,40,248,0,0,48,248,0,0,56,248,0,0,64,248,0,0,0,0,0,0,0,0,0,0,80,248,0,0,88,248,0,0,0,0,0,0,96,248,0,0,104,248,0,0,112,248,0,0,120,248,0,0,136,248,0,0,144,248,0,0,152,248,0,0,0,0,0,0,168,248,0,0,176,248,0,0,184,248,0,0,192,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,248,0,0,0,0,0,0,248,248,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,249,0,0,0,0,0,0,8,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,249,0,0,24,249,0,0,32,249,0,0,40,249,0,0,48,249,0,0,56,249,0,0,64,249,0,0,72,249,0,0,80,249,0,0,88,249,0,0,96,249,0,0,104,249,0,0,0,0,0,0,112,249,0,0,0,0,0,0,120,249,0,0,128,249,0,0,136,249,0,0,144,249,0,0,152,249,0,0,0,0,0,0,160,249,0,0,168,249,0,0,176,249,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,184,249,0,0,200,249,0,0,0,0,0,0,0,0,0,0,216,249,0,0,232,249,0,0,248,249,0,0,8,250,0,0,24,250,0,0,40,250,0,0,56,250,0,0,72,250,0,0,88,250,0,0,104,250,0,0,0,0,0,0,0,0,0,0,0,0,0,0,120,250,0,0,128,250,0,0,136,250,0,0,0,0,0,0,144,250,0,0,152,250,0,0,0,0,0,0,0,0,0,0,176,250,0,0,184,250,0,0,200,250,0,0,208,250,0,0,216,250,0,0,224,250,0,0,56,251,0,0,0,0,0,0,64,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,72,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,80,251,0,0,0,0,0,0,136,251,0,0,0,0,0,0,0,0,0,0,144,251,0,0,152,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,251,0,0,168,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,176,251,0,0,0,0,0,0,0,0,0,0,184,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,251,0,0,200,251,0,0,208,251,0,0,0,0,0,0,0,0,0,0,216,251,0,0,0,0,0,0,224,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,232,251,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,251,0,0,248,251,0,0,0,252,0,0,8,252,0,0,16,252,0,0,24,252,0,0,32,252,0,0,40,252,0,0,48,252,0,0,56,252,0,0,64,252,0,0,72,252,0,0,80,252,0,0,88,252,0,0,96,252,0,0,104,252,0,0,112,252,0,0,120,252,0,0,128,252,0,0,136,252,0,0,144,252,0,0,152,252,0,0,160,252,0,0,168,252,0,0,176,252,0,0,184,252,0,0,192,252,0,0,200,252,0,0,208,252,0,0,216,252,0,0,224,252,0,0,232,252,0,0,240,252,0,0,248,252,0,0,0,253,0,0,8,253,0,0,16,253,0,0,24,253,0,0,32,253,0,0,40,253,0,0,48,253,0,0,56,253,0,0,64,253,0,0,72,253,0,0,80,253,0,0,88,253,0,0,96,253,0,0,104,253,0,0,112,253,0,0,120,253,0,0,128,253,0,0,136,253,0,0,144,253,0,0,152,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,160,253,0,0,176,253,0,0,184,253,0,0,192,253,0,0,200,253,0,0,0,0,0,0,216,253,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,254,0,0,128,254,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,254,0,0,200,254,0,0,0,0,0,0,0,1,0,0,1,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,1,0,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,1,0,0,0,0,0,0,0,0,0,0,80,0,8,0,24,0,255,255,255,255,255,255,3,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,244,0,0,8,244,0,0,16,244,0,0,40,244,0,0,48,244,0,0,64,244,0,0,72,244,0,0,0,0,0,0,0,0,0,0,88,244,0,0,112,244,0,0,120,244,0,0,0,0,0,0,128,244,0,0,0,0,0,0,0,0,0,0,136,244,0,0,0,0,0,0,144,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,152,244,0,0,160,244,0,0,176,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,244,0,0,208,244,0,0,224,244,0,0,0,0,0,0,240,244,0,0,248,244,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,245,0,0,16,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,24,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,245,0,0,48,245,0,0,56,245,0,0,64,245,0,0,72,245,0,0,80,245,0,0,88,245,0,0,96,245,0,0,104,245,0,0,112,245,0,0,120,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,136,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,144,245,0,0,152,245,0,0,160,245,0,0,0,0,0,0,168,245,0,0,0,0,0,0,176,245,0,0,184,245,0,0,192,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,200,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,216,245,0,0,232,245,0,0,0,0,0,0,248,245,0,0,0,0,0,0,0,0,0,0,0,0,0,0,8,246,0,0,16,246,0,0,24,246,0,0,0,0,0,0,0,0,0,0,32,246,0,0,0,0,0,0,0,0,0,0,64,246,0,0,0,0,0,0,72,246,0,0,80,246,0,0,88,246,0,0,96,246,0,0,176,246,0,0,0,0,0,0,184,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,246,0,0,200,246,0,0,208,246,0,0,216,246,0,0,224,246,0,0,0,0,0,0,0,0,0,0,232,246,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,247,0,0,40,247,0,0,0,0,0,0,0,0,0,0,48,247,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,56,247,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,64,247,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,27,91,37,105,37,112,49,37,100,59,37,112,50,37,100,114,0,0,0,0,0,0,0,0,27,91,51,103,0,0,0,0,27,91,72,27,91,74,36,60,53,48,62,0,0,0,0,0,27,91,75,36,60,51,62,0,27,91,74,36,60,53,48,62,0,0,0,0,0,0,0,0,27,91,37,105,37,112,49,37,100,59,37,112,50,37,100,72,36,60,53,62,0,0,0,0,10,0,0,0,0,0,0,0,27,91,72,0,0,0,0,0,8,0,0,0,0,0,0,0,27,91,67,36,60,50,62,0,27,91,65,36,60,50,62,0,14,0,0,0,0,0,0,0,27,91,53,109,36,60,50,62,0,0,0,0,0,0,0,0,27,91,49,109,36,60,50,62,0,0,0,0,0,0,0,0,27,91,55,109,36,60,50,62,0,0,0,0,0,0,0,0,27,91,55,109,36,60,50,62,0,0,0,0,0,0,0,0,27,91,52,109,36,60,50,62,0,0,0,0,0,0,0,0,15,0,0,0,0,0,0,0,27,91,109,15,36,60,50,62,0,0,0,0,0,0,0,0,27,91,109,36,60,50,62,0,27,91,109,36,60,50,62,0,8,0,0,0,0,0,0,0,27,79,66,0,0,0,0,0,27,79,121,0,0,0,0,0,27,79,80,0,0,0,0,0,27,79,120,0,0,0,0,0,27,79,81,0,0,0,0,0,27,79,82,0,0,0,0,0,27,79,83,0,0,0,0,0,27,79,116,0,0,0,0,0,27,79,117,0,0,0,0,0,27,79,118,0,0,0,0,0,27,79,108,0,0,0,0,0,27,79,119,0,0,0,0,0,27,79,68,0,0,0,0,0,27,79,67,0,0,0,0,0,27,79,65,0,0,0,0,0,27,91,63,49,108,27,62,0,27,91,63,49,104,27,61,0,112,102,49,0,0,0,0,0,112,102,50,0,0,0,0,0,112,102,51,0,0,0,0,0,112,102,52,0,0,0,0,0,27,91,37,112,49,37,100,66,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,68,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,67,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,65,0,0,0,0,0,0,0,0,27,91,48,105,0,0,0,0,27,91,52,105,0,0,0,0,27,91,53,105,0,0,0,0,27,62,27,91,63,51,108,27,91,63,52,108,27,91,63,53,108,27,91,63,55,104,27,91,63,56,104,0,0,0,0,0,27,56,0,0,0,0,0,0,27,55,0,0,0,0,0,0,10,0,0,0,0,0,0,0,27,77,36,60,53,62,0,0,27,91,48,37,63,37,112,49,37,112,54,37,124,37,116,59,49,37,59,37,63,37,112,50,37,116,59,52,37,59,37,63,37,112,49,37,112,51,37,124,37,116,59,55,37,59,37,63,37,112,52,37,116,59,53,37,59,109,37,63,37,112,57,37,116,14,37,101,15,37,59,36,60,50,62,0,0,0,0,0,27,72,0,0,0,0,0,0,9,0,0,0,0,0,0,0,27,79,113,0,0,0,0,0,27,79,115,0,0,0,0,0,27,79,114,0,0,0,0,0,27,79,112,0,0,0,0,0,27,79,110,0,0,0,0,0,96,96,97,97,102,102,103,103,106,106,107,107,108,108,109,109,110,110,111,111,112,112,113,113,114,114,115,115,116,116,117,117,118,118,119,119,120,120,121,121,122,122,123,123,124,124,125,125,126,126,0,0,0,0,0,0,27,91,63,55,104,0,0,0,27,91,63,55,108,0,0,0,27,40,66,27,41,48,0,0,27,79,77,0,0,0,0,0,27,91,49,75,36,60,51,62,0,0,0,0,0,0,0,0,27,91,90,0,0,0,0,0,7,0,0,0,0,0,0,0,13,0,0,0,0,0,0,0,27,91,37,105,37,112,49,37,100,59,37,112,50,37,100,114,0,0,0,0,0,0,0,0,27,91,51,103,0,0,0,0,27,91,72,27,91,50,74,0,27,91,75,0,0,0,0,0,27,91,74,0,0,0,0,0,27,91,37,105,37,112,49,37,100,71,0,0,0,0,0,0,27,91,37,105,37,112,49,37,100,59,37,112,50,37,100,72,0,0,0,0,0,0,0,0,10,0,0,0,0,0,0,0,27,91,72,0,0,0,0,0,27,91,63,50,53,108,0,0,8,0,0,0,0,0,0,0,27,91,63,49,50,108,27,91,63,50,53,104,0,0,0,0,27,91,67,0,0,0,0,0,27,91,65,0,0,0,0,0,27,91,63,49,50,59,50,53,104,0,0,0,0,0,0,0,27,91,80,0,0,0,0,0,27,91,77,0,0,0,0,0,27,40,48,0,0,0,0,0,27,91,53,109,0,0,0,0,27,91,49,109,0,0,0,0,27,91,63,49,48,52,57,104,0,0,0,0,0,0,0,0,27,91,52,104,0,0,0,0,27,91,56,109,0,0,0,0,27,91,55,109,0,0,0,0,27,91,55,109,0,0,0,0,27,91,52,109,0,0,0,0,27,91,37,112,49,37,100,88,0,0,0,0,0,0,0,0,27,40,66,0,0,0,0,0,27,40,66,27,91,109,0,0,27,91,63,49,48,52,57,108,0,0,0,0,0,0,0,0,27,91,52,108,0,0,0,0,27,91,50,55,109,0,0,0,27,91,50,52,109,0,0,0,27,91,63,53,104,36,60,49,48,48,47,62,27,91,63,53,108,0,0,0,0,0,0,0,27,91,33,112,27,91,63,51,59,52,108,27,91,52,108,27,62,0,0,0,0,0,0,0,27,91,76,0,0,0,0,0,8,0,0,0,0,0,0,0,27,91,51,126,0,0,0,0,27,79,66,0,0,0,0,0,27,79,80,0,0,0,0,0,27,91,50,49,126,0,0,0,27,79,81,0,0,0,0,0,27,79,82,0,0,0,0,0,27,79,83,0,0,0,0,0,27,91,49,53,126,0,0,0,27,91,49,55,126,0,0,0,27,91,49,56,126,0,0,0,27,91,49,57,126,0,0,0,27,91,50,48,126,0,0,0,27,79,72,0,0,0,0,0,27,91,50,126,0,0,0,0,27,79,68,0,0,0,0,0,27,91,54,126,0,0,0,0,27,91,53,126,0,0,0,0,27,79,67,0,0,0,0,0,27,91,49,59,50,66,0,0,27,91,49,59,50,65,0,0,27,79,65,0,0,0,0,0,27,91,63,49,108,27,62,0,27,91,63,49,104,27,61,0,27,91,63,49,48,51,52,108,0,0,0,0,0,0,0,0,27,91,63,49,48,51,52,104,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,80,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,77,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,66,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,64,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,83,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,76,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,68,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,67,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,84,0,0,0,0,0,0,0,0,27,91,37,112,49,37,100,65,0,0,0,0,0,0,0,0,27,91,105,0,0,0,0,0,27,91,52,105,0,0,0,0,27,91,53,105,0,0,0,0,27,99,0,0,0,0,0,0,27,91,33,112,27,91,63,51,59,52,108,27,91,52,108,27,62,0,0,0,0,0,0,0,27,56,0,0,0,0,0,0,27,91,37,105,37,112,49,37,100,100,0,0,0,0,0,0,27,55,0,0,0,0,0,0,10,0,0,0,0,0,0,0,27,77,0,0,0,0,0,0,37,63,37,112,57,37,116,27,40,48,37,101,27,40,66,37,59,27,91,48,37,63,37,112,54,37,116,59,49,37,59,37,63,37,112,50,37,116,59,52,37,59,37,63,37,112,49,37,112,51,37,124,37,116,59,55,37,59,37,63,37,112,52,37,116,59,53,37,59,37,63,37,112,55,37,116,59,56,37,59,109,0,0,0,0,0,0,0,27,72,0,0,0,0,0,0,9,0,0,0,0,0,0,0,27,79,69,0,0,0,0,0,96,96,97,97,102,102,103,103,105,105,106,106,107,107,108,108,109,109,110,110,111,111,112,112,113,113,114,114,115,115,116,116,117,117,118,118,119,119,120,120,121,121,122,122,123,123,124,124,125,125,126,126,0,0,0,0,27,91,90,0,0,0,0,0,27,91,63,55,104,0,0,0,27,91,63,55,108,0,0,0,27,79,70,0,0,0,0,0,27,79,77,0,0,0,0,0,27,91,51,59,50,126,0,0,27,91,49,59,50,70,0,0,27,91,49,59,50,72,0,0,27,91,50,59,50,126,0,0,27,91,49,59,50,68,0,0,27,91,54,59,50,126,0,0,27,91,53,59,50,126,0,0,27,91,49,59,50,67,0,0,27,91,50,51,126,0,0,0,27,91,50,52,126,0,0,0,27,91,49,59,50,80,0,0,27,91,49,59,50,81,0,0,27,91,49,59,50,82,0,0,27,91,49,59,50,83,0,0,27,91,49,53,59,50,126,0,27,91,49,55,59,50,126,0,27,91,49,56,59,50,126,0,27,91,49,57,59,50,126,0,27,91,50,48,59,50,126,0,27,91,50,49,59,50,126,0,27,91,50,51,59,50,126,0,27,91,50,52,59,50,126,0,27,91,49,59,53,80,0,0,27,91,49,59,53,81,0,0,27,91,49,59,53,82,0,0,27,91,49,59,53,83,0,0,27,91,49,53,59,53,126,0,27,91,49,55,59,53,126,0,27,91,49,56,59,53,126,0,27,91,49,57,59,53,126,0,27,91,50,48,59,53,126,0,27,91,50,49,59,53,126,0,27,91,50,51,59,53,126,0,27,91,50,52,59,53,126,0,27,91,49,59,54,80,0,0,27,91,49,59,54,81,0,0,27,91,49,59,54,82,0,0,27,91,49,59,54,83,0,0,27,91,49,53,59,54,126,0,27,91,49,55,59,54,126,0,27,91,49,56,59,54,126,0,27,91,49,57,59,54,126,0,27,91,50,48,59,54,126,0,27,91,50,49,59,54,126,0,27,91,50,51,59,54,126,0,27,91,50,52,59,54,126,0,27,91,49,59,51,80,0,0,27,91,49,59,51,81,0,0,27,91,49,59,51,82,0,0,27,91,49,59,51,83,0,0,27,91,49,53,59,51,126,0,27,91,49,55,59,51,126,0,27,91,49,56,59,51,126,0,27,91,49,57,59,51,126,0,27,91,50,48,59,51,126,0,27,91,50,49,59,51,126,0,27,91,50,51,59,51,126,0,27,91,50,52,59,51,126,0,27,91,49,59,52,80,0,0,27,91,49,59,52,81,0,0,27,91,49,59,52,82,0,0,27,91,49,75,0,0,0,0,27,91,37,105,37,100,59,37,100,82,0,0,0,0,0,0,27,91,54,110,0,0,0,0,27,91,63,49,59,50,99,0,27,91,99,0,0,0,0,0,27,91,51,57,59,52,57,109,0,0,0,0,0,0,0,0,27,93,52,59,37,112,49,37,100,59,114,103,98,58,37,112,50,37,123,50,53,53,125,37,42,37,123,49,48,48,48,125,37,47,37,50,46,50,88,47], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+54776);
/* memory initializer */ allocate([37,112,51,37,123,50,53,53,125,37,42,37,123,49,48,48,48,125,37,47,37,50,46,50,88,47,37,112,52,37,123,50,53,53,125,37,42,37,123,49,48,48,48,125,37,47,37,50,46,50,88,27,92,0,0,0,27,91,77,0,0,0,0,0,27,91,37,63,37,112,49,37,123,56,125,37,60,37,116,51,37,112,49,37,100,37,101,37,112,49,37,123,49,54,125,37,60,37,116,57,37,112,49,37,123,56,125,37,45,37,100,37,101,51,56,59,53,59,37,112,49,37,100,37,59,109,0,0,27,91,37,63,37,112,49,37,123,56,125,37,60,37,116,52,37,112,49,37,100,37,101,37,112,49,37,123,49,54,125,37,60,37,116,49,48,37,112,49,37,123,56,125,37,45,37,100,37,101,52,56,59,53,59,37,112,49,37,100,37,59,109,0,27,108,0,0,0,0,0,0,27,109,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,192,3,0,0,192,4,0,0,192,5,0,0,192,6,0,0,192,7,0,0,192,8,0,0,192,9,0,0,192,10,0,0,192,11,0,0,192,12,0,0,192,13,0,0,192,14,0,0,192,15,0,0,192,16,0,0,192,17,0,0,192,18,0,0,192,19,0,0,192,20,0,0,192,21,0,0,192,22,0,0,192,23,0,0,192,24,0,0,192,25,0,0,192,26,0,0,192,27,0,0,192,28,0,0,192,29,0,0,192,30,0,0,192,31,0,0,192,0,0,0,179,1,0,0,195,2,0,0,195,3,0,0,195,4,0,0,195,5,0,0,195,6,0,0,195,7,0,0,195,8,0,0,195,9,0,0,195,10,0,0,195,11,0,0,195,12,0,0,195,13,0,0,211,14,0,0,195,15,0,0,195,0,0,12,187,1,0,12,195,2,0,12,195,3,0,12,195,4,0,12,211,0,0,0,0,18,17,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,17,34,35,36,17,37,38,39,40,41,42,43,44,17,45,46,47,16,16,48,16,16,16,16,16,16,16,49,50,51,16,52,53,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,54,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,55,17,17,17,17,56,17,57,58,59,60,61,62,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,63,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,64,65,17,66,67,68,69,70,71,72,73,16,16,16,74,75,76,77,78,16,16,16,79,80,16,16,16,16,81,16,16,16,16,16,16,16,16,16,17,17,17,82,83,16,16,16,16,16,16,16,16,16,16,16,17,17,17,17,84,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,85,16,16,16,16,86,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,87,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,88,89,90,91,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,92,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,254,255,255,7,254,255,255,7,0,0,0,0,0,4,32,4,255,255,127,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,195,255,3,0,31,80,0,0,0,0,0,0,0,0,0,0,32,0,0,0,0,0,223,60,64,215,255,255,251,255,255,255,255,255,255,255,255,255,191,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,3,252,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,254,255,255,255,127,2,254,255,255,255,255,0,0,0,0,0,255,191,182,0,255,255,255,7,7,0,0,0,255,7,255,255,255,255,255,255,255,254,255,195,255,255,255,255,255,255,255,255,255,255,255,255,239,31,254,225,255,159,0,0,255,255,255,255,255,255,0,224,255,255,255,255,255,255,255,255,255,255,255,255,3,0,255,255,255,255,255,7,48,4,255,255,255,252,255,31,0,0,255,255,255,1,0,0,0,0,0,0,0,0,253,31,0,0,0,0,0,0,240,3,255,127,255,255,255,255,255,255,255,239,255,223,225,255,207,255,254,254,238,159,249,255,255,253,197,227,159,89,128,176,207,255,3,0,238,135,249,255,255,253,109,195,135,25,2,94,192,255,63,0,238,191,251,255,255,253,237,227,191,27,1,0,207,255,0,0,238,159,249,255,255,253,237,227,159,25,192,176,207,255,2,0,236,199,61,214,24,199,255,195,199,29,129,0,192,255,0,0,238,223,253,255,255,253,239,227,223,29,96,3,207,255,0,0,236,223,253,255,255,253,239,227,223,29,96,64,207,255,6,0,236,223,253,255,255,255,255,231,223,93,128,0,207,255,0,252,236,255,127,252,255,255,251,47,127,128,95,255,0,0,12,0,254,255,255,255,255,127,255,7,63,32,255,3,0,0,0,0,150,37,240,254,174,236,255,59,95,32,255,243,0,0,0,0,1,0,0,0,255,3,0,0,255,254,255,255,255,31,254,255,3,255,255,254,255,255,255,31,0,0,0,0,0,0,0,0,255,255,255,255,255,255,127,249,255,3,255,255,231,193,255,255,127,64,255,51,255,255,255,255,191,32,255,255,255,255,255,247,255,255,255,255,255,255,255,255,255,61,127,61,255,255,255,255,255,61,255,255,255,255,61,127,61,255,127,255,255,255,255,255,255,255,61,255,255,255,255,255,255,255,255,135,0,0,0,0,255,255,0,0,255,255,255,255,255,255,255,255,255,255,31,0,254,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,159,255,255,254,255,255,7,255,255,255,255,255,255,255,255,255,199,1,0,255,223,15,0,255,255,15,0,255,255,15,0,255,223,13,0,255,255,255,255,255,255,207,255,255,1,128,16,255,3,0,0,0,0,255,3,255,255,255,255,255,255,255,255,255,255,255,0,255,255,255,255,255,7,255,255,255,255,255,255,255,255,63,0,255,255,255,31,255,15,255,1,192,255,255,255,255,63,31,0,255,255,255,255,255,15,255,255,255,3,255,3,0,0,0,0,255,255,255,15,255,255,255,255,255,255,255,127,254,255,31,0,255,3,255,3,128,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,239,255,239,15,255,3,0,0,0,0,255,255,255,255,255,243,255,255,255,255,255,255,191,255,3,0,255,255,255,255,255,255,63,0,255,227,255,255,255,255,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,222,111,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,63,63,255,255,255,255,63,63,255,170,255,255,255,63,255,255,255,255,255,255,223,95,220,31,207,15,255,31,220,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,128,0,0,255,31,0,0,0,0,0,0,0,0,0,0,0,0,132,252,47,62,80,189,255,243,224,67,0,0,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,192,255,255,255,255,255,255,3,0,0,255,255,255,255,255,127,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,120,12,0,255,255,255,255,191,32,255,255,255,255,255,255,255,128,0,0,255,255,127,0,127,127,127,127,127,127,127,127,255,255,255,255,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,254,3,62,31,254,255,255,255,255,255,255,255,255,255,127,224,254,255,255,255,255,255,255,255,255,255,255,247,224,255,255,255,255,63,254,255,255,255,255,255,255,255,255,255,255,127,0,0,255,255,255,7,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,0,0,0,0,0,0,255,255,255,255,255,63,255,31,255,255,255,15,0,0,255,255,255,255,255,127,240,143,255,255,255,128,255,255,255,255,255,255,255,255,255,255,0,0,0,0,128,255,252,255,255,255,255,255,255,255,255,255,255,255,255,121,15,0,255,7,0,0,0,0,0,0,0,0,0,255,187,247,255,255,255,0,0,0,255,255,255,255,255,255,15,0,255,255,255,255,255,255,255,255,15,0,255,3,0,0,252,8,255,255,255,255,255,7,255,255,255,255,7,0,255,255,255,31,255,255,255,255,255,255,247,255,0,128,255,3,0,0,0,0,255,255,255,255,255,255,127,0,255,63,255,3,255,255,127,4,255,255,255,255,255,255,255,127,5,0,0,56,255,255,60,0,126,126,126,0,127,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,7,255,3,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,255,127,248,255,255,255,255,255,15,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,255,255,255,255,255,255,255,255,255,255,3,0,0,0,0,127,0,248,224,255,253,127,95,219,255,255,255,255,255,255,255,255,255,255,255,255,255,3,0,0,0,248,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,255,255,255,255,255,255,255,255,252,255,255,255,255,255,255,0,0,0,0,0,255,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,223,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,0,0,255,3,254,255,255,7,254,255,255,7,192,255,255,255,255,255,255,255,255,255,255,127,252,252,252,28,0,0,0,0,255,239,255,255,127,255,255,183,255,63,255,63,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,7,0,0,0,0,0,0,0,0,255,255,255,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,31,255,255,255,255,255,255,1,0,0,0,0,0,255,255,255,127,0,0,255,255,255,7,0,0,0,0,0,0,255,255,255,63,255,255,255,255,15,255,62,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,3,0,0,0,0,0,0,0,0,0,0,63,253,255,255,255,255,191,145,255,255,63,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,63,0,255,255,255,3,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,192,0,0,0,0,0,0,0,0,111,240,239,254,255,255,15,0,0,0,0,0,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,63,0,255,255,63,0,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,63,0,0,0,192,255,0,0,252,255,255,255,255,255,255,1,0,0,255,255,255,1,255,3,255,255,255,255,255,255,199,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,30,0,255,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,63,0,255,3,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,31,0,255,255,255,255,255,127,0,0,248,255,0,0,0,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,223,255,255,255,255,255,255,255,255,223,100,222,255,235,239,255,255,255,255,255,255,255,191,231,223,223,255,255,255,123,95,252,253,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,255,255,255,253,255,255,247,255,255,255,247,255,255,223,255,255,255,223,255,255,127,255,255,255,127,255,255,255,253,255,255,255,253,255,255,247,207,255,255,255,255,255,255,239,255,255,255,150,254,247,10,132,234,150,170,150,247,247,94,255,251,255,15,238,251,255,15,0,0,0,0,0,0,0,0,16,16,16,18,19,20,21,22,23,24,25,26,27,28,29,30,31,16,16,32,16,16,16,33,34,35,36,37,38,39,16,16,40,16,16,16,16,16,16,16,16,16,16,16,41,42,16,16,43,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,44,16,45,46,47,48,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,49,16,16,50,51,16,52,16,16,16,16,16,16,16,16,53,16,16,16,16,16,54,55,16,16,16,16,56,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,57,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,58,59,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,248,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,255,191,182,0,0,0,0,0,0,0,31,0,255,7,0,0,0,0,0,248,255,255,0,0,1,0,0,0,0,0,0,0,0,0,0,0,192,191,159,61,0,0,0,128,2,0,0,0,255,255,255,7,0,0,0,0,0,0,0,0,0,0,192,255,1,0,0,0,0,0,0,248,15,0,0,0,192,251,239,62,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,240,255,255,127,7,0,0,0,0,0,0,20,254,33,254,0,12,0,0,0,2,0,0,0,0,0,0,16,30,32,0,0,12,0,0,0,6,0,0,0,0,0,0,16,134,57,2,0,0,0,35,0,6,0,0,0,0,0,0,16,190,33,0,0,12,0,0,0,2,0,0,0,0,0,0,144,30,32,64,0,12,0,0,0,4,0,0,0,0,0,0,0,1,32,0,0,0,0,0,0,0,0,0,0,0,0,0,192,193,61,96,0,12,0,0,0,0,0,0,0,0,0,0,144,64,48,0,0,12,0,0,0,0,0,0,0,0,0,0,0,30,32,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,4,92,0,0,0,0,0,0,0,0,0,0,0,242,7,128,127,0,0,0,0,0,0,0,0,0,0,0,0,242,27,0,63,0,0,0,0,0,0,0,0,0,3,0,0,160,2,0,0,0,0,0,0,254,127,223,224,255,254,255,255,255,31,64,0,0,0,0,0,0,0,0,0,0,0,0,224,253,102,0,0,0,195,1,0,30,0,100,32,0,32,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,224,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,28,0,0,0,12,0,0,0,12,0,0,0,0,0,0,0,176,63,64,254,15,32,0,0,0,0,0,56,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,0,0,0,0,0,0,0,0,135,1,4,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,1,0,0,0,0,0,0,64,127,229,31,248,159,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,0,208,23,4,0,0,0,0,248,15,0,3,0,0,0,60,11,0,0,0,0,0,0,64,163,3,0,0,0,0,0,0,240,207,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,247,255,253,33,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,127,0,0,240,0,248,0,0,0,124,0,0,0,0,0,0,31,252,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,0,0,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,247,63,0,0,0,128,0,0,0,0,0,0,0,0,0,0,3,0,68,8,0,0,96,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,255,255,3,0,0,0,0,0,192,63,0,0,128,255,3,0,0,0,0,0,7,0,0,0,0,0,200,19,0,0,0,0,0,0,0,0,0,0,0,0,0,126,102,0,8,16,0,0,0,0,0,0,0,0,0,0,0,0,157,193,2,0,0,0,0,48,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,33,0,0,0,0,0,64,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,0,0,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,32,110,240,0,0,0,0,0,135,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,2,0,0,0,0,0,0,255,127,0,0,0,0,0,0,0,3,0,0,0,0,0,120,38,0,0,0,0,0,0,0,0,7,0,0,0,128,239,31,0,0,0,0,0,0,0,0,0,3,0,0,0,0,0,192,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,40,191,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,7,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,128,3,248,255,231,15,0,0,0,60,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,28,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,18,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,19,16,16,16,16,16,16,16,16,16,16,20,21,22,23,24,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,25,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,26,16,16,16,16,27,16,16,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,17,28,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,17,17,16,16,16,29,30,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,31,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,16,32,16,16,16,16,16,16,16,16,16,16,16,16,16,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,248,0,0,0,0,0,0,0,0,0,0,252,0,0,0,0,0,6,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,251,255,255,255,255,255,255,255,255,255,255,15,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,63,0,0,0,255,15,255,255,255,255,255,255,255,127,254,255,255,255,255,255,255,255,255,255,127,254,255,255,255,255,255,255,255,255,255,255,255,255,224,255,255,255,255,63,254,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,7,255,255,255,255,15,0,255,255,255,255,255,127,255,255,255,255,255,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,127,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,31,255,255,255,255,255,255,127,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,31,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,15,0,255,255,127,248,255,255,255,255,255,15,0,0,255,3,0,0,255,255,255,255,247,255,127,15,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,254,255,255,255,255,255,255,255,255,255,255,255,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,127,0,0,0,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,7,0,255,255,255,255,255,7,255,1,3,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,73,0,49,1,83,0,127,1,48,1,105,0,120,1,255,0,129,1,83,2,130,1,131,1,132,1,133,1,134,1,84,2,135,1,136,1,137,1,86,2,138,1,87,2,139,1,140,1,142,1,221,1,143,1,89,2,144,1,91,2,145,1,146,1,147,1,96,2,148,1,99,2,150,1,105,2,151,1,104,2,152,1,153,1,156,1,111,2,157,1,114,2,159,1,117,2,166,1,128,2,167,1,168,1,169,1,131,2,172,1,173,1,174,1,136,2,175,1,176,1,177,1,138,2,178,1,139,2,183,1,146,2,184,1,185,1,188,1,189,1,196,1,198,1,196,1,197,1,197,1,198,1,199,1,201,1,199,1,200,1,200,1,201,1,202,1,204,1,202,1,203,1,203,1,204,1,241,1,243,1,241,1,242,1,242,1,243,1,244,1,245,1,246,1,149,1,247,1,191,1,32,2,158,1,134,3,172,3,136,3,173,3,137,3,174,3,138,3,175,3,140,3,204,3,142,3,205,3,143,3,206,3,153,3,69,3,153,3,190,31,163,3,194,3,247,3,248,3,250,3,251,3,96,30,155,30,223,0,223,0,158,30,223,0,89,31,81,31,91,31,83,31,93,31,85,31,95,31,87,31,188,31,179,31,204,31,195,31,236,31,229,31,252,31,243,31,58,2,101,44,59,2,60,2,61,2,154,1,62,2,102,44,65,2,66,2,67,2,128,1,68,2,137,2,69,2,140,2,244,3,184,3,249,3,242,3,253,3,123,3,254,3,124,3,255,3,125,3,192,4,207,4,38,33,201,3,42,33,107,0,43,33,229,0,50,33,78,33,131,33,132,33,96,44,97,44,98,44,107,2,99,44,125,29,100,44,125,2,109,44,81,2,110,44,113,2,111,44,80,2,112,44,82,2,114,44,115,44,117,44,118,44,126,44,63,2,127,44,64,2,242,44,243,44,125,167,121,29,139,167,140,167,141,167,101,2,170,167,102,2,199,16,39,45,205,16,45,45,118,3,119,3,156,3,181,0,146,3,208,3,152,3,209,3,166,3,213,3,160,3,214,3,154,3,240,3,161,3,241,3,149,3,245,3,207,3,215,3,0,0,0,0,0,0,0,0,65,0,32,26,192,0,32,31,0,1,1,47,50,1,1,5,57,1,1,15,74,1,1,45,121,1,1,5,112,3,1,3,145,3,32,17,163,3,32,9,0,4,80,16,16,4,32,32,96,4,1,33,138,4,1,53,193,4,1,13,208,4,1,63,20,5,1,19,49,5,48,38,160,1,1,5,179,1,1,3,205,1,1,15,222,1,1,17,248,1,1,39,34,2,1,17,216,3,1,23,0,30,1,149,160,30,1,95,8,31,248,8,24,31,248,6,40,31,248,8,56,31,248,8,72,31,248,6,104,31,248,8,136,31,248,8,152,31,248,8,168,31,248,8,184,31,248,2,186,31,182,2,200,31,170,4,216,31,248,2,218,31,156,2,232,31,248,2,234,31,144,2,248,31,128,2,250,31,130,2,70,2,1,9,16,5,1,3,96,33,16,16,0,44,48,47,103,44,1,5,128,44,1,99,235,44,1,3,64,166,1,45,128,166,1,23,34,167,1,13,50,167,1,61,121,167,1,3,126,167,1,9,144,167,1,3,160,167,1,9,33,255,32,26,0,0,0,0,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,1,2,3,4,5,6,7,8,9,255,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,10,11,12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,30,31,32,33,34,35,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,255,0,0,0,0,0,0,0,0,1,2,4,7,3,6,5,0,0,0,0,0,0,0,0,105,110,102,105,110,105,116,121,0,0,0,0,0,0,0,0,10,0,0,0,100,0,0,0,232,3,0,0,16,39,0,0,160,134,1,0,64,66,15,0,128,150,152,0,0,225,245,5,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,47,1,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,17,0,10,0,17,17,17,0,0,0,0,5,0,0,0,0,0,0,9,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,15,10,17,17,17,3,10,7,0,1,19,9,11,11,0,0,9,6,11,0,0,11,0,6,17,0,0,0,17,17,17,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,17,0,10,10,17,17,17,0,10,0,0,2,0,9,11,0,0,0,9,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,14,0,0,0,0,0,0,0,0,0,0,0,13,0,0,0,4,13,0,0,0,0,9,14,0,0,0,0,0,14,0,0,14,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,16,0,0,0,0,0,0,0,0,0,0,0,15,0,0,0,0,15,0,0,0,0,9,16,0,0,0,0,0,16,0,0,16,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,18,0,0,0,18,18,18,0,0,0,0,0,0,9,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,11,0,0,0,0,0,0,0,0,0,0,0,10,0,0,0,0,10,0,0,0,0,9,11,0,0,0,0,0,11,0,0,11,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,0,0,0,0,0,0,0,12,0,0,0,0,12,0,0,0,0,9,12,0,0,0,0,0,12,0,0,12,0,0,48,49,50,51,52,53,54,55,56,57,65,66,67,68,69,70,45,43,32,32,32,48,88,48,120,0,0,0,0,0,0,0,40,110,117,108,108,41,0,0,45,48,88,43,48,88,32,48,88,45,48,120,43,48,120,32,48,120,0,0,0,0,0,0,105,110,102,0,0,0,0,0,73,78,70,0,0,0,0,0,110,97,110,0,0,0,0,0,78,65,78,0,0,0,0,0,46,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0,0], "i8", ALLOC_NONE, Runtime.GLOBAL_BASE+65016);





/* no memory initializer */
var tempDoublePtr = Runtime.alignMemory(allocate(12, "i8", ALLOC_STATIC), 8);

assert(tempDoublePtr % 8 == 0);

function copyTempFloat(ptr) { // functions, because inlining this code increases code size too much

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

}

function copyTempDouble(ptr) {

  HEAP8[tempDoublePtr] = HEAP8[ptr];

  HEAP8[tempDoublePtr+1] = HEAP8[ptr+1];

  HEAP8[tempDoublePtr+2] = HEAP8[ptr+2];

  HEAP8[tempDoublePtr+3] = HEAP8[ptr+3];

  HEAP8[tempDoublePtr+4] = HEAP8[ptr+4];

  HEAP8[tempDoublePtr+5] = HEAP8[ptr+5];

  HEAP8[tempDoublePtr+6] = HEAP8[ptr+6];

  HEAP8[tempDoublePtr+7] = HEAP8[ptr+7];

}

// {{PRE_LIBRARY}}


  
  
  var ERRNO_CODES={EPERM:1,ENOENT:2,ESRCH:3,EINTR:4,EIO:5,ENXIO:6,E2BIG:7,ENOEXEC:8,EBADF:9,ECHILD:10,EAGAIN:11,EWOULDBLOCK:11,ENOMEM:12,EACCES:13,EFAULT:14,ENOTBLK:15,EBUSY:16,EEXIST:17,EXDEV:18,ENODEV:19,ENOTDIR:20,EISDIR:21,EINVAL:22,ENFILE:23,EMFILE:24,ENOTTY:25,ETXTBSY:26,EFBIG:27,ENOSPC:28,ESPIPE:29,EROFS:30,EMLINK:31,EPIPE:32,EDOM:33,ERANGE:34,ENOMSG:42,EIDRM:43,ECHRNG:44,EL2NSYNC:45,EL3HLT:46,EL3RST:47,ELNRNG:48,EUNATCH:49,ENOCSI:50,EL2HLT:51,EDEADLK:35,ENOLCK:37,EBADE:52,EBADR:53,EXFULL:54,ENOANO:55,EBADRQC:56,EBADSLT:57,EDEADLOCK:35,EBFONT:59,ENOSTR:60,ENODATA:61,ETIME:62,ENOSR:63,ENONET:64,ENOPKG:65,EREMOTE:66,ENOLINK:67,EADV:68,ESRMNT:69,ECOMM:70,EPROTO:71,EMULTIHOP:72,EDOTDOT:73,EBADMSG:74,ENOTUNIQ:76,EBADFD:77,EREMCHG:78,ELIBACC:79,ELIBBAD:80,ELIBSCN:81,ELIBMAX:82,ELIBEXEC:83,ENOSYS:38,ENOTEMPTY:39,ENAMETOOLONG:36,ELOOP:40,EOPNOTSUPP:95,EPFNOSUPPORT:96,ECONNRESET:104,ENOBUFS:105,EAFNOSUPPORT:97,EPROTOTYPE:91,ENOTSOCK:88,ENOPROTOOPT:92,ESHUTDOWN:108,ECONNREFUSED:111,EADDRINUSE:98,ECONNABORTED:103,ENETUNREACH:101,ENETDOWN:100,ETIMEDOUT:110,EHOSTDOWN:112,EHOSTUNREACH:113,EINPROGRESS:115,EALREADY:114,EDESTADDRREQ:89,EMSGSIZE:90,EPROTONOSUPPORT:93,ESOCKTNOSUPPORT:94,EADDRNOTAVAIL:99,ENETRESET:102,EISCONN:106,ENOTCONN:107,ETOOMANYREFS:109,EUSERS:87,EDQUOT:122,ESTALE:116,ENOTSUP:95,ENOMEDIUM:123,EILSEQ:84,EOVERFLOW:75,ECANCELED:125,ENOTRECOVERABLE:131,EOWNERDEAD:130,ESTRPIPE:86};
  
  var ERRNO_MESSAGES={0:"Success",1:"Not super-user",2:"No such file or directory",3:"No such process",4:"Interrupted system call",5:"I/O error",6:"No such device or address",7:"Arg list too long",8:"Exec format error",9:"Bad file number",10:"No children",11:"No more processes",12:"Not enough core",13:"Permission denied",14:"Bad address",15:"Block device required",16:"Mount device busy",17:"File exists",18:"Cross-device link",19:"No such device",20:"Not a directory",21:"Is a directory",22:"Invalid argument",23:"Too many open files in system",24:"Too many open files",25:"Not a typewriter",26:"Text file busy",27:"File too large",28:"No space left on device",29:"Illegal seek",30:"Read only file system",31:"Too many links",32:"Broken pipe",33:"Math arg out of domain of func",34:"Math result not representable",35:"File locking deadlock error",36:"File or path name too long",37:"No record locks available",38:"Function not implemented",39:"Directory not empty",40:"Too many symbolic links",42:"No message of desired type",43:"Identifier removed",44:"Channel number out of range",45:"Level 2 not synchronized",46:"Level 3 halted",47:"Level 3 reset",48:"Link number out of range",49:"Protocol driver not attached",50:"No CSI structure available",51:"Level 2 halted",52:"Invalid exchange",53:"Invalid request descriptor",54:"Exchange full",55:"No anode",56:"Invalid request code",57:"Invalid slot",59:"Bad font file fmt",60:"Device not a stream",61:"No data (for no delay io)",62:"Timer expired",63:"Out of streams resources",64:"Machine is not on the network",65:"Package not installed",66:"The object is remote",67:"The link has been severed",68:"Advertise error",69:"Srmount error",70:"Communication error on send",71:"Protocol error",72:"Multihop attempted",73:"Cross mount point (not really error)",74:"Trying to read unreadable message",75:"Value too large for defined data type",76:"Given log. name not unique",77:"f.d. invalid for this operation",78:"Remote address changed",79:"Can   access a needed shared lib",80:"Accessing a corrupted shared lib",81:".lib section in a.out corrupted",82:"Attempting to link in too many libs",83:"Attempting to exec a shared library",84:"Illegal byte sequence",86:"Streams pipe error",87:"Too many users",88:"Socket operation on non-socket",89:"Destination address required",90:"Message too long",91:"Protocol wrong type for socket",92:"Protocol not available",93:"Unknown protocol",94:"Socket type not supported",95:"Not supported",96:"Protocol family not supported",97:"Address family not supported by protocol family",98:"Address already in use",99:"Address not available",100:"Network interface is not configured",101:"Network is unreachable",102:"Connection reset by network",103:"Connection aborted",104:"Connection reset by peer",105:"No buffer space available",106:"Socket is already connected",107:"Socket is not connected",108:"Can't send after socket shutdown",109:"Too many references",110:"Connection timed out",111:"Connection refused",112:"Host is down",113:"Host is unreachable",114:"Socket already connected",115:"Connection already in progress",116:"Stale file handle",122:"Quota exceeded",123:"No medium (in tape drive)",125:"Operation canceled",130:"Previous owner died",131:"State not recoverable"};
  
  
  var ___errno_state=0;function ___setErrNo(value) {
      // For convenient setting and returning of errno.
      HEAP32[((___errno_state)>>2)]=value;
      return value;
    }
  
  var PATH={splitPath:function (filename) {
        var splitPathRe = /^(\/?|)([\s\S]*?)((?:\.{1,2}|[^\/]+?|)(\.[^.\/]*|))(?:[\/]*)$/;
        return splitPathRe.exec(filename).slice(1);
      },normalizeArray:function (parts, allowAboveRoot) {
        // if the path tries to go above the root, `up` ends up > 0
        var up = 0;
        for (var i = parts.length - 1; i >= 0; i--) {
          var last = parts[i];
          if (last === '.') {
            parts.splice(i, 1);
          } else if (last === '..') {
            parts.splice(i, 1);
            up++;
          } else if (up) {
            parts.splice(i, 1);
            up--;
          }
        }
        // if the path is allowed to go above the root, restore leading ..s
        if (allowAboveRoot) {
          for (; up--; up) {
            parts.unshift('..');
          }
        }
        return parts;
      },normalize:function (path) {
        var isAbsolute = path.charAt(0) === '/',
            trailingSlash = path.substr(-1) === '/';
        // Normalize the path
        path = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), !isAbsolute).join('/');
        if (!path && !isAbsolute) {
          path = '.';
        }
        if (path && trailingSlash) {
          path += '/';
        }
        return (isAbsolute ? '/' : '') + path;
      },dirname:function (path) {
        var result = PATH.splitPath(path),
            root = result[0],
            dir = result[1];
        if (!root && !dir) {
          // No dirname whatsoever
          return '.';
        }
        if (dir) {
          // It has a dirname, strip trailing slash
          dir = dir.substr(0, dir.length - 1);
        }
        return root + dir;
      },basename:function (path) {
        // EMSCRIPTEN return '/'' for '/', not an empty string
        if (path === '/') return '/';
        var lastSlash = path.lastIndexOf('/');
        if (lastSlash === -1) return path;
        return path.substr(lastSlash+1);
      },extname:function (path) {
        return PATH.splitPath(path)[3];
      },join:function () {
        var paths = Array.prototype.slice.call(arguments, 0);
        return PATH.normalize(paths.join('/'));
      },join2:function (l, r) {
        return PATH.normalize(l + '/' + r);
      },resolve:function () {
        var resolvedPath = '',
          resolvedAbsolute = false;
        for (var i = arguments.length - 1; i >= -1 && !resolvedAbsolute; i--) {
          var path = (i >= 0) ? arguments[i] : FS.cwd();
          // Skip empty and invalid entries
          if (typeof path !== 'string') {
            throw new TypeError('Arguments to path.resolve must be strings');
          } else if (!path) {
            return ''; // an invalid portion invalidates the whole thing
          }
          resolvedPath = path + '/' + resolvedPath;
          resolvedAbsolute = path.charAt(0) === '/';
        }
        // At this point the path should be resolved to a full absolute path, but
        // handle relative paths to be safe (might happen when process.cwd() fails)
        resolvedPath = PATH.normalizeArray(resolvedPath.split('/').filter(function(p) {
          return !!p;
        }), !resolvedAbsolute).join('/');
        return ((resolvedAbsolute ? '/' : '') + resolvedPath) || '.';
      },relative:function (from, to) {
        from = PATH.resolve(from).substr(1);
        to = PATH.resolve(to).substr(1);
        function trim(arr) {
          var start = 0;
          for (; start < arr.length; start++) {
            if (arr[start] !== '') break;
          }
          var end = arr.length - 1;
          for (; end >= 0; end--) {
            if (arr[end] !== '') break;
          }
          if (start > end) return [];
          return arr.slice(start, end - start + 1);
        }
        var fromParts = trim(from.split('/'));
        var toParts = trim(to.split('/'));
        var length = Math.min(fromParts.length, toParts.length);
        var samePartsLength = length;
        for (var i = 0; i < length; i++) {
          if (fromParts[i] !== toParts[i]) {
            samePartsLength = i;
            break;
          }
        }
        var outputParts = [];
        for (var i = samePartsLength; i < fromParts.length; i++) {
          outputParts.push('..');
        }
        outputParts = outputParts.concat(toParts.slice(samePartsLength));
        return outputParts.join('/');
      }};
  
  var TTY={ttys:[],init:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // currently, FS.init does not distinguish if process.stdin is a file or TTY
        //   // device, it always assumes it's a TTY device. because of this, we're forcing
        //   // process.stdin to UTF8 encoding to at least make stdin reading compatible
        //   // with text files until FS.init can be refactored.
        //   process['stdin']['setEncoding']('utf8');
        // }
      },shutdown:function () {
        // https://github.com/kripken/emscripten/pull/1555
        // if (ENVIRONMENT_IS_NODE) {
        //   // inolen: any idea as to why node -e 'process.stdin.read()' wouldn't exit immediately (with process.stdin being a tty)?
        //   // isaacs: because now it's reading from the stream, you've expressed interest in it, so that read() kicks off a _read() which creates a ReadReq operation
        //   // inolen: I thought read() in that case was a synchronous operation that just grabbed some amount of buffered data if it exists?
        //   // isaacs: it is. but it also triggers a _read() call, which calls readStart() on the handle
        //   // isaacs: do process.stdin.pause() and i'd think it'd probably close the pending call
        //   process['stdin']['pause']();
        // }
      },register:function (dev, ops) {
        TTY.ttys[dev] = { input: [], output: [], ops: ops };
        FS.registerDevice(dev, TTY.stream_ops);
      },stream_ops:{open:function (stream) {
          var tty = TTY.ttys[stream.node.rdev];
          if (!tty) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          stream.tty = tty;
          stream.seekable = false;
        },close:function (stream) {
          // flush any pending line data
          stream.tty.ops.flush(stream.tty);
        },flush:function (stream) {
          stream.tty.ops.flush(stream.tty);
        },read:function (stream, buffer, offset, length, pos /* ignored */) {
          if (!stream.tty || !stream.tty.ops.get_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          var bytesRead = 0;
          for (var i = 0; i < length; i++) {
            var result;
            try {
              result = stream.tty.ops.get_char(stream.tty);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            if (result === undefined && bytesRead === 0) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
            if (result === null || result === undefined) break;
            bytesRead++;
            buffer[offset+i] = result;
          }
          if (bytesRead) {
            stream.node.timestamp = Date.now();
          }
          return bytesRead;
        },write:function (stream, buffer, offset, length, pos) {
          if (!stream.tty || !stream.tty.ops.put_char) {
            throw new FS.ErrnoError(ERRNO_CODES.ENXIO);
          }
          for (var i = 0; i < length; i++) {
            try {
              stream.tty.ops.put_char(stream.tty, buffer[offset+i]);
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
          }
          if (length) {
            stream.node.timestamp = Date.now();
          }
          return i;
        }},default_tty_ops:{get_char:function (tty) {
          if (!tty.input.length) {
            var result = null;
            if (ENVIRONMENT_IS_NODE) {
              // we will read data by chunks of BUFSIZE
              var BUFSIZE = 256;
              var buf = new Buffer(BUFSIZE);
              var bytesRead = 0;
  
              var fd = process.stdin.fd;
              // Linux and Mac cannot use process.stdin.fd (which isn't set up as sync)
              var usingDevice = false;
              try {
                fd = fs.openSync('/dev/stdin', 'r');
                usingDevice = true;
              } catch (e) {}
  
              bytesRead = fs.readSync(fd, buf, 0, BUFSIZE, null);
  
              if (usingDevice) { fs.closeSync(fd); }
              if (bytesRead > 0) {
                result = buf.slice(0, bytesRead).toString('utf-8');
              } else {
                result = null;
              }
  
            } else if (typeof window != 'undefined' &&
              typeof window.prompt == 'function') {
              // Browser.
              result = window.prompt('Input: ');  // returns null on cancel
              if (result !== null) {
                result += '\n';
              }
            } else if (typeof readline == 'function') {
              // Command line.
              result = readline();
              if (result !== null) {
                result += '\n';
              }
            }
            if (!result) {
              return null;
            }
            tty.input = intArrayFromString(result, true);
          }
          return tty.input.shift();
        },put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val); // val == 0 would cut text output off in the middle.
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['print'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }},default_tty1_ops:{put_char:function (tty, val) {
          if (val === null || val === 10) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          } else {
            if (val != 0) tty.output.push(val);
          }
        },flush:function (tty) {
          if (tty.output && tty.output.length > 0) {
            Module['printErr'](UTF8ArrayToString(tty.output, 0));
            tty.output = [];
          }
        }}};
  
  var MEMFS={ops_table:null,mount:function (mount) {
        return MEMFS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createNode:function (parent, name, mode, dev) {
        if (FS.isBlkdev(mode) || FS.isFIFO(mode)) {
          // no supported
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (!MEMFS.ops_table) {
          MEMFS.ops_table = {
            dir: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                lookup: MEMFS.node_ops.lookup,
                mknod: MEMFS.node_ops.mknod,
                rename: MEMFS.node_ops.rename,
                unlink: MEMFS.node_ops.unlink,
                rmdir: MEMFS.node_ops.rmdir,
                readdir: MEMFS.node_ops.readdir,
                symlink: MEMFS.node_ops.symlink
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek
              }
            },
            file: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: {
                llseek: MEMFS.stream_ops.llseek,
                read: MEMFS.stream_ops.read,
                write: MEMFS.stream_ops.write,
                allocate: MEMFS.stream_ops.allocate,
                mmap: MEMFS.stream_ops.mmap,
                msync: MEMFS.stream_ops.msync
              }
            },
            link: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr,
                readlink: MEMFS.node_ops.readlink
              },
              stream: {}
            },
            chrdev: {
              node: {
                getattr: MEMFS.node_ops.getattr,
                setattr: MEMFS.node_ops.setattr
              },
              stream: FS.chrdev_stream_ops
            }
          };
        }
        var node = FS.createNode(parent, name, mode, dev);
        if (FS.isDir(node.mode)) {
          node.node_ops = MEMFS.ops_table.dir.node;
          node.stream_ops = MEMFS.ops_table.dir.stream;
          node.contents = {};
        } else if (FS.isFile(node.mode)) {
          node.node_ops = MEMFS.ops_table.file.node;
          node.stream_ops = MEMFS.ops_table.file.stream;
          node.usedBytes = 0; // The actual number of bytes used in the typed array, as opposed to contents.buffer.byteLength which gives the whole capacity.
          // When the byte data of the file is populated, this will point to either a typed array, or a normal JS array. Typed arrays are preferred
          // for performance, and used by default. However, typed arrays are not resizable like normal JS arrays are, so there is a small disk size
          // penalty involved for appending file writes that continuously grow a file similar to std::vector capacity vs used -scheme.
          node.contents = null; 
        } else if (FS.isLink(node.mode)) {
          node.node_ops = MEMFS.ops_table.link.node;
          node.stream_ops = MEMFS.ops_table.link.stream;
        } else if (FS.isChrdev(node.mode)) {
          node.node_ops = MEMFS.ops_table.chrdev.node;
          node.stream_ops = MEMFS.ops_table.chrdev.stream;
        }
        node.timestamp = Date.now();
        // add the new node to the parent
        if (parent) {
          parent.contents[name] = node;
        }
        return node;
      },getFileDataAsRegularArray:function (node) {
        if (node.contents && node.contents.subarray) {
          var arr = [];
          for (var i = 0; i < node.usedBytes; ++i) arr.push(node.contents[i]);
          return arr; // Returns a copy of the original data.
        }
        return node.contents; // No-op, the file contents are already in a JS array. Return as-is.
      },getFileDataAsTypedArray:function (node) {
        if (!node.contents) return new Uint8Array;
        if (node.contents.subarray) return node.contents.subarray(0, node.usedBytes); // Make sure to not return excess unused bytes.
        return new Uint8Array(node.contents);
      },expandFileStorage:function (node, newCapacity) {
        // If we are asked to expand the size of a file that already exists, revert to using a standard JS array to store the file
        // instead of a typed array. This makes resizing the array more flexible because we can just .push() elements at the back to
        // increase the size.
        if (node.contents && node.contents.subarray && newCapacity > node.contents.length) {
          node.contents = MEMFS.getFileDataAsRegularArray(node);
          node.usedBytes = node.contents.length; // We might be writing to a lazy-loaded file which had overridden this property, so force-reset it.
        }
  
        if (!node.contents || node.contents.subarray) { // Keep using a typed array if creating a new storage, or if old one was a typed array as well.
          var prevCapacity = node.contents ? node.contents.buffer.byteLength : 0;
          if (prevCapacity >= newCapacity) return; // No need to expand, the storage was already large enough.
          // Don't expand strictly to the given requested limit if it's only a very small increase, but instead geometrically grow capacity.
          // For small filesizes (<1MB), perform size*2 geometric increase, but for large sizes, do a much more conservative size*1.125 increase to
          // avoid overshooting the allocation cap by a very large margin.
          var CAPACITY_DOUBLING_MAX = 1024 * 1024;
          newCapacity = Math.max(newCapacity, (prevCapacity * (prevCapacity < CAPACITY_DOUBLING_MAX ? 2.0 : 1.125)) | 0);
          if (prevCapacity != 0) newCapacity = Math.max(newCapacity, 256); // At minimum allocate 256b for each file when expanding.
          var oldContents = node.contents;
          node.contents = new Uint8Array(newCapacity); // Allocate new storage.
          if (node.usedBytes > 0) node.contents.set(oldContents.subarray(0, node.usedBytes), 0); // Copy old data over to the new storage.
          return;
        }
        // Not using a typed array to back the file storage. Use a standard JS array instead.
        if (!node.contents && newCapacity > 0) node.contents = [];
        while (node.contents.length < newCapacity) node.contents.push(0);
      },resizeFileStorage:function (node, newSize) {
        if (node.usedBytes == newSize) return;
        if (newSize == 0) {
          node.contents = null; // Fully decommit when requesting a resize to zero.
          node.usedBytes = 0;
          return;
        }
        if (!node.contents || node.contents.subarray) { // Resize a typed array if that is being used as the backing store.
          var oldContents = node.contents;
          node.contents = new Uint8Array(new ArrayBuffer(newSize)); // Allocate new storage.
          if (oldContents) {
            node.contents.set(oldContents.subarray(0, Math.min(newSize, node.usedBytes))); // Copy old data over to the new storage.
          }
          node.usedBytes = newSize;
          return;
        }
        // Backing with a JS array.
        if (!node.contents) node.contents = [];
        if (node.contents.length > newSize) node.contents.length = newSize;
        else while (node.contents.length < newSize) node.contents.push(0);
        node.usedBytes = newSize;
      },node_ops:{getattr:function (node) {
          var attr = {};
          // device numbers reuse inode numbers.
          attr.dev = FS.isChrdev(node.mode) ? node.id : 1;
          attr.ino = node.id;
          attr.mode = node.mode;
          attr.nlink = 1;
          attr.uid = 0;
          attr.gid = 0;
          attr.rdev = node.rdev;
          if (FS.isDir(node.mode)) {
            attr.size = 4096;
          } else if (FS.isFile(node.mode)) {
            attr.size = node.usedBytes;
          } else if (FS.isLink(node.mode)) {
            attr.size = node.link.length;
          } else {
            attr.size = 0;
          }
          attr.atime = new Date(node.timestamp);
          attr.mtime = new Date(node.timestamp);
          attr.ctime = new Date(node.timestamp);
          // NOTE: In our implementation, st_blocks = Math.ceil(st_size/st_blksize),
          //       but this is not required by the standard.
          attr.blksize = 4096;
          attr.blocks = Math.ceil(attr.size / attr.blksize);
          return attr;
        },setattr:function (node, attr) {
          if (attr.mode !== undefined) {
            node.mode = attr.mode;
          }
          if (attr.timestamp !== undefined) {
            node.timestamp = attr.timestamp;
          }
          if (attr.size !== undefined) {
            MEMFS.resizeFileStorage(node, attr.size);
          }
        },lookup:function (parent, name) {
          throw FS.genericErrors[ERRNO_CODES.ENOENT];
        },mknod:function (parent, name, mode, dev) {
          return MEMFS.createNode(parent, name, mode, dev);
        },rename:function (old_node, new_dir, new_name) {
          // if we're overwriting a directory at new_name, make sure it's empty.
          if (FS.isDir(old_node.mode)) {
            var new_node;
            try {
              new_node = FS.lookupNode(new_dir, new_name);
            } catch (e) {
            }
            if (new_node) {
              for (var i in new_node.contents) {
                throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
              }
            }
          }
          // do the internal rewiring
          delete old_node.parent.contents[old_node.name];
          old_node.name = new_name;
          new_dir.contents[new_name] = old_node;
          old_node.parent = new_dir;
        },unlink:function (parent, name) {
          delete parent.contents[name];
        },rmdir:function (parent, name) {
          var node = FS.lookupNode(parent, name);
          for (var i in node.contents) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
          }
          delete parent.contents[name];
        },readdir:function (node) {
          var entries = ['.', '..']
          for (var key in node.contents) {
            if (!node.contents.hasOwnProperty(key)) {
              continue;
            }
            entries.push(key);
          }
          return entries;
        },symlink:function (parent, newname, oldpath) {
          var node = MEMFS.createNode(parent, newname, 511 /* 0777 */ | 40960, 0);
          node.link = oldpath;
          return node;
        },readlink:function (node) {
          if (!FS.isLink(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return node.link;
        }},stream_ops:{read:function (stream, buffer, offset, length, position) {
          var contents = stream.node.contents;
          if (position >= stream.node.usedBytes) return 0;
          var size = Math.min(stream.node.usedBytes - position, length);
          assert(size >= 0);
          if (size > 8 && contents.subarray) { // non-trivial, and typed array
            buffer.set(contents.subarray(position, position + size), offset);
          } else {
            for (var i = 0; i < size; i++) buffer[offset + i] = contents[position + i];
          }
          return size;
        },write:function (stream, buffer, offset, length, position, canOwn) {
          if (!length) return 0;
          var node = stream.node;
          node.timestamp = Date.now();
  
          if (buffer.subarray && (!node.contents || node.contents.subarray)) { // This write is from a typed array to a typed array?
            if (canOwn) { // Can we just reuse the buffer we are given?
              assert(position === 0, 'canOwn must imply no weird position inside the file');
              node.contents = buffer.subarray(offset, offset + length);
              node.usedBytes = length;
              return length;
            } else if (node.usedBytes === 0 && position === 0) { // If this is a simple first write to an empty file, do a fast set since we don't need to care about old data.
              node.contents = new Uint8Array(buffer.subarray(offset, offset + length));
              node.usedBytes = length;
              return length;
            } else if (position + length <= node.usedBytes) { // Writing to an already allocated and used subrange of the file?
              node.contents.set(buffer.subarray(offset, offset + length), position);
              return length;
            }
          }
  
          // Appending to an existing file and we need to reallocate, or source data did not come as a typed array.
          MEMFS.expandFileStorage(node, position+length);
          if (node.contents.subarray && buffer.subarray) node.contents.set(buffer.subarray(offset, offset + length), position); // Use typed array write if available.
          else {
            for (var i = 0; i < length; i++) {
             node.contents[position + i] = buffer[offset + i]; // Or fall back to manual write if not.
            }
          }
          node.usedBytes = Math.max(node.usedBytes, position+length);
          return length;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              position += stream.node.usedBytes;
            }
          }
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          return position;
        },allocate:function (stream, offset, length) {
          MEMFS.expandFileStorage(stream.node, offset + length);
          stream.node.usedBytes = Math.max(stream.node.usedBytes, offset + length);
        },mmap:function (stream, buffer, offset, length, position, prot, flags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          var ptr;
          var allocated;
          var contents = stream.node.contents;
          // Only make a new copy when MAP_PRIVATE is specified.
          if ( !(flags & 2) &&
                (contents.buffer === buffer || contents.buffer === buffer.buffer) ) {
            // We can't emulate MAP_SHARED when the file is not backed by the buffer
            // we're mapping to (e.g. the HEAP buffer).
            allocated = false;
            ptr = contents.byteOffset;
          } else {
            // Try to avoid unnecessary slices.
            if (position > 0 || position + length < stream.node.usedBytes) {
              if (contents.subarray) {
                contents = contents.subarray(position, position + length);
              } else {
                contents = Array.prototype.slice.call(contents, position, position + length);
              }
            }
            allocated = true;
            ptr = _malloc(length);
            if (!ptr) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOMEM);
            }
            buffer.set(contents, ptr);
          }
          return { ptr: ptr, allocated: allocated };
        },msync:function (stream, buffer, offset, length, mmapFlags) {
          if (!FS.isFile(stream.node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
          }
          if (mmapFlags & 2) {
            // MAP_PRIVATE calls need not to be synced back to underlying fs
            return 0;
          }
  
          var bytesWritten = MEMFS.stream_ops.write(stream, buffer, 0, length, offset, false);
          // should we check if bytesWritten and length are the same?
          return 0;
        }}};
  
  var IDBFS={dbs:{},indexedDB:function () {
        if (typeof indexedDB !== 'undefined') return indexedDB;
        var ret = null;
        if (typeof window === 'object') ret = window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
        assert(ret, 'IDBFS used, but indexedDB not supported');
        return ret;
      },DB_VERSION:21,DB_STORE_NAME:"FILE_DATA",mount:function (mount) {
        // reuse all of the core MEMFS functionality
        return MEMFS.mount.apply(null, arguments);
      },syncfs:function (mount, populate, callback) {
        IDBFS.getLocalSet(mount, function(err, local) {
          if (err) return callback(err);
  
          IDBFS.getRemoteSet(mount, function(err, remote) {
            if (err) return callback(err);
  
            var src = populate ? remote : local;
            var dst = populate ? local : remote;
  
            IDBFS.reconcile(src, dst, callback);
          });
        });
      },getDB:function (name, callback) {
        // check the cache first
        var db = IDBFS.dbs[name];
        if (db) {
          return callback(null, db);
        }
  
        var req;
        try {
          req = IDBFS.indexedDB().open(name, IDBFS.DB_VERSION);
        } catch (e) {
          return callback(e);
        }
        req.onupgradeneeded = function(e) {
          var db = e.target.result;
          var transaction = e.target.transaction;
  
          var fileStore;
  
          if (db.objectStoreNames.contains(IDBFS.DB_STORE_NAME)) {
            fileStore = transaction.objectStore(IDBFS.DB_STORE_NAME);
          } else {
            fileStore = db.createObjectStore(IDBFS.DB_STORE_NAME);
          }
  
          if (!fileStore.indexNames.contains('timestamp')) {
            fileStore.createIndex('timestamp', 'timestamp', { unique: false });
          }
        };
        req.onsuccess = function() {
          db = req.result;
  
          // add to the cache
          IDBFS.dbs[name] = db;
          callback(null, db);
        };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },getLocalSet:function (mount, callback) {
        var entries = {};
  
        function isRealDir(p) {
          return p !== '.' && p !== '..';
        };
        function toAbsolute(root) {
          return function(p) {
            return PATH.join2(root, p);
          }
        };
  
        var check = FS.readdir(mount.mountpoint).filter(isRealDir).map(toAbsolute(mount.mountpoint));
  
        while (check.length) {
          var path = check.pop();
          var stat;
  
          try {
            stat = FS.stat(path);
          } catch (e) {
            return callback(e);
          }
  
          if (FS.isDir(stat.mode)) {
            check.push.apply(check, FS.readdir(path).filter(isRealDir).map(toAbsolute(path)));
          }
  
          entries[path] = { timestamp: stat.mtime };
        }
  
        return callback(null, { type: 'local', entries: entries });
      },getRemoteSet:function (mount, callback) {
        var entries = {};
  
        IDBFS.getDB(mount.mountpoint, function(err, db) {
          if (err) return callback(err);
  
          var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readonly');
          transaction.onerror = function(e) {
            callback(this.error);
            e.preventDefault();
          };
  
          var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
          var index = store.index('timestamp');
  
          index.openKeyCursor().onsuccess = function(event) {
            var cursor = event.target.result;
  
            if (!cursor) {
              return callback(null, { type: 'remote', db: db, entries: entries });
            }
  
            entries[cursor.primaryKey] = { timestamp: cursor.key };
  
            cursor.continue();
          };
        });
      },loadLocalEntry:function (path, callback) {
        var stat, node;
  
        try {
          var lookup = FS.lookupPath(path);
          node = lookup.node;
          stat = FS.stat(path);
        } catch (e) {
          return callback(e);
        }
  
        if (FS.isDir(stat.mode)) {
          return callback(null, { timestamp: stat.mtime, mode: stat.mode });
        } else if (FS.isFile(stat.mode)) {
          // Performance consideration: storing a normal JavaScript array to a IndexedDB is much slower than storing a typed array.
          // Therefore always convert the file contents to a typed array first before writing the data to IndexedDB.
          node.contents = MEMFS.getFileDataAsTypedArray(node);
          return callback(null, { timestamp: stat.mtime, mode: stat.mode, contents: node.contents });
        } else {
          return callback(new Error('node type not supported'));
        }
      },storeLocalEntry:function (path, entry, callback) {
        try {
          if (FS.isDir(entry.mode)) {
            FS.mkdir(path, entry.mode);
          } else if (FS.isFile(entry.mode)) {
            FS.writeFile(path, entry.contents, { encoding: 'binary', canOwn: true });
          } else {
            return callback(new Error('node type not supported'));
          }
  
          FS.chmod(path, entry.mode);
          FS.utime(path, entry.timestamp, entry.timestamp);
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },removeLocalEntry:function (path, callback) {
        try {
          var lookup = FS.lookupPath(path);
          var stat = FS.stat(path);
  
          if (FS.isDir(stat.mode)) {
            FS.rmdir(path);
          } else if (FS.isFile(stat.mode)) {
            FS.unlink(path);
          }
        } catch (e) {
          return callback(e);
        }
  
        callback(null);
      },loadRemoteEntry:function (store, path, callback) {
        var req = store.get(path);
        req.onsuccess = function(event) { callback(null, event.target.result); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },storeRemoteEntry:function (store, path, entry, callback) {
        var req = store.put(entry, path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },removeRemoteEntry:function (store, path, callback) {
        var req = store.delete(path);
        req.onsuccess = function() { callback(null); };
        req.onerror = function(e) {
          callback(this.error);
          e.preventDefault();
        };
      },reconcile:function (src, dst, callback) {
        var total = 0;
  
        var create = [];
        Object.keys(src.entries).forEach(function (key) {
          var e = src.entries[key];
          var e2 = dst.entries[key];
          if (!e2 || e.timestamp > e2.timestamp) {
            create.push(key);
            total++;
          }
        });
  
        var remove = [];
        Object.keys(dst.entries).forEach(function (key) {
          var e = dst.entries[key];
          var e2 = src.entries[key];
          if (!e2) {
            remove.push(key);
            total++;
          }
        });
  
        if (!total) {
          return callback(null);
        }
  
        var errored = false;
        var completed = 0;
        var db = src.type === 'remote' ? src.db : dst.db;
        var transaction = db.transaction([IDBFS.DB_STORE_NAME], 'readwrite');
        var store = transaction.objectStore(IDBFS.DB_STORE_NAME);
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= total) {
            return callback(null);
          }
        };
  
        transaction.onerror = function(e) {
          done(this.error);
          e.preventDefault();
        };
  
        // sort paths in ascending order so directory entries are created
        // before the files inside them
        create.sort().forEach(function (path) {
          if (dst.type === 'local') {
            IDBFS.loadRemoteEntry(store, path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeLocalEntry(path, entry, done);
            });
          } else {
            IDBFS.loadLocalEntry(path, function (err, entry) {
              if (err) return done(err);
              IDBFS.storeRemoteEntry(store, path, entry, done);
            });
          }
        });
  
        // sort paths in descending order so files are deleted before their
        // parent directories
        remove.sort().reverse().forEach(function(path) {
          if (dst.type === 'local') {
            IDBFS.removeLocalEntry(path, done);
          } else {
            IDBFS.removeRemoteEntry(store, path, done);
          }
        });
      }};
  
  var NODEFS={isWindows:false,staticInit:function () {
        NODEFS.isWindows = !!process.platform.match(/^win/);
      },mount:function (mount) {
        assert(ENVIRONMENT_IS_NODE);
        return NODEFS.createNode(null, '/', NODEFS.getMode(mount.opts.root), 0);
      },createNode:function (parent, name, mode, dev) {
        if (!FS.isDir(mode) && !FS.isFile(mode) && !FS.isLink(mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node = FS.createNode(parent, name, mode);
        node.node_ops = NODEFS.node_ops;
        node.stream_ops = NODEFS.stream_ops;
        return node;
      },getMode:function (path) {
        var stat;
        try {
          stat = fs.lstatSync(path);
          if (NODEFS.isWindows) {
            // On Windows, directories return permission bits 'rw-rw-rw-', even though they have 'rwxrwxrwx', so
            // propagate write bits to execute bits.
            stat.mode = stat.mode | ((stat.mode & 146) >> 1);
          }
        } catch (e) {
          if (!e.code) throw e;
          throw new FS.ErrnoError(ERRNO_CODES[e.code]);
        }
        return stat.mode;
      },realPath:function (node) {
        var parts = [];
        while (node.parent !== node) {
          parts.push(node.name);
          node = node.parent;
        }
        parts.push(node.mount.opts.root);
        parts.reverse();
        return PATH.join.apply(null, parts);
      },flagsToPermissionStringMap:{0:"r",1:"r+",2:"r+",64:"r",65:"r+",66:"r+",129:"rx+",193:"rx+",514:"w+",577:"w",578:"w+",705:"wx",706:"wx+",1024:"a",1025:"a",1026:"a+",1089:"a",1090:"a+",1153:"ax",1154:"ax+",1217:"ax",1218:"ax+",4096:"rs",4098:"rs+"},flagsToPermissionString:function (flags) {
        if (flags in NODEFS.flagsToPermissionStringMap) {
          return NODEFS.flagsToPermissionStringMap[flags];
        } else {
          return flags;
        }
      },node_ops:{getattr:function (node) {
          var path = NODEFS.realPath(node);
          var stat;
          try {
            stat = fs.lstatSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          // node.js v0.10.20 doesn't report blksize and blocks on Windows. Fake them with default blksize of 4096.
          // See http://support.microsoft.com/kb/140365
          if (NODEFS.isWindows && !stat.blksize) {
            stat.blksize = 4096;
          }
          if (NODEFS.isWindows && !stat.blocks) {
            stat.blocks = (stat.size+stat.blksize-1)/stat.blksize|0;
          }
          return {
            dev: stat.dev,
            ino: stat.ino,
            mode: stat.mode,
            nlink: stat.nlink,
            uid: stat.uid,
            gid: stat.gid,
            rdev: stat.rdev,
            size: stat.size,
            atime: stat.atime,
            mtime: stat.mtime,
            ctime: stat.ctime,
            blksize: stat.blksize,
            blocks: stat.blocks
          };
        },setattr:function (node, attr) {
          var path = NODEFS.realPath(node);
          try {
            if (attr.mode !== undefined) {
              fs.chmodSync(path, attr.mode);
              // update the common node structure mode as well
              node.mode = attr.mode;
            }
            if (attr.timestamp !== undefined) {
              var date = new Date(attr.timestamp);
              fs.utimesSync(path, date, date);
            }
            if (attr.size !== undefined) {
              fs.truncateSync(path, attr.size);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },lookup:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          var mode = NODEFS.getMode(path);
          return NODEFS.createNode(parent, name, mode);
        },mknod:function (parent, name, mode, dev) {
          var node = NODEFS.createNode(parent, name, mode, dev);
          // create the backing node for this in the fs root as well
          var path = NODEFS.realPath(node);
          try {
            if (FS.isDir(node.mode)) {
              fs.mkdirSync(path, node.mode);
            } else {
              fs.writeFileSync(path, '', { mode: node.mode });
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return node;
        },rename:function (oldNode, newDir, newName) {
          var oldPath = NODEFS.realPath(oldNode);
          var newPath = PATH.join2(NODEFS.realPath(newDir), newName);
          try {
            fs.renameSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },unlink:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.unlinkSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },rmdir:function (parent, name) {
          var path = PATH.join2(NODEFS.realPath(parent), name);
          try {
            fs.rmdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readdir:function (node) {
          var path = NODEFS.realPath(node);
          try {
            return fs.readdirSync(path);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },symlink:function (parent, newName, oldPath) {
          var newPath = PATH.join2(NODEFS.realPath(parent), newName);
          try {
            fs.symlinkSync(oldPath, newPath);
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },readlink:function (node) {
          var path = NODEFS.realPath(node);
          try {
            path = fs.readlinkSync(path);
            path = NODEJS_PATH.relative(NODEJS_PATH.resolve(node.mount.opts.root), path);
            return path;
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        }},stream_ops:{open:function (stream) {
          var path = NODEFS.realPath(stream.node);
          try {
            if (FS.isFile(stream.node.mode)) {
              stream.nfd = fs.openSync(path, NODEFS.flagsToPermissionString(stream.flags));
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },close:function (stream) {
          try {
            if (FS.isFile(stream.node.mode) && stream.nfd) {
              fs.closeSync(stream.nfd);
            }
          } catch (e) {
            if (!e.code) throw e;
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
        },read:function (stream, buffer, offset, length, position) {
          if (length === 0) return 0; // node errors on 0 length reads
          // FIXME this is terrible.
          var nbuffer = new Buffer(length);
          var res;
          try {
            res = fs.readSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          if (res > 0) {
            for (var i = 0; i < res; i++) {
              buffer[offset + i] = nbuffer[i];
            }
          }
          return res;
        },write:function (stream, buffer, offset, length, position) {
          // FIXME this is terrible.
          var nbuffer = new Buffer(buffer.subarray(offset, offset + length));
          var res;
          try {
            res = fs.writeSync(stream.nfd, nbuffer, 0, length, position);
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES[e.code]);
          }
          return res;
        },llseek:function (stream, offset, whence) {
          var position = offset;
          if (whence === 1) {  // SEEK_CUR.
            position += stream.position;
          } else if (whence === 2) {  // SEEK_END.
            if (FS.isFile(stream.node.mode)) {
              try {
                var stat = fs.fstatSync(stream.nfd);
                position += stat.size;
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES[e.code]);
              }
            }
          }
  
          if (position < 0) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
  
          return position;
        }}};
  
  var _stdin=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stdout=allocate(1, "i32*", ALLOC_STATIC);
  
  var _stderr=allocate(1, "i32*", ALLOC_STATIC);
  
  function _fflush(stream) {
      // int fflush(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fflush.html
  
      /*
      // Disabled, see https://github.com/kripken/emscripten/issues/2770
      stream = FS.getStreamFromPtr(stream);
      if (stream.stream_ops.flush) {
        stream.stream_ops.flush(stream);
      }
      */
    }var FS={root:null,mounts:[],devices:[null],streams:[],nextInode:1,nameTable:null,currentPath:"/",initialized:false,ignorePermissions:true,trackingDelegate:{},tracking:{openFlags:{READ:1,WRITE:2}},ErrnoError:null,genericErrors:{},handleFSError:function (e) {
        if (!(e instanceof FS.ErrnoError)) throw e + ' : ' + stackTrace();
        return ___setErrNo(e.errno);
      },lookupPath:function (path, opts) {
        path = PATH.resolve(FS.cwd(), path);
        opts = opts || {};
  
        if (!path) return { path: '', node: null };
  
        var defaults = {
          follow_mount: true,
          recurse_count: 0
        };
        for (var key in defaults) {
          if (opts[key] === undefined) {
            opts[key] = defaults[key];
          }
        }
  
        if (opts.recurse_count > 8) {  // max recursive lookup of 8
          throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
        }
  
        // split the path
        var parts = PATH.normalizeArray(path.split('/').filter(function(p) {
          return !!p;
        }), false);
  
        // start at the root
        var current = FS.root;
        var current_path = '/';
  
        for (var i = 0; i < parts.length; i++) {
          var islast = (i === parts.length-1);
          if (islast && opts.parent) {
            // stop resolving
            break;
          }
  
          current = FS.lookupNode(current, parts[i]);
          current_path = PATH.join2(current_path, parts[i]);
  
          // jump to the mount's root node if this is a mountpoint
          if (FS.isMountpoint(current)) {
            if (!islast || (islast && opts.follow_mount)) {
              current = current.mounted.root;
            }
          }
  
          // by default, lookupPath will not follow a symlink if it is the final path component.
          // setting opts.follow = true will override this behavior.
          if (!islast || opts.follow) {
            var count = 0;
            while (FS.isLink(current.mode)) {
              var link = FS.readlink(current_path);
              current_path = PATH.resolve(PATH.dirname(current_path), link);
  
              var lookup = FS.lookupPath(current_path, { recurse_count: opts.recurse_count });
              current = lookup.node;
  
              if (count++ > 40) {  // limit max consecutive symlinks to 40 (SYMLOOP_MAX).
                throw new FS.ErrnoError(ERRNO_CODES.ELOOP);
              }
            }
          }
        }
  
        return { path: current_path, node: current };
      },getPath:function (node) {
        var path;
        while (true) {
          if (FS.isRoot(node)) {
            var mount = node.mount.mountpoint;
            if (!path) return mount;
            return mount[mount.length-1] !== '/' ? mount + '/' + path : mount + path;
          }
          path = path ? node.name + '/' + path : node.name;
          node = node.parent;
        }
      },hashName:function (parentid, name) {
        var hash = 0;
  
  
        for (var i = 0; i < name.length; i++) {
          hash = ((hash << 5) - hash + name.charCodeAt(i)) | 0;
        }
        return ((parentid + hash) >>> 0) % FS.nameTable.length;
      },hashAddNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        node.name_next = FS.nameTable[hash];
        FS.nameTable[hash] = node;
      },hashRemoveNode:function (node) {
        var hash = FS.hashName(node.parent.id, node.name);
        if (FS.nameTable[hash] === node) {
          FS.nameTable[hash] = node.name_next;
        } else {
          var current = FS.nameTable[hash];
          while (current) {
            if (current.name_next === node) {
              current.name_next = node.name_next;
              break;
            }
            current = current.name_next;
          }
        }
      },lookupNode:function (parent, name) {
        var err = FS.mayLookup(parent);
        if (err) {
          throw new FS.ErrnoError(err, parent);
        }
        var hash = FS.hashName(parent.id, name);
        for (var node = FS.nameTable[hash]; node; node = node.name_next) {
          var nodeName = node.name;
          if (node.parent.id === parent.id && nodeName === name) {
            return node;
          }
        }
        // if we failed to find it in the cache, call into the VFS
        return FS.lookup(parent, name);
      },createNode:function (parent, name, mode, rdev) {
        if (!FS.FSNode) {
          FS.FSNode = function(parent, name, mode, rdev) {
            if (!parent) {
              parent = this;  // root node sets parent to itself
            }
            this.parent = parent;
            this.mount = parent.mount;
            this.mounted = null;
            this.id = FS.nextInode++;
            this.name = name;
            this.mode = mode;
            this.node_ops = {};
            this.stream_ops = {};
            this.rdev = rdev;
          };
  
          FS.FSNode.prototype = {};
  
          // compatibility
          var readMode = 292 | 73;
          var writeMode = 146;
  
          // NOTE we must use Object.defineProperties instead of individual calls to
          // Object.defineProperty in order to make closure compiler happy
          Object.defineProperties(FS.FSNode.prototype, {
            read: {
              get: function() { return (this.mode & readMode) === readMode; },
              set: function(val) { val ? this.mode |= readMode : this.mode &= ~readMode; }
            },
            write: {
              get: function() { return (this.mode & writeMode) === writeMode; },
              set: function(val) { val ? this.mode |= writeMode : this.mode &= ~writeMode; }
            },
            isFolder: {
              get: function() { return FS.isDir(this.mode); }
            },
            isDevice: {
              get: function() { return FS.isChrdev(this.mode); }
            }
          });
        }
  
        var node = new FS.FSNode(parent, name, mode, rdev);
  
        FS.hashAddNode(node);
  
        return node;
      },destroyNode:function (node) {
        FS.hashRemoveNode(node);
      },isRoot:function (node) {
        return node === node.parent;
      },isMountpoint:function (node) {
        return !!node.mounted;
      },isFile:function (mode) {
        return (mode & 61440) === 32768;
      },isDir:function (mode) {
        return (mode & 61440) === 16384;
      },isLink:function (mode) {
        return (mode & 61440) === 40960;
      },isChrdev:function (mode) {
        return (mode & 61440) === 8192;
      },isBlkdev:function (mode) {
        return (mode & 61440) === 24576;
      },isFIFO:function (mode) {
        return (mode & 61440) === 4096;
      },isSocket:function (mode) {
        return (mode & 49152) === 49152;
      },flagModes:{"r":0,"rs":1052672,"r+":2,"w":577,"wx":705,"xw":705,"w+":578,"wx+":706,"xw+":706,"a":1089,"ax":1217,"xa":1217,"a+":1090,"ax+":1218,"xa+":1218},modeStringToFlags:function (str) {
        var flags = FS.flagModes[str];
        if (typeof flags === 'undefined') {
          throw new Error('Unknown file open mode: ' + str);
        }
        return flags;
      },flagsToPermissionString:function (flag) {
        var accmode = flag & 2097155;
        var perms = ['r', 'w', 'rw'][accmode];
        if ((flag & 512)) {
          perms += 'w';
        }
        return perms;
      },nodePermissions:function (node, perms) {
        if (FS.ignorePermissions) {
          return 0;
        }
        // return 0 if any user, group or owner bits are set.
        if (perms.indexOf('r') !== -1 && !(node.mode & 292)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('w') !== -1 && !(node.mode & 146)) {
          return ERRNO_CODES.EACCES;
        } else if (perms.indexOf('x') !== -1 && !(node.mode & 73)) {
          return ERRNO_CODES.EACCES;
        }
        return 0;
      },mayLookup:function (dir) {
        var err = FS.nodePermissions(dir, 'x');
        if (err) return err;
        if (!dir.node_ops.lookup) return ERRNO_CODES.EACCES;
        return 0;
      },mayCreate:function (dir, name) {
        try {
          var node = FS.lookupNode(dir, name);
          return ERRNO_CODES.EEXIST;
        } catch (e) {
        }
        return FS.nodePermissions(dir, 'wx');
      },mayDelete:function (dir, name, isdir) {
        var node;
        try {
          node = FS.lookupNode(dir, name);
        } catch (e) {
          return e.errno;
        }
        var err = FS.nodePermissions(dir, 'wx');
        if (err) {
          return err;
        }
        if (isdir) {
          if (!FS.isDir(node.mode)) {
            return ERRNO_CODES.ENOTDIR;
          }
          if (FS.isRoot(node) || FS.getPath(node) === FS.cwd()) {
            return ERRNO_CODES.EBUSY;
          }
        } else {
          if (FS.isDir(node.mode)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return 0;
      },mayOpen:function (node, flags) {
        if (!node) {
          return ERRNO_CODES.ENOENT;
        }
        if (FS.isLink(node.mode)) {
          return ERRNO_CODES.ELOOP;
        } else if (FS.isDir(node.mode)) {
          if ((flags & 2097155) !== 0 ||  // opening for write
              (flags & 512)) {
            return ERRNO_CODES.EISDIR;
          }
        }
        return FS.nodePermissions(node, FS.flagsToPermissionString(flags));
      },MAX_OPEN_FDS:4096,nextfd:function (fd_start, fd_end) {
        fd_start = fd_start || 0;
        fd_end = fd_end || FS.MAX_OPEN_FDS;
        for (var fd = fd_start; fd <= fd_end; fd++) {
          if (!FS.streams[fd]) {
            return fd;
          }
        }
        throw new FS.ErrnoError(ERRNO_CODES.EMFILE);
      },getStream:function (fd) {
        return FS.streams[fd];
      },createStream:function (stream, fd_start, fd_end) {
        if (!FS.FSStream) {
          FS.FSStream = function(){};
          FS.FSStream.prototype = {};
          // compatibility
          Object.defineProperties(FS.FSStream.prototype, {
            object: {
              get: function() { return this.node; },
              set: function(val) { this.node = val; }
            },
            isRead: {
              get: function() { return (this.flags & 2097155) !== 1; }
            },
            isWrite: {
              get: function() { return (this.flags & 2097155) !== 0; }
            },
            isAppend: {
              get: function() { return (this.flags & 1024); }
            }
          });
        }
        // clone it, so we can return an instance of FSStream
        var newStream = new FS.FSStream();
        for (var p in stream) {
          newStream[p] = stream[p];
        }
        stream = newStream;
        var fd = FS.nextfd(fd_start, fd_end);
        stream.fd = fd;
        FS.streams[fd] = stream;
        return stream;
      },closeStream:function (fd) {
        FS.streams[fd] = null;
      },getStreamFromPtr:function (ptr) {
        return FS.streams[ptr - 1];
      },getPtrForStream:function (stream) {
        return stream ? stream.fd + 1 : 0;
      },chrdev_stream_ops:{open:function (stream) {
          var device = FS.getDevice(stream.node.rdev);
          // override node's stream ops with the device's
          stream.stream_ops = device.stream_ops;
          // forward the open call
          if (stream.stream_ops.open) {
            stream.stream_ops.open(stream);
          }
        },llseek:function () {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }},major:function (dev) {
        return ((dev) >> 8);
      },minor:function (dev) {
        return ((dev) & 0xff);
      },makedev:function (ma, mi) {
        return ((ma) << 8 | (mi));
      },registerDevice:function (dev, ops) {
        FS.devices[dev] = { stream_ops: ops };
      },getDevice:function (dev) {
        return FS.devices[dev];
      },getMounts:function (mount) {
        var mounts = [];
        var check = [mount];
  
        while (check.length) {
          var m = check.pop();
  
          mounts.push(m);
  
          check.push.apply(check, m.mounts);
        }
  
        return mounts;
      },syncfs:function (populate, callback) {
        if (typeof(populate) === 'function') {
          callback = populate;
          populate = false;
        }
  
        var mounts = FS.getMounts(FS.root.mount);
        var completed = 0;
  
        function done(err) {
          if (err) {
            if (!done.errored) {
              done.errored = true;
              return callback(err);
            }
            return;
          }
          if (++completed >= mounts.length) {
            callback(null);
          }
        };
  
        // sync all mounts
        mounts.forEach(function (mount) {
          if (!mount.type.syncfs) {
            return done(null);
          }
          mount.type.syncfs(mount, populate, done);
        });
      },mount:function (type, opts, mountpoint) {
        var root = mountpoint === '/';
        var pseudo = !mountpoint;
        var node;
  
        if (root && FS.root) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        } else if (!root && !pseudo) {
          var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
          mountpoint = lookup.path;  // use the absolute path
          node = lookup.node;
  
          if (FS.isMountpoint(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
          }
  
          if (!FS.isDir(node.mode)) {
            throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
          }
        }
  
        var mount = {
          type: type,
          opts: opts,
          mountpoint: mountpoint,
          mounts: []
        };
  
        // create a root node for the fs
        var mountRoot = type.mount(mount);
        mountRoot.mount = mount;
        mount.root = mountRoot;
  
        if (root) {
          FS.root = mountRoot;
        } else if (node) {
          // set as a mountpoint
          node.mounted = mount;
  
          // add the new mount to the current mount's children
          if (node.mount) {
            node.mount.mounts.push(mount);
          }
        }
  
        return mountRoot;
      },unmount:function (mountpoint) {
        var lookup = FS.lookupPath(mountpoint, { follow_mount: false });
  
        if (!FS.isMountpoint(lookup.node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
  
        // destroy the nodes for this mount, and all its child mounts
        var node = lookup.node;
        var mount = node.mounted;
        var mounts = FS.getMounts(mount);
  
        Object.keys(FS.nameTable).forEach(function (hash) {
          var current = FS.nameTable[hash];
  
          while (current) {
            var next = current.name_next;
  
            if (mounts.indexOf(current.mount) !== -1) {
              FS.destroyNode(current);
            }
  
            current = next;
          }
        });
  
        // no longer a mountpoint
        node.mounted = null;
  
        // remove this mount from the child mounts
        var idx = node.mount.mounts.indexOf(mount);
        assert(idx !== -1);
        node.mount.mounts.splice(idx, 1);
      },lookup:function (parent, name) {
        return parent.node_ops.lookup(parent, name);
      },mknod:function (path, mode, dev) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        if (!name || name === '.' || name === '..') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.mayCreate(parent, name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.mknod) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.mknod(parent, name, mode, dev);
      },create:function (path, mode) {
        mode = mode !== undefined ? mode : 438 /* 0666 */;
        mode &= 4095;
        mode |= 32768;
        return FS.mknod(path, mode, 0);
      },mkdir:function (path, mode) {
        mode = mode !== undefined ? mode : 511 /* 0777 */;
        mode &= 511 | 512;
        mode |= 16384;
        return FS.mknod(path, mode, 0);
      },mkdev:function (path, mode, dev) {
        if (typeof(dev) === 'undefined') {
          dev = mode;
          mode = 438 /* 0666 */;
        }
        mode |= 8192;
        return FS.mknod(path, mode, dev);
      },symlink:function (oldpath, newpath) {
        if (!PATH.resolve(oldpath)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var lookup = FS.lookupPath(newpath, { parent: true });
        var parent = lookup.node;
        if (!parent) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        var newname = PATH.basename(newpath);
        var err = FS.mayCreate(parent, newname);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.symlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return parent.node_ops.symlink(parent, newname, oldpath);
      },rename:function (old_path, new_path) {
        var old_dirname = PATH.dirname(old_path);
        var new_dirname = PATH.dirname(new_path);
        var old_name = PATH.basename(old_path);
        var new_name = PATH.basename(new_path);
        // parents must exist
        var lookup, old_dir, new_dir;
        try {
          lookup = FS.lookupPath(old_path, { parent: true });
          old_dir = lookup.node;
          lookup = FS.lookupPath(new_path, { parent: true });
          new_dir = lookup.node;
        } catch (e) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        if (!old_dir || !new_dir) throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        // need to be part of the same mount
        if (old_dir.mount !== new_dir.mount) {
          throw new FS.ErrnoError(ERRNO_CODES.EXDEV);
        }
        // source must exist
        var old_node = FS.lookupNode(old_dir, old_name);
        // old path should not be an ancestor of the new path
        var relative = PATH.relative(old_path, new_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        // new path should not be an ancestor of the old path
        relative = PATH.relative(new_path, old_dirname);
        if (relative.charAt(0) !== '.') {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTEMPTY);
        }
        // see if the new path already exists
        var new_node;
        try {
          new_node = FS.lookupNode(new_dir, new_name);
        } catch (e) {
          // not fatal
        }
        // early out if nothing needs to change
        if (old_node === new_node) {
          return;
        }
        // we'll need to delete the old entry
        var isdir = FS.isDir(old_node.mode);
        var err = FS.mayDelete(old_dir, old_name, isdir);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        // need delete permissions if we'll be overwriting.
        // need create permissions if new doesn't already exist.
        err = new_node ?
          FS.mayDelete(new_dir, new_name, isdir) :
          FS.mayCreate(new_dir, new_name);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!old_dir.node_ops.rename) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(old_node) || (new_node && FS.isMountpoint(new_node))) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        // if we are going to change the parent, check write permissions
        if (new_dir !== old_dir) {
          err = FS.nodePermissions(old_dir, 'w');
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        try {
          if (FS.trackingDelegate['willMovePath']) {
            FS.trackingDelegate['willMovePath'](old_path, new_path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
        // remove the node from the lookup hash
        FS.hashRemoveNode(old_node);
        // do the underlying fs rename
        try {
          old_dir.node_ops.rename(old_node, new_dir, new_name);
        } catch (e) {
          throw e;
        } finally {
          // add the node back to the hash (in case node_ops.rename
          // changed its name)
          FS.hashAddNode(old_node);
        }
        try {
          if (FS.trackingDelegate['onMovePath']) FS.trackingDelegate['onMovePath'](old_path, new_path);
        } catch(e) {
          console.log("FS.trackingDelegate['onMovePath']('"+old_path+"', '"+new_path+"') threw an exception: " + e.message);
        }
      },rmdir:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, true);
        if (err) {
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.rmdir) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.rmdir(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        if (!node.node_ops.readdir) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        return node.node_ops.readdir(node);
      },unlink:function (path) {
        var lookup = FS.lookupPath(path, { parent: true });
        var parent = lookup.node;
        var name = PATH.basename(path);
        var node = FS.lookupNode(parent, name);
        var err = FS.mayDelete(parent, name, false);
        if (err) {
          // POSIX says unlink should set EPERM, not EISDIR
          if (err === ERRNO_CODES.EISDIR) err = ERRNO_CODES.EPERM;
          throw new FS.ErrnoError(err);
        }
        if (!parent.node_ops.unlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isMountpoint(node)) {
          throw new FS.ErrnoError(ERRNO_CODES.EBUSY);
        }
        try {
          if (FS.trackingDelegate['willDeletePath']) {
            FS.trackingDelegate['willDeletePath'](path);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['willDeletePath']('"+path+"') threw an exception: " + e.message);
        }
        parent.node_ops.unlink(parent, name);
        FS.destroyNode(node);
        try {
          if (FS.trackingDelegate['onDeletePath']) FS.trackingDelegate['onDeletePath'](path);
        } catch(e) {
          console.log("FS.trackingDelegate['onDeletePath']('"+path+"') threw an exception: " + e.message);
        }
      },readlink:function (path) {
        var lookup = FS.lookupPath(path);
        var link = lookup.node;
        if (!link) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!link.node_ops.readlink) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        return PATH.resolve(FS.getPath(lookup.node.parent), link.node_ops.readlink(link));
      },stat:function (path, dontFollow) {
        var lookup = FS.lookupPath(path, { follow: !dontFollow });
        var node = lookup.node;
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        if (!node.node_ops.getattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        return node.node_ops.getattr(node);
      },lstat:function (path) {
        return FS.stat(path, true);
      },chmod:function (path, mode, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          mode: (mode & 4095) | (node.mode & ~4095),
          timestamp: Date.now()
        });
      },lchmod:function (path, mode) {
        FS.chmod(path, mode, true);
      },fchmod:function (fd, mode) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chmod(stream.node, mode);
      },chown:function (path, uid, gid, dontFollow) {
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: !dontFollow });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        node.node_ops.setattr(node, {
          timestamp: Date.now()
          // we ignore the uid / gid for now
        });
      },lchown:function (path, uid, gid) {
        FS.chown(path, uid, gid, true);
      },fchown:function (fd, uid, gid) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        FS.chown(stream.node, uid, gid);
      },truncate:function (path, len) {
        if (len < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var node;
        if (typeof path === 'string') {
          var lookup = FS.lookupPath(path, { follow: true });
          node = lookup.node;
        } else {
          node = path;
        }
        if (!node.node_ops.setattr) {
          throw new FS.ErrnoError(ERRNO_CODES.EPERM);
        }
        if (FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!FS.isFile(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var err = FS.nodePermissions(node, 'w');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        node.node_ops.setattr(node, {
          size: len,
          timestamp: Date.now()
        });
      },ftruncate:function (fd, len) {
        var stream = FS.getStream(fd);
        if (!stream) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        FS.truncate(stream.node, len);
      },utime:function (path, atime, mtime) {
        var lookup = FS.lookupPath(path, { follow: true });
        var node = lookup.node;
        node.node_ops.setattr(node, {
          timestamp: Math.max(atime, mtime)
        });
      },open:function (path, flags, mode, fd_start, fd_end) {
        if (path === "") {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        flags = typeof flags === 'string' ? FS.modeStringToFlags(flags) : flags;
        mode = typeof mode === 'undefined' ? 438 /* 0666 */ : mode;
        if ((flags & 64)) {
          mode = (mode & 4095) | 32768;
        } else {
          mode = 0;
        }
        var node;
        if (typeof path === 'object') {
          node = path;
        } else {
          path = PATH.normalize(path);
          try {
            var lookup = FS.lookupPath(path, {
              follow: !(flags & 131072)
            });
            node = lookup.node;
          } catch (e) {
            // ignore
          }
        }
        // perhaps we need to create the node
        var created = false;
        if ((flags & 64)) {
          if (node) {
            // if O_CREAT and O_EXCL are set, error out if the node already exists
            if ((flags & 128)) {
              throw new FS.ErrnoError(ERRNO_CODES.EEXIST);
            }
          } else {
            // node doesn't exist, try to create it
            node = FS.mknod(path, mode, 0);
            created = true;
          }
        }
        if (!node) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOENT);
        }
        // can't truncate a device
        if (FS.isChrdev(node.mode)) {
          flags &= ~512;
        }
        // check permissions, if this is not a file we just created now (it is ok to
        // create and write to a file with read-only permissions; it is read-only
        // for later use)
        if (!created) {
          var err = FS.mayOpen(node, flags);
          if (err) {
            throw new FS.ErrnoError(err);
          }
        }
        // do truncation if necessary
        if ((flags & 512)) {
          FS.truncate(node, 0);
        }
        // we've already handled these, don't pass down to the underlying vfs
        flags &= ~(128 | 512);
  
        // register the stream with the filesystem
        var stream = FS.createStream({
          node: node,
          path: FS.getPath(node),  // we want the absolute path to the node
          flags: flags,
          seekable: true,
          position: 0,
          stream_ops: node.stream_ops,
          // used by the file family libc calls (fopen, fwrite, ferror, etc.)
          ungotten: [],
          error: false
        }, fd_start, fd_end);
        // call the new stream's open function
        if (stream.stream_ops.open) {
          stream.stream_ops.open(stream);
        }
        if (Module['logReadFiles'] && !(flags & 1)) {
          if (!FS.readFiles) FS.readFiles = {};
          if (!(path in FS.readFiles)) {
            FS.readFiles[path] = 1;
            Module['printErr']('read file: ' + path);
          }
        }
        try {
          if (FS.trackingDelegate['onOpenFile']) {
            var trackingFlags = 0;
            if ((flags & 2097155) !== 1) {
              trackingFlags |= FS.tracking.openFlags.READ;
            }
            if ((flags & 2097155) !== 0) {
              trackingFlags |= FS.tracking.openFlags.WRITE;
            }
            FS.trackingDelegate['onOpenFile'](path, trackingFlags);
          }
        } catch(e) {
          console.log("FS.trackingDelegate['onOpenFile']('"+path+"', flags) threw an exception: " + e.message);
        }
        return stream;
      },close:function (stream) {
        try {
          if (stream.stream_ops.close) {
            stream.stream_ops.close(stream);
          }
        } catch (e) {
          throw e;
        } finally {
          FS.closeStream(stream.fd);
        }
      },llseek:function (stream, offset, whence) {
        if (!stream.seekable || !stream.stream_ops.llseek) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        stream.position = stream.stream_ops.llseek(stream, offset, whence);
        stream.ungotten = [];
        return stream.position;
      },read:function (stream, buffer, offset, length, position) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.read) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesRead = stream.stream_ops.read(stream, buffer, offset, length, position);
        if (!seeking) stream.position += bytesRead;
        return bytesRead;
      },write:function (stream, buffer, offset, length, position, canOwn) {
        if (length < 0 || position < 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (FS.isDir(stream.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.EISDIR);
        }
        if (!stream.stream_ops.write) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if (stream.flags & 1024) {
          // seek to the end before writing in append mode
          FS.llseek(stream, 0, 2);
        }
        var seeking = true;
        if (typeof position === 'undefined') {
          position = stream.position;
          seeking = false;
        } else if (!stream.seekable) {
          throw new FS.ErrnoError(ERRNO_CODES.ESPIPE);
        }
        var bytesWritten = stream.stream_ops.write(stream, buffer, offset, length, position, canOwn);
        if (!seeking) stream.position += bytesWritten;
        try {
          if (stream.path && FS.trackingDelegate['onWriteToFile']) FS.trackingDelegate['onWriteToFile'](stream.path);
        } catch(e) {
          console.log("FS.trackingDelegate['onWriteToFile']('"+path+"') threw an exception: " + e.message);
        }
        return bytesWritten;
      },allocate:function (stream, offset, length) {
        if (offset < 0 || length <= 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
        }
        if ((stream.flags & 2097155) === 0) {
          throw new FS.ErrnoError(ERRNO_CODES.EBADF);
        }
        if (!FS.isFile(stream.node.mode) && !FS.isDir(node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        if (!stream.stream_ops.allocate) {
          throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
        }
        stream.stream_ops.allocate(stream, offset, length);
      },mmap:function (stream, buffer, offset, length, position, prot, flags) {
        // TODO if PROT is PROT_WRITE, make sure we have write access
        if ((stream.flags & 2097155) === 1) {
          throw new FS.ErrnoError(ERRNO_CODES.EACCES);
        }
        if (!stream.stream_ops.mmap) {
          throw new FS.ErrnoError(ERRNO_CODES.ENODEV);
        }
        return stream.stream_ops.mmap(stream, buffer, offset, length, position, prot, flags);
      },msync:function (stream, buffer, offset, length, mmapFlags) {
        if (!stream || !stream.stream_ops.msync) {
          return 0;
        }
        return stream.stream_ops.msync(stream, buffer, offset, length, mmapFlags);
      },munmap:function (stream) {
        return 0;
      },ioctl:function (stream, cmd, arg) {
        if (!stream.stream_ops.ioctl) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTTY);
        }
        return stream.stream_ops.ioctl(stream, cmd, arg);
      },readFile:function (path, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'r';
        opts.encoding = opts.encoding || 'binary';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var ret;
        var stream = FS.open(path, opts.flags);
        var stat = FS.stat(path);
        var length = stat.size;
        var buf = new Uint8Array(length);
        FS.read(stream, buf, 0, length, 0);
        if (opts.encoding === 'utf8') {
          ret = UTF8ArrayToString(buf, 0);
        } else if (opts.encoding === 'binary') {
          ret = buf;
        }
        FS.close(stream);
        return ret;
      },writeFile:function (path, data, opts) {
        opts = opts || {};
        opts.flags = opts.flags || 'w';
        opts.encoding = opts.encoding || 'utf8';
        if (opts.encoding !== 'utf8' && opts.encoding !== 'binary') {
          throw new Error('Invalid encoding type "' + opts.encoding + '"');
        }
        var stream = FS.open(path, opts.flags, opts.mode);
        if (opts.encoding === 'utf8') {
          var buf = new Uint8Array(lengthBytesUTF8(data)+1);
          var actualNumBytes = stringToUTF8Array(data, buf, 0, buf.length);
          FS.write(stream, buf, 0, actualNumBytes, 0, opts.canOwn);
        } else if (opts.encoding === 'binary') {
          FS.write(stream, data, 0, data.length, 0, opts.canOwn);
        }
        FS.close(stream);
      },cwd:function () {
        return FS.currentPath;
      },chdir:function (path) {
        var lookup = FS.lookupPath(path, { follow: true });
        if (!FS.isDir(lookup.node.mode)) {
          throw new FS.ErrnoError(ERRNO_CODES.ENOTDIR);
        }
        var err = FS.nodePermissions(lookup.node, 'x');
        if (err) {
          throw new FS.ErrnoError(err);
        }
        FS.currentPath = lookup.path;
      },createDefaultDirectories:function () {
        FS.mkdir('/tmp');
        FS.mkdir('/home');
        FS.mkdir('/home/web_user');
      },createDefaultDevices:function () {
        // create /dev
        FS.mkdir('/dev');
        // setup /dev/null
        FS.registerDevice(FS.makedev(1, 3), {
          read: function() { return 0; },
          write: function(stream, buffer, offset, length, pos) { return length; }
        });
        FS.mkdev('/dev/null', FS.makedev(1, 3));
        // setup /dev/tty and /dev/tty1
        // stderr needs to print output using Module['printErr']
        // so we register a second tty just for it.
        TTY.register(FS.makedev(5, 0), TTY.default_tty_ops);
        TTY.register(FS.makedev(6, 0), TTY.default_tty1_ops);
        FS.mkdev('/dev/tty', FS.makedev(5, 0));
        FS.mkdev('/dev/tty1', FS.makedev(6, 0));
        // setup /dev/[u]random
        var random_device;
        if (typeof crypto !== 'undefined') {
          // for modern web browsers
          var randomBuffer = new Uint8Array(1);
          random_device = function() { crypto.getRandomValues(randomBuffer); return randomBuffer[0]; };
        } else if (ENVIRONMENT_IS_NODE) {
          // for nodejs
          random_device = function() { return require('crypto').randomBytes(1)[0]; };
        } else {
          // default for ES5 platforms
          random_device = function() { return (Math.random()*256)|0; };
        }
        FS.createDevice('/dev', 'random', random_device);
        FS.createDevice('/dev', 'urandom', random_device);
        // we're not going to emulate the actual shm device,
        // just create the tmp dirs that reside in it commonly
        FS.mkdir('/dev/shm');
        FS.mkdir('/dev/shm/tmp');
      },createStandardStreams:function () {
        // TODO deprecate the old functionality of a single
        // input / output callback and that utilizes FS.createDevice
        // and instead require a unique set of stream ops
  
        // by default, we symlink the standard streams to the
        // default tty devices. however, if the standard streams
        // have been overwritten we create a unique device for
        // them instead.
        if (Module['stdin']) {
          FS.createDevice('/dev', 'stdin', Module['stdin']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdin');
        }
        if (Module['stdout']) {
          FS.createDevice('/dev', 'stdout', null, Module['stdout']);
        } else {
          FS.symlink('/dev/tty', '/dev/stdout');
        }
        if (Module['stderr']) {
          FS.createDevice('/dev', 'stderr', null, Module['stderr']);
        } else {
          FS.symlink('/dev/tty1', '/dev/stderr');
        }
  
        // open default streams for the stdin, stdout and stderr devices
        var stdin = FS.open('/dev/stdin', 'r');
        HEAP32[((_stdin)>>2)]=FS.getPtrForStream(stdin);
        assert(stdin.fd === 0, 'invalid handle for stdin (' + stdin.fd + ')');
  
        var stdout = FS.open('/dev/stdout', 'w');
        HEAP32[((_stdout)>>2)]=FS.getPtrForStream(stdout);
        assert(stdout.fd === 1, 'invalid handle for stdout (' + stdout.fd + ')');
  
        var stderr = FS.open('/dev/stderr', 'w');
        HEAP32[((_stderr)>>2)]=FS.getPtrForStream(stderr);
        assert(stderr.fd === 2, 'invalid handle for stderr (' + stderr.fd + ')');
      },ensureErrnoError:function () {
        if (FS.ErrnoError) return;
        FS.ErrnoError = function ErrnoError(errno, node) {
          this.node = node;
          this.setErrno = function(errno) {
            this.errno = errno;
            for (var key in ERRNO_CODES) {
              if (ERRNO_CODES[key] === errno) {
                this.code = key;
                break;
              }
            }
          };
          this.setErrno(errno);
          this.message = ERRNO_MESSAGES[errno];
          if (this.stack) this.stack = demangleAll(this.stack);
        };
        FS.ErrnoError.prototype = new Error();
        FS.ErrnoError.prototype.constructor = FS.ErrnoError;
        // Some errors may happen quite a bit, to avoid overhead we reuse them (and suffer a lack of stack info)
        [ERRNO_CODES.ENOENT].forEach(function(code) {
          FS.genericErrors[code] = new FS.ErrnoError(code);
          FS.genericErrors[code].stack = '<generic error, no stack>';
        });
      },staticInit:function () {
        FS.ensureErrnoError();
  
        FS.nameTable = new Array(4096);
  
        FS.mount(MEMFS, {}, '/');
  
        FS.createDefaultDirectories();
        FS.createDefaultDevices();
      },init:function (input, output, error) {
        assert(!FS.init.initialized, 'FS.init was previously called. If you want to initialize later with custom parameters, remove any earlier calls (note that one is automatically added to the generated code)');
        FS.init.initialized = true;
  
        FS.ensureErrnoError();
  
        // Allow Module.stdin etc. to provide defaults, if none explicitly passed to us here
        Module['stdin'] = input || Module['stdin'];
        Module['stdout'] = output || Module['stdout'];
        Module['stderr'] = error || Module['stderr'];
  
        FS.createStandardStreams();
      },quit:function () {
        FS.init.initialized = false;
        for (var i = 0; i < FS.streams.length; i++) {
          var stream = FS.streams[i];
          if (!stream) {
            continue;
          }
          FS.close(stream);
        }
      },getMode:function (canRead, canWrite) {
        var mode = 0;
        if (canRead) mode |= 292 | 73;
        if (canWrite) mode |= 146;
        return mode;
      },joinPath:function (parts, forceRelative) {
        var path = PATH.join.apply(null, parts);
        if (forceRelative && path[0] == '/') path = path.substr(1);
        return path;
      },absolutePath:function (relative, base) {
        return PATH.resolve(base, relative);
      },standardizePath:function (path) {
        return PATH.normalize(path);
      },findObject:function (path, dontResolveLastLink) {
        var ret = FS.analyzePath(path, dontResolveLastLink);
        if (ret.exists) {
          return ret.object;
        } else {
          ___setErrNo(ret.error);
          return null;
        }
      },analyzePath:function (path, dontResolveLastLink) {
        // operate from within the context of the symlink's target
        try {
          var lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          path = lookup.path;
        } catch (e) {
        }
        var ret = {
          isRoot: false, exists: false, error: 0, name: null, path: null, object: null,
          parentExists: false, parentPath: null, parentObject: null
        };
        try {
          var lookup = FS.lookupPath(path, { parent: true });
          ret.parentExists = true;
          ret.parentPath = lookup.path;
          ret.parentObject = lookup.node;
          ret.name = PATH.basename(path);
          lookup = FS.lookupPath(path, { follow: !dontResolveLastLink });
          ret.exists = true;
          ret.path = lookup.path;
          ret.object = lookup.node;
          ret.name = lookup.node.name;
          ret.isRoot = lookup.path === '/';
        } catch (e) {
          ret.error = e.errno;
        };
        return ret;
      },createFolder:function (parent, name, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.mkdir(path, mode);
      },createPath:function (parent, path, canRead, canWrite) {
        parent = typeof parent === 'string' ? parent : FS.getPath(parent);
        var parts = path.split('/').reverse();
        while (parts.length) {
          var part = parts.pop();
          if (!part) continue;
          var current = PATH.join2(parent, part);
          try {
            FS.mkdir(current);
          } catch (e) {
            // ignore EEXIST
          }
          parent = current;
        }
        return current;
      },createFile:function (parent, name, properties, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(canRead, canWrite);
        return FS.create(path, mode);
      },createDataFile:function (parent, name, data, canRead, canWrite, canOwn) {
        var path = name ? PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name) : parent;
        var mode = FS.getMode(canRead, canWrite);
        var node = FS.create(path, mode);
        if (data) {
          if (typeof data === 'string') {
            var arr = new Array(data.length);
            for (var i = 0, len = data.length; i < len; ++i) arr[i] = data.charCodeAt(i);
            data = arr;
          }
          // make sure we can write to the file
          FS.chmod(node, mode | 146);
          var stream = FS.open(node, 'w');
          FS.write(stream, data, 0, data.length, 0, canOwn);
          FS.close(stream);
          FS.chmod(node, mode);
        }
        return node;
      },createDevice:function (parent, name, input, output) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        var mode = FS.getMode(!!input, !!output);
        if (!FS.createDevice.major) FS.createDevice.major = 64;
        var dev = FS.makedev(FS.createDevice.major++, 0);
        // Create a fake device that a set of stream ops to emulate
        // the old behavior.
        FS.registerDevice(dev, {
          open: function(stream) {
            stream.seekable = false;
          },
          close: function(stream) {
            // flush any pending line data
            if (output && output.buffer && output.buffer.length) {
              output(10);
            }
          },
          read: function(stream, buffer, offset, length, pos /* ignored */) {
            var bytesRead = 0;
            for (var i = 0; i < length; i++) {
              var result;
              try {
                result = input();
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
              if (result === undefined && bytesRead === 0) {
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
              if (result === null || result === undefined) break;
              bytesRead++;
              buffer[offset+i] = result;
            }
            if (bytesRead) {
              stream.node.timestamp = Date.now();
            }
            return bytesRead;
          },
          write: function(stream, buffer, offset, length, pos) {
            for (var i = 0; i < length; i++) {
              try {
                output(buffer[offset+i]);
              } catch (e) {
                throw new FS.ErrnoError(ERRNO_CODES.EIO);
              }
            }
            if (length) {
              stream.node.timestamp = Date.now();
            }
            return i;
          }
        });
        return FS.mkdev(path, mode, dev);
      },createLink:function (parent, name, target, canRead, canWrite) {
        var path = PATH.join2(typeof parent === 'string' ? parent : FS.getPath(parent), name);
        return FS.symlink(target, path);
      },forceLoadFile:function (obj) {
        if (obj.isDevice || obj.isFolder || obj.link || obj.contents) return true;
        var success = true;
        if (typeof XMLHttpRequest !== 'undefined') {
          throw new Error("Lazy loading should have been performed (contents set) in createLazyFile, but it was not. Lazy loading only works in web workers. Use --embed-file or --preload-file in emcc on the main thread.");
        } else if (Module['read']) {
          // Command-line.
          try {
            // WARNING: Can't read binary files in V8's d8 or tracemonkey's js, as
            //          read() will try to parse UTF8.
            obj.contents = intArrayFromString(Module['read'](obj.url), true);
            obj.usedBytes = obj.contents.length;
          } catch (e) {
            success = false;
          }
        } else {
          throw new Error('Cannot load without read() or XMLHttpRequest.');
        }
        if (!success) ___setErrNo(ERRNO_CODES.EIO);
        return success;
      },createLazyFile:function (parent, name, url, canRead, canWrite) {
        // Lazy chunked Uint8Array (implements get and length from Uint8Array). Actual getting is abstracted away for eventual reuse.
        function LazyUint8Array() {
          this.lengthKnown = false;
          this.chunks = []; // Loaded chunks. Index is the chunk number
        }
        LazyUint8Array.prototype.get = function LazyUint8Array_get(idx) {
          if (idx > this.length-1 || idx < 0) {
            return undefined;
          }
          var chunkOffset = idx % this.chunkSize;
          var chunkNum = (idx / this.chunkSize)|0;
          return this.getter(chunkNum)[chunkOffset];
        }
        LazyUint8Array.prototype.setDataGetter = function LazyUint8Array_setDataGetter(getter) {
          this.getter = getter;
        }
        LazyUint8Array.prototype.cacheLength = function LazyUint8Array_cacheLength() {
          // Find length
          var xhr = new XMLHttpRequest();
          xhr.open('HEAD', url, false);
          xhr.send(null);
          if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
          var datalength = Number(xhr.getResponseHeader("Content-length"));
          var header;
          var hasByteServing = (header = xhr.getResponseHeader("Accept-Ranges")) && header === "bytes";
          var chunkSize = 1024*1024; // Chunk size in bytes
  
          if (!hasByteServing) chunkSize = datalength;
  
          // Function to get a range from the remote URL.
          var doXHR = (function(from, to) {
            if (from > to) throw new Error("invalid range (" + from + ", " + to + ") or no bytes requested!");
            if (to > datalength-1) throw new Error("only " + datalength + " bytes available! programmer error!");
  
            // TODO: Use mozResponseArrayBuffer, responseStream, etc. if available.
            var xhr = new XMLHttpRequest();
            xhr.open('GET', url, false);
            if (datalength !== chunkSize) xhr.setRequestHeader("Range", "bytes=" + from + "-" + to);
  
            // Some hints to the browser that we want binary data.
            if (typeof Uint8Array != 'undefined') xhr.responseType = 'arraybuffer';
            if (xhr.overrideMimeType) {
              xhr.overrideMimeType('text/plain; charset=x-user-defined');
            }
  
            xhr.send(null);
            if (!(xhr.status >= 200 && xhr.status < 300 || xhr.status === 304)) throw new Error("Couldn't load " + url + ". Status: " + xhr.status);
            if (xhr.response !== undefined) {
              return new Uint8Array(xhr.response || []);
            } else {
              return intArrayFromString(xhr.responseText || '', true);
            }
          });
          var lazyArray = this;
          lazyArray.setDataGetter(function(chunkNum) {
            var start = chunkNum * chunkSize;
            var end = (chunkNum+1) * chunkSize - 1; // including this byte
            end = Math.min(end, datalength-1); // if datalength-1 is selected, this is the last block
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") {
              lazyArray.chunks[chunkNum] = doXHR(start, end);
            }
            if (typeof(lazyArray.chunks[chunkNum]) === "undefined") throw new Error("doXHR failed!");
            return lazyArray.chunks[chunkNum];
          });
  
          this._length = datalength;
          this._chunkSize = chunkSize;
          this.lengthKnown = true;
        }
        if (typeof XMLHttpRequest !== 'undefined') {
          if (!ENVIRONMENT_IS_WORKER) throw 'Cannot do synchronous binary XHRs outside webworkers in modern browsers. Use --embed-file or --preload-file in emcc';
          var lazyArray = new LazyUint8Array();
          Object.defineProperty(lazyArray, "length", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._length;
              }
          });
          Object.defineProperty(lazyArray, "chunkSize", {
              get: function() {
                  if(!this.lengthKnown) {
                      this.cacheLength();
                  }
                  return this._chunkSize;
              }
          });
  
          var properties = { isDevice: false, contents: lazyArray };
        } else {
          var properties = { isDevice: false, url: url };
        }
  
        var node = FS.createFile(parent, name, properties, canRead, canWrite);
        // This is a total hack, but I want to get this lazy file code out of the
        // core of MEMFS. If we want to keep this lazy file concept I feel it should
        // be its own thin LAZYFS proxying calls to MEMFS.
        if (properties.contents) {
          node.contents = properties.contents;
        } else if (properties.url) {
          node.contents = null;
          node.url = properties.url;
        }
        // Add a function that defers querying the file size until it is asked the first time.
        Object.defineProperty(node, "usedBytes", {
            get: function() { return this.contents.length; }
        });
        // override each stream op with one that tries to force load the lazy file first
        var stream_ops = {};
        var keys = Object.keys(node.stream_ops);
        keys.forEach(function(key) {
          var fn = node.stream_ops[key];
          stream_ops[key] = function forceLoadLazyFile() {
            if (!FS.forceLoadFile(node)) {
              throw new FS.ErrnoError(ERRNO_CODES.EIO);
            }
            return fn.apply(null, arguments);
          };
        });
        // use a custom read function
        stream_ops.read = function stream_ops_read(stream, buffer, offset, length, position) {
          if (!FS.forceLoadFile(node)) {
            throw new FS.ErrnoError(ERRNO_CODES.EIO);
          }
          var contents = stream.node.contents;
          if (position >= contents.length)
            return 0;
          var size = Math.min(contents.length - position, length);
          assert(size >= 0);
          if (contents.slice) { // normal array
            for (var i = 0; i < size; i++) {
              buffer[offset + i] = contents[position + i];
            }
          } else {
            for (var i = 0; i < size; i++) { // LazyUint8Array from sync binary XHR
              buffer[offset + i] = contents.get(position + i);
            }
          }
          return size;
        };
        node.stream_ops = stream_ops;
        return node;
      },createPreloadedFile:function (parent, name, url, canRead, canWrite, onload, onerror, dontCreateFile, canOwn, preFinish) {
        Browser.init();
        // TODO we should allow people to just pass in a complete filename instead
        // of parent and name being that we just join them anyways
        var fullname = name ? PATH.resolve(PATH.join2(parent, name)) : parent;
        var dep = getUniqueRunDependency('cp ' + fullname); // might have several active requests for the same fullname
        function processData(byteArray) {
          function finish(byteArray) {
            if (preFinish) preFinish();
            if (!dontCreateFile) {
              FS.createDataFile(parent, name, byteArray, canRead, canWrite, canOwn);
            }
            if (onload) onload();
            removeRunDependency(dep);
          }
          var handled = false;
          Module['preloadPlugins'].forEach(function(plugin) {
            if (handled) return;
            if (plugin['canHandle'](fullname)) {
              plugin['handle'](byteArray, fullname, finish, function() {
                if (onerror) onerror();
                removeRunDependency(dep);
              });
              handled = true;
            }
          });
          if (!handled) finish(byteArray);
        }
        addRunDependency(dep);
        if (typeof url == 'string') {
          Browser.asyncLoad(url, function(byteArray) {
            processData(byteArray);
          }, onerror);
        } else {
          processData(url);
        }
      },indexedDB:function () {
        return window.indexedDB || window.mozIndexedDB || window.webkitIndexedDB || window.msIndexedDB;
      },DB_NAME:function () {
        return 'EM_FS_' + window.location.pathname;
      },DB_VERSION:20,DB_STORE_NAME:"FILE_DATA",saveFilesToDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = function openRequest_onupgradeneeded() {
          console.log('creating db');
          var db = openRequest.result;
          db.createObjectStore(FS.DB_STORE_NAME);
        };
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          var transaction = db.transaction([FS.DB_STORE_NAME], 'readwrite');
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var putRequest = files.put(FS.analyzePath(path).object.contents, path);
            putRequest.onsuccess = function putRequest_onsuccess() { ok++; if (ok + fail == total) finish() };
            putRequest.onerror = function putRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      },loadFilesFromDB:function (paths, onload, onerror) {
        onload = onload || function(){};
        onerror = onerror || function(){};
        var indexedDB = FS.indexedDB();
        try {
          var openRequest = indexedDB.open(FS.DB_NAME(), FS.DB_VERSION);
        } catch (e) {
          return onerror(e);
        }
        openRequest.onupgradeneeded = onerror; // no database to load from
        openRequest.onsuccess = function openRequest_onsuccess() {
          var db = openRequest.result;
          try {
            var transaction = db.transaction([FS.DB_STORE_NAME], 'readonly');
          } catch(e) {
            onerror(e);
            return;
          }
          var files = transaction.objectStore(FS.DB_STORE_NAME);
          var ok = 0, fail = 0, total = paths.length;
          function finish() {
            if (fail == 0) onload(); else onerror();
          }
          paths.forEach(function(path) {
            var getRequest = files.get(path);
            getRequest.onsuccess = function getRequest_onsuccess() {
              if (FS.analyzePath(path).exists) {
                FS.unlink(path);
              }
              FS.createDataFile(PATH.dirname(path), PATH.basename(path), getRequest.result, true, true, true);
              ok++;
              if (ok + fail == total) finish();
            };
            getRequest.onerror = function getRequest_onerror() { fail++; if (ok + fail == total) finish() };
          });
          transaction.onerror = onerror;
        };
        openRequest.onerror = onerror;
      }};
  
  function _lseek(fildes, offset, whence) {
      // off_t lseek(int fildes, off_t offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/lseek.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        return FS.llseek(stream, offset, whence);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _fileno(stream) {
      // int fileno(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fileno.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) return -1;
      return stream.fd;
    }function _fseek(stream, offset, whence) {
      // int fseek(FILE *stream, long offset, int whence);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fseek.html
      var fd = _fileno(stream);
      var ret = _lseek(fd, offset, whence);
      if (ret == -1) {
        return -1;
      }
      stream = FS.getStreamFromPtr(stream);
      stream.eof = false;
      return 0;
    }

   
  Module["_i64Subtract"] = _i64Subtract;

  var _DtoILow=true;

   
  Module["_i64Add"] = _i64Add;

  
  var LOCALE={curr:0,check:function (locale) {
        if (locale) locale = Pointer_stringify(locale);
        return locale === 'C' || locale === 'POSIX' || !locale;
      }};function _setlocale(category, locale) {
      if (LOCALE.check(locale)) {
        if (!_setlocale.ret) _setlocale.ret = allocate(intArrayFromString('C'), 'i8', ALLOC_NORMAL);
        return _setlocale.ret;
      }
      return 0;
    }

  
  function _close(fildes) {
      // int close(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/close.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        FS.close(stream);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fclose(stream) {
      // int fclose(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fclose.html
      var fd = _fileno(stream);
      return _close(fd);
    }

  function _kill(pid, sig) {
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/kill.html
      // Makes no sense in a single-process environment.
  	  // Should kill itself somtimes depending on `pid`
      Module.printErr('Calling stub instead of kill()');
      ___setErrNo(ERRNO_CODES.EPERM);
      return -1;
    }

  
  
  
  
  
  
  function _mkport() { throw 'TODO' }var SOCKFS={mount:function (mount) {
        // If Module['websocket'] has already been defined (e.g. for configuring
        // the subprotocol/url) use that, if not initialise it to a new object.
        Module['websocket'] = (Module['websocket'] && 
                               ('object' === typeof Module['websocket'])) ? Module['websocket'] : {};
  
        // Add the Event registration mechanism to the exported websocket configuration
        // object so we can register network callbacks from native JavaScript too.
        // For more documentation see system/include/emscripten/emscripten.h
        Module['websocket']._callbacks = {};
        Module['websocket']['on'] = function(event, callback) {
  	    if ('function' === typeof callback) {
  		  this._callbacks[event] = callback;
          }
  	    return this;
        };
  
        Module['websocket'].emit = function(event, param) {
  	    if ('function' === typeof this._callbacks[event]) {
  		  this._callbacks[event].call(this, param);
          }
        };
  
        // If debug is enabled register simple default logging callbacks for each Event.
  
        return FS.createNode(null, '/', 16384 | 511 /* 0777 */, 0);
      },createSocket:function (family, type, protocol) {
        var streaming = type == 1;
        if (protocol) {
          assert(streaming == (protocol == 6)); // if SOCK_STREAM, must be tcp
        }
  
        // create our internal socket structure
        var sock = {
          family: family,
          type: type,
          protocol: protocol,
          server: null,
          error: null, // Used in getsockopt for SOL_SOCKET/SO_ERROR test
          peers: {},
          pending: [],
          recv_queue: [],
          sock_ops: SOCKFS.websocket_sock_ops
        };
  
        // create the filesystem node to store the socket structure
        var name = SOCKFS.nextname();
        var node = FS.createNode(SOCKFS.root, name, 49152, 0);
        node.sock = sock;
  
        // and the wrapping stream that enables library functions such
        // as read and write to indirectly interact with the socket
        var stream = FS.createStream({
          path: name,
          node: node,
          flags: FS.modeStringToFlags('r+'),
          seekable: false,
          stream_ops: SOCKFS.stream_ops
        });
  
        // map the new stream to the socket structure (sockets have a 1:1
        // relationship with a stream)
        sock.stream = stream;
  
        return sock;
      },getSocket:function (fd) {
        var stream = FS.getStream(fd);
        if (!stream || !FS.isSocket(stream.node.mode)) {
          return null;
        }
        return stream.node.sock;
      },stream_ops:{poll:function (stream) {
          var sock = stream.node.sock;
          return sock.sock_ops.poll(sock);
        },ioctl:function (stream, request, varargs) {
          var sock = stream.node.sock;
          return sock.sock_ops.ioctl(sock, request, varargs);
        },read:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          var msg = sock.sock_ops.recvmsg(sock, length);
          if (!msg) {
            // socket is closed
            return 0;
          }
          buffer.set(msg.buffer, offset);
          return msg.buffer.length;
        },write:function (stream, buffer, offset, length, position /* ignored */) {
          var sock = stream.node.sock;
          return sock.sock_ops.sendmsg(sock, buffer, offset, length);
        },close:function (stream) {
          var sock = stream.node.sock;
          sock.sock_ops.close(sock);
        }},nextname:function () {
        if (!SOCKFS.nextname.current) {
          SOCKFS.nextname.current = 0;
        }
        return 'socket[' + (SOCKFS.nextname.current++) + ']';
      },websocket_sock_ops:{createPeer:function (sock, addr, port) {
          var ws;
  
          if (typeof addr === 'object') {
            ws = addr;
            addr = null;
            port = null;
          }
  
          if (ws) {
            // for sockets that've already connected (e.g. we're the server)
            // we can inspect the _socket property for the address
            if (ws._socket) {
              addr = ws._socket.remoteAddress;
              port = ws._socket.remotePort;
            }
            // if we're just now initializing a connection to the remote,
            // inspect the url property
            else {
              var result = /ws[s]?:\/\/([^:]+):(\d+)/.exec(ws.url);
              if (!result) {
                throw new Error('WebSocket URL must be in the format ws(s)://address:port');
              }
              addr = result[1];
              port = parseInt(result[2], 10);
            }
          } else {
            // create the actual websocket object and connect
            try {
              // runtimeConfig gets set to true if WebSocket runtime configuration is available.
              var runtimeConfig = (Module['websocket'] && ('object' === typeof Module['websocket']));
  
              // The default value is 'ws://' the replace is needed because the compiler replaces '//' comments with '#'
              // comments without checking context, so we'd end up with ws:#, the replace swaps the '#' for '//' again.
              var url = 'ws:#'.replace('#', '//');
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['url']) {
                  url = Module['websocket']['url']; // Fetch runtime WebSocket URL config.
                }
              }
  
              if (url === 'ws://' || url === 'wss://') { // Is the supplied URL config just a prefix, if so complete it.
                var parts = addr.split('/');
                url = url + parts[0] + ":" + port + "/" + parts.slice(1).join('/');
              }
  
              // Make the WebSocket subprotocol (Sec-WebSocket-Protocol) default to binary if no configuration is set.
              var subProtocols = 'binary'; // The default value is 'binary'
  
              if (runtimeConfig) {
                if ('string' === typeof Module['websocket']['subprotocol']) {
                  subProtocols = Module['websocket']['subprotocol']; // Fetch runtime WebSocket subprotocol config.
                }
              }
  
              // The regex trims the string (removes spaces at the beginning and end, then splits the string by
              // <any space>,<any space> into an Array. Whitespace removal is important for Websockify and ws.
              subProtocols = subProtocols.replace(/^ +| +$/g,"").split(/ *, */);
  
              // The node ws library API for specifying optional subprotocol is slightly different than the browser's.
              var opts = ENVIRONMENT_IS_NODE ? {'protocol': subProtocols.toString()} : subProtocols;
  
              // If node we use the ws library.
              var WebSocket = ENVIRONMENT_IS_NODE ? require('ws') : window['WebSocket'];
              ws = new WebSocket(url, opts);
              ws.binaryType = 'arraybuffer';
            } catch (e) {
              throw new FS.ErrnoError(ERRNO_CODES.EHOSTUNREACH);
            }
          }
  
  
          var peer = {
            addr: addr,
            port: port,
            socket: ws,
            dgram_send_queue: []
          };
  
          SOCKFS.websocket_sock_ops.addPeer(sock, peer);
          SOCKFS.websocket_sock_ops.handlePeerEvents(sock, peer);
  
          // if this is a bound dgram socket, send the port number first to allow
          // us to override the ephemeral port reported to us by remotePort on the
          // remote end.
          if (sock.type === 2 && typeof sock.sport !== 'undefined') {
            peer.dgram_send_queue.push(new Uint8Array([
                255, 255, 255, 255,
                'p'.charCodeAt(0), 'o'.charCodeAt(0), 'r'.charCodeAt(0), 't'.charCodeAt(0),
                ((sock.sport & 0xff00) >> 8) , (sock.sport & 0xff)
            ]));
          }
  
          return peer;
        },getPeer:function (sock, addr, port) {
          return sock.peers[addr + ':' + port];
        },addPeer:function (sock, peer) {
          sock.peers[peer.addr + ':' + peer.port] = peer;
        },removePeer:function (sock, peer) {
          delete sock.peers[peer.addr + ':' + peer.port];
        },handlePeerEvents:function (sock, peer) {
          var first = true;
  
          var handleOpen = function () {
  
            Module['websocket'].emit('open', sock.stream.fd);
  
            try {
              var queued = peer.dgram_send_queue.shift();
              while (queued) {
                peer.socket.send(queued);
                queued = peer.dgram_send_queue.shift();
              }
            } catch (e) {
              // not much we can do here in the way of proper error handling as we've already
              // lied and said this data was sent. shut it down.
              peer.socket.close();
            }
          };
  
          function handleMessage(data) {
            assert(typeof data !== 'string' && data.byteLength !== undefined);  // must receive an ArrayBuffer
            data = new Uint8Array(data);  // make a typed array view on the array buffer
  
  
            // if this is the port message, override the peer's port with it
            var wasfirst = first;
            first = false;
            if (wasfirst &&
                data.length === 10 &&
                data[0] === 255 && data[1] === 255 && data[2] === 255 && data[3] === 255 &&
                data[4] === 'p'.charCodeAt(0) && data[5] === 'o'.charCodeAt(0) && data[6] === 'r'.charCodeAt(0) && data[7] === 't'.charCodeAt(0)) {
              // update the peer's port and it's key in the peer map
              var newport = ((data[8] << 8) | data[9]);
              SOCKFS.websocket_sock_ops.removePeer(sock, peer);
              peer.port = newport;
              SOCKFS.websocket_sock_ops.addPeer(sock, peer);
              return;
            }
  
            sock.recv_queue.push({ addr: peer.addr, port: peer.port, data: data });
            Module['websocket'].emit('message', sock.stream.fd);
          };
  
          if (ENVIRONMENT_IS_NODE) {
            peer.socket.on('open', handleOpen);
            peer.socket.on('message', function(data, flags) {
              if (!flags.binary) {
                return;
              }
              handleMessage((new Uint8Array(data)).buffer);  // copy from node Buffer -> ArrayBuffer
            });
            peer.socket.on('close', function() {
              Module['websocket'].emit('close', sock.stream.fd);
            });
            peer.socket.on('error', function(error) {
              // Although the ws library may pass errors that may be more descriptive than
              // ECONNREFUSED they are not necessarily the expected error code e.g. 
              // ENOTFOUND on getaddrinfo seems to be node.js specific, so using ECONNREFUSED
              // is still probably the most useful thing to do.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
              // don't throw
            });
          } else {
            peer.socket.onopen = handleOpen;
            peer.socket.onclose = function() {
              Module['websocket'].emit('close', sock.stream.fd);
            };
            peer.socket.onmessage = function peer_socket_onmessage(event) {
              handleMessage(event.data);
            };
            peer.socket.onerror = function(error) {
              // The WebSocket spec only allows a 'simple event' to be thrown on error,
              // so we only really know as much as ECONNREFUSED.
              sock.error = ERRNO_CODES.ECONNREFUSED; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
              Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'ECONNREFUSED: Connection refused']);
            };
          }
        },poll:function (sock) {
          if (sock.type === 1 && sock.server) {
            // listen sockets should only say they're available for reading
            // if there are pending clients.
            return sock.pending.length ? (64 | 1) : 0;
          }
  
          var mask = 0;
          var dest = sock.type === 1 ?  // we only care about the socket state for connection-based sockets
            SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport) :
            null;
  
          if (sock.recv_queue.length ||
              !dest ||  // connection-less sockets are always ready to read
              (dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {  // let recv return 0 once closed
            mask |= (64 | 1);
          }
  
          if (!dest ||  // connection-less sockets are always ready to write
              (dest && dest.socket.readyState === dest.socket.OPEN)) {
            mask |= 4;
          }
  
          if ((dest && dest.socket.readyState === dest.socket.CLOSING) ||
              (dest && dest.socket.readyState === dest.socket.CLOSED)) {
            mask |= 16;
          }
  
          return mask;
        },ioctl:function (sock, request, arg) {
          switch (request) {
            case 21531:
              var bytes = 0;
              if (sock.recv_queue.length) {
                bytes = sock.recv_queue[0].data.length;
              }
              HEAP32[((arg)>>2)]=bytes;
              return 0;
            default:
              return ERRNO_CODES.EINVAL;
          }
        },close:function (sock) {
          // if we've spawned a listen server, close it
          if (sock.server) {
            try {
              sock.server.close();
            } catch (e) {
            }
            sock.server = null;
          }
          // close any peer connections
          var peers = Object.keys(sock.peers);
          for (var i = 0; i < peers.length; i++) {
            var peer = sock.peers[peers[i]];
            try {
              peer.socket.close();
            } catch (e) {
            }
            SOCKFS.websocket_sock_ops.removePeer(sock, peer);
          }
          return 0;
        },bind:function (sock, addr, port) {
          if (typeof sock.saddr !== 'undefined' || typeof sock.sport !== 'undefined') {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already bound
          }
          sock.saddr = addr;
          sock.sport = port || _mkport();
          // in order to emulate dgram sockets, we need to launch a listen server when
          // binding on a connection-less socket
          // note: this is only required on the server side
          if (sock.type === 2) {
            // close the existing server if it exists
            if (sock.server) {
              sock.server.close();
              sock.server = null;
            }
            // swallow error operation not supported error that occurs when binding in the
            // browser where this isn't supported
            try {
              sock.sock_ops.listen(sock, 0);
            } catch (e) {
              if (!(e instanceof FS.ErrnoError)) throw e;
              if (e.errno !== ERRNO_CODES.EOPNOTSUPP) throw e;
            }
          }
        },connect:function (sock, addr, port) {
          if (sock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
  
          // TODO autobind
          // if (!sock.addr && sock.type == 2) {
          // }
  
          // early out if we're already connected / in the middle of connecting
          if (typeof sock.daddr !== 'undefined' && typeof sock.dport !== 'undefined') {
            var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
            if (dest) {
              if (dest.socket.readyState === dest.socket.CONNECTING) {
                throw new FS.ErrnoError(ERRNO_CODES.EALREADY);
              } else {
                throw new FS.ErrnoError(ERRNO_CODES.EISCONN);
              }
            }
          }
  
          // add the socket to our peer list and set our
          // destination address / port to match
          var peer = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
          sock.daddr = peer.addr;
          sock.dport = peer.port;
  
          // always "fail" in non-blocking mode
          throw new FS.ErrnoError(ERRNO_CODES.EINPROGRESS);
        },listen:function (sock, backlog) {
          if (!ENVIRONMENT_IS_NODE) {
            throw new FS.ErrnoError(ERRNO_CODES.EOPNOTSUPP);
          }
          if (sock.server) {
             throw new FS.ErrnoError(ERRNO_CODES.EINVAL);  // already listening
          }
          var WebSocketServer = require('ws').Server;
          var host = sock.saddr;
          sock.server = new WebSocketServer({
            host: host,
            port: sock.sport
            // TODO support backlog
          });
          Module['websocket'].emit('listen', sock.stream.fd); // Send Event with listen fd.
  
          sock.server.on('connection', function(ws) {
            if (sock.type === 1) {
              var newsock = SOCKFS.createSocket(sock.family, sock.type, sock.protocol);
  
              // create a peer on the new socket
              var peer = SOCKFS.websocket_sock_ops.createPeer(newsock, ws);
              newsock.daddr = peer.addr;
              newsock.dport = peer.port;
  
              // push to queue for accept to pick up
              sock.pending.push(newsock);
              Module['websocket'].emit('connection', newsock.stream.fd);
            } else {
              // create a peer on the listen socket so calling sendto
              // with the listen socket and an address will resolve
              // to the correct client
              SOCKFS.websocket_sock_ops.createPeer(sock, ws);
              Module['websocket'].emit('connection', sock.stream.fd);
            }
          });
          sock.server.on('closed', function() {
            Module['websocket'].emit('close', sock.stream.fd);
            sock.server = null;
          });
          sock.server.on('error', function(error) {
            // Although the ws library may pass errors that may be more descriptive than
            // ECONNREFUSED they are not necessarily the expected error code e.g. 
            // ENOTFOUND on getaddrinfo seems to be node.js specific, so using EHOSTUNREACH
            // is still probably the most useful thing to do. This error shouldn't
            // occur in a well written app as errors should get trapped in the compiled
            // app's own getaddrinfo call.
            sock.error = ERRNO_CODES.EHOSTUNREACH; // Used in getsockopt for SOL_SOCKET/SO_ERROR test.
            Module['websocket'].emit('error', [sock.stream.fd, sock.error, 'EHOSTUNREACH: Host is unreachable']);
            // don't throw
          });
        },accept:function (listensock) {
          if (!listensock.server) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
          var newsock = listensock.pending.shift();
          newsock.stream.flags = listensock.stream.flags;
          return newsock;
        },getname:function (sock, peer) {
          var addr, port;
          if (peer) {
            if (sock.daddr === undefined || sock.dport === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            }
            addr = sock.daddr;
            port = sock.dport;
          } else {
            // TODO saddr and sport will be set for bind()'d UDP sockets, but what
            // should we be returning for TCP sockets that've been connect()'d?
            addr = sock.saddr || 0;
            port = sock.sport || 0;
          }
          return { addr: addr, port: port };
        },sendmsg:function (sock, buffer, offset, length, addr, port) {
          if (sock.type === 2) {
            // connection-less sockets will honor the message address,
            // and otherwise fall back to the bound destination address
            if (addr === undefined || port === undefined) {
              addr = sock.daddr;
              port = sock.dport;
            }
            // if there was no address to fall back to, error out
            if (addr === undefined || port === undefined) {
              throw new FS.ErrnoError(ERRNO_CODES.EDESTADDRREQ);
            }
          } else {
            // connection-based sockets will only use the bound
            addr = sock.daddr;
            port = sock.dport;
          }
  
          // find the peer for the destination address
          var dest = SOCKFS.websocket_sock_ops.getPeer(sock, addr, port);
  
          // early out if not connected with a connection-based socket
          if (sock.type === 1) {
            if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
              throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
            } else if (dest.socket.readyState === dest.socket.CONNECTING) {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // create a copy of the incoming data to send, as the WebSocket API
          // doesn't work entirely with an ArrayBufferView, it'll just send
          // the entire underlying buffer
          var data;
          if (buffer instanceof Array || buffer instanceof ArrayBuffer) {
            data = buffer.slice(offset, offset + length);
          } else {  // ArrayBufferView
            data = buffer.buffer.slice(buffer.byteOffset + offset, buffer.byteOffset + offset + length);
          }
  
          // if we're emulating a connection-less dgram socket and don't have
          // a cached connection, queue the buffer to send upon connect and
          // lie, saying the data was sent now.
          if (sock.type === 2) {
            if (!dest || dest.socket.readyState !== dest.socket.OPEN) {
              // if we're not connected, open a new connection
              if (!dest || dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                dest = SOCKFS.websocket_sock_ops.createPeer(sock, addr, port);
              }
              dest.dgram_send_queue.push(data);
              return length;
            }
          }
  
          try {
            // send the actual data
            dest.socket.send(data);
            return length;
          } catch (e) {
            throw new FS.ErrnoError(ERRNO_CODES.EINVAL);
          }
        },recvmsg:function (sock, length) {
          // http://pubs.opengroup.org/onlinepubs/7908799/xns/recvmsg.html
          if (sock.type === 1 && sock.server) {
            // tcp servers should not be recv()'ing on the listen socket
            throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
          }
  
          var queued = sock.recv_queue.shift();
          if (!queued) {
            if (sock.type === 1) {
              var dest = SOCKFS.websocket_sock_ops.getPeer(sock, sock.daddr, sock.dport);
  
              if (!dest) {
                // if we have a destination address but are not connected, error out
                throw new FS.ErrnoError(ERRNO_CODES.ENOTCONN);
              }
              else if (dest.socket.readyState === dest.socket.CLOSING || dest.socket.readyState === dest.socket.CLOSED) {
                // return null if the socket has closed
                return null;
              }
              else {
                // else, our socket is in a valid state but truly has nothing available
                throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
              }
            } else {
              throw new FS.ErrnoError(ERRNO_CODES.EAGAIN);
            }
          }
  
          // queued.data will be an ArrayBuffer if it's unadulterated, but if it's
          // requeued TCP data it'll be an ArrayBufferView
          var queuedLength = queued.data.byteLength || queued.data.length;
          var queuedOffset = queued.data.byteOffset || 0;
          var queuedBuffer = queued.data.buffer || queued.data;
          var bytesRead = Math.min(length, queuedLength);
          var res = {
            buffer: new Uint8Array(queuedBuffer, queuedOffset, bytesRead),
            addr: queued.addr,
            port: queued.port
          };
  
  
          // push back any unread data for TCP connections
          if (sock.type === 1 && bytesRead < queuedLength) {
            var bytesRemaining = queuedLength - bytesRead;
            queued.data = new Uint8Array(queuedBuffer, queuedOffset + bytesRead, bytesRemaining);
            sock.recv_queue.unshift(queued);
          }
  
          return res;
        }}};function _send(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _write(fd, buf, len);
    }
  
  function _pwrite(fildes, buf, nbyte, offset) {
      // ssize_t pwrite(int fildes, const void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _write(fildes, buf, nbyte) {
      // ssize_t write(int fildes, const void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/write.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.write(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fwrite(ptr, size, nitems, stream) {
      // size_t fwrite(const void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fwrite.html
      var bytesToWrite = nitems * size;
      if (bytesToWrite == 0) return 0;
      var fd = _fileno(stream);
      var bytesWritten = _write(fd, ptr, bytesToWrite);
      if (bytesWritten == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return 0;
      } else {
        return (bytesWritten / size)|0;
      }
    }
  
  
   
  Module["_strlen"] = _strlen;
  
  function __reallyNegative(x) {
      return x < 0 || (x === 0 && (1/x) === -Infinity);
    }function __formatString(format, varargs) {
      assert((varargs & 3) === 0);
      var textIndex = format;
      var argIndex = 0;
      function getNextArg(type) {
        // NOTE: Explicitly ignoring type safety. Otherwise this fails:
        //       int x = 4; printf("%c\n", (char)x);
        var ret;
        argIndex = Runtime.prepVararg(argIndex, type);
        if (type === 'double') {
          ret = (HEAP32[((tempDoublePtr)>>2)]=HEAP32[(((varargs)+(argIndex))>>2)],HEAP32[(((tempDoublePtr)+(4))>>2)]=HEAP32[(((varargs)+((argIndex)+(4)))>>2)],(+(HEAPF64[(tempDoublePtr)>>3])));
          argIndex += 8;
        } else if (type == 'i64') {
          ret = [HEAP32[(((varargs)+(argIndex))>>2)],
                 HEAP32[(((varargs)+(argIndex+4))>>2)]];
  
          argIndex += 8;
        } else {
          assert((argIndex & 3) === 0);
          type = 'i32'; // varargs are always i32, i64, or double
          ret = HEAP32[(((varargs)+(argIndex))>>2)];
          argIndex += 4;
        }
        return ret;
      }
  
      var ret = [];
      var curr, next, currArg;
      while(1) {
        var startTextIndex = textIndex;
        curr = HEAP8[((textIndex)>>0)];
        if (curr === 0) break;
        next = HEAP8[((textIndex+1)>>0)];
        if (curr == 37) {
          // Handle flags.
          var flagAlwaysSigned = false;
          var flagLeftAlign = false;
          var flagAlternative = false;
          var flagZeroPad = false;
          var flagPadSign = false;
          flagsLoop: while (1) {
            switch (next) {
              case 43:
                flagAlwaysSigned = true;
                break;
              case 45:
                flagLeftAlign = true;
                break;
              case 35:
                flagAlternative = true;
                break;
              case 48:
                if (flagZeroPad) {
                  break flagsLoop;
                } else {
                  flagZeroPad = true;
                  break;
                }
              case 32:
                flagPadSign = true;
                break;
              default:
                break flagsLoop;
            }
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          }
  
          // Handle width.
          var width = 0;
          if (next == 42) {
            width = getNextArg('i32');
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
          } else {
            while (next >= 48 && next <= 57) {
              width = width * 10 + (next - 48);
              textIndex++;
              next = HEAP8[((textIndex+1)>>0)];
            }
          }
  
          // Handle precision.
          var precisionSet = false, precision = -1;
          if (next == 46) {
            precision = 0;
            precisionSet = true;
            textIndex++;
            next = HEAP8[((textIndex+1)>>0)];
            if (next == 42) {
              precision = getNextArg('i32');
              textIndex++;
            } else {
              while(1) {
                var precisionChr = HEAP8[((textIndex+1)>>0)];
                if (precisionChr < 48 ||
                    precisionChr > 57) break;
                precision = precision * 10 + (precisionChr - 48);
                textIndex++;
              }
            }
            next = HEAP8[((textIndex+1)>>0)];
          }
          if (precision < 0) {
            precision = 6; // Standard default.
            precisionSet = false;
          }
  
          // Handle integer sizes. WARNING: These assume a 32-bit architecture!
          var argSize;
          switch (String.fromCharCode(next)) {
            case 'h':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 104) {
                textIndex++;
                argSize = 1; // char (actually i32 in varargs)
              } else {
                argSize = 2; // short (actually i32 in varargs)
              }
              break;
            case 'l':
              var nextNext = HEAP8[((textIndex+2)>>0)];
              if (nextNext == 108) {
                textIndex++;
                argSize = 8; // long long
              } else {
                argSize = 4; // long
              }
              break;
            case 'L': // long long
            case 'q': // int64_t
            case 'j': // intmax_t
              argSize = 8;
              break;
            case 'z': // size_t
            case 't': // ptrdiff_t
            case 'I': // signed ptrdiff_t or unsigned size_t
              argSize = 4;
              break;
            default:
              argSize = null;
          }
          if (argSize) textIndex++;
          next = HEAP8[((textIndex+1)>>0)];
  
          // Handle type specifier.
          switch (String.fromCharCode(next)) {
            case 'd': case 'i': case 'u': case 'o': case 'x': case 'X': case 'p': {
              // Integer.
              var signed = next == 100 || next == 105;
              argSize = argSize || 4;
              var currArg = getNextArg('i' + (argSize * 8));
              var origArg = currArg;
              var argText;
              // Flatten i64-1 [low, high] into a (slightly rounded) double
              if (argSize == 8) {
                currArg = Runtime.makeBigInt(currArg[0], currArg[1], next == 117);
              }
              // Truncate to requested size.
              if (argSize <= 4) {
                var limit = Math.pow(256, argSize) - 1;
                currArg = (signed ? reSign : unSign)(currArg & limit, argSize * 8);
              }
              // Format the number.
              var currAbsArg = Math.abs(currArg);
              var prefix = '';
              if (next == 100 || next == 105) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], null); else
                argText = reSign(currArg, 8 * argSize, 1).toString(10);
              } else if (next == 117) {
                if (argSize == 8 && i64Math) argText = i64Math.stringify(origArg[0], origArg[1], true); else
                argText = unSign(currArg, 8 * argSize, 1).toString(10);
                currArg = Math.abs(currArg);
              } else if (next == 111) {
                argText = (flagAlternative ? '0' : '') + currAbsArg.toString(8);
              } else if (next == 120 || next == 88) {
                prefix = (flagAlternative && currArg != 0) ? '0x' : '';
                if (argSize == 8 && i64Math) {
                  if (origArg[1]) {
                    argText = (origArg[1]>>>0).toString(16);
                    var lower = (origArg[0]>>>0).toString(16);
                    while (lower.length < 8) lower = '0' + lower;
                    argText += lower;
                  } else {
                    argText = (origArg[0]>>>0).toString(16);
                  }
                } else
                if (currArg < 0) {
                  // Represent negative numbers in hex as 2's complement.
                  currArg = -currArg;
                  argText = (currAbsArg - 1).toString(16);
                  var buffer = [];
                  for (var i = 0; i < argText.length; i++) {
                    buffer.push((0xF - parseInt(argText[i], 16)).toString(16));
                  }
                  argText = buffer.join('');
                  while (argText.length < argSize * 2) argText = 'f' + argText;
                } else {
                  argText = currAbsArg.toString(16);
                }
                if (next == 88) {
                  prefix = prefix.toUpperCase();
                  argText = argText.toUpperCase();
                }
              } else if (next == 112) {
                if (currAbsArg === 0) {
                  argText = '(nil)';
                } else {
                  prefix = '0x';
                  argText = currAbsArg.toString(16);
                }
              }
              if (precisionSet) {
                while (argText.length < precision) {
                  argText = '0' + argText;
                }
              }
  
              // Add sign if needed
              if (currArg >= 0) {
                if (flagAlwaysSigned) {
                  prefix = '+' + prefix;
                } else if (flagPadSign) {
                  prefix = ' ' + prefix;
                }
              }
  
              // Move sign to prefix so we zero-pad after the sign
              if (argText.charAt(0) == '-') {
                prefix = '-' + prefix;
                argText = argText.substr(1);
              }
  
              // Add padding.
              while (prefix.length + argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad) {
                    argText = '0' + argText;
                  } else {
                    prefix = ' ' + prefix;
                  }
                }
              }
  
              // Insert the result into the buffer.
              argText = prefix + argText;
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 'f': case 'F': case 'e': case 'E': case 'g': case 'G': {
              // Float.
              var currArg = getNextArg('double');
              var argText;
              if (isNaN(currArg)) {
                argText = 'nan';
                flagZeroPad = false;
              } else if (!isFinite(currArg)) {
                argText = (currArg < 0 ? '-' : '') + 'inf';
                flagZeroPad = false;
              } else {
                var isGeneral = false;
                var effectivePrecision = Math.min(precision, 20);
  
                // Convert g/G to f/F or e/E, as per:
                // http://pubs.opengroup.org/onlinepubs/9699919799/functions/printf.html
                if (next == 103 || next == 71) {
                  isGeneral = true;
                  precision = precision || 1;
                  var exponent = parseInt(currArg.toExponential(effectivePrecision).split('e')[1], 10);
                  if (precision > exponent && exponent >= -4) {
                    next = ((next == 103) ? 'f' : 'F').charCodeAt(0);
                    precision -= exponent + 1;
                  } else {
                    next = ((next == 103) ? 'e' : 'E').charCodeAt(0);
                    precision--;
                  }
                  effectivePrecision = Math.min(precision, 20);
                }
  
                if (next == 101 || next == 69) {
                  argText = currArg.toExponential(effectivePrecision);
                  // Make sure the exponent has at least 2 digits.
                  if (/[eE][-+]\d$/.test(argText)) {
                    argText = argText.slice(0, -1) + '0' + argText.slice(-1);
                  }
                } else if (next == 102 || next == 70) {
                  argText = currArg.toFixed(effectivePrecision);
                  if (currArg === 0 && __reallyNegative(currArg)) {
                    argText = '-' + argText;
                  }
                }
  
                var parts = argText.split('e');
                if (isGeneral && !flagAlternative) {
                  // Discard trailing zeros and periods.
                  while (parts[0].length > 1 && parts[0].indexOf('.') != -1 &&
                         (parts[0].slice(-1) == '0' || parts[0].slice(-1) == '.')) {
                    parts[0] = parts[0].slice(0, -1);
                  }
                } else {
                  // Make sure we have a period in alternative mode.
                  if (flagAlternative && argText.indexOf('.') == -1) parts[0] += '.';
                  // Zero pad until required precision.
                  while (precision > effectivePrecision++) parts[0] += '0';
                }
                argText = parts[0] + (parts.length > 1 ? 'e' + parts[1] : '');
  
                // Capitalize 'E' if needed.
                if (next == 69) argText = argText.toUpperCase();
  
                // Add sign.
                if (currArg >= 0) {
                  if (flagAlwaysSigned) {
                    argText = '+' + argText;
                  } else if (flagPadSign) {
                    argText = ' ' + argText;
                  }
                }
              }
  
              // Add padding.
              while (argText.length < width) {
                if (flagLeftAlign) {
                  argText += ' ';
                } else {
                  if (flagZeroPad && (argText[0] == '-' || argText[0] == '+')) {
                    argText = argText[0] + '0' + argText.slice(1);
                  } else {
                    argText = (flagZeroPad ? '0' : ' ') + argText;
                  }
                }
              }
  
              // Adjust case.
              if (next < 97) argText = argText.toUpperCase();
  
              // Insert the result into the buffer.
              argText.split('').forEach(function(chr) {
                ret.push(chr.charCodeAt(0));
              });
              break;
            }
            case 's': {
              // String.
              var arg = getNextArg('i8*');
              var argLength = arg ? _strlen(arg) : '(null)'.length;
              if (precisionSet) argLength = Math.min(argLength, precision);
              if (!flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              if (arg) {
                for (var i = 0; i < argLength; i++) {
                  ret.push(HEAPU8[((arg++)>>0)]);
                }
              } else {
                ret = ret.concat(intArrayFromString('(null)'.substr(0, argLength), true));
              }
              if (flagLeftAlign) {
                while (argLength < width--) {
                  ret.push(32);
                }
              }
              break;
            }
            case 'c': {
              // Character.
              if (flagLeftAlign) ret.push(getNextArg('i8'));
              while (--width > 0) {
                ret.push(32);
              }
              if (!flagLeftAlign) ret.push(getNextArg('i8'));
              break;
            }
            case 'n': {
              // Write the length written so far to the next parameter.
              var ptr = getNextArg('i32*');
              HEAP32[((ptr)>>2)]=ret.length;
              break;
            }
            case '%': {
              // Literal percent sign.
              ret.push(curr);
              break;
            }
            default: {
              // Unknown specifiers remain untouched.
              for (var i = startTextIndex; i < textIndex + 2; i++) {
                ret.push(HEAP8[((i)>>0)]);
              }
            }
          }
          textIndex += 2;
          // TODO: Support a/A (hex float) and m (last error) specifiers.
          // TODO: Support %1${specifier} for arg selection.
        } else {
          ret.push(curr);
          textIndex += 1;
        }
      }
      return ret;
    }function _fprintf(stream, format, varargs) {
      // int fprintf(FILE *restrict stream, const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var result = __formatString(format, varargs);
      var stack = Runtime.stackSave();
      var ret = _fwrite(allocate(result, 'i8', ALLOC_STACK), 1, result.length, stream);
      Runtime.stackRestore(stack);
      return ret;
    }function _printf(format, varargs) {
      // int printf(const char *restrict format, ...);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/printf.html
      var stdout = HEAP32[((_stdout)>>2)];
      return _fprintf(stdout, format, varargs);
    }

  function _sigemptyset(set) {
      HEAP32[((set)>>2)]=0;
      return 0;
    }


  
  function _open(path, oflag, varargs) {
      // int open(const char *path, int oflag, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/open.html
      var mode = HEAP32[((varargs)>>2)];
      path = Pointer_stringify(path);
      try {
        var stream = FS.open(path, oflag, mode);
        return stream.fd;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fopen(filename, mode) {
      // FILE *fopen(const char *restrict filename, const char *restrict mode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fopen.html
      var flags;
      mode = Pointer_stringify(mode);
      if (mode[0] == 'r') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 0;
        }
      } else if (mode[0] == 'w') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 512;
      } else if (mode[0] == 'a') {
        if (mode.indexOf('+') != -1) {
          flags = 2;
        } else {
          flags = 1;
        }
        flags |= 64;
        flags |= 1024;
      } else {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return 0;
      }
      var fd = _open(filename, flags, allocate([0x1FF, 0, 0, 0], 'i32', ALLOC_STACK));  // All creation permissions.
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }


  var _emscripten_check_longjmp=true;

   
  Module["_strncpy"] = _strncpy;

  function _fputc(c, stream) {
      // int fputc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputc.html
      var chr = unSign(c & 0xFF);
      HEAP8[((_fputc.ret)>>0)]=chr;
      var fd = _fileno(stream);
      var ret = _write(fd, _fputc.ret, 1);
      if (ret == -1) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (streamObj) streamObj.error = true;
        return -1;
      } else {
        return chr;
      }
    }

  function _sigprocmask() {
      Module.printErr('Calling stub instead of sigprocmask()');
      return 0;
    }

  var _log=Math_log;

  var _emscripten_postinvoke=true;

  
  
  var _tzname=allocate(8, "i32*", ALLOC_STATIC);
  
  var _daylight=allocate(1, "i32*", ALLOC_STATIC);
  
  var _timezone=allocate(1, "i32*", ALLOC_STATIC);function _tzset() {
      // TODO: Use (malleable) environment variables instead of system settings.
      if (_tzset.called) return;
      _tzset.called = true;
  
      HEAP32[((_timezone)>>2)]=-(new Date()).getTimezoneOffset() * 60;
  
      var winter = new Date(2000, 0, 1);
      var summer = new Date(2000, 6, 1);
      HEAP32[((_daylight)>>2)]=Number(winter.getTimezoneOffset() != summer.getTimezoneOffset());
  
      function extractZone(date) {
        var match = date.toTimeString().match(/\(([A-Za-z ]+)\)$/);
        return match ? match[1] : "GMT";
      };
      var winterName = extractZone(winter);
      var summerName = extractZone(summer);
      var winterNamePtr = allocate(intArrayFromString(winterName), 'i8', ALLOC_NORMAL);
      var summerNamePtr = allocate(intArrayFromString(summerName), 'i8', ALLOC_NORMAL);
      if (summer.getTimezoneOffset() < winter.getTimezoneOffset()) {
        // Northern hemisphere
        HEAP32[((_tzname)>>2)]=winterNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=summerNamePtr;
      } else {
        HEAP32[((_tzname)>>2)]=summerNamePtr;
        HEAP32[(((_tzname)+(4))>>2)]=winterNamePtr;
      }
    }function _mktime(tmPtr) {
      _tzset();
      var date = new Date(HEAP32[(((tmPtr)+(20))>>2)] + 1900,
                          HEAP32[(((tmPtr)+(16))>>2)],
                          HEAP32[(((tmPtr)+(12))>>2)],
                          HEAP32[(((tmPtr)+(8))>>2)],
                          HEAP32[(((tmPtr)+(4))>>2)],
                          HEAP32[((tmPtr)>>2)],
                          0);
  
      // There's an ambiguous hour when the time goes back; the tm_isdst field is
      // used to disambiguate it.  Date() basically guesses, so we fix it up if it
      // guessed wrong, or fill in tm_isdst with the guess if it's -1.
      var dst = HEAP32[(((tmPtr)+(32))>>2)];
      var guessedOffset = date.getTimezoneOffset();
      var start = new Date(date.getFullYear(), 0, 1);
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dstOffset = Math.min(winterOffset, summerOffset); // DST is in December in South
      if (dst < 0) {
        HEAP32[(((tmPtr)+(32))>>2)]=Number(winterOffset != guessedOffset);
      } else if ((dst > 0) != (winterOffset != guessedOffset)) {
        var summerOffset = new Date(date.getFullYear(), 6, 1).getTimezoneOffset();
        var trueOffset = dst > 0 ? summerOffset : winterOffset;
        // Don't try setMinutes(date.getMinutes() + ...) -- it's messed up.
        date.setTime(date.getTime() + (trueOffset - guessedOffset)*60000);
      }
  
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
  
      return (date.getTime() / 1000)|0;
    }


  function _system(command) {
      // int system(const char *command);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/system.html
      // Can't call external programs.
      ___setErrNo(ERRNO_CODES.EAGAIN);
      return -1;
    }

  
  
  
  function _emscripten_memcpy_big(dest, src, num) {
      HEAPU8.set(HEAPU8.subarray(src, src+num), dest);
      return dest;
    } 
  Module["_memcpy"] = _memcpy;function _realloc(ptr, size) {
      // Very simple, inefficient implementation - if you use a real malloc, best to use
      // a real realloc with it
      if (!size) {
        if (ptr) _free(ptr);
        return 0;
      }
      var ret = _malloc(size);
      if (ptr) {
        _memcpy(ret, ptr, size); // might be some invalid reads
        _free(ptr);
      }
      return ret;
    } 
  Module["_saveSetjmp"] = _saveSetjmp;

  function _fputs(s, stream) {
      // int fputs(const char *restrict s, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fputs.html
      var fd = _fileno(stream);
      return _write(fd, s, _strlen(s));
    }

  
  var PROCINFO={ppid:1,pid:42,sid:42,pgid:42};function _getpid() {  return PROCINFO.pid;  }

  function _putc() {
  return _fputc.apply(null, arguments)
  }

  function _tmpnam(s, dir, prefix) {
      // char *tmpnam(char *s);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/tmpnam.html
      // NOTE: The dir and prefix arguments are for internal use only.
      dir = dir || '/tmp';
      var folder = FS.findObject(dir);
      if (!folder || !folder.isFolder) {
        dir = '/tmp';
        folder = FS.findObject(dir);
        if (!folder || !folder.isFolder) return 0;
      }
      var name = prefix || 'file';
      do {
        name += String.fromCharCode(65 + (Math.random() * 25)|0);
      } while (name in folder.contents);
      var result = dir + '/' + name;
      if (!_tmpnam.buffer) _tmpnam.buffer = _malloc(256);
      if (!s) s = _tmpnam.buffer;
      assert(result.length <= 255);
      writeAsciiToMemory(result, s);
      return s;
    }

  
  
  function _emscripten_set_main_loop_timing(mode, value) {
      Browser.mainLoop.timingMode = mode;
      Browser.mainLoop.timingValue = value;
  
      if (!Browser.mainLoop.func) {
        console.error('emscripten_set_main_loop_timing: Cannot set timing mode for main loop since a main loop does not exist! Call emscripten_set_main_loop first to set one up.');
        return 1; // Return non-zero on failure, can't set timing mode when there is no main loop.
      }
  
      if (mode == 0 /*EM_TIMING_SETTIMEOUT*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          setTimeout(Browser.mainLoop.runner, value); // doing this each time means that on exception, we stop
        };
        Browser.mainLoop.method = 'timeout';
      } else if (mode == 1 /*EM_TIMING_RAF*/) {
        Browser.mainLoop.scheduler = function Browser_mainLoop_scheduler() {
          Browser.requestAnimationFrame(Browser.mainLoop.runner);
        };
        Browser.mainLoop.method = 'rAF';
      }
      return 0;
    }function _emscripten_set_main_loop(func, fps, simulateInfiniteLoop, arg, noSetTiming) {
      Module['noExitRuntime'] = true;
  
      assert(!Browser.mainLoop.func, 'emscripten_set_main_loop: there can only be one main loop function at once: call emscripten_cancel_main_loop to cancel the previous one before setting a new one with different parameters.');
  
      Browser.mainLoop.func = func;
      Browser.mainLoop.arg = arg;
  
      var thisMainLoopId = Browser.mainLoop.currentlyRunningMainloop;
  
      Browser.mainLoop.runner = function Browser_mainLoop_runner() {
        if (ABORT) return;
        if (Browser.mainLoop.queue.length > 0) {
          var start = Date.now();
          var blocker = Browser.mainLoop.queue.shift();
          blocker.func(blocker.arg);
          if (Browser.mainLoop.remainingBlockers) {
            var remaining = Browser.mainLoop.remainingBlockers;
            var next = remaining%1 == 0 ? remaining-1 : Math.floor(remaining);
            if (blocker.counted) {
              Browser.mainLoop.remainingBlockers = next;
            } else {
              // not counted, but move the progress along a tiny bit
              next = next + 0.5; // do not steal all the next one's progress
              Browser.mainLoop.remainingBlockers = (8*remaining + next)/9;
            }
          }
          console.log('main loop blocker "' + blocker.name + '" took ' + (Date.now() - start) + ' ms'); //, left: ' + Browser.mainLoop.remainingBlockers);
          Browser.mainLoop.updateStatus();
          setTimeout(Browser.mainLoop.runner, 0);
          return;
        }
  
        // catch pauses from non-main loop sources
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Implement very basic swap interval control
        Browser.mainLoop.currentFrameNumber = Browser.mainLoop.currentFrameNumber + 1 | 0;
        if (Browser.mainLoop.timingMode == 1/*EM_TIMING_RAF*/ && Browser.mainLoop.timingValue > 1 && Browser.mainLoop.currentFrameNumber % Browser.mainLoop.timingValue != 0) {
          // Not the scheduled time to render this frame - skip.
          Browser.mainLoop.scheduler();
          return;
        }
  
        // Signal GL rendering layer that processing of a new frame is about to start. This helps it optimize
        // VBO double-buffering and reduce GPU stalls.
  
        if (Browser.mainLoop.method === 'timeout' && Module.ctx) {
          Module.printErr('Looks like you are rendering without using requestAnimationFrame for the main loop. You should use 0 for the frame rate in emscripten_set_main_loop in order to use requestAnimationFrame, as that can greatly improve your frame rates!');
          Browser.mainLoop.method = ''; // just warn once per call to set main loop
        }
  
        Browser.mainLoop.runIter(function() {
          if (typeof arg !== 'undefined') {
            Runtime.dynCall('vi', func, [arg]);
          } else {
            Runtime.dynCall('v', func);
          }
        });
  
        // catch pauses from the main loop itself
        if (thisMainLoopId < Browser.mainLoop.currentlyRunningMainloop) return;
  
        // Queue new audio data. This is important to be right after the main loop invocation, so that we will immediately be able
        // to queue the newest produced audio samples.
        // TODO: Consider adding pre- and post- rAF callbacks so that GL.newRenderingFrameStarted() and SDL.audio.queueNewAudioData()
        //       do not need to be hardcoded into this function, but can be more generic.
        if (typeof SDL === 'object' && SDL.audio && SDL.audio.queueNewAudioData) SDL.audio.queueNewAudioData();
  
        Browser.mainLoop.scheduler();
      }
  
      if (!noSetTiming) {
        if (fps && fps > 0) _emscripten_set_main_loop_timing(0/*EM_TIMING_SETTIMEOUT*/, 1000.0 / fps);
        else _emscripten_set_main_loop_timing(1/*EM_TIMING_RAF*/, 1); // Do rAF by rendering each frame (no decimating)
  
        Browser.mainLoop.scheduler();
      }
  
      if (simulateInfiniteLoop) {
        throw 'SimulateInfiniteLoop';
      }
    }var Browser={mainLoop:{scheduler:null,method:"",currentlyRunningMainloop:0,func:null,arg:0,timingMode:0,timingValue:0,currentFrameNumber:0,queue:[],pause:function () {
          Browser.mainLoop.scheduler = null;
          Browser.mainLoop.currentlyRunningMainloop++; // Incrementing this signals the previous main loop that it's now become old, and it must return.
        },resume:function () {
          Browser.mainLoop.currentlyRunningMainloop++;
          var timingMode = Browser.mainLoop.timingMode;
          var timingValue = Browser.mainLoop.timingValue;
          var func = Browser.mainLoop.func;
          Browser.mainLoop.func = null;
          _emscripten_set_main_loop(func, 0, false, Browser.mainLoop.arg, true /* do not set timing and call scheduler, we will do it on the next lines */);
          _emscripten_set_main_loop_timing(timingMode, timingValue);
          Browser.mainLoop.scheduler();
        },updateStatus:function () {
          if (Module['setStatus']) {
            var message = Module['statusMessage'] || 'Please wait...';
            var remaining = Browser.mainLoop.remainingBlockers;
            var expected = Browser.mainLoop.expectedBlockers;
            if (remaining) {
              if (remaining < expected) {
                Module['setStatus'](message + ' (' + (expected - remaining) + '/' + expected + ')');
              } else {
                Module['setStatus'](message);
              }
            } else {
              Module['setStatus']('');
            }
          }
        },runIter:function (func) {
          if (ABORT) return;
          if (Module['preMainLoop']) {
            var preRet = Module['preMainLoop']();
            if (preRet === false) {
              return; // |return false| skips a frame
            }
          }
          try {
            func();
          } catch (e) {
            if (e instanceof ExitStatus) {
              return;
            } else {
              if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
              throw e;
            }
          }
          if (Module['postMainLoop']) Module['postMainLoop']();
        }},isFullScreen:false,pointerLock:false,moduleContextCreatedCallbacks:[],workers:[],init:function () {
        if (!Module["preloadPlugins"]) Module["preloadPlugins"] = []; // needs to exist even in workers
  
        if (Browser.initted) return;
        Browser.initted = true;
  
        try {
          new Blob();
          Browser.hasBlobConstructor = true;
        } catch(e) {
          Browser.hasBlobConstructor = false;
          console.log("warning: no blob constructor, cannot create blobs with mimetypes");
        }
        Browser.BlobBuilder = typeof MozBlobBuilder != "undefined" ? MozBlobBuilder : (typeof WebKitBlobBuilder != "undefined" ? WebKitBlobBuilder : (!Browser.hasBlobConstructor ? console.log("warning: no BlobBuilder") : null));
        Browser.URLObject = typeof window != "undefined" ? (window.URL ? window.URL : window.webkitURL) : undefined;
        if (!Module.noImageDecoding && typeof Browser.URLObject === 'undefined') {
          console.log("warning: Browser does not support creating object URLs. Built-in browser image decoding will not be available.");
          Module.noImageDecoding = true;
        }
  
        // Support for plugins that can process preloaded files. You can add more of these to
        // your app by creating and appending to Module.preloadPlugins.
        //
        // Each plugin is asked if it can handle a file based on the file's name. If it can,
        // it is given the file's raw data. When it is done, it calls a callback with the file's
        // (possibly modified) data. For example, a plugin might decompress a file, or it
        // might create some side data structure for use later (like an Image element, etc.).
  
        var imagePlugin = {};
        imagePlugin['canHandle'] = function imagePlugin_canHandle(name) {
          return !Module.noImageDecoding && /\.(jpg|jpeg|png|bmp)$/i.test(name);
        };
        imagePlugin['handle'] = function imagePlugin_handle(byteArray, name, onload, onerror) {
          var b = null;
          if (Browser.hasBlobConstructor) {
            try {
              b = new Blob([byteArray], { type: Browser.getMimetype(name) });
              if (b.size !== byteArray.length) { // Safari bug #118630
                // Safari's Blob can only take an ArrayBuffer
                b = new Blob([(new Uint8Array(byteArray)).buffer], { type: Browser.getMimetype(name) });
              }
            } catch(e) {
              Runtime.warnOnce('Blob constructor present but fails: ' + e + '; falling back to blob builder');
            }
          }
          if (!b) {
            var bb = new Browser.BlobBuilder();
            bb.append((new Uint8Array(byteArray)).buffer); // we need to pass a buffer, and must copy the array to get the right data range
            b = bb.getBlob();
          }
          var url = Browser.URLObject.createObjectURL(b);
          assert(typeof url == 'string', 'createObjectURL must return a url as a string');
          var img = new Image();
          img.onload = function img_onload() {
            assert(img.complete, 'Image ' + name + ' could not be decoded');
            var canvas = document.createElement('canvas');
            canvas.width = img.width;
            canvas.height = img.height;
            var ctx = canvas.getContext('2d');
            ctx.drawImage(img, 0, 0);
            Module["preloadedImages"][name] = canvas;
            Browser.URLObject.revokeObjectURL(url);
            if (onload) onload(byteArray);
          };
          img.onerror = function img_onerror(event) {
            console.log('Image ' + url + ' could not be decoded');
            if (onerror) onerror();
          };
          img.src = url;
        };
        Module['preloadPlugins'].push(imagePlugin);
  
        var audioPlugin = {};
        audioPlugin['canHandle'] = function audioPlugin_canHandle(name) {
          return !Module.noAudioDecoding && name.substr(-4) in { '.ogg': 1, '.wav': 1, '.mp3': 1 };
        };
        audioPlugin['handle'] = function audioPlugin_handle(byteArray, name, onload, onerror) {
          var done = false;
          function finish(audio) {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = audio;
            if (onload) onload(byteArray);
          }
          function fail() {
            if (done) return;
            done = true;
            Module["preloadedAudios"][name] = new Audio(); // empty shim
            if (onerror) onerror();
          }
          if (Browser.hasBlobConstructor) {
            try {
              var b = new Blob([byteArray], { type: Browser.getMimetype(name) });
            } catch(e) {
              return fail();
            }
            var url = Browser.URLObject.createObjectURL(b); // XXX we never revoke this!
            assert(typeof url == 'string', 'createObjectURL must return a url as a string');
            var audio = new Audio();
            audio.addEventListener('canplaythrough', function() { finish(audio) }, false); // use addEventListener due to chromium bug 124926
            audio.onerror = function audio_onerror(event) {
              if (done) return;
              console.log('warning: browser could not fully decode audio ' + name + ', trying slower base64 approach');
              function encode64(data) {
                var BASE = 'ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz0123456789+/';
                var PAD = '=';
                var ret = '';
                var leftchar = 0;
                var leftbits = 0;
                for (var i = 0; i < data.length; i++) {
                  leftchar = (leftchar << 8) | data[i];
                  leftbits += 8;
                  while (leftbits >= 6) {
                    var curr = (leftchar >> (leftbits-6)) & 0x3f;
                    leftbits -= 6;
                    ret += BASE[curr];
                  }
                }
                if (leftbits == 2) {
                  ret += BASE[(leftchar&3) << 4];
                  ret += PAD + PAD;
                } else if (leftbits == 4) {
                  ret += BASE[(leftchar&0xf) << 2];
                  ret += PAD;
                }
                return ret;
              }
              audio.src = 'data:audio/x-' + name.substr(-3) + ';base64,' + encode64(byteArray);
              finish(audio); // we don't wait for confirmation this worked - but it's worth trying
            };
            audio.src = url;
            // workaround for chrome bug 124926 - we do not always get oncanplaythrough or onerror
            Browser.safeSetTimeout(function() {
              finish(audio); // try to use it even though it is not necessarily ready to play
            }, 10000);
          } else {
            return fail();
          }
        };
        Module['preloadPlugins'].push(audioPlugin);
  
        // Canvas event setup
  
        var canvas = Module['canvas'];
        function pointerLockChange() {
          Browser.pointerLock = document['pointerLockElement'] === canvas ||
                                document['mozPointerLockElement'] === canvas ||
                                document['webkitPointerLockElement'] === canvas ||
                                document['msPointerLockElement'] === canvas;
        }
        if (canvas) {
          // forced aspect ratio can be enabled by defining 'forcedAspectRatio' on Module
          // Module['forcedAspectRatio'] = 4 / 3;
          
          canvas.requestPointerLock = canvas['requestPointerLock'] ||
                                      canvas['mozRequestPointerLock'] ||
                                      canvas['webkitRequestPointerLock'] ||
                                      canvas['msRequestPointerLock'] ||
                                      function(){};
          canvas.exitPointerLock = document['exitPointerLock'] ||
                                   document['mozExitPointerLock'] ||
                                   document['webkitExitPointerLock'] ||
                                   document['msExitPointerLock'] ||
                                   function(){}; // no-op if function does not exist
          canvas.exitPointerLock = canvas.exitPointerLock.bind(document);
  
  
          document.addEventListener('pointerlockchange', pointerLockChange, false);
          document.addEventListener('mozpointerlockchange', pointerLockChange, false);
          document.addEventListener('webkitpointerlockchange', pointerLockChange, false);
          document.addEventListener('mspointerlockchange', pointerLockChange, false);
  
          if (Module['elementPointerLock']) {
            canvas.addEventListener("click", function(ev) {
              if (!Browser.pointerLock && canvas.requestPointerLock) {
                canvas.requestPointerLock();
                ev.preventDefault();
              }
            }, false);
          }
        }
      },createContext:function (canvas, useWebGL, setInModule, webGLContextAttributes) {
        if (useWebGL && Module.ctx && canvas == Module.canvas) return Module.ctx; // no need to recreate GL context if it's already been created for this canvas.
  
        var ctx;
        var contextHandle;
        if (useWebGL) {
          // For GLES2/desktop GL compatibility, adjust a few defaults to be different to WebGL defaults, so that they align better with the desktop defaults.
          var contextAttributes = {
            antialias: false,
            alpha: false
          };
  
          if (webGLContextAttributes) {
            for (var attribute in webGLContextAttributes) {
              contextAttributes[attribute] = webGLContextAttributes[attribute];
            }
          }
  
          contextHandle = GL.createContext(canvas, contextAttributes);
          if (contextHandle) {
            ctx = GL.getContext(contextHandle).GLctx;
          }
          // Set the background of the WebGL canvas to black
          canvas.style.backgroundColor = "black";
        } else {
          ctx = canvas.getContext('2d');
        }
  
        if (!ctx) return null;
  
        if (setInModule) {
          if (!useWebGL) assert(typeof GLctx === 'undefined', 'cannot set in module if GLctx is used, but we are a non-GL context that would replace it');
  
          Module.ctx = ctx;
          if (useWebGL) GL.makeContextCurrent(contextHandle);
          Module.useWebGL = useWebGL;
          Browser.moduleContextCreatedCallbacks.forEach(function(callback) { callback() });
          Browser.init();
        }
        return ctx;
      },destroyContext:function (canvas, useWebGL, setInModule) {},fullScreenHandlersInstalled:false,lockPointer:undefined,resizeCanvas:undefined,requestFullScreen:function (lockPointer, resizeCanvas, vrDevice) {
        Browser.lockPointer = lockPointer;
        Browser.resizeCanvas = resizeCanvas;
        Browser.vrDevice = vrDevice;
        if (typeof Browser.lockPointer === 'undefined') Browser.lockPointer = true;
        if (typeof Browser.resizeCanvas === 'undefined') Browser.resizeCanvas = false;
        if (typeof Browser.vrDevice === 'undefined') Browser.vrDevice = null;
  
        var canvas = Module['canvas'];
        function fullScreenChange() {
          Browser.isFullScreen = false;
          var canvasContainer = canvas.parentNode;
          if ((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
               document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
               document['fullScreenElement'] || document['fullscreenElement'] ||
               document['msFullScreenElement'] || document['msFullscreenElement'] ||
               document['webkitCurrentFullScreenElement']) === canvasContainer) {
            canvas.cancelFullScreen = document['cancelFullScreen'] ||
                                      document['mozCancelFullScreen'] ||
                                      document['webkitCancelFullScreen'] ||
                                      document['msExitFullscreen'] ||
                                      document['exitFullscreen'] ||
                                      function() {};
            canvas.cancelFullScreen = canvas.cancelFullScreen.bind(document);
            if (Browser.lockPointer) canvas.requestPointerLock();
            Browser.isFullScreen = true;
            if (Browser.resizeCanvas) Browser.setFullScreenCanvasSize();
          } else {
            
            // remove the full screen specific parent of the canvas again to restore the HTML structure from before going full screen
            canvasContainer.parentNode.insertBefore(canvas, canvasContainer);
            canvasContainer.parentNode.removeChild(canvasContainer);
            
            if (Browser.resizeCanvas) Browser.setWindowedCanvasSize();
          }
          if (Module['onFullScreen']) Module['onFullScreen'](Browser.isFullScreen);
          Browser.updateCanvasDimensions(canvas);
        }
  
        if (!Browser.fullScreenHandlersInstalled) {
          Browser.fullScreenHandlersInstalled = true;
          document.addEventListener('fullscreenchange', fullScreenChange, false);
          document.addEventListener('mozfullscreenchange', fullScreenChange, false);
          document.addEventListener('webkitfullscreenchange', fullScreenChange, false);
          document.addEventListener('MSFullscreenChange', fullScreenChange, false);
        }
  
        // create a new parent to ensure the canvas has no siblings. this allows browsers to optimize full screen performance when its parent is the full screen root
        var canvasContainer = document.createElement("div");
        canvas.parentNode.insertBefore(canvasContainer, canvas);
        canvasContainer.appendChild(canvas);
  
        // use parent of canvas as full screen root to allow aspect ratio correction (Firefox stretches the root to screen size)
        canvasContainer.requestFullScreen = canvasContainer['requestFullScreen'] ||
                                            canvasContainer['mozRequestFullScreen'] ||
                                            canvasContainer['msRequestFullscreen'] ||
                                           (canvasContainer['webkitRequestFullScreen'] ? function() { canvasContainer['webkitRequestFullScreen'](Element['ALLOW_KEYBOARD_INPUT']) } : null);
  
        if (vrDevice) {
          canvasContainer.requestFullScreen({ vrDisplay: vrDevice });
        } else {
          canvasContainer.requestFullScreen();
        }
      },nextRAF:0,fakeRequestAnimationFrame:function (func) {
        // try to keep 60fps between calls to here
        var now = Date.now();
        if (Browser.nextRAF === 0) {
          Browser.nextRAF = now + 1000/60;
        } else {
          while (now + 2 >= Browser.nextRAF) { // fudge a little, to avoid timer jitter causing us to do lots of delay:0
            Browser.nextRAF += 1000/60;
          }
        }
        var delay = Math.max(Browser.nextRAF - now, 0);
        setTimeout(func, delay);
      },requestAnimationFrame:function requestAnimationFrame(func) {
        if (typeof window === 'undefined') { // Provide fallback to setTimeout if window is undefined (e.g. in Node.js)
          Browser.fakeRequestAnimationFrame(func);
        } else {
          if (!window.requestAnimationFrame) {
            window.requestAnimationFrame = window['requestAnimationFrame'] ||
                                           window['mozRequestAnimationFrame'] ||
                                           window['webkitRequestAnimationFrame'] ||
                                           window['msRequestAnimationFrame'] ||
                                           window['oRequestAnimationFrame'] ||
                                           Browser.fakeRequestAnimationFrame;
          }
          window.requestAnimationFrame(func);
        }
      },safeCallback:function (func) {
        return function() {
          if (!ABORT) return func.apply(null, arguments);
        };
      },allowAsyncCallbacks:true,queuedAsyncCallbacks:[],pauseAsyncCallbacks:function () {
        Browser.allowAsyncCallbacks = false;
      },resumeAsyncCallbacks:function () { // marks future callbacks as ok to execute, and synchronously runs any remaining ones right now
        Browser.allowAsyncCallbacks = true;
        if (Browser.queuedAsyncCallbacks.length > 0) {
          var callbacks = Browser.queuedAsyncCallbacks;
          Browser.queuedAsyncCallbacks = [];
          callbacks.forEach(function(func) {
            func();
          });
        }
      },safeRequestAnimationFrame:function (func) {
        return Browser.requestAnimationFrame(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        });
      },safeSetTimeout:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setTimeout(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } else {
            Browser.queuedAsyncCallbacks.push(func);
          }
        }, timeout);
      },safeSetInterval:function (func, timeout) {
        Module['noExitRuntime'] = true;
        return setInterval(function() {
          if (ABORT) return;
          if (Browser.allowAsyncCallbacks) {
            func();
          } // drop it on the floor otherwise, next interval will kick in
        }, timeout);
      },getMimetype:function (name) {
        return {
          'jpg': 'image/jpeg',
          'jpeg': 'image/jpeg',
          'png': 'image/png',
          'bmp': 'image/bmp',
          'ogg': 'audio/ogg',
          'wav': 'audio/wav',
          'mp3': 'audio/mpeg'
        }[name.substr(name.lastIndexOf('.')+1)];
      },getUserMedia:function (func) {
        if(!window.getUserMedia) {
          window.getUserMedia = navigator['getUserMedia'] ||
                                navigator['mozGetUserMedia'];
        }
        window.getUserMedia(func);
      },getMovementX:function (event) {
        return event['movementX'] ||
               event['mozMovementX'] ||
               event['webkitMovementX'] ||
               0;
      },getMovementY:function (event) {
        return event['movementY'] ||
               event['mozMovementY'] ||
               event['webkitMovementY'] ||
               0;
      },getMouseWheelDelta:function (event) {
        var delta = 0;
        switch (event.type) {
          case 'DOMMouseScroll': 
            delta = event.detail;
            break;
          case 'mousewheel': 
            delta = event.wheelDelta;
            break;
          case 'wheel': 
            delta = event['deltaY'];
            break;
          default:
            throw 'unrecognized mouse wheel event: ' + event.type;
        }
        return delta;
      },mouseX:0,mouseY:0,mouseMovementX:0,mouseMovementY:0,touches:{},lastTouches:{},calculateMouseEvent:function (event) { // event should be mousemove, mousedown or mouseup
        if (Browser.pointerLock) {
          // When the pointer is locked, calculate the coordinates
          // based on the movement of the mouse.
          // Workaround for Firefox bug 764498
          if (event.type != 'mousemove' &&
              ('mozMovementX' in event)) {
            Browser.mouseMovementX = Browser.mouseMovementY = 0;
          } else {
            Browser.mouseMovementX = Browser.getMovementX(event);
            Browser.mouseMovementY = Browser.getMovementY(event);
          }
          
          // check if SDL is available
          if (typeof SDL != "undefined") {
          	Browser.mouseX = SDL.mouseX + Browser.mouseMovementX;
          	Browser.mouseY = SDL.mouseY + Browser.mouseMovementY;
          } else {
          	// just add the mouse delta to the current absolut mouse position
          	// FIXME: ideally this should be clamped against the canvas size and zero
          	Browser.mouseX += Browser.mouseMovementX;
          	Browser.mouseY += Browser.mouseMovementY;
          }        
        } else {
          // Otherwise, calculate the movement based on the changes
          // in the coordinates.
          var rect = Module["canvas"].getBoundingClientRect();
          var cw = Module["canvas"].width;
          var ch = Module["canvas"].height;
  
          // Neither .scrollX or .pageXOffset are defined in a spec, but
          // we prefer .scrollX because it is currently in a spec draft.
          // (see: http://www.w3.org/TR/2013/WD-cssom-view-20131217/)
          var scrollX = ((typeof window.scrollX !== 'undefined') ? window.scrollX : window.pageXOffset);
          var scrollY = ((typeof window.scrollY !== 'undefined') ? window.scrollY : window.pageYOffset);
          // If this assert lands, it's likely because the browser doesn't support scrollX or pageXOffset
          // and we have no viable fallback.
          assert((typeof scrollX !== 'undefined') && (typeof scrollY !== 'undefined'), 'Unable to retrieve scroll position, mouse positions likely broken.');
  
          if (event.type === 'touchstart' || event.type === 'touchend' || event.type === 'touchmove') {
            var touch = event.touch;
            if (touch === undefined) {
              return; // the "touch" property is only defined in SDL
  
            }
            var adjustedX = touch.pageX - (scrollX + rect.left);
            var adjustedY = touch.pageY - (scrollY + rect.top);
  
            adjustedX = adjustedX * (cw / rect.width);
            adjustedY = adjustedY * (ch / rect.height);
  
            var coords = { x: adjustedX, y: adjustedY };
            
            if (event.type === 'touchstart') {
              Browser.lastTouches[touch.identifier] = coords;
              Browser.touches[touch.identifier] = coords;
            } else if (event.type === 'touchend' || event.type === 'touchmove') {
              var last = Browser.touches[touch.identifier];
              if (!last) last = coords;
              Browser.lastTouches[touch.identifier] = last;
              Browser.touches[touch.identifier] = coords;
            } 
            return;
          }
  
          var x = event.pageX - (scrollX + rect.left);
          var y = event.pageY - (scrollY + rect.top);
  
          // the canvas might be CSS-scaled compared to its backbuffer;
          // SDL-using content will want mouse coordinates in terms
          // of backbuffer units.
          x = x * (cw / rect.width);
          y = y * (ch / rect.height);
  
          Browser.mouseMovementX = x - Browser.mouseX;
          Browser.mouseMovementY = y - Browser.mouseY;
          Browser.mouseX = x;
          Browser.mouseY = y;
        }
      },xhrLoad:function (url, onload, onerror) {
        var xhr = new XMLHttpRequest();
        xhr.open('GET', url, true);
        xhr.responseType = 'arraybuffer';
        xhr.onload = function xhr_onload() {
          if (xhr.status == 200 || (xhr.status == 0 && xhr.response)) { // file URLs can return 0
            onload(xhr.response);
          } else {
            onerror();
          }
        };
        xhr.onerror = onerror;
        xhr.send(null);
      },asyncLoad:function (url, onload, onerror, noRunDep) {
        Browser.xhrLoad(url, function(arrayBuffer) {
          assert(arrayBuffer, 'Loading data file "' + url + '" failed (no arrayBuffer).');
          onload(new Uint8Array(arrayBuffer));
          if (!noRunDep) removeRunDependency('al ' + url);
        }, function(event) {
          if (onerror) {
            onerror();
          } else {
            throw 'Loading data file "' + url + '" failed.';
          }
        });
        if (!noRunDep) addRunDependency('al ' + url);
      },resizeListeners:[],updateResizeListeners:function () {
        var canvas = Module['canvas'];
        Browser.resizeListeners.forEach(function(listener) {
          listener(canvas.width, canvas.height);
        });
      },setCanvasSize:function (width, height, noUpdates) {
        var canvas = Module['canvas'];
        Browser.updateCanvasDimensions(canvas, width, height);
        if (!noUpdates) Browser.updateResizeListeners();
      },windowedWidth:0,windowedHeight:0,setFullScreenCanvasSize:function () {
        // check if SDL is available   
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags | 0x00800000; // set SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },setWindowedCanvasSize:function () {
        // check if SDL is available       
        if (typeof SDL != "undefined") {
        	var flags = HEAPU32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)];
        	flags = flags & ~0x00800000; // clear SDL_FULLSCREEN flag
        	HEAP32[((SDL.screen+Runtime.QUANTUM_SIZE*0)>>2)]=flags
        }
        Browser.updateResizeListeners();
      },updateCanvasDimensions:function (canvas, wNative, hNative) {
        if (wNative && hNative) {
          canvas.widthNative = wNative;
          canvas.heightNative = hNative;
        } else {
          wNative = canvas.widthNative;
          hNative = canvas.heightNative;
        }
        var w = wNative;
        var h = hNative;
        if (Module['forcedAspectRatio'] && Module['forcedAspectRatio'] > 0) {
          if (w/h < Module['forcedAspectRatio']) {
            w = Math.round(h * Module['forcedAspectRatio']);
          } else {
            h = Math.round(w / Module['forcedAspectRatio']);
          }
        }
        if (((document['webkitFullScreenElement'] || document['webkitFullscreenElement'] ||
             document['mozFullScreenElement'] || document['mozFullscreenElement'] ||
             document['fullScreenElement'] || document['fullscreenElement'] ||
             document['msFullScreenElement'] || document['msFullscreenElement'] ||
             document['webkitCurrentFullScreenElement']) === canvas.parentNode) && (typeof screen != 'undefined')) {
           var factor = Math.min(screen.width / w, screen.height / h);
           w = Math.round(w * factor);
           h = Math.round(h * factor);
        }
        if (Browser.resizeCanvas) {
          if (canvas.width  != w) canvas.width  = w;
          if (canvas.height != h) canvas.height = h;
          if (typeof canvas.style != 'undefined') {
            canvas.style.removeProperty( "width");
            canvas.style.removeProperty("height");
          }
        } else {
          if (canvas.width  != wNative) canvas.width  = wNative;
          if (canvas.height != hNative) canvas.height = hNative;
          if (typeof canvas.style != 'undefined') {
            if (w != wNative || h != hNative) {
              canvas.style.setProperty( "width", w + "px", "important");
              canvas.style.setProperty("height", h + "px", "important");
            } else {
              canvas.style.removeProperty( "width");
              canvas.style.removeProperty("height");
            }
          }
        }
      },wgetRequests:{},nextWgetRequestHandle:0,getNextWgetRequestHandle:function () {
        var handle = Browser.nextWgetRequestHandle;
        Browser.nextWgetRequestHandle++;
        return handle;
      }};

  
  var ___tm_current=allocate(44, "i8", ALLOC_STATIC);
  
  
  var ___tm_timezone=allocate(intArrayFromString("GMT"), "i8", ALLOC_STATIC);function _localtime_r(time, tmPtr) {
      _tzset();
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getDay();
  
      var start = new Date(date.getFullYear(), 0, 1);
      var yday = ((date.getTime() - start.getTime()) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(36))>>2)]=-(date.getTimezoneOffset() * 60);
  
      // DST is in December in South
      var summerOffset = new Date(2000, 6, 1).getTimezoneOffset();
      var winterOffset = start.getTimezoneOffset();
      var dst = (date.getTimezoneOffset() == Math.min(winterOffset, summerOffset))|0;
      HEAP32[(((tmPtr)+(32))>>2)]=dst;
  
      var zonePtr = HEAP32[(((_tzname)+(dst ? Runtime.QUANTUM_SIZE : 0))>>2)];
      HEAP32[(((tmPtr)+(40))>>2)]=zonePtr;
  
      return tmPtr;
    }function _localtime(time) {
      return _localtime_r(time, ___tm_current);
    }

  function _sysconf(name) {
      // long sysconf(int name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/sysconf.html
      switch(name) {
        case 30: return PAGE_SIZE;
        case 85: return totalMemory / PAGE_SIZE;
        case 132:
        case 133:
        case 12:
        case 137:
        case 138:
        case 15:
        case 235:
        case 16:
        case 17:
        case 18:
        case 19:
        case 20:
        case 149:
        case 13:
        case 10:
        case 236:
        case 153:
        case 9:
        case 21:
        case 22:
        case 159:
        case 154:
        case 14:
        case 77:
        case 78:
        case 139:
        case 80:
        case 81:
        case 82:
        case 68:
        case 67:
        case 164:
        case 11:
        case 29:
        case 47:
        case 48:
        case 95:
        case 52:
        case 51:
        case 46:
          return 200809;
        case 79:
          return 0;
        case 27:
        case 246:
        case 127:
        case 128:
        case 23:
        case 24:
        case 160:
        case 161:
        case 181:
        case 182:
        case 242:
        case 183:
        case 184:
        case 243:
        case 244:
        case 245:
        case 165:
        case 178:
        case 179:
        case 49:
        case 50:
        case 168:
        case 169:
        case 175:
        case 170:
        case 171:
        case 172:
        case 97:
        case 76:
        case 32:
        case 173:
        case 35:
          return -1;
        case 176:
        case 177:
        case 7:
        case 155:
        case 8:
        case 157:
        case 125:
        case 126:
        case 92:
        case 93:
        case 129:
        case 130:
        case 131:
        case 94:
        case 91:
          return 1;
        case 74:
        case 60:
        case 69:
        case 70:
        case 4:
          return 1024;
        case 31:
        case 42:
        case 72:
          return 32;
        case 87:
        case 26:
        case 33:
          return 2147483647;
        case 34:
        case 1:
          return 47839;
        case 38:
        case 36:
          return 99;
        case 43:
        case 37:
          return 2048;
        case 0: return 2097152;
        case 3: return 65536;
        case 28: return 32768;
        case 44: return 32767;
        case 75: return 16384;
        case 39: return 1000;
        case 89: return 700;
        case 71: return 256;
        case 40: return 255;
        case 2: return 100;
        case 180: return 64;
        case 25: return 20;
        case 5: return 16;
        case 6: return 6;
        case 73: return 4;
        case 84: {
          if (typeof navigator === 'object') return navigator['hardwareConcurrency'] || 1;
          return 1;
        }
      }
      ___setErrNo(ERRNO_CODES.EINVAL);
      return -1;
    }

   
  Module["_bitshift64Lshr"] = _bitshift64Lshr;

  
  
  function _recv(fd, buf, len, flags) {
      var sock = SOCKFS.getSocket(fd);
      if (!sock) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      // TODO honor flags
      return _read(fd, buf, len);
    }
  
  function _pread(fildes, buf, nbyte, offset) {
      // ssize_t pread(int fildes, void *buf, size_t nbyte, off_t offset);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte, offset);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _read(fildes, buf, nbyte) {
      // ssize_t read(int fildes, void *buf, size_t nbyte);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/read.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
  
  
      try {
        var slab = HEAP8;
        return FS.read(stream, slab, buf, nbyte);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _fread(ptr, size, nitems, stream) {
      // size_t fread(void *restrict ptr, size_t size, size_t nitems, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fread.html
      var bytesToRead = nitems * size;
      if (bytesToRead == 0) {
        return 0;
      }
      var bytesRead = 0;
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      while (streamObj.ungotten.length && bytesToRead > 0) {
        HEAP8[((ptr++)>>0)]=streamObj.ungotten.pop();
        bytesToRead--;
        bytesRead++;
      }
      var err = _read(streamObj.fd, ptr, bytesToRead);
      if (err == -1) {
        if (streamObj) streamObj.error = true;
        return 0;
      }
      bytesRead += err;
      if (bytesRead < bytesToRead) streamObj.eof = true;
      return (bytesRead / size)|0;
    }

  function _isatty(fildes) {
      // int isatty(int fildes);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/isatty.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // HACK - implement tcgetattr
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return 0;
      }
      return 1;
    }


  var _BDtoIHigh=true;

  function _sigaddset(set, signum) {
      HEAP32[((set)>>2)]=HEAP32[((set)>>2)]| (1 << (signum-1));
      return 0;
    }

  
  
   
  Module["_testSetjmp"] = _testSetjmp;function _longjmp(env, value) {
      asm['setThrew'](env, value || 1);
      throw 'longjmp';
    }function _emscripten_longjmp(env, value) {
      _longjmp(env, value);
    }

  var _ceil=Math_ceil;

  function _gettimeofday(ptr) {
      var now = Date.now();
      HEAP32[((ptr)>>2)]=(now/1000)|0; // seconds
      HEAP32[(((ptr)+(4))>>2)]=((now % 1000)*1000)|0; // microseconds
      return 0;
    }

  function _vfprintf(s, f, va_arg) {
      return _fprintf(s, f, HEAP32[((va_arg)>>2)]);
    }

  function _getpwnam() { throw 'getpwnam: TODO' }



  var _llvm_pow_f64=Math_pow;

  function _sbrk(bytes) {
      // Implement a Linux-like 'memory area' for our 'process'.
      // Changes the size of the memory area by |bytes|; returns the
      // address of the previous top ('break') of the memory area
      // We control the "dynamic" memory - DYNAMIC_BASE to DYNAMICTOP
      var self = _sbrk;
      if (!self.called) {
        DYNAMICTOP = alignMemoryPage(DYNAMICTOP); // make sure we start out aligned
        self.called = true;
        assert(Runtime.dynamicAlloc);
        self.alloc = Runtime.dynamicAlloc;
        Runtime.dynamicAlloc = function() { abort('cannot dynamically allocate, sbrk now has control') };
      }
      var ret = DYNAMICTOP;
      if (bytes != 0) {
        var success = self.alloc(bytes);
        if (!success) return -1 >>> 0; // sbrk failure code
      }
      return ret;  // Previous break location.
    }

   
  Module["_memmove"] = _memmove;

  
  var __sigalrm_handler=0;function _signal(sig, func) {
      if (sig == 14 /*SIGALRM*/) {
        __sigalrm_handler = func;
      } else {
        Module.printErr('Calling stub instead of signal()');
      }
      return 0;
    }

  var _emscripten_preinvoke=true;

  var _BItoD=true;

  
  function _unlink(path) {
      // int unlink(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/unlink.html
      path = Pointer_stringify(path);
      try {
        FS.unlink(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }
  
  function _rmdir(path) {
      // int rmdir(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rmdir.html
      path = Pointer_stringify(path);
      try {
        FS.rmdir(path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }function _remove(path) {
      // int remove(const char *path);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/remove.html
      var ret = _unlink(path);
      if (ret == -1) ret = _rmdir(path);
      return ret;
    }

  function _opendir(dirname) {
      // DIR *opendir(const char *dirname);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/opendir.html
      // NOTE: Calculating absolute path redundantly since we need to associate it
      //       with the opened stream.
      var path = Pointer_stringify(dirname);
      if (!path) {
        ___setErrNo(ERRNO_CODES.ENOENT);
        return 0;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return 0;
      }
      if (!FS.isDir(node.mode)) {
        ___setErrNo(ERRNO_CODES.ENOTDIR);
        return 0;
      }
      var fd = _open(dirname, 0, allocate([0, 0, 0, 0], 'i32', ALLOC_STACK));
      return fd === -1 ? 0 : FS.getPtrForStream(FS.getStream(fd));
    }

  function _freopen(filename, mode, stream) {
      // FILE *freopen(const char *restrict filename, const char *restrict mode, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/freopen.html
      if (!filename) {
        var streamObj = FS.getStreamFromPtr(stream);
        if (!streamObj) {
          ___setErrNo(ERRNO_CODES.EBADF);
          return 0;
        }
        if (_freopen.buffer) _free(_freopen.buffer);
        filename = intArrayFromString(streamObj.path);
        filename = allocate(filename, 'i8', ALLOC_NORMAL);
      }
      _fclose(stream);
      return _fopen(filename, mode);
    }

  function _ungetc(c, stream) {
      // int ungetc(int c, FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ungetc.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return -1;
      }
      if (c === -1) {
        // do nothing for EOF character
        return c;
      }
      c = unSign(c & 0xFF);
      stream.ungotten.push(c);
      stream.eof = false;
      return c;
    }

  function _getpwuid(uid) {
      return 0; // NULL
    }

  function _localeconv() {
      // %struct.timeval = type { char* decimal point, other stuff... }
      // var indexes = Runtime.calculateStructAlignment({ fields: ['i32', 'i32'] });
      var me = _localeconv;
      if (!me.ret) {
      // These are defaults from the "C" locale
        me.ret = allocate([
          allocate(intArrayFromString('.'), 'i8', ALLOC_NORMAL),0,0,0, // decimal_point
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // thousands_sep
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // grouping
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // int_curr_symbol
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // currency_symbol
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_decimal_point
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_thousands_sep
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // mon_grouping
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0, // positive_sign
          allocate(intArrayFromString(''), 'i8', ALLOC_NORMAL),0,0,0 // negative_sign
        ], 'i8*', ALLOC_NORMAL); // Allocate strings in lconv, still don't allocate chars
      }
      return me.ret;
    }

  function _rename(old_path, new_path) {
      // int rename(const char *old, const char *new);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/rename.html
      old_path = Pointer_stringify(old_path);
      new_path = Pointer_stringify(new_path);
      try {
        FS.rename(old_path, new_path);
        return 0;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _tmpfile() {
      // FILE *tmpfile(void);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/tmpfile.html
      // TODO: Delete the created file on closing.
      if (!_tmpfile.mode) {
        _tmpfile.mode = allocate(intArrayFromString('w+'), 'i8', ALLOC_NORMAL);
      }
      return _fopen(_tmpnam(0), _tmpfile.mode);
    }

  var _emscripten_cleanup_setjmp=true;

  var _SItoD=true;

  function ___errno_location() {
      return ___errno_state;
    }

   
  Module["_memset"] = _memset;

  var _BDtoILow=true;

   
  Module["_strcat"] = _strcat;

  
  function _readdir_r(dirp, entry, result) {
      // int readdir_r(DIR *dirp, struct dirent *entry, struct dirent **result);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStreamFromPtr(dirp);
      if (!stream) {
        return ___setErrNo(ERRNO_CODES.EBADF);
      }
      if (!stream.currReading) {
        try {
          // load the list of entries now, then readdir will traverse that list, to ignore changes to files
          stream.currReading = FS.readdir(stream.path);
        } catch (e) {
          return FS.handleFSError(e);
        }
      }
      if (stream.position < 0 || stream.position >= stream.currReading.length) {
        HEAP32[((result)>>2)]=0;
        return 0;
      }
      var id;
      var type;
      var name = stream.currReading[stream.position++];
      if (!name.indexOf('.')) {
        id = 1;
        type = 4;
      } else {
        try {
          // child may have been removed since we started to read this directory
          var child = FS.lookupNode(stream.node, name);
        } catch (e) {
          // skip to the next entry (not infinite since position is incremented until currReading.length)
          return _readdir_r(dirp, entry, result);
        }
        id = child.id;
        type = FS.isChrdev(child.mode) ? 2 :  // DT_CHR, character device.
               FS.isDir(child.mode) ? 4 :     // DT_DIR, directory.
               FS.isLink(child.mode) ? 10 :   // DT_LNK, symbolic link.
               8;                             // DT_REG, regular file.
      }
      HEAP32[((entry)>>2)]=id;
      HEAP32[(((entry)+(4))>>2)]=stream.position;
      HEAP32[(((entry)+(8))>>2)]=268;
      for (var i = 0; i < name.length; i++) {
        HEAP8[(((entry + 11)+(i))>>0)]=name.charCodeAt(i);
      }
      HEAP8[(((entry + 11)+(i))>>0)]=0;
      HEAP8[(((entry)+(10))>>0)]=type;
      HEAP32[((result)>>2)]=entry;
      return 0;
    }function _readdir(dirp) {
      // struct dirent *readdir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/readdir_r.html
      var stream = FS.getStreamFromPtr(dirp);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return 0;
      }
      // TODO Is it supposed to be safe to execute multiple readdirs?
      if (!_readdir.entry) _readdir.entry = _malloc(268);
      if (!_readdir.result) _readdir.result = _malloc(4);
      var err = _readdir_r(dirp, _readdir.entry, _readdir.result);
      if (err) {
        ___setErrNo(err);
        return 0;
      }
      return HEAP32[((_readdir.result)>>2)];
    }

  
  function _strerror_r(errnum, strerrbuf, buflen) {
      if (errnum in ERRNO_MESSAGES) {
        if (ERRNO_MESSAGES[errnum].length > buflen - 1) {
          return ___setErrNo(ERRNO_CODES.ERANGE);
        } else {
          var msg = ERRNO_MESSAGES[errnum];
          writeAsciiToMemory(msg, strerrbuf);
          return 0;
        }
      } else {
        return ___setErrNo(ERRNO_CODES.EINVAL);
      }
    }function _strerror(errnum) {
      if (!_strerror.buffer) _strerror.buffer = _malloc(256);
      _strerror_r(errnum, _strerror.buffer, 256);
      return _strerror.buffer;
    }

  var _DtoIHigh=true;

   
  Module["_bitshift64Shl"] = _bitshift64Shl;

  function _abort() {
      Module['abort']();
    }


  
  function _fgetc(stream) {
      // int fgetc(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgetc.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return -1;
      if (streamObj.eof || streamObj.error) return -1;
      var ret = _fread(_fgetc.ret, 1, 1, stream);
      if (ret == 0) {
        return -1;
      } else if (ret == -1) {
        streamObj.error = true;
        return -1;
      } else {
        return HEAPU8[((_fgetc.ret)>>0)];
      }
    }function _fgets(s, n, stream) {
      // char *fgets(char *restrict s, int n, FILE *restrict stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/fgets.html
      var streamObj = FS.getStreamFromPtr(stream);
      if (!streamObj) return 0;
      if (streamObj.error || streamObj.eof) return 0;
      var byte_;
      for (var i = 0; i < n - 1 && byte_ != 10; i++) {
        byte_ = _fgetc(stream);
        if (byte_ == -1) {
          if (streamObj.error || (streamObj.eof && i == 0)) return 0;
          else if (streamObj.eof) break;
        }
        HEAP8[(((s)+(i))>>0)]=byte_;
      }
      HEAP8[(((s)+(i))>>0)]=0;
      return s;
    }


  var _tan=Math_tan;

  function _feof(stream) {
      // int feof(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/feof.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.eof);
    }

  var _asin=Math_asin;

  function _clearerr(stream) {
      // void clearerr(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/clearerr.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        return;
      }
      stream.eof = false;
      stream.error = false;
    }

  var _fabs=Math_abs;

  function _clock() {
      if (_clock.start === undefined) _clock.start = Date.now();
      return ((Date.now() - _clock.start) * (1000000 / 1000))|0;
    }

  var _emscripten_prep_setjmp=true;



  function _getc() {
  return _fgetc.apply(null, arguments)
  }

  function _cfgetospeed(termios_p) {
      Runtime.warnOnce('cfgetospeed() returning a fake value');
      return 15;
    }

  var _sqrt=Math_sqrt;

  function _access(path, amode) {
      // int access(const char *path, int amode);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/access.html
      path = Pointer_stringify(path);
      if (amode & ~7) {
        // need a valid mode
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var node;
      try {
        var lookup = FS.lookupPath(path, { follow: true });
        node = lookup.node;
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
      var perms = '';
      if (amode & 4) perms += 'r';
      if (amode & 2) perms += 'w';
      if (amode & 1) perms += 'x';
      if (perms /* otherwise, they've just passed F_OK */ && FS.nodePermissions(node, perms)) {
        ___setErrNo(ERRNO_CODES.EACCES);
        return -1;
      }
      return 0;
    }

  function _ftell(stream) {
      // long ftell(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ftell.html
      stream = FS.getStreamFromPtr(stream);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (FS.isChrdev(stream.node.mode)) {
        ___setErrNo(ERRNO_CODES.ESPIPE);
        return -1;
      } else {
        return stream.position;
      }
    }

  
  
  
  
  var _environ=allocate(1, "i32*", ALLOC_STATIC);var ___environ=_environ;function ___buildEnvironment(env) {
      // WARNING: Arbitrary limit!
      var MAX_ENV_VALUES = 64;
      var TOTAL_ENV_SIZE = 1024;
  
      // Statically allocate memory for the environment.
      var poolPtr;
      var envPtr;
      if (!___buildEnvironment.called) {
        ___buildEnvironment.called = true;
        // Set default values. Use string keys for Closure Compiler compatibility.
        ENV['USER'] = 'web_user';
        ENV['PATH'] = '/';
        ENV['PWD'] = '/';
        ENV['HOME'] = '/home/web_user';
        ENV['LANG'] = 'C';
        ENV['_'] = Module['thisProgram'];
        // Allocate memory.
        poolPtr = allocate(TOTAL_ENV_SIZE, 'i8', ALLOC_STATIC);
        envPtr = allocate(MAX_ENV_VALUES * 4,
                          'i8*', ALLOC_STATIC);
        HEAP32[((envPtr)>>2)]=poolPtr;
        HEAP32[((_environ)>>2)]=envPtr;
      } else {
        envPtr = HEAP32[((_environ)>>2)];
        poolPtr = HEAP32[((envPtr)>>2)];
      }
  
      // Collect key=value lines.
      var strings = [];
      var totalSize = 0;
      for (var key in env) {
        if (typeof env[key] === 'string') {
          var line = key + '=' + env[key];
          strings.push(line);
          totalSize += line.length;
        }
      }
      if (totalSize > TOTAL_ENV_SIZE) {
        throw new Error('Environment size exceeded TOTAL_ENV_SIZE!');
      }
  
      // Make new.
      var ptrSize = 4;
      for (var i = 0; i < strings.length; i++) {
        var line = strings[i];
        writeAsciiToMemory(line, poolPtr);
        HEAP32[(((envPtr)+(i * ptrSize))>>2)]=poolPtr;
        poolPtr += line.length + 1;
      }
      HEAP32[(((envPtr)+(strings.length * ptrSize))>>2)]=0;
    }var ENV={};function _setenv(envname, envval, overwrite) {
      // int setenv(const char *envname, const char *envval, int overwrite);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/setenv.html
      if (envname === 0) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      var name = Pointer_stringify(envname);
      var val = Pointer_stringify(envval);
      if (name === '' || name.indexOf('=') !== -1) {
        ___setErrNo(ERRNO_CODES.EINVAL);
        return -1;
      }
      if (ENV.hasOwnProperty(name) && !overwrite) return 0;
      ENV[name] = val;
      ___buildEnvironment(ENV);
      return 0;
    }

  
  function __exit(status) {
      // void _exit(int status);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/exit.html
      Module['exit'](status);
    }function _exit(status) {
      __exit(status);
    }

  
  var ___DEFAULT_POLLMASK=5;function _select(nfds, readfds, writefds, exceptfds, timeout) {
      // readfds are supported,
      // writefds checks socket open status
      // exceptfds not supported
      // timeout is always 0 - fully async
      assert(nfds <= 64, 'nfds must be less than or equal to 64');  // fd sets have 64 bits
      assert(!exceptfds, 'exceptfds not supported');
  
      var total = 0;
      
      var srcReadLow = (readfds ? HEAP32[((readfds)>>2)] : 0),
          srcReadHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0);
      var srcWriteLow = (writefds ? HEAP32[((writefds)>>2)] : 0),
          srcWriteHigh = (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0);
      var srcExceptLow = (exceptfds ? HEAP32[((exceptfds)>>2)] : 0),
          srcExceptHigh = (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      var dstReadLow = 0,
          dstReadHigh = 0;
      var dstWriteLow = 0,
          dstWriteHigh = 0;
      var dstExceptLow = 0,
          dstExceptHigh = 0;
  
      var allLow = (readfds ? HEAP32[((readfds)>>2)] : 0) |
                   (writefds ? HEAP32[((writefds)>>2)] : 0) |
                   (exceptfds ? HEAP32[((exceptfds)>>2)] : 0);
      var allHigh = (readfds ? HEAP32[(((readfds)+(4))>>2)] : 0) |
                    (writefds ? HEAP32[(((writefds)+(4))>>2)] : 0) |
                    (exceptfds ? HEAP32[(((exceptfds)+(4))>>2)] : 0);
  
      function get(fd, low, high, val) {
        return (fd < 32 ? (low & val) : (high & val));
      }
  
      for (var fd = 0; fd < nfds; fd++) {
        var mask = 1 << (fd % 32);
        if (!(get(fd, allLow, allHigh, mask))) {
          continue;  // index isn't in the set
        }
  
        var stream = FS.getStream(fd);
        if (!stream) {
          ___setErrNo(ERRNO_CODES.EBADF);
          return -1;
        }
  
        var flags = ___DEFAULT_POLLMASK;
  
        if (stream.stream_ops.poll) {
          flags = stream.stream_ops.poll(stream);
        }
  
        if ((flags & 1) && get(fd, srcReadLow, srcReadHigh, mask)) {
          fd < 32 ? (dstReadLow = dstReadLow | mask) : (dstReadHigh = dstReadHigh | mask);
          total++;
        }
        if ((flags & 4) && get(fd, srcWriteLow, srcWriteHigh, mask)) {
          fd < 32 ? (dstWriteLow = dstWriteLow | mask) : (dstWriteHigh = dstWriteHigh | mask);
          total++;
        }
        if ((flags & 2) && get(fd, srcExceptLow, srcExceptHigh, mask)) {
          fd < 32 ? (dstExceptLow = dstExceptLow | mask) : (dstExceptHigh = dstExceptHigh | mask);
          total++;
        }
      }
  
      if (readfds) {
        HEAP32[((readfds)>>2)]=dstReadLow;
        HEAP32[(((readfds)+(4))>>2)]=dstReadHigh;
      }
      if (writefds) {
        HEAP32[((writefds)>>2)]=dstWriteLow;
        HEAP32[(((writefds)+(4))>>2)]=dstWriteHigh;
      }
      if (exceptfds) {
        HEAP32[((exceptfds)>>2)]=dstExceptLow;
        HEAP32[(((exceptfds)+(4))>>2)]=dstExceptHigh;
      }
      
      return total;
    }

  var _emscripten_get_longjmp_result=true;

  var _sin=Math_sin;

  function _fcntl(fildes, cmd, varargs, dup2) {
      // int fcntl(int fildes, int cmd, ...);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/fcntl.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      switch (cmd) {
        case 0:
          var arg = HEAP32[((varargs)>>2)];
          if (arg < 0) {
            ___setErrNo(ERRNO_CODES.EINVAL);
            return -1;
          }
          var newStream;
          try {
            newStream = FS.open(stream.path, stream.flags, 0, arg);
          } catch (e) {
            FS.handleFSError(e);
            return -1;
          }
          return newStream.fd;
        case 1:
        case 2:
          return 0;  // FD_CLOEXEC makes no sense for a single process.
        case 3:
          return stream.flags;
        case 4:
          var arg = HEAP32[((varargs)>>2)];
          stream.flags |= arg;
          return 0;
        case 12:
        case 12:
          var arg = HEAP32[((varargs)>>2)];
          var offset = 0;
          // We're always unlocked.
          HEAP16[(((arg)+(offset))>>1)]=2;
          return 0;
        case 13:
        case 14:
        case 13:
        case 14:
          // Pretend that the locking is successful.
          return 0;
        case 8:
        case 9:
          // These are for sockets. We don't have them fully implemented yet.
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
        default:
          ___setErrNo(ERRNO_CODES.EINVAL);
          return -1;
      }
      // Should never be reached. Only to silence strict warnings.
      return -1;
    }

  function _stat(path, buf, dontResolveLastLink) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/stat.html
      // int stat(const char *path, struct stat *buf);
      // NOTE: dontResolveLastLink is a shortcut for lstat(). It should never be
      //       used in client code.
      path = typeof path !== 'string' ? Pointer_stringify(path) : path;
      try {
        var stat = dontResolveLastLink ? FS.lstat(path) : FS.stat(path);
        HEAP32[((buf)>>2)]=stat.dev;
        HEAP32[(((buf)+(4))>>2)]=0;
        HEAP32[(((buf)+(8))>>2)]=stat.ino;
        HEAP32[(((buf)+(12))>>2)]=stat.mode;
        HEAP32[(((buf)+(16))>>2)]=stat.nlink;
        HEAP32[(((buf)+(20))>>2)]=stat.uid;
        HEAP32[(((buf)+(24))>>2)]=stat.gid;
        HEAP32[(((buf)+(28))>>2)]=stat.rdev;
        HEAP32[(((buf)+(32))>>2)]=0;
        HEAP32[(((buf)+(36))>>2)]=stat.size;
        HEAP32[(((buf)+(40))>>2)]=4096;
        HEAP32[(((buf)+(44))>>2)]=stat.blocks;
        HEAP32[(((buf)+(48))>>2)]=(stat.atime.getTime() / 1000)|0;
        HEAP32[(((buf)+(52))>>2)]=0;
        HEAP32[(((buf)+(56))>>2)]=(stat.mtime.getTime() / 1000)|0;
        HEAP32[(((buf)+(60))>>2)]=0;
        HEAP32[(((buf)+(64))>>2)]=(stat.ctime.getTime() / 1000)|0;
        HEAP32[(((buf)+(68))>>2)]=0;
        HEAP32[(((buf)+(72))>>2)]=stat.ino;
        return 0;
      } catch (e) {
        if (e.node && PATH.normalize(path) !== PATH.normalize(FS.getPath(e.node))) {
          // an error occurred while trying to look up the path; we should just report ENOTDIR
          e.setErrno(ERRNO_CODES.ENOTDIR);
        }
        FS.handleFSError(e);
        return -1;
      }
    }


  function _tcsetattr(fildes, optional_actions, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/tcsetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _lstat(path, buf) {
      // int lstat(const char *path, struct stat *buf);
      // http://pubs.opengroup.org/onlinepubs/7908799/xsh/lstat.html
      return _stat(path, buf, true);
    }

  function _ferror(stream) {
      // int ferror(FILE *stream);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/ferror.html
      stream = FS.getStreamFromPtr(stream);
      return Number(stream && stream.error);
    }

  
  function _gmtime_r(time, tmPtr) {
      var date = new Date(HEAP32[((time)>>2)]*1000);
      HEAP32[((tmPtr)>>2)]=date.getUTCSeconds();
      HEAP32[(((tmPtr)+(4))>>2)]=date.getUTCMinutes();
      HEAP32[(((tmPtr)+(8))>>2)]=date.getUTCHours();
      HEAP32[(((tmPtr)+(12))>>2)]=date.getUTCDate();
      HEAP32[(((tmPtr)+(16))>>2)]=date.getUTCMonth();
      HEAP32[(((tmPtr)+(20))>>2)]=date.getUTCFullYear()-1900;
      HEAP32[(((tmPtr)+(24))>>2)]=date.getUTCDay();
      HEAP32[(((tmPtr)+(36))>>2)]=0;
      HEAP32[(((tmPtr)+(32))>>2)]=0;
      var start = Date.UTC(date.getUTCFullYear(), 0, 1, 0, 0, 0, 0);
      var yday = ((date.getTime() - start) / (1000 * 60 * 60 * 24))|0;
      HEAP32[(((tmPtr)+(28))>>2)]=yday;
      HEAP32[(((tmPtr)+(40))>>2)]=___tm_timezone;
  
      return tmPtr;
    }function _gmtime(time) {
      return _gmtime_r(time, ___tm_current);
    }

  function _closedir(dirp) {
      // int closedir(DIR *dirp);
      // http://pubs.opengroup.org/onlinepubs/007908799/xsh/closedir.html
      var fd = _fileno(dirp);
      var stream = FS.getStream(fd);
      if (stream.currReading) stream.currReading = null;
      return _close(fd);
    }

  function _ioctl(fd, request, varargs) {
      var stream = FS.getStream(fd);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      var arg = HEAP32[((varargs)>>2)];
  
      try {
        return FS.ioctl(stream, request, arg);
      } catch (e) {
        FS.handleFSError(e);
        return -1;
      }
    }

  function _nl_langinfo(item) {
      // char *nl_langinfo(nl_item item);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/nl_langinfo.html
      var result;
      switch (item) {
        case 14:
          result = 'ANSI_X3.4-1968';
          break;
        case 131112:
          result = '%a %b %e %H:%M:%S %Y';
          break;
        case 131113:
          result = '%m/%d/%y';
          break;
        case 131114:
          result = '%H:%M:%S';
          break;
        case 131115:
          result = '%I:%M:%S %p';
          break;
        case 131110:
          result = 'AM';
          break;
        case 131111:
          result = 'PM';
          break;
        case 131079:
          result = 'Sunday';
          break;
        case 131080:
          result = 'Monday';
          break;
        case 131081:
          result = 'Tuesday';
          break;
        case 131082:
          result = 'Wednesday';
          break;
        case 131083:
          result = 'Thursday';
          break;
        case 131084:
          result = 'Friday';
          break;
        case 131085:
          result = 'Saturday';
          break;
        case 131072:
          result = 'Sun';
          break;
        case 131073:
          result = 'Mon';
          break;
        case 131074:
          result = 'Tue';
          break;
        case 131075:
          result = 'Wed';
          break;
        case 131076:
          result = 'Thu';
          break;
        case 131077:
          result = 'Fri';
          break;
        case 131078:
          result = 'Sat';
          break;
        case 131098:
          result = 'January';
          break;
        case 131099:
          result = 'February';
          break;
        case 131100:
          result = 'March';
          break;
        case 131101:
          result = 'April';
          break;
        case 131102:
          result = 'May';
          break;
        case 131103:
          result = 'June';
          break;
        case 131104:
          result = 'July';
          break;
        case 131105:
          result = 'August';
          break;
        case 131106:
          result = 'September';
          break;
        case 131107:
          result = 'October';
          break;
        case 131108:
          result = 'November';
          break;
        case 131109:
          result = 'December';
          break;
        case 131086:
          result = 'Jan';
          break;
        case 131087:
          result = 'Feb';
          break;
        case 131088:
          result = 'Mar';
          break;
        case 131089:
          result = 'Apr';
          break;
        case 131090:
          result = 'May';
          break;
        case 131091:
          result = 'Jun';
          break;
        case 131092:
          result = 'Jul';
          break;
        case 131093:
          result = 'Aug';
          break;
        case 131094:
          result = 'Sep';
          break;
        case 131095:
          result = 'Oct';
          break;
        case 131096:
          result = 'Nov';
          break;
        case 131097:
          result = 'Dec';
          break;
        case 131119:
          result = '';
          break;
        case 65536:
          result = '.';
          break;
        case 65537:
          result = '';
          break;
        case 327680:
          result = '^[yY]';
          break;
        case 327681:
          result = '^[nN]';
          break;
        case 262159:
          result = '-';
          break;
        case 131116:
        case 131118:
        case 131120:
        case 131121:
        default:
          result = '';
          break;
      }
  
      var me = _nl_langinfo;
      if (!me.ret) me.ret = _malloc(32);
      writeAsciiToMemory(result, me.ret);
      return me.ret;
    }

  function _getenv(name) {
      // char *getenv(const char *name);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/getenv.html
      if (name === 0) return 0;
      name = Pointer_stringify(name);
      if (!ENV.hasOwnProperty(name)) return 0;
  
      if (_getenv.ret) _free(_getenv.ret);
      _getenv.ret = allocate(intArrayFromString(ENV[name]), 'i8', ALLOC_NORMAL);
      return _getenv.ret;
    }

  function _sigaction(signum, act, oldact) {
      //int sigaction(int signum, const struct sigaction *act, struct sigaction *oldact);
      Module.printErr('Calling stub instead of sigaction()');
      return 0;
    }

  var _emscripten_setjmp=true;

  var _cos=Math_cos;

  function _getuid() { return 0; }

  function _sigdelset(set, signum) {
      HEAP32[((set)>>2)]=HEAP32[((set)>>2)]& (~(1 << (signum-1)));
      return 0;
    }

  function _tcgetattr(fildes, termios_p) {
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/tcgetattr.html
      var stream = FS.getStream(fildes);
      if (!stream) {
        ___setErrNo(ERRNO_CODES.EBADF);
        return -1;
      }
      if (!stream.tty) {
        ___setErrNo(ERRNO_CODES.ENOTTY);
        return -1;
      }
      return 0;
    }

  function _difftime(time1, time0) {
      return time1 - time0;
    }

  var _floor=Math_floor;

  function _endpwent() { throw 'endpwent: TODO' }

  var _atan2=Math_atan2;

   
  Module["_strcpy"] = _strcpy;

  function _setvbuf(stream, buf, type, size) {
      // int setvbuf(FILE *restrict stream, char *restrict buf, int type, size_t size);
      // http://pubs.opengroup.org/onlinepubs/000095399/functions/setvbuf.html
      // TODO: Implement custom buffering.
      return 0;
    }

  var _exp=Math_exp;

  function _time(ptr) {
      var ret = (Date.now()/1000)|0;
      if (ptr) {
        HEAP32[((ptr)>>2)]=ret;
      }
      return ret;
    }

  function _tcflow() {
  Module['printErr']('missing function: tcflow'); abort(-1);
  }

  var _acos=Math_acos;

  
  function __isLeapYear(year) {
        return year%4 === 0 && (year%100 !== 0 || year%400 === 0);
    }
  
  function __arraySum(array, index) {
      var sum = 0;
      for (var i = 0; i <= index; sum += array[i++]);
      return sum;
    }
  
  
  var __MONTH_DAYS_LEAP=[31,29,31,30,31,30,31,31,30,31,30,31];
  
  var __MONTH_DAYS_REGULAR=[31,28,31,30,31,30,31,31,30,31,30,31];function __addDays(date, days) {
      var newDate = new Date(date.getTime());
      while(days > 0) {
        var leap = __isLeapYear(newDate.getFullYear());
        var currentMonth = newDate.getMonth();
        var daysInCurrentMonth = (leap ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR)[currentMonth];
  
        if (days > daysInCurrentMonth-newDate.getDate()) {
          // we spill over to next month
          days -= (daysInCurrentMonth-newDate.getDate()+1);
          newDate.setDate(1);
          if (currentMonth < 11) {
            newDate.setMonth(currentMonth+1)
          } else {
            newDate.setMonth(0);
            newDate.setFullYear(newDate.getFullYear()+1);
          }
        } else {
          // we stay in current month 
          newDate.setDate(newDate.getDate()+days);
          return newDate;
        }
      }
  
      return newDate;
    }function _strftime(s, maxsize, format, tm) {
      // size_t strftime(char *restrict s, size_t maxsize, const char *restrict format, const struct tm *restrict timeptr);
      // http://pubs.opengroup.org/onlinepubs/009695399/functions/strftime.html
  
      var tm_zone = HEAP32[(((tm)+(40))>>2)];
  
      var date = {
        tm_sec: HEAP32[((tm)>>2)],
        tm_min: HEAP32[(((tm)+(4))>>2)],
        tm_hour: HEAP32[(((tm)+(8))>>2)],
        tm_mday: HEAP32[(((tm)+(12))>>2)],
        tm_mon: HEAP32[(((tm)+(16))>>2)],
        tm_year: HEAP32[(((tm)+(20))>>2)],
        tm_wday: HEAP32[(((tm)+(24))>>2)],
        tm_yday: HEAP32[(((tm)+(28))>>2)],
        tm_isdst: HEAP32[(((tm)+(32))>>2)],
        tm_gmtoff: HEAP32[(((tm)+(36))>>2)],
        tm_zone: tm_zone ? Pointer_stringify(tm_zone) : ''
      };
  
      var pattern = Pointer_stringify(format);
  
      // expand format
      var EXPANSION_RULES_1 = {
        '%c': '%a %b %d %H:%M:%S %Y',     // Replaced by the locale's appropriate date and time representation - e.g., Mon Aug  3 14:02:01 2013
        '%D': '%m/%d/%y',                 // Equivalent to %m / %d / %y
        '%F': '%Y-%m-%d',                 // Equivalent to %Y - %m - %d
        '%h': '%b',                       // Equivalent to %b
        '%r': '%I:%M:%S %p',              // Replaced by the time in a.m. and p.m. notation
        '%R': '%H:%M',                    // Replaced by the time in 24-hour notation
        '%T': '%H:%M:%S',                 // Replaced by the time
        '%x': '%m/%d/%y',                 // Replaced by the locale's appropriate date representation
        '%X': '%H:%M:%S'                  // Replaced by the locale's appropriate date representation
      };
      for (var rule in EXPANSION_RULES_1) {
        pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_1[rule]);
      }
  
      var WEEKDAYS = ['Sunday', 'Monday', 'Tuesday', 'Wednesday', 'Thursday', 'Friday', 'Saturday'];
      var MONTHS = ['January', 'February', 'March', 'April', 'May', 'June', 'July', 'August', 'September', 'October', 'November', 'December'];
  
      function leadingSomething(value, digits, character) {
        var str = typeof value === 'number' ? value.toString() : (value || '');
        while (str.length < digits) {
          str = character[0]+str;
        }
        return str;
      };
  
      function leadingNulls(value, digits) {
        return leadingSomething(value, digits, '0');
      };
  
      function compareByDay(date1, date2) {
        function sgn(value) {
          return value < 0 ? -1 : (value > 0 ? 1 : 0);
        };
  
        var compare;
        if ((compare = sgn(date1.getFullYear()-date2.getFullYear())) === 0) {
          if ((compare = sgn(date1.getMonth()-date2.getMonth())) === 0) {
            compare = sgn(date1.getDate()-date2.getDate());
          }
        }
        return compare;
      };
  
      function getFirstWeekStartDate(janFourth) {
          switch (janFourth.getDay()) {
            case 0: // Sunday
              return new Date(janFourth.getFullYear()-1, 11, 29);
            case 1: // Monday
              return janFourth;
            case 2: // Tuesday
              return new Date(janFourth.getFullYear(), 0, 3);
            case 3: // Wednesday
              return new Date(janFourth.getFullYear(), 0, 2);
            case 4: // Thursday
              return new Date(janFourth.getFullYear(), 0, 1);
            case 5: // Friday
              return new Date(janFourth.getFullYear()-1, 11, 31);
            case 6: // Saturday
              return new Date(janFourth.getFullYear()-1, 11, 30);
          }
      };
  
      function getWeekBasedYear(date) {
          var thisDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          var janFourthThisYear = new Date(thisDate.getFullYear(), 0, 4);
          var janFourthNextYear = new Date(thisDate.getFullYear()+1, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          if (compareByDay(firstWeekStartThisYear, thisDate) <= 0) {
            // this date is after the start of the first week of this year
            if (compareByDay(firstWeekStartNextYear, thisDate) <= 0) {
              return thisDate.getFullYear()+1;
            } else {
              return thisDate.getFullYear();
            }
          } else { 
            return thisDate.getFullYear()-1;
          }
      };
  
      var EXPANSION_RULES_2 = {
        '%a': function(date) {
          return WEEKDAYS[date.tm_wday].substring(0,3);
        },
        '%A': function(date) {
          return WEEKDAYS[date.tm_wday];
        },
        '%b': function(date) {
          return MONTHS[date.tm_mon].substring(0,3);
        },
        '%B': function(date) {
          return MONTHS[date.tm_mon];
        },
        '%C': function(date) {
          var year = date.tm_year+1900;
          return leadingNulls((year/100)|0,2);
        },
        '%d': function(date) {
          return leadingNulls(date.tm_mday, 2);
        },
        '%e': function(date) {
          return leadingSomething(date.tm_mday, 2, ' ');
        },
        '%g': function(date) {
          // %g, %G, and %V give values according to the ISO 8601:2000 standard week-based year. 
          // In this system, weeks begin on a Monday and week 1 of the year is the week that includes 
          // January 4th, which is also the week that includes the first Thursday of the year, and 
          // is also the first week that contains at least four days in the year. 
          // If the first Monday of January is the 2nd, 3rd, or 4th, the preceding days are part of 
          // the last week of the preceding year; thus, for Saturday 2nd January 1999, 
          // %G is replaced by 1998 and %V is replaced by 53. If December 29th, 30th, 
          // or 31st is a Monday, it and any following days are part of week 1 of the following year. 
          // Thus, for Tuesday 30th December 1997, %G is replaced by 1998 and %V is replaced by 01.
          
          return getWeekBasedYear(date).toString().substring(2);
        },
        '%G': function(date) {
          return getWeekBasedYear(date);
        },
        '%H': function(date) {
          return leadingNulls(date.tm_hour, 2);
        },
        '%I': function(date) {
          return leadingNulls(date.tm_hour < 13 ? date.tm_hour : date.tm_hour-12, 2);
        },
        '%j': function(date) {
          // Day of the year (001-366)
          return leadingNulls(date.tm_mday+__arraySum(__isLeapYear(date.tm_year+1900) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, date.tm_mon-1), 3);
        },
        '%m': function(date) {
          return leadingNulls(date.tm_mon+1, 2);
        },
        '%M': function(date) {
          return leadingNulls(date.tm_min, 2);
        },
        '%n': function() {
          return '\n';
        },
        '%p': function(date) {
          if (date.tm_hour > 0 && date.tm_hour < 13) {
            return 'AM';
          } else {
            return 'PM';
          }
        },
        '%S': function(date) {
          return leadingNulls(date.tm_sec, 2);
        },
        '%t': function() {
          return '\t';
        },
        '%u': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay() || 7;
        },
        '%U': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Sunday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year+1900, 0, 1);
          var firstSunday = janFirst.getDay() === 0 ? janFirst : __addDays(janFirst, 7-janFirst.getDay());
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
          
          // is target date after the first Sunday?
          if (compareByDay(firstSunday, endDate) < 0) {
            // calculate difference in days between first Sunday and endDate
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstSundayUntilEndJanuary = 31-firstSunday.getDate();
            var days = firstSundayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
  
          return compareByDay(firstSunday, janFirst) === 0 ? '01': '00';
        },
        '%V': function(date) {
          // Replaced by the week number of the year (Monday as the first day of the week) 
          // as a decimal number [01,53]. If the week containing 1 January has four 
          // or more days in the new year, then it is considered week 1. 
          // Otherwise, it is the last week of the previous year, and the next week is week 1. 
          // Both January 4th and the first Thursday of January are always in week 1. [ tm_year, tm_wday, tm_yday]
          var janFourthThisYear = new Date(date.tm_year+1900, 0, 4);
          var janFourthNextYear = new Date(date.tm_year+1901, 0, 4);
  
          var firstWeekStartThisYear = getFirstWeekStartDate(janFourthThisYear);
          var firstWeekStartNextYear = getFirstWeekStartDate(janFourthNextYear);
  
          var endDate = __addDays(new Date(date.tm_year+1900, 0, 1), date.tm_yday);
  
          if (compareByDay(endDate, firstWeekStartThisYear) < 0) {
            // if given date is before this years first week, then it belongs to the 53rd week of last year
            return '53';
          } 
  
          if (compareByDay(firstWeekStartNextYear, endDate) <= 0) {
            // if given date is after next years first week, then it belongs to the 01th week of next year
            return '01';
          }
  
          // given date is in between CW 01..53 of this calendar year
          var daysDifference;
          if (firstWeekStartThisYear.getFullYear() < date.tm_year+1900) {
            // first CW of this year starts last year
            daysDifference = date.tm_yday+32-firstWeekStartThisYear.getDate()
          } else {
            // first CW of this year starts this year
            daysDifference = date.tm_yday+1-firstWeekStartThisYear.getDate();
          }
          return leadingNulls(Math.ceil(daysDifference/7), 2);
        },
        '%w': function(date) {
          var day = new Date(date.tm_year+1900, date.tm_mon+1, date.tm_mday, 0, 0, 0, 0);
          return day.getDay();
        },
        '%W': function(date) {
          // Replaced by the week number of the year as a decimal number [00,53]. 
          // The first Monday of January is the first day of week 1; 
          // days in the new year before this are in week 0. [ tm_year, tm_wday, tm_yday]
          var janFirst = new Date(date.tm_year, 0, 1);
          var firstMonday = janFirst.getDay() === 1 ? janFirst : __addDays(janFirst, janFirst.getDay() === 0 ? 1 : 7-janFirst.getDay()+1);
          var endDate = new Date(date.tm_year+1900, date.tm_mon, date.tm_mday);
  
          // is target date after the first Monday?
          if (compareByDay(firstMonday, endDate) < 0) {
            var februaryFirstUntilEndMonth = __arraySum(__isLeapYear(endDate.getFullYear()) ? __MONTH_DAYS_LEAP : __MONTH_DAYS_REGULAR, endDate.getMonth()-1)-31;
            var firstMondayUntilEndJanuary = 31-firstMonday.getDate();
            var days = firstMondayUntilEndJanuary+februaryFirstUntilEndMonth+endDate.getDate();
            return leadingNulls(Math.ceil(days/7), 2);
          }
          return compareByDay(firstMonday, janFirst) === 0 ? '01': '00';
        },
        '%y': function(date) {
          // Replaced by the last two digits of the year as a decimal number [00,99]. [ tm_year]
          return (date.tm_year+1900).toString().substring(2);
        },
        '%Y': function(date) {
          // Replaced by the year as a decimal number (for example, 1997). [ tm_year]
          return date.tm_year+1900;
        },
        '%z': function(date) {
          // Replaced by the offset from UTC in the ISO 8601:2000 standard format ( +hhmm or -hhmm ).
          // For example, "-0430" means 4 hours 30 minutes behind UTC (west of Greenwich).
          var off = date.tm_gmtoff;
          var ahead = off >= 0;
          off = Math.abs(off) / 60;
          // convert from minutes into hhmm format (which means 60 minutes = 100 units)
          off = (off / 60)*100 + (off % 60);
          return (ahead ? '+' : '-') + String("0000" + off).slice(-4);
        },
        '%Z': function(date) {
          return date.tm_zone;
        },
        '%%': function() {
          return '%';
        }
      };
      for (var rule in EXPANSION_RULES_2) {
        if (pattern.indexOf(rule) >= 0) {
          pattern = pattern.replace(new RegExp(rule, 'g'), EXPANSION_RULES_2[rule](date));
        }
      }
  
      var bytes = intArrayFromString(pattern, false);
      if (bytes.length > maxsize) {
        return 0;
      } 
  
      writeArrayToMemory(bytes, s);
      return bytes.length-1;
    }



FS.staticInit();__ATINIT__.unshift(function() { if (!Module["noFSInit"] && !FS.init.initialized) FS.init() });__ATMAIN__.push(function() { FS.ignorePermissions = false });__ATEXIT__.push(function() { FS.quit() });Module["FS_createFolder"] = FS.createFolder;Module["FS_createPath"] = FS.createPath;Module["FS_createDataFile"] = FS.createDataFile;Module["FS_createPreloadedFile"] = FS.createPreloadedFile;Module["FS_createLazyFile"] = FS.createLazyFile;Module["FS_createLink"] = FS.createLink;Module["FS_createDevice"] = FS.createDevice;
___errno_state = Runtime.staticAlloc(4); HEAP32[((___errno_state)>>2)]=0;
__ATINIT__.unshift(function() { TTY.init() });__ATEXIT__.push(function() { TTY.shutdown() });
if (ENVIRONMENT_IS_NODE) { var fs = require("fs"); var NODEJS_PATH = require("path"); NODEFS.staticInit(); }
__ATINIT__.push(function() { SOCKFS.root = FS.mount(SOCKFS, {}, null); });
_fputc.ret = allocate([0], "i8", ALLOC_STATIC);
Module["requestFullScreen"] = function Module_requestFullScreen(lockPointer, resizeCanvas, vrDevice) { Browser.requestFullScreen(lockPointer, resizeCanvas, vrDevice) };
  Module["requestAnimationFrame"] = function Module_requestAnimationFrame(func) { Browser.requestAnimationFrame(func) };
  Module["setCanvasSize"] = function Module_setCanvasSize(width, height, noUpdates) { Browser.setCanvasSize(width, height, noUpdates) };
  Module["pauseMainLoop"] = function Module_pauseMainLoop() { Browser.mainLoop.pause() };
  Module["resumeMainLoop"] = function Module_resumeMainLoop() { Browser.mainLoop.resume() };
  Module["getUserMedia"] = function Module_getUserMedia() { Browser.getUserMedia() }
  Module["createContext"] = function Module_createContext(canvas, useWebGL, setInModule, webGLContextAttributes) { return Browser.createContext(canvas, useWebGL, setInModule, webGLContextAttributes) }
_fgetc.ret = allocate([0], "i8", ALLOC_STATIC);
___buildEnvironment(ENV);
STACK_BASE = STACKTOP = Runtime.alignMemory(STATICTOP);

staticSealed = true; // seal the static portion of memory

STACK_MAX = STACK_BASE + TOTAL_STACK;

DYNAMIC_BASE = DYNAMICTOP = Runtime.alignMemory(STACK_MAX);

assert(DYNAMIC_BASE < TOTAL_MEMORY, "TOTAL_MEMORY not big enough for stack");

 var cttz_i8 = allocate([8,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,7,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,6,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,5,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0,4,0,1,0,2,0,1,0,3,0,1,0,2,0,1,0], "i8", ALLOC_DYNAMIC);


function nullFunc_iiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_i(x) { Module["printErr"]("Invalid function pointer called with signature 'i'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vi(x) { Module["printErr"]("Invalid function pointer called with signature 'vi'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_vii(x) { Module["printErr"]("Invalid function pointer called with signature 'vii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_ii(x) { Module["printErr"]("Invalid function pointer called with signature 'ii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viii(x) { Module["printErr"]("Invalid function pointer called with signature 'viii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_v(x) { Module["printErr"]("Invalid function pointer called with signature 'v'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iiiii(x) { Module["printErr"]("Invalid function pointer called with signature 'iiiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_iii(x) { Module["printErr"]("Invalid function pointer called with signature 'iii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function nullFunc_viiii(x) { Module["printErr"]("Invalid function pointer called with signature 'viiii'. Perhaps this is an invalid value (e.g. caused by calling a virtual method on a NULL pointer)? Or calling a function with an incorrect type, which will fail? (it is worth building your source files with -Werror (warnings are errors), as warnings can indicate undefined behavior which can cause this)");  Module["printErr"]("Build with ASSERTIONS=2 for more info.");abort(x) }

function invoke_iiii(index,a1,a2,a3) {
  try {
    return Module["dynCall_iiii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_i(index) {
  try {
    return Module["dynCall_i"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vi(index,a1) {
  try {
    Module["dynCall_vi"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_vii(index,a1,a2) {
  try {
    Module["dynCall_vii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_ii(index,a1) {
  try {
    return Module["dynCall_ii"](index,a1);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viii(index,a1,a2,a3) {
  try {
    Module["dynCall_viii"](index,a1,a2,a3);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_v(index) {
  try {
    Module["dynCall_v"](index);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iiiii(index,a1,a2,a3,a4) {
  try {
    return Module["dynCall_iiiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_iii(index,a1,a2) {
  try {
    return Module["dynCall_iii"](index,a1,a2);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

function invoke_viiii(index,a1,a2,a3,a4) {
  try {
    Module["dynCall_viiii"](index,a1,a2,a3,a4);
  } catch(e) {
    if (typeof e !== 'number' && e !== 'longjmp') throw e;
    asm["setThrew"](1, 0);
  }
}

Module.asmGlobalArg = { "Math": Math, "Int8Array": Int8Array, "Int16Array": Int16Array, "Int32Array": Int32Array, "Uint8Array": Uint8Array, "Uint16Array": Uint16Array, "Uint32Array": Uint32Array, "Float32Array": Float32Array, "Float64Array": Float64Array, "NaN": NaN, "Infinity": Infinity };
Module.asmLibraryArg = { "abort": abort, "assert": assert, "nullFunc_iiii": nullFunc_iiii, "nullFunc_i": nullFunc_i, "nullFunc_vi": nullFunc_vi, "nullFunc_vii": nullFunc_vii, "nullFunc_ii": nullFunc_ii, "nullFunc_viii": nullFunc_viii, "nullFunc_v": nullFunc_v, "nullFunc_iiiii": nullFunc_iiiii, "nullFunc_iii": nullFunc_iii, "nullFunc_viiii": nullFunc_viiii, "invoke_iiii": invoke_iiii, "invoke_i": invoke_i, "invoke_vi": invoke_vi, "invoke_vii": invoke_vii, "invoke_ii": invoke_ii, "invoke_viii": invoke_viii, "invoke_v": invoke_v, "invoke_iiiii": invoke_iiiii, "invoke_iii": invoke_iii, "invoke_viiii": invoke_viiii, "_fabs": _fabs, "_exp": _exp, "_fread": _fread, "_longjmp": _longjmp, "__addDays": __addDays, "_nl_langinfo": _nl_langinfo, "_emscripten_set_main_loop_timing": _emscripten_set_main_loop_timing, "_sbrk": _sbrk, "_emscripten_memcpy_big": _emscripten_memcpy_big, "_tcgetattr": _tcgetattr, "_sysconf": _sysconf, "_close": _close, "_ferror": _ferror, "_clock": _clock, "_cos": _cos, "_readdir": _readdir, "_isatty": _isatty, "_write": _write, "__isLeapYear": __isLeapYear, "_ftell": _ftell, "_select": _select, "_gmtime_r": _gmtime_r, "_tcflow": _tcflow, "_tmpnam": _tmpnam, "_closedir": _closedir, "_tmpfile": _tmpfile, "_getuid": _getuid, "_send": _send, "_setvbuf": _setvbuf, "_atan2": _atan2, "_cfgetospeed": _cfgetospeed, "_setlocale": _setlocale, "_fcntl": _fcntl, "_lstat": _lstat, "_opendir": _opendir, "_strerror_r": _strerror_r, "___setErrNo": ___setErrNo, "_getpid": _getpid, "_unlink": _unlink, "_mktime": _mktime, "_gmtime": _gmtime, "_kill": _kill, "_localeconv": _localeconv, "_printf": _printf, "_fopen": _fopen, "_stat": _stat, "_sigdelset": _sigdelset, "_getpwnam": _getpwnam, "_read": _read, "_fwrite": _fwrite, "_time": _time, "_fprintf": _fprintf, "_gettimeofday": _gettimeofday, "_pwrite": _pwrite, "_exit": _exit, "_readdir_r": _readdir_r, "_freopen": _freopen, "_llvm_pow_f64": _llvm_pow_f64, "_signal": _signal, "_lseek": _lseek, "_rename": _rename, "_access": _access, "_vfprintf": _vfprintf, "_rmdir": _rmdir, "_asin": _asin, "___buildEnvironment": ___buildEnvironment, "_sigaddset": _sigaddset, "_endpwent": _endpwent, "_localtime_r": _localtime_r, "_tzset": _tzset, "_open": _open, "_remove": _remove, "_sigemptyset": _sigemptyset, "_strftime": _strftime, "_fseek": _fseek, "_getenv": _getenv, "_fclose": _fclose, "_log": _log, "_recv": _recv, "_tan": _tan, "_fgetc": _fgetc, "_abort": _abort, "_ceil": _ceil, "_localtime": _localtime, "_floor": _floor, "_putc": _putc, "_sin": _sin, "_acos": _acos, "_sigaction": _sigaction, "_difftime": _difftime, "_ungetc": _ungetc, "_system": _system, "_ioctl": _ioctl, "__reallyNegative": __reallyNegative, "_fileno": _fileno, "__exit": __exit, "_tcsetattr": _tcsetattr, "__arraySum": __arraySum, "_fgets": _fgets, "_pread": _pread, "_mkport": _mkport, "_getc": _getc, "_feof": _feof, "_fflush": _fflush, "_emscripten_set_main_loop": _emscripten_set_main_loop, "___errno_location": ___errno_location, "_getpwuid": _getpwuid, "_clearerr": _clearerr, "_fputc": _fputc, "_sigprocmask": _sigprocmask, "_strerror": _strerror, "_emscripten_longjmp": _emscripten_longjmp, "__formatString": __formatString, "_fputs": _fputs, "_sqrt": _sqrt, "_setenv": _setenv, "STACKTOP": STACKTOP, "STACK_MAX": STACK_MAX, "tempDoublePtr": tempDoublePtr, "ABORT": ABORT, "cttz_i8": cttz_i8, "_stderr": _stderr, "_stdin": _stdin, "_stdout": _stdout };
// EMSCRIPTEN_START_ASM
var asm = (function(global, env, buffer) {
  'almost asm';
  
  var HEAP8 = new global.Int8Array(buffer);
  var HEAP16 = new global.Int16Array(buffer);
  var HEAP32 = new global.Int32Array(buffer);
  var HEAPU8 = new global.Uint8Array(buffer);
  var HEAPU16 = new global.Uint16Array(buffer);
  var HEAPU32 = new global.Uint32Array(buffer);
  var HEAPF32 = new global.Float32Array(buffer);
  var HEAPF64 = new global.Float64Array(buffer);


  var STACKTOP=env.STACKTOP|0;
  var STACK_MAX=env.STACK_MAX|0;
  var tempDoublePtr=env.tempDoublePtr|0;
  var ABORT=env.ABORT|0;
  var cttz_i8=env.cttz_i8|0;
  var _stderr=env._stderr|0;
  var _stdin=env._stdin|0;
  var _stdout=env._stdout|0;

  var __THREW__ = 0;
  var threwValue = 0;
  var setjmpId = 0;
  var undef = 0;
  var nan = global.NaN, inf = global.Infinity;
  var tempInt = 0, tempBigInt = 0, tempBigIntP = 0, tempBigIntS = 0, tempBigIntR = 0.0, tempBigIntI = 0, tempBigIntD = 0, tempValue = 0, tempDouble = 0.0;

  var tempRet0 = 0;
  var tempRet1 = 0;
  var tempRet2 = 0;
  var tempRet3 = 0;
  var tempRet4 = 0;
  var tempRet5 = 0;
  var tempRet6 = 0;
  var tempRet7 = 0;
  var tempRet8 = 0;
  var tempRet9 = 0;
  var Math_floor=global.Math.floor;
  var Math_abs=global.Math.abs;
  var Math_sqrt=global.Math.sqrt;
  var Math_pow=global.Math.pow;
  var Math_cos=global.Math.cos;
  var Math_sin=global.Math.sin;
  var Math_tan=global.Math.tan;
  var Math_acos=global.Math.acos;
  var Math_asin=global.Math.asin;
  var Math_atan=global.Math.atan;
  var Math_atan2=global.Math.atan2;
  var Math_exp=global.Math.exp;
  var Math_log=global.Math.log;
  var Math_ceil=global.Math.ceil;
  var Math_imul=global.Math.imul;
  var Math_min=global.Math.min;
  var Math_clz32=global.Math.clz32;
  var abort=env.abort;
  var assert=env.assert;
  var nullFunc_iiii=env.nullFunc_iiii;
  var nullFunc_i=env.nullFunc_i;
  var nullFunc_vi=env.nullFunc_vi;
  var nullFunc_vii=env.nullFunc_vii;
  var nullFunc_ii=env.nullFunc_ii;
  var nullFunc_viii=env.nullFunc_viii;
  var nullFunc_v=env.nullFunc_v;
  var nullFunc_iiiii=env.nullFunc_iiiii;
  var nullFunc_iii=env.nullFunc_iii;
  var nullFunc_viiii=env.nullFunc_viiii;
  var invoke_iiii=env.invoke_iiii;
  var invoke_i=env.invoke_i;
  var invoke_vi=env.invoke_vi;
  var invoke_vii=env.invoke_vii;
  var invoke_ii=env.invoke_ii;
  var invoke_viii=env.invoke_viii;
  var invoke_v=env.invoke_v;
  var invoke_iiiii=env.invoke_iiiii;
  var invoke_iii=env.invoke_iii;
  var invoke_viiii=env.invoke_viiii;
  var _fabs=env._fabs;
  var _exp=env._exp;
  var _fread=env._fread;
  var _longjmp=env._longjmp;
  var __addDays=env.__addDays;
  var _nl_langinfo=env._nl_langinfo;
  var _emscripten_set_main_loop_timing=env._emscripten_set_main_loop_timing;
  var _sbrk=env._sbrk;
  var _emscripten_memcpy_big=env._emscripten_memcpy_big;
  var _tcgetattr=env._tcgetattr;
  var _sysconf=env._sysconf;
  var _close=env._close;
  var _ferror=env._ferror;
  var _clock=env._clock;
  var _cos=env._cos;
  var _readdir=env._readdir;
  var _isatty=env._isatty;
  var _write=env._write;
  var __isLeapYear=env.__isLeapYear;
  var _ftell=env._ftell;
  var _select=env._select;
  var _gmtime_r=env._gmtime_r;
  var _tcflow=env._tcflow;
  var _tmpnam=env._tmpnam;
  var _closedir=env._closedir;
  var _tmpfile=env._tmpfile;
  var _getuid=env._getuid;
  var _send=env._send;
  var _setvbuf=env._setvbuf;
  var _atan2=env._atan2;
  var _cfgetospeed=env._cfgetospeed;
  var _setlocale=env._setlocale;
  var _fcntl=env._fcntl;
  var _lstat=env._lstat;
  var _opendir=env._opendir;
  var _strerror_r=env._strerror_r;
  var ___setErrNo=env.___setErrNo;
  var _getpid=env._getpid;
  var _unlink=env._unlink;
  var _mktime=env._mktime;
  var _gmtime=env._gmtime;
  var _kill=env._kill;
  var _localeconv=env._localeconv;
  var _printf=env._printf;
  var _fopen=env._fopen;
  var _stat=env._stat;
  var _sigdelset=env._sigdelset;
  var _getpwnam=env._getpwnam;
  var _read=env._read;
  var _fwrite=env._fwrite;
  var _time=env._time;
  var _fprintf=env._fprintf;
  var _gettimeofday=env._gettimeofday;
  var _pwrite=env._pwrite;
  var _exit=env._exit;
  var _readdir_r=env._readdir_r;
  var _freopen=env._freopen;
  var _llvm_pow_f64=env._llvm_pow_f64;
  var _signal=env._signal;
  var _lseek=env._lseek;
  var _rename=env._rename;
  var _access=env._access;
  var _vfprintf=env._vfprintf;
  var _rmdir=env._rmdir;
  var _asin=env._asin;
  var ___buildEnvironment=env.___buildEnvironment;
  var _sigaddset=env._sigaddset;
  var _endpwent=env._endpwent;
  var _localtime_r=env._localtime_r;
  var _tzset=env._tzset;
  var _open=env._open;
  var _remove=env._remove;
  var _sigemptyset=env._sigemptyset;
  var _strftime=env._strftime;
  var _fseek=env._fseek;
  var _getenv=env._getenv;
  var _fclose=env._fclose;
  var _log=env._log;
  var _recv=env._recv;
  var _tan=env._tan;
  var _fgetc=env._fgetc;
  var _abort=env._abort;
  var _ceil=env._ceil;
  var _localtime=env._localtime;
  var _floor=env._floor;
  var _putc=env._putc;
  var _sin=env._sin;
  var _acos=env._acos;
  var _sigaction=env._sigaction;
  var _difftime=env._difftime;
  var _ungetc=env._ungetc;
  var _system=env._system;
  var _ioctl=env._ioctl;
  var __reallyNegative=env.__reallyNegative;
  var _fileno=env._fileno;
  var __exit=env.__exit;
  var _tcsetattr=env._tcsetattr;
  var __arraySum=env.__arraySum;
  var _fgets=env._fgets;
  var _pread=env._pread;
  var _mkport=env._mkport;
  var _getc=env._getc;
  var _feof=env._feof;
  var _fflush=env._fflush;
  var _emscripten_set_main_loop=env._emscripten_set_main_loop;
  var ___errno_location=env.___errno_location;
  var _getpwuid=env._getpwuid;
  var _clearerr=env._clearerr;
  var _fputc=env._fputc;
  var _sigprocmask=env._sigprocmask;
  var _strerror=env._strerror;
  var _emscripten_longjmp=env._emscripten_longjmp;
  var __formatString=env.__formatString;
  var _fputs=env._fputs;
  var _sqrt=env._sqrt;
  var _setenv=env._setenv;
  var tempFloat = 0.0;

// EMSCRIPTEN_START_FUNCS
function stackAlloc(size) {
  size = size|0;
  var ret = 0;
  ret = STACKTOP;
  STACKTOP = (STACKTOP + size)|0;
  STACKTOP = (STACKTOP + 15)&-16;
if ((STACKTOP|0) >= (STACK_MAX|0)) abort();

  return ret|0;
}
function stackSave() {
  return STACKTOP|0;
}
function stackRestore(top) {
  top = top|0;
  STACKTOP = top;
}
function establishStackSpace(stackBase, stackMax) {
  stackBase = stackBase|0;
  stackMax = stackMax|0;
  STACKTOP = stackBase;
  STACK_MAX = stackMax;
}

function setThrew(threw, value) {
  threw = threw|0;
  value = value|0;
  if ((__THREW__|0) == 0) {
    __THREW__ = threw;
    threwValue = value;
  }
}
function copyTempFloat(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
}
function copyTempDouble(ptr) {
  ptr = ptr|0;
  HEAP8[tempDoublePtr>>0] = HEAP8[ptr>>0];
  HEAP8[tempDoublePtr+1>>0] = HEAP8[ptr+1>>0];
  HEAP8[tempDoublePtr+2>>0] = HEAP8[ptr+2>>0];
  HEAP8[tempDoublePtr+3>>0] = HEAP8[ptr+3>>0];
  HEAP8[tempDoublePtr+4>>0] = HEAP8[ptr+4>>0];
  HEAP8[tempDoublePtr+5>>0] = HEAP8[ptr+5>>0];
  HEAP8[tempDoublePtr+6>>0] = HEAP8[ptr+6>>0];
  HEAP8[tempDoublePtr+7>>0] = HEAP8[ptr+7>>0];
}

function setTempRet0(value) {
  value = value|0;
  tempRet0 = value;
}
function getTempRet0() {
  return tempRet0|0;
}

function _main($argc,$argv) {
 $argc = $argc|0;
 $argv = $argv|0;
 var $$0 = 0, $$pre$i = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_newstate()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = HEAP32[$argv>>2]|0;
  $3 = ($2|0)==(0|0);
  $$pre$i = HEAP32[_stderr>>2]|0;
  if (!($3)) {
   HEAP32[$vararg_buffer>>2] = $2;
   (_fprintf(($$pre$i|0),(8|0),($vararg_buffer|0))|0);
   (_fflush(($$pre$i|0))|0);
  }
  HEAP32[$vararg_buffer1>>2] = 16;
  (_fprintf(($$pre$i|0),(8264|0),($vararg_buffer1|0))|0);
  (_fflush(($$pre$i|0))|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_pushcclosure($0,304,0);
 $4 = ($argc|0)<(0);
 $5 = $4 << 31 >> 31;
 _lua_pushinteger($0,$argc,$5);
 _lua_pushlightuserdata($0,$argv);
 $6 = (_lua_pcallk($0,2,1,0,0,0)|0);
 $7 = (_lua_toboolean($0,-1)|0);
 $8 = ($6|0)==(0);
 if (!($8)) {
  $9 = (_lua_tolstring($0,-1,0)|0);
  $10 = HEAP32[56>>2]|0;
  $11 = ($10|0)==(0|0);
  $$pre$i$i = HEAP32[_stderr>>2]|0;
  if (!($11)) {
   HEAP32[$vararg_buffer4>>2] = $10;
   (_fprintf(($$pre$i$i|0),(8|0),($vararg_buffer4|0))|0);
   (_fflush(($$pre$i$i|0))|0);
  }
  HEAP32[$vararg_buffer7>>2] = $9;
  (_fprintf(($$pre$i$i|0),(8264|0),($vararg_buffer7|0))|0);
  (_fflush(($$pre$i$i|0))|0);
  _lua_settop($0,-2);
 }
 _lua_close($0);
 $12 = ($7|0)!=(0);
 $13 = $8 & $12;
 $14 = $13&1;
 $15 = $14 ^ 1;
 $$0 = $15;
 STACKTOP = sp;return ($$0|0);
}
function _pmain($L) {
 $L = $L|0;
 var $$$i = 0, $$0 = 0, $$0$i = 0, $$i$07$i = 0, $$lcssa$i$i = 0, $$lcssa59 = 0, $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i$i$i15 = 0, $$pre$i$i$i12 = 0, $$pre$i$i$i18 = 0, $$script$i = 0, $$script$i3 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $args$06$i = 0, $args$06$i$ = 0, $args$06$i$lcssa63 = 0, $args$1$i = 0, $args$2$i = 0, $args$3$i = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i5 = 0, $extra$0$i = 0, $fname$0$i = 0, $i$01$i = 0, $i$01$i$i = 0, $i$01$i4 = 0, $i$06$i = 0, $i$07$i = 0, $i$07$i$lcssa60 = 0, $i$07$i$lcssa61 = 0, $i$1$i = 0;
 var $i$1$i10 = 0, $i$2$i = 0, $init$03$i = 0, $name$02$i = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer13 = 0, $vararg_buffer16 = 0, $vararg_buffer19 = 0, $vararg_buffer22 = 0, $vararg_buffer25 = 0, $vararg_buffer28 = 0, $vararg_buffer31 = 0, $vararg_buffer34 = 0, $vararg_buffer36 = 0, $vararg_buffer39 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer39 = sp + 112|0;
 $vararg_buffer36 = sp + 104|0;
 $vararg_buffer34 = sp + 96|0;
 $vararg_buffer31 = sp + 88|0;
 $vararg_buffer28 = sp + 80|0;
 $vararg_buffer25 = sp + 72|0;
 $vararg_buffer22 = sp + 64|0;
 $vararg_buffer19 = sp + 56|0;
 $vararg_buffer16 = sp + 48|0;
 $vararg_buffer13 = sp + 40|0;
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_lua_tointegerx($L,1,0)|0);
 $1 = tempRet0;
 $2 = (_lua_touserdata($L,2)|0);
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 L1: do {
  if ($5) {
   $$0$i = 0;$45 = 1;
  } else {
   $7 = $4;$args$06$i = 0;$i$07$i = 1;
   L2: while(1) {
    $6 = HEAP8[$7>>0]|0;
    $8 = ($6<<24>>24)==(45);
    if (!($8)) {
     $$0$i = $args$06$i;$45 = $i$07$i;
     break L1;
    }
    $9 = ((($7)) + 1|0);
    $10 = HEAP8[$9>>0]|0;
    $11 = $10 << 24 >> 24;
    switch ($11|0) {
    case 0:  {
     $$0$i = $args$06$i;$45 = $i$07$i;
     break L1;
     break;
    }
    case 45:  {
     $$lcssa59 = $7;$args$06$i$lcssa63 = $args$06$i;$i$07$i$lcssa61 = $i$07$i;
     label = 4;
     break L2;
     break;
    }
    case 69:  {
     $16 = ((($7)) + 2|0);
     $17 = HEAP8[$16>>0]|0;
     $18 = ($17<<24>>24)==(0);
     if (!($18)) {
      $$0$i = 1;$45 = $i$07$i;
      break L1;
     }
     $19 = $args$06$i | 16;
     $args$3$i = $19;$i$1$i = $i$07$i;
     break;
    }
    case 105:  {
     $20 = $args$06$i | 2;
     $args$1$i = $20;
     label = 8;
     break;
    }
    case 118:  {
     $args$1$i = $args$06$i;
     label = 8;
     break;
    }
    case 101:  {
     $25 = $args$06$i | 8;
     $args$2$i = $25;
     label = 11;
     break;
    }
    case 108:  {
     $args$2$i = $args$06$i;
     label = 11;
     break;
    }
    default: {
     $i$07$i$lcssa60 = $i$07$i;
     label = 15;
     break L2;
    }
    }
    if ((label|0) == 8) {
     label = 0;
     $21 = ((($7)) + 2|0);
     $22 = HEAP8[$21>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if (!($23)) {
      $$0$i = 1;$45 = $i$07$i;
      break L1;
     }
     $24 = $args$1$i | 4;
     $args$3$i = $24;$i$1$i = $i$07$i;
    }
    else if ((label|0) == 11) {
     label = 0;
     $26 = ((($7)) + 2|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if ($28) {
      $29 = (($i$07$i) + 1)|0;
      $30 = (($2) + ($29<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       $$0$i = 1;$45 = $i$07$i;
       break L1;
      }
      $33 = HEAP8[$31>>0]|0;
      $34 = ($33<<24>>24)==(45);
      if ($34) {
       $$0$i = 1;$45 = $i$07$i;
       break L1;
      } else {
       $args$3$i = $args$2$i;$i$1$i = $29;
      }
     } else {
      $args$3$i = $args$2$i;$i$1$i = $i$07$i;
     }
    }
    $35 = (($i$1$i) + 1)|0;
    $36 = (($2) + ($35<<2)|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0|0);
    if ($38) {
     $$0$i = $args$3$i;$45 = $35;
     break L1;
    } else {
     $7 = $37;$args$06$i = $args$3$i;$i$07$i = $35;
    }
   }
   if ((label|0) == 4) {
    $12 = ((($$lcssa59)) + 2|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    $15 = $14&1;
    $$i$07$i = (($15) + ($i$07$i$lcssa61))|0;
    $args$06$i$ = $14 ? $args$06$i$lcssa63 : 1;
    $$0$i = $args$06$i$;$45 = $$i$07$i;
    break;
   }
   else if ((label|0) == 15) {
    $$0$i = 1;$45 = $i$07$i$lcssa60;
    break;
   }
  }
 } while(0);
 _luaL_checkversion_($L,503.0,136);
 $39 = HEAP32[$2>>2]|0;
 $40 = ($39|0)==(0|0);
 if (!($40)) {
  $41 = HEAP8[$39>>0]|0;
  $42 = ($41<<24>>24)==(0);
  if (!($42)) {
   HEAP32[56>>2] = $39;
  }
 }
 $43 = ($$0$i|0)==(1);
 if ($43) {
  $44 = (($2) + ($45<<2)|0);
  $46 = HEAP32[$44>>2]|0;
  $47 = HEAP32[_stderr>>2]|0;
  $48 = HEAP32[56>>2]|0;
  HEAP32[$vararg_buffer>>2] = $48;
  (_fprintf(($47|0),(8|0),($vararg_buffer|0))|0);
  (_fflush(($47|0))|0);
  $49 = ((($46)) + 1|0);
  $50 = HEAP8[$49>>0]|0;
  if ((($50<<24>>24) == 108) | (($50<<24>>24) == 101)) {
   HEAP32[$vararg_buffer1>>2] = $46;
   (_fprintf(($47|0),(72|0),($vararg_buffer1|0))|0);
   (_fflush(($47|0))|0);
  } else {
   HEAP32[$vararg_buffer4>>2] = $46;
   (_fprintf(($47|0),(96|0),($vararg_buffer4|0))|0);
   (_fflush(($47|0))|0);
  }
  $51 = HEAP32[56>>2]|0;
  HEAP32[$vararg_buffer7>>2] = $51;
  (_fprintf(($47|0),(128|0),($vararg_buffer7|0))|0);
  (_fflush(($47|0))|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = $$0$i & 4;
 $53 = ($52|0)==(0);
 if (!($53)) {
  $54 = HEAP32[_stdout>>2]|0;
  (_fwrite((480|0),1,51,($54|0))|0);
  (_fputc(10,($54|0))|0);
  (_fflush(($54|0))|0);
 }
 $55 = $$0$i & 16;
 $56 = ($55|0)==(0);
 do {
  if ($56) {
   _luaL_openlibs($L);
   $67 = ($45|0)==($0|0);
   $$script$i3 = $67 ? 0 : $45;
   $68 = (($$script$i3) + 1)|0;
   $69 = (($0) - ($68))|0;
   _lua_createtable($L,$69,$68);
   $70 = ($0|0)>(0);
   if ($70) {
    $i$01$i4 = 0;
    while(1) {
     $71 = (($2) + ($i$01$i4<<2)|0);
     $72 = HEAP32[$71>>2]|0;
     (_lua_pushstring($L,$72)|0);
     $73 = (($i$01$i4) - ($$script$i3))|0;
     $74 = ($73|0)<(0);
     $75 = $74 << 31 >> 31;
     _lua_rawseti($L,-2,$73,$75);
     $76 = (($i$01$i4) + 1)|0;
     $exitcond$i5 = ($76|0)==($0|0);
     if ($exitcond$i5) {
      break;
     } else {
      $i$01$i4 = $76;
     }
    }
   }
   _lua_setglobal($L,536);
   $77 = (_getenv(((545)|0))|0);
   $78 = ($77|0)==(0|0);
   if ($78) {
    $79 = (_getenv(((561)|0))|0);
    $80 = ($79|0)==(0|0);
    if ($80) {
     break;
    } else {
     $init$03$i = $79;$name$02$i = 560;
    }
   } else {
    $init$03$i = $77;$name$02$i = 544;
   }
   $81 = HEAP8[$init$03$i>>0]|0;
   $82 = ($81<<24>>24)==(64);
   if ($82) {
    $83 = ((($init$03$i)) + 1|0);
    $84 = (_luaL_loadfilex($L,$83,0)|0);
    $85 = ($84|0)==(0);
    if ($85) {
     $86 = (_lua_gettop($L)|0);
     _lua_pushcclosure($L,305,0);
     _lua_rotate($L,$86,1);
     HEAP32[576>>2] = $L;
     (_signal(2,(306|0))|0);
     $87 = (_lua_pcallk($L,0,0,$86,0,0)|0);
     (_signal(2,(0|0))|0);
     _lua_rotate($L,$86,-1);
     _lua_settop($L,-2);
     $88 = ($87|0)==(0);
     if ($88) {
      break;
     }
    }
    $89 = (_lua_tolstring($L,-1,0)|0);
    $90 = HEAP32[56>>2]|0;
    $91 = ($90|0)==(0|0);
    $$pre$i$i$i$i = HEAP32[_stderr>>2]|0;
    if (!($91)) {
     HEAP32[$vararg_buffer10>>2] = $90;
     (_fprintf(($$pre$i$i$i$i|0),(8|0),($vararg_buffer10|0))|0);
     (_fflush(($$pre$i$i$i$i|0))|0);
    }
    HEAP32[$vararg_buffer13>>2] = $89;
    (_fprintf(($$pre$i$i$i$i|0),(8264|0),($vararg_buffer13|0))|0);
    (_fflush(($$pre$i$i$i$i|0))|0);
    _lua_settop($L,-2);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   } else {
    $92 = (_strlen(($init$03$i|0))|0);
    $93 = (_luaL_loadbufferx($L,$init$03$i,$92,$name$02$i,0)|0);
    $94 = ($93|0)==(0);
    if ($94) {
     $95 = (_lua_gettop($L)|0);
     _lua_pushcclosure($L,305,0);
     _lua_rotate($L,$95,1);
     HEAP32[576>>2] = $L;
     (_signal(2,(306|0))|0);
     $96 = (_lua_pcallk($L,0,0,$95,0,0)|0);
     (_signal(2,(0|0))|0);
     _lua_rotate($L,$95,-1);
     _lua_settop($L,-2);
     $97 = ($96|0)==(0);
     if ($97) {
      break;
     }
    }
    $98 = (_lua_tolstring($L,-1,0)|0);
    $99 = HEAP32[56>>2]|0;
    $100 = ($99|0)==(0|0);
    $$pre$i$i$i = HEAP32[_stderr>>2]|0;
    if (!($100)) {
     HEAP32[$vararg_buffer16>>2] = $99;
     (_fprintf(($$pre$i$i$i|0),(8|0),($vararg_buffer16|0))|0);
     (_fflush(($$pre$i$i$i|0))|0);
    }
    HEAP32[$vararg_buffer19>>2] = $98;
    (_fprintf(($$pre$i$i$i|0),(8264|0),($vararg_buffer19|0))|0);
    (_fflush(($$pre$i$i$i|0))|0);
    _lua_settop($L,-2);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   _lua_pushboolean($L,1);
   _lua_setfield($L,-1001000,13088);
   _luaL_openlibs($L);
   $57 = ($45|0)==($0|0);
   $$script$i = $57 ? 0 : $45;
   $58 = (($$script$i) + 1)|0;
   $59 = (($0) - ($58))|0;
   _lua_createtable($L,$59,$58);
   $60 = ($0|0)>(0);
   if ($60) {
    $i$01$i = 0;
    while(1) {
     $61 = (($2) + ($i$01$i<<2)|0);
     $62 = HEAP32[$61>>2]|0;
     (_lua_pushstring($L,$62)|0);
     $63 = (($i$01$i) - ($$script$i))|0;
     $64 = ($63|0)<(0);
     $65 = $64 << 31 >> 31;
     _lua_rawseti($L,-2,$63,$65);
     $66 = (($i$01$i) + 1)|0;
     $exitcond$i = ($66|0)==($0|0);
     if ($exitcond$i) {
      break;
     } else {
      $i$01$i = $66;
     }
    }
   }
   _lua_setglobal($L,536);
  }
 } while(0);
 $101 = ($45|0)>(1);
 L68: do {
  if ($101) {
   $i$06$i = 1;
   L69: while(1) {
    $102 = (($2) + ($i$06$i<<2)|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = ((($103)) + 1|0);
    $105 = HEAP8[$104>>0]|0;
    $106 = ($105<<24>>24)==(101);
    do {
     if ((($105<<24>>24) == 101) | (($105<<24>>24) == 108)) {
      $107 = ((($103)) + 2|0);
      $108 = HEAP8[$107>>0]|0;
      $109 = ($108<<24>>24)==(0);
      if ($109) {
       $110 = (($i$06$i) + 1)|0;
       $111 = (($2) + ($110<<2)|0);
       $112 = HEAP32[$111>>2]|0;
       $extra$0$i = $112;$i$1$i10 = $110;
      } else {
       $extra$0$i = $107;$i$1$i10 = $i$06$i;
      }
      if ($106) {
       $113 = (_strlen(($extra$0$i|0))|0);
       $114 = (_luaL_loadbufferx($L,$extra$0$i,$113,584,0)|0);
       $115 = ($114|0)==(0);
       if (!($115)) {
        label = 52;
        break L69;
       }
       $116 = (_lua_gettop($L)|0);
       _lua_pushcclosure($L,305,0);
       _lua_rotate($L,$116,1);
       HEAP32[576>>2] = $L;
       (_signal(2,(306|0))|0);
       $117 = (_lua_pcallk($L,0,0,$116,0,0)|0);
       (_signal(2,(0|0))|0);
       _lua_rotate($L,$116,-1);
       _lua_settop($L,-2);
       $118 = ($117|0)==(0);
       if ($118) {
        $i$2$i = $i$1$i10;
        break;
       } else {
        label = 52;
        break L69;
       }
      } else {
       (_lua_getglobal($L,13008)|0);
       (_lua_pushstring($L,$extra$0$i)|0);
       $122 = (_lua_gettop($L)|0);
       $123 = (($122) + -1)|0;
       _lua_pushcclosure($L,305,0);
       _lua_rotate($L,$123,1);
       HEAP32[576>>2] = $L;
       (_signal(2,(306|0))|0);
       $124 = (_lua_pcallk($L,1,1,$123,0,0)|0);
       (_signal(2,(0|0))|0);
       _lua_rotate($L,$123,-1);
       _lua_settop($L,-2);
       $125 = ($124|0)==(0);
       if (!($125)) {
        label = 57;
        break L69;
       }
       _lua_setglobal($L,$extra$0$i);
       $i$2$i = $i$1$i10;
       break;
      }
     } else {
      $i$2$i = $i$06$i;
     }
    } while(0);
    $129 = (($i$2$i) + 1)|0;
    $130 = ($129|0)<($45|0);
    if ($130) {
     $i$06$i = $129;
    } else {
     break L68;
    }
   }
   if ((label|0) == 52) {
    $119 = (_lua_tolstring($L,-1,0)|0);
    $120 = HEAP32[56>>2]|0;
    $121 = ($120|0)==(0|0);
    $$pre$i$i$i12 = HEAP32[_stderr>>2]|0;
    if (!($121)) {
     HEAP32[$vararg_buffer22>>2] = $120;
     (_fprintf(($$pre$i$i$i12|0),(8|0),($vararg_buffer22|0))|0);
     (_fflush(($$pre$i$i$i12|0))|0);
    }
    HEAP32[$vararg_buffer25>>2] = $119;
    (_fprintf(($$pre$i$i$i12|0),(8264|0),($vararg_buffer25|0))|0);
    (_fflush(($$pre$i$i$i12|0))|0);
    _lua_settop($L,-2);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   else if ((label|0) == 57) {
    $126 = (_lua_tolstring($L,-1,0)|0);
    $127 = HEAP32[56>>2]|0;
    $128 = ($127|0)==(0|0);
    $$pre$i$i$i$i15 = HEAP32[_stderr>>2]|0;
    if (!($128)) {
     HEAP32[$vararg_buffer28>>2] = $127;
     (_fprintf(($$pre$i$i$i$i15|0),(8|0),($vararg_buffer28|0))|0);
     (_fflush(($$pre$i$i$i$i15|0))|0);
    }
    HEAP32[$vararg_buffer31>>2] = $126;
    (_fprintf(($$pre$i$i$i$i15|0),(8264|0),($vararg_buffer31|0))|0);
    (_fflush(($$pre$i$i$i$i15|0))|0);
    _lua_settop($L,-2);
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 $131 = ($45|0)<($0|0);
 do {
  if ($131) {
   $132 = (($2) + ($45<<2)|0);
   $133 = HEAP32[$132>>2]|0;
   $134 = (_strcmp($133,600)|0);
   $135 = ($134|0)==(0);
   if ($135) {
    $$sum = (($45) + -1)|0;
    $136 = (($2) + ($$sum<<2)|0);
    $137 = HEAP32[$136>>2]|0;
    $138 = (_strcmp($137,608)|0);
    $139 = ($138|0)==(0);
    $$$i = $139 ? $133 : 0;
    $fname$0$i = $$$i;
   } else {
    $fname$0$i = $133;
   }
   $140 = (_luaL_loadfilex($L,$fname$0$i,0)|0);
   $141 = ($140|0)==(0);
   if ($141) {
    $142 = (_lua_getglobal($L,536)|0);
    $143 = ($142|0)==(5);
    if (!($143)) {
     (_luaL_error($L,616,$vararg_buffer34)|0);
    }
    $144 = (_luaL_len($L,-1)|0);
    $145 = tempRet0;
    $146 = (($144) + 3)|0;
    _luaL_checkstack($L,$146,640);
    $147 = ($144|0)<(1);
    if ($147) {
     $$lcssa$i$i = -1;
    } else {
     $150 = -1;$i$01$i$i = 1;
     while(1) {
      $148 = ($i$01$i$i|0)<(0);
      $149 = $148 << 31 >> 31;
      (_lua_rawgeti($L,$150,$i$01$i$i,$149)|0);
      $151 = (($i$01$i$i) + 1)|0;
      $152 = $i$01$i$i ^ -1;
      $exitcond$i$i = ($i$01$i$i|0)==($144|0);
      if ($exitcond$i$i) {
       break;
      } else {
       $150 = $152;$i$01$i$i = $151;
      }
     }
     $153 = $144 ^ -1;
     $$lcssa$i$i = $153;
    }
    _lua_rotate($L,$$lcssa$i$i,-1);
    _lua_settop($L,-2);
    $154 = (_lua_gettop($L)|0);
    $155 = (($154) - ($144))|0;
    _lua_pushcclosure($L,305,0);
    _lua_rotate($L,$155,1);
    HEAP32[576>>2] = $L;
    (_signal(2,(306|0))|0);
    $156 = (_lua_pcallk($L,$144,-1,$155,0,0)|0);
    (_signal(2,(0|0))|0);
    _lua_rotate($L,$155,-1);
    _lua_settop($L,-2);
    $157 = ($156|0)==(0);
    if ($157) {
     break;
    }
   }
   $158 = (_lua_tolstring($L,-1,0)|0);
   $159 = HEAP32[56>>2]|0;
   $160 = ($159|0)==(0|0);
   $$pre$i$i$i18 = HEAP32[_stderr>>2]|0;
   if (!($160)) {
    HEAP32[$vararg_buffer36>>2] = $159;
    (_fprintf(($$pre$i$i$i18|0),(8|0),($vararg_buffer36|0))|0);
    (_fflush(($$pre$i$i$i18|0))|0);
   }
   HEAP32[$vararg_buffer39>>2] = $158;
   (_fprintf(($$pre$i$i$i18|0),(8264|0),($vararg_buffer39|0))|0);
   (_fflush(($$pre$i$i$i18|0))|0);
   _lua_settop($L,-2);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $161 = $$0$i & 2;
 $162 = ($161|0)==(0);
 if ($162) {
  $163 = ($45|0)==($0|0);
  $164 = $$0$i & 12;
  $165 = ($164|0)==(0);
  $or$cond = $163 & $165;
  if ($or$cond) {
   $166 = HEAP32[_stdout>>2]|0;
   (_fwrite((480|0),1,51,($166|0))|0);
   (_fputc(10,($166|0))|0);
   (_fflush(($166|0))|0);
   _doREPL($L);
  }
 } else {
  _doREPL($L);
 }
 _lua_pushboolean($L,1);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _msghandler($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $msg$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_lua_tolstring($L,1,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_luaL_callmeta($L,1,8600)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = (_lua_type($L,-1)|0);
   $5 = ($4|0)==(4);
   if ($5) {
    STACKTOP = sp;return 1;
   }
  }
  $6 = (_lua_type($L,1)|0);
  $7 = (_lua_typename($L,$6)|0);
  HEAP32[$vararg_buffer>>2] = $7;
  $8 = (_lua_pushfstring($L,816,$vararg_buffer)|0);
  $msg$0 = $8;
 } else {
  $msg$0 = $0;
 }
 _luaL_traceback($L,$L,$msg$0,1);
 STACKTOP = sp;return 1;
}
function _laction($i) {
 $i = $i|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_signal(($i|0),(0|0))|0);
 $0 = HEAP32[576>>2]|0;
 _lua_sethook($0,307,11,1);
 return;
}
function _doREPL($L) {
 $L = $L|0;
 var $$lcssa$i$i = 0, $$pre$i$i1 = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $len$i$i = 0, $len$i1$i = 0, $lmsg$i$i$i = 0, $status$0$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $lmsg$i$i$i = sp + 44|0;
 $len$i1$i = sp + 40|0;
 $len$i$i = sp + 36|0;
 $0 = HEAP32[14]|0;
 HEAP32[56>>2] = 0;
 _lua_settop($L,0);
 $1 = (_pushline($L,1)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  _lua_settop($L,0);
  $42 = HEAP32[_stdout>>2]|0;
  (_fputc(10,($42|0))|0);
  (_fflush(($42|0))|0);
  HEAP32[14] = $0;
  STACKTOP = sp;return;
 }
 $$pre$i$i1 = HEAP32[_stderr>>2]|0;
 while(1) {
  (_lua_pushlstring($L,672,7)|0);
  _lua_pushvalue($L,-2);
  _lua_concat($L,2);
  $3 = (_lua_tolstring($L,-1,$len$i$i)|0);
  $4 = HEAP32[$len$i$i>>2]|0;
  $5 = (_luaL_loadbufferx($L,$3,$4,4288,0)|0);
  $6 = ($5|0)==(0);
  if ($6) {
   _lua_rotate($L,-3,-1);
   _lua_settop($L,-2);
   $status$0$i = 0;
  } else {
   _lua_settop($L,-3);
   $7 = (_lua_tolstring($L,1,$len$i1$i)|0);
   $8 = HEAP32[$len$i1$i>>2]|0;
   $9 = (_luaL_loadbufferx($L,$7,$8,4288,0)|0);
   $10 = ($9|0)==(3);
   L8: do {
    if ($10) {
     while(1) {
      $11 = (_lua_tolstring($L,-1,$lmsg$i$i$i)|0);
      $12 = HEAP32[$lmsg$i$i$i>>2]|0;
      $13 = ($12>>>0)>(4);
      if (!($13)) {
       $$lcssa$i$i = 3;
       label = 8;
       break L8;
      }
      $$sum$i$i$i = (($12) + -5)|0;
      $14 = (($11) + ($$sum$i$i$i)|0);
      $15 = (_strcmp($14,5912)|0);
      $16 = ($15|0)==(0);
      if (!($16)) {
       $$lcssa$i$i = 3;
       label = 8;
       break L8;
      }
      _lua_settop($L,-2);
      $17 = (_pushline($L,0)|0);
      $18 = ($17|0)==(0);
      if ($18) {
       $43 = 3;
       break L8;
      }
      (_lua_pushlstring($L,37240,1)|0);
      _lua_rotate($L,-2,1);
      _lua_concat($L,3);
      $19 = (_lua_tolstring($L,1,$len$i1$i)|0);
      $20 = HEAP32[$len$i1$i>>2]|0;
      $21 = (_luaL_loadbufferx($L,$19,$20,4288,0)|0);
      $22 = ($21|0)==(3);
      if (!($22)) {
       $$lcssa$i$i = $21;
       label = 8;
       break;
      }
     }
    } else {
     $$lcssa$i$i = $9;
     label = 8;
    }
   } while(0);
   if ((label|0) == 8) {
    label = 0;
    $43 = $$lcssa$i$i;
   }
   $status$0$i = $43;
  }
  $23 = (_lua_rawlen($L,1)|0);
  $24 = ($23|0)==(0);
  if (!($24)) {
   $25 = (_lua_tolstring($L,1,0)|0);
   _add_history($25);
  }
  _lua_rotate($L,1,-1);
  _lua_settop($L,-2);
  if ((($status$0$i|0) == 0)) {
   $26 = (_lua_gettop($L)|0);
   _lua_pushcclosure($L,305,0);
   _lua_rotate($L,$26,1);
   HEAP32[576>>2] = $L;
   (_signal(2,(306|0))|0);
   $27 = (_lua_pcallk($L,0,-1,$26,0,0)|0);
   (_signal(2,(0|0))|0);
   _lua_rotate($L,$26,-1);
   _lua_settop($L,-2);
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = (_lua_gettop($L)|0);
    $30 = ($29|0)>(0);
    if ($30) {
     _luaL_checkstack($L,20,680);
     (_lua_getglobal($L,6304)|0);
     _lua_rotate($L,1,1);
     $31 = (_lua_pcallk($L,$29,0,0,0,0)|0);
     $32 = ($31|0)==(0);
     if (!($32)) {
      $33 = HEAP32[56>>2]|0;
      $34 = (_lua_tolstring($L,-1,0)|0);
      HEAP32[$vararg_buffer>>2] = $34;
      $35 = (_lua_pushfstring($L,712,$vararg_buffer)|0);
      $36 = ($33|0)==(0|0);
      if (!($36)) {
       HEAP32[$vararg_buffer1>>2] = $33;
       (_fprintf(($$pre$i$i1|0),(8|0),($vararg_buffer1|0))|0);
       (_fflush(($$pre$i$i1|0))|0);
      }
      HEAP32[$vararg_buffer4>>2] = $35;
      (_fprintf(($$pre$i$i1|0),(8264|0),($vararg_buffer4|0))|0);
      (_fflush(($$pre$i$i1|0))|0);
     }
    }
   } else {
    label = 21;
   }
  } else if ((($status$0$i|0) == -1)) {
   label = 25;
   break;
  } else {
   label = 21;
  }
  if ((label|0) == 21) {
   label = 0;
   $37 = (_lua_tolstring($L,-1,0)|0);
   $38 = HEAP32[56>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    HEAP32[$vararg_buffer7>>2] = $38;
    (_fprintf(($$pre$i$i1|0),(8|0),($vararg_buffer7|0))|0);
    (_fflush(($$pre$i$i1|0))|0);
   }
   HEAP32[$vararg_buffer10>>2] = $37;
   (_fprintf(($$pre$i$i1|0),(8264|0),($vararg_buffer10|0))|0);
   (_fflush(($$pre$i$i1|0))|0);
   _lua_settop($L,-2);
  }
  _lua_settop($L,0);
  $40 = (_pushline($L,1)|0);
  $41 = ($40|0)==(0);
  if ($41) {
   label = 25;
   break;
  }
 }
 if ((label|0) == 25) {
  _lua_settop($L,0);
  $42 = HEAP32[_stdout>>2]|0;
  (_fputc(10,($42|0))|0);
  (_fflush(($42|0))|0);
  HEAP32[14] = $0;
  STACKTOP = sp;return;
 }
}
function _pushline($L,$firstline) {
 $L = $L|0;
 $firstline = $firstline|0;
 var $$$i = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ($firstline|0)!=(0);
 $1 = $0 ? 744 : 752;
 (_lua_getglobal($L,$1)|0);
 $2 = (_lua_tolstring($L,-1,0)|0);
 $3 = ($2|0)==(0|0);
 $4 = $0 ? 768 : 776;
 $$$i = $3 ? $4 : $2;
 $5 = (_readline($$$i)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_settop($L,-2);
 $7 = (_strlen(($5|0))|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  $9 = (($7) + -1)|0;
  $10 = (($5) + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(10);
  if ($12) {
   HEAP8[$10>>0] = 0;
  }
 }
 $13 = ($firstline|0)==(0);
 if ($13) {
  label = 8;
 } else {
  $14 = HEAP8[$5>>0]|0;
  $15 = ($14<<24>>24)==(61);
  if ($15) {
   $16 = ((($5)) + 1|0);
   HEAP32[$vararg_buffer>>2] = $16;
   (_lua_pushfstring($L,784,$vararg_buffer)|0);
  } else {
   label = 8;
  }
 }
 if ((label|0) == 8) {
  (_lua_pushstring($L,$5)|0);
 }
 _free($5);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _lstop($L,$ar) {
 $L = $L|0;
 $ar = $ar|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 _lua_sethook($L,0,0,0);
 (_luaL_error($L,800,$vararg_buffer)|0);
 STACKTOP = sp;return;
}
function _lua_checkstack($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $res$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $0 = sp;
 HEAP32[$0>>2] = $n;
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($L)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($L)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = ($10|0)>($n|0);
 do {
  if ($11) {
   $25 = $6;$26 = $n;
  } else {
   $12 = ((($L)) + 28|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13;
   $15 = (($8) - ($14))|0;
   $16 = $15 >> 4;
   $17 = (($16) + 5)|0;
   $18 = (1000000 - ($n))|0;
   $19 = ($17|0)>($18|0);
   if ($19) {
    $res$01 = 0;
    STACKTOP = sp;return ($res$01|0);
   }
   $20 = (_luaD_rawrunprotected($L,308,$0)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    $$pre = HEAP32[$5>>2]|0;
    $$pre4 = HEAP32[$0>>2]|0;
    $25 = $$pre;$26 = $$pre4;
    break;
   } else {
    $res$01 = 0;
    STACKTOP = sp;return ($res$01|0);
   }
  }
 } while(0);
 $22 = ((($2)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (($25) + ($26<<4)|0);
 $27 = ($23>>>0)<($24>>>0);
 if (!($27)) {
  $res$01 = 1;
  STACKTOP = sp;return ($res$01|0);
 }
 HEAP32[$22>>2] = $24;
 $res$01 = 1;
 STACKTOP = sp;return ($res$01|0);
}
function _lua_xmove($from,$to,$n) {
 $from = $from|0;
 $to = $to|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($from|0)==($to|0);
 if ($0) {
  return;
 }
 $1 = ((($from)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (0 - ($n))|0;
 $4 = (($2) + ($3<<4)|0);
 HEAP32[$1>>2] = $4;
 $5 = ($n|0)>(0);
 if (!($5)) {
  return;
 }
 $6 = ((($to)) + 8|0);
 $i$01 = 0;
 while(1) {
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 16|0);
  HEAP32[$6>>2] = $8;
  $9 = HEAP32[$1>>2]|0;
  $10 = (($9) + ($i$01<<4)|0);
  ;HEAP32[$7>>2]=HEAP32[$10>>2]|0;HEAP32[$7+4>>2]=HEAP32[$10+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$10+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$10+12>>2]|0;
  $11 = (($i$01) + 1)|0;
  $exitcond = ($11|0)==($n|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $11;
  }
 }
 return;
}
function _lua_atpanic($L,$panicf) {
 $L = $L|0;
 $panicf = $panicf|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 132|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$2>>2] = $panicf;
 return ($3|0);
}
function _lua_version($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($L|0)==(0|0);
 if ($0) {
  $$0 = 848;
  return ($$0|0);
 }
 $1 = ((($L)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 140|0);
 $4 = HEAP32[$3>>2]|0;
 $$0 = $4;
 return ($$0|0);
}
function _lua_absindex($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $idx$off = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $idx$off = (($idx) + 1000999)|0;
 $0 = ($idx$off>>>0)>(1000999);
 if ($0) {
  $11 = $idx;
  return ($11|0);
 }
 $1 = ((($L)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($L)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$4>>2]|0;
 $6 = $2;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 4;
 $10 = (($9) + ($idx))|0;
 $11 = $10;
 return ($11|0);
}
function _lua_gettop($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 16|0);
 $6 = $1;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 $9 = $8 >> 4;
 return ($9|0);
}
function _lua_settop($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $scevgep = 0, $scevgep4 = 0, $scevgep7 = 0, $uglygep = 0, $uglygep6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($idx|0)>(-1);
 if (!($0)) {
  $16 = (($idx) + 1)|0;
  $17 = ((($L)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($18) + ($16<<4)|0);
  HEAP32[$17>>2] = $19;
  return;
 }
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($L)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $$sum = (($idx) + 1)|0;
 $6 = (($3) + ($$sum<<4)|0);
 $7 = ($5>>>0)<($6>>>0);
 if ($7) {
  $8 = $5;
  $scevgep = (((($3) + ($idx<<4)|0)) + 8|0);
  $scevgep4 = ((($scevgep)) + 4|0);
  $9 = (3 - ($8))|0;
  $uglygep = (($scevgep4) + ($9)|0);
  $uglygep6 = $uglygep;
  $10 = $uglygep6 >>> 4;
  $11 = (($10) + 1)|0;
  $13 = $5;
  while(1) {
   $12 = ((($13)) + 16|0);
   $14 = ((($13)) + 8|0);
   HEAP32[$14>>2] = 0;
   $15 = ($12>>>0)<($6>>>0);
   if ($15) {
    $13 = $12;
   } else {
    break;
   }
  }
  $scevgep7 = (($5) + ($11<<4)|0);
  HEAP32[$4>>2] = $scevgep7;
 }
 HEAP32[$4>>2] = $6;
 return;
}
function _lua_rotate($L,$idx,$n) {
 $L = $L|0;
 $idx = $idx|0;
 $n = $n|0;
 var $$0$i = 0, $$011$i = 0, $$011$i10 = 0, $$011$i5 = 0, $$02$i = 0, $$02$i4 = 0, $$02$i9 = 0, $$luaO_nilobject_$i = 0, $$sink = 0, $$sum = 0, $$sum1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$i = 0, $temp$i2 = 0, $temp$i7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp$i7 = sp + 32|0;
 $temp$i2 = sp + 16|0;
 $temp$i = sp;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -16|0);
 $3 = ((($L)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($idx|0)>(0);
 do {
  if ($5) {
   $6 = HEAP32[$4>>2]|0;
   $7 = (($6) + ($idx<<4)|0);
   $8 = ($7>>>0)<($1>>>0);
   $$luaO_nilobject_$i = $8 ? $7 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $9 = ($idx|0)<(-1000999);
   if (!($9)) {
    $10 = (($1) + ($idx<<4)|0);
    $$0$i = $10;
    break;
   }
   $11 = ($idx|0)==(-1001000);
   if ($11) {
    $12 = ((($L)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($13)) + 40|0);
    $$0$i = $14;
    break;
   }
   $15 = (-1001000 - ($idx))|0;
   $16 = HEAP32[$4>>2]|0;
   $17 = ((($16)) + 8|0);
   $18 = HEAP32[$17>>2]|0;
   $19 = ($18|0)==(22);
   if ($19) {
    $$0$i = 1568;
   } else {
    $20 = HEAP32[$16>>2]|0;
    $21 = ((($20)) + 6|0);
    $22 = HEAP8[$21>>0]|0;
    $23 = $22&255;
    $24 = ($15|0)>($23|0);
    $25 = (($15) + -1)|0;
    $26 = (((($20)) + 16|0) + ($25<<4)|0);
    $27 = $24 ? 1568 : $26;
    $$0$i = $27;
   }
  }
 } while(0);
 $28 = ($n|0)>(-1);
 $$sum1 = $n ^ -1;
 $$sink = $28 ? $1 : $$0$i;
 $29 = (($$sink) + ($$sum1<<4)|0);
 $30 = ($$0$i>>>0)<($29>>>0);
 if ($30) {
  $$011$i10 = $29;$$02$i9 = $$0$i;
  while(1) {
   ;HEAP32[$temp$i7>>2]=HEAP32[$$02$i9>>2]|0;HEAP32[$temp$i7+4>>2]=HEAP32[$$02$i9+4>>2]|0;HEAP32[$temp$i7+8>>2]=HEAP32[$$02$i9+8>>2]|0;HEAP32[$temp$i7+12>>2]=HEAP32[$$02$i9+12>>2]|0;
   ;HEAP32[$$02$i9>>2]=HEAP32[$$011$i10>>2]|0;HEAP32[$$02$i9+4>>2]=HEAP32[$$011$i10+4>>2]|0;HEAP32[$$02$i9+8>>2]=HEAP32[$$011$i10+8>>2]|0;HEAP32[$$02$i9+12>>2]=HEAP32[$$011$i10+12>>2]|0;
   ;HEAP32[$$011$i10>>2]=HEAP32[$temp$i7>>2]|0;HEAP32[$$011$i10+4>>2]=HEAP32[$temp$i7+4>>2]|0;HEAP32[$$011$i10+8>>2]=HEAP32[$temp$i7+8>>2]|0;HEAP32[$$011$i10+12>>2]=HEAP32[$temp$i7+12>>2]|0;
   $31 = ((($$02$i9)) + 16|0);
   $32 = ((($$011$i10)) + -16|0);
   $33 = ($31>>>0)<($32>>>0);
   if ($33) {
    $$011$i10 = $32;$$02$i9 = $31;
   } else {
    break;
   }
  }
 }
 $$sum = (0 - ($n))|0;
 $34 = (($$sink) + ($$sum<<4)|0);
 $35 = ($34>>>0)<($2>>>0);
 if ($35) {
  $$011$i5 = $2;$$02$i4 = $34;
  while(1) {
   ;HEAP32[$temp$i2>>2]=HEAP32[$$02$i4>>2]|0;HEAP32[$temp$i2+4>>2]=HEAP32[$$02$i4+4>>2]|0;HEAP32[$temp$i2+8>>2]=HEAP32[$$02$i4+8>>2]|0;HEAP32[$temp$i2+12>>2]=HEAP32[$$02$i4+12>>2]|0;
   ;HEAP32[$$02$i4>>2]=HEAP32[$$011$i5>>2]|0;HEAP32[$$02$i4+4>>2]=HEAP32[$$011$i5+4>>2]|0;HEAP32[$$02$i4+8>>2]=HEAP32[$$011$i5+8>>2]|0;HEAP32[$$02$i4+12>>2]=HEAP32[$$011$i5+12>>2]|0;
   ;HEAP32[$$011$i5>>2]=HEAP32[$temp$i2>>2]|0;HEAP32[$$011$i5+4>>2]=HEAP32[$temp$i2+4>>2]|0;HEAP32[$$011$i5+8>>2]=HEAP32[$temp$i2+8>>2]|0;HEAP32[$$011$i5+12>>2]=HEAP32[$temp$i2+12>>2]|0;
   $36 = ((($$02$i4)) + 16|0);
   $37 = ((($$011$i5)) + -16|0);
   $38 = ($36>>>0)<($37>>>0);
   if ($38) {
    $$011$i5 = $37;$$02$i4 = $36;
   } else {
    break;
   }
  }
 }
 $39 = ($$0$i>>>0)<($2>>>0);
 if ($39) {
  $$011$i = $2;$$02$i = $$0$i;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  ;HEAP32[$temp$i>>2]=HEAP32[$$02$i>>2]|0;HEAP32[$temp$i+4>>2]=HEAP32[$$02$i+4>>2]|0;HEAP32[$temp$i+8>>2]=HEAP32[$$02$i+8>>2]|0;HEAP32[$temp$i+12>>2]=HEAP32[$$02$i+12>>2]|0;
  ;HEAP32[$$02$i>>2]=HEAP32[$$011$i>>2]|0;HEAP32[$$02$i+4>>2]=HEAP32[$$011$i+4>>2]|0;HEAP32[$$02$i+8>>2]=HEAP32[$$011$i+8>>2]|0;HEAP32[$$02$i+12>>2]=HEAP32[$$011$i+12>>2]|0;
  ;HEAP32[$$011$i>>2]=HEAP32[$temp$i>>2]|0;HEAP32[$$011$i+4>>2]=HEAP32[$temp$i+4>>2]|0;HEAP32[$$011$i+8>>2]=HEAP32[$temp$i+8>>2]|0;HEAP32[$$011$i+12>>2]=HEAP32[$temp$i+12>>2]|0;
  $40 = ((($$02$i)) + 16|0);
  $41 = ((($$011$i)) + -16|0);
  $42 = ($40>>>0)<($41>>>0);
  if ($42) {
   $$011$i = $41;$$02$i = $40;
  } else {
   break;
  }
 }
 STACKTOP = sp;return;
}
function _lua_copy($L,$fromidx,$toidx) {
 $L = $L|0;
 $fromidx = $fromidx|0;
 $toidx = $toidx|0;
 var $$0$i = 0, $$0$i2 = 0, $$0$i2$ph = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($fromidx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($fromidx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($fromidx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($fromidx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($fromidx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($fromidx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ($toidx|0)>(0);
 do {
  if ($29) {
   $30 = HEAP32[$1>>2]|0;
   $31 = (($30) + ($toidx<<4)|0);
   $32 = ((($L)) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($31>>>0)<($33>>>0);
   $$luaO_nilobject_$i1 = $34 ? $31 : 1568;
   $$0$i2$ph = $$luaO_nilobject_$i1;
  } else {
   $35 = ($toidx|0)<(-1000999);
   if (!($35)) {
    $36 = ((($L)) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + ($toidx<<4)|0);
    $$0$i2$ph = $38;
    break;
   }
   $39 = ($toidx|0)==(-1001000);
   if ($39) {
    $40 = ((($L)) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + 40|0);
    $$0$i2$ph = $42;
    break;
   }
   $43 = (-1001000 - ($toidx))|0;
   $44 = HEAP32[$1>>2]|0;
   $45 = ((($44)) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(22);
   if ($47) {
    $$0$i2 = 1568;
   } else {
    $48 = HEAP32[$44>>2]|0;
    $49 = ((($48)) + 6|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50&255;
    $52 = ($43|0)>($51|0);
    $53 = (($43) + -1)|0;
    $54 = (((($48)) + 16|0) + ($53<<4)|0);
    $phitmp = $52 ? 1568 : $54;
    $$0$i2 = $phitmp;
   }
   ;HEAP32[$$0$i2>>2]=HEAP32[$$0$i>>2]|0;HEAP32[$$0$i2+4>>2]=HEAP32[$$0$i+4>>2]|0;HEAP32[$$0$i2+8>>2]=HEAP32[$$0$i+8>>2]|0;HEAP32[$$0$i2+12>>2]=HEAP32[$$0$i+12>>2]|0;
   $55 = ((($$0$i)) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = $56 & 64;
   $58 = ($57|0)==(0);
   if ($58) {
    return;
   }
   $59 = HEAP32[$0>>2]|0;
   $60 = HEAP32[$59>>2]|0;
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($61)) + 5|0);
   $63 = HEAP8[$62>>0]|0;
   $64 = $63 & 4;
   $65 = ($64<<24>>24)==(0);
   if ($65) {
    return;
   }
   $66 = HEAP32[$$0$i>>2]|0;
   $67 = ((($66)) + 5|0);
   $68 = HEAP8[$67>>0]|0;
   $69 = $68 & 3;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    return;
   }
   _luaC_barrier_($L,$61,$66);
   return;
  }
 } while(0);
 ;HEAP32[$$0$i2$ph>>2]=HEAP32[$$0$i>>2]|0;HEAP32[$$0$i2$ph+4>>2]=HEAP32[$$0$i+4>>2]|0;HEAP32[$$0$i2$ph+8>>2]=HEAP32[$$0$i+8>>2]|0;HEAP32[$$0$i2$ph+12>>2]=HEAP32[$$0$i+12>>2]|0;
 return;
}
function _lua_pushvalue($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($idx|0)>(0);
 do {
  if ($4) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($idx<<4)|0);
   $7 = ($6>>>0)<($1>>>0);
   $$luaO_nilobject_$i = $7 ? $6 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = (($1) + ($idx<<4)|0);
    $$0$i = $9;
    break;
   }
   $10 = ($idx|0)==(-1001000);
   if ($10) {
    $11 = ((($L)) + 12|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12)) + 40|0);
    $$0$i = $13;
    break;
   }
   $14 = (-1001000 - ($idx))|0;
   $15 = HEAP32[$3>>2]|0;
   $16 = ((($15)) + 8|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(22);
   if ($18) {
    $$0$i = 1568;
   } else {
    $19 = HEAP32[$15>>2]|0;
    $20 = ((($19)) + 6|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = $21&255;
    $23 = ($14|0)>($22|0);
    $24 = (($14) + -1)|0;
    $25 = (((($19)) + 16|0) + ($24<<4)|0);
    $26 = $23 ? 1568 : $25;
    $$0$i = $26;
   }
  }
 } while(0);
 ;HEAP32[$1>>2]=HEAP32[$$0$i>>2]|0;HEAP32[$1+4>>2]=HEAP32[$$0$i+4>>2]|0;HEAP32[$1+8>>2]=HEAP32[$$0$i+8>>2]|0;HEAP32[$1+12>>2]=HEAP32[$$0$i+12>>2]|0;
 $27 = HEAP32[$0>>2]|0;
 $28 = ((($27)) + 16|0);
 HEAP32[$0>>2] = $28;
 return;
}
function _lua_type($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   if ($7) {
    $$0$i = $4;
   } else {
    $32 = -1;
    return ($32|0);
   }
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $32 = -1;
    return ($32|0);
   }
   $21 = HEAP32[$17>>2]|0;
   $22 = ((($21)) + 6|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = $23&255;
   $25 = ($16|0)>($24|0);
   $26 = (($16) + -1)|0;
   $27 = (((($21)) + 16|0) + ($26<<4)|0);
   if ($25) {
    $32 = -1;
    return ($32|0);
   } else {
    $$0$i = $27;
   }
  }
 } while(0);
 $28 = ($$0$i|0)==(1568|0);
 if ($28) {
  $32 = -1;
  return ($32|0);
 }
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 $32 = $31;
 return ($32|0);
}
function _lua_typename($L,$t) {
 $L = $L|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($t) + 1)|0;
 $1 = (2872 + ($0<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 return ($2|0);
}
function _lua_iscfunction($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$ = 0, $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(22);
 $32 = ($30|0)==(102);
 $$ = $31 | $32;
 $33 = $$&1;
 return ($33|0);
}
function _lua_isinteger($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(19);
 $32 = $31&1;
 return ($32|0);
}
function _lua_isnumber($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $n = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(3);
 if ($31) {
  $32 = +HEAPF64[$$0$i>>3];
  HEAPF64[$n>>3] = $32;
  $34 = 1;
  STACKTOP = sp;return ($34|0);
 } else {
  $33 = (_luaV_tonumber_($$0$i,$n)|0);
  $34 = $33;
  STACKTOP = sp;return ($34|0);
 }
 return (0)|0;
}
function _lua_isstring($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 $$off = (($31) + -3)|0;
 $32 = ($$off>>>0)<(2);
 $33 = $32&1;
 return ($33|0);
}
function _lua_rawequal($L,$index1,$index2) {
 $L = $L|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 var $$0$i = 0, $$0$i3 = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($index1|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($index1<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($index1|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($index1<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($index1|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($index1))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ($index2|0)>(0);
 do {
  if ($29) {
   $30 = HEAP32[$1>>2]|0;
   $31 = (($30) + ($index2<<4)|0);
   $32 = ((($L)) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($31>>>0)<($33>>>0);
   $$luaO_nilobject_$i2 = $34 ? $31 : 1568;
   $$0$i3 = $$luaO_nilobject_$i2;
  } else {
   $35 = ($index2|0)<(-1000999);
   if (!($35)) {
    $36 = ((($L)) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + ($index2<<4)|0);
    $$0$i3 = $38;
    break;
   }
   $39 = ($index2|0)==(-1001000);
   if ($39) {
    $40 = ((($L)) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + 40|0);
    $$0$i3 = $42;
    break;
   }
   $43 = (-1001000 - ($index2))|0;
   $44 = HEAP32[$1>>2]|0;
   $45 = ((($44)) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(22);
   if ($47) {
    $59 = 0;
    return ($59|0);
   } else {
    $48 = HEAP32[$44>>2]|0;
    $49 = ((($48)) + 6|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50&255;
    $52 = ($43|0)>($51|0);
    $53 = (($43) + -1)|0;
    $54 = (((($48)) + 16|0) + ($53<<4)|0);
    $55 = $52 ? 1568 : $54;
    $$0$i3 = $55;
    break;
   }
  }
 } while(0);
 $56 = ($$0$i|0)!=(1568|0);
 $57 = ($$0$i3|0)!=(1568|0);
 $or$cond = $56 & $57;
 if (!($or$cond)) {
  $59 = 0;
  return ($59|0);
 }
 $58 = (_luaV_equalobj(0,$$0$i,$$0$i3)|0);
 $59 = $58;
 return ($59|0);
}
function _lua_compare($L,$index1,$index2,$op) {
 $L = $L|0;
 $index1 = $index1|0;
 $index2 = $index2|0;
 $op = $op|0;
 var $$0$i = 0, $$0$i3 = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($index1|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($index1<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($index1|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($index1<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($index1|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($index1))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ($index2|0)>(0);
 do {
  if ($29) {
   $30 = HEAP32[$1>>2]|0;
   $31 = (($30) + ($index2<<4)|0);
   $32 = ((($L)) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($31>>>0)<($33>>>0);
   $$luaO_nilobject_$i2 = $34 ? $31 : 1568;
   $$0$i3 = $$luaO_nilobject_$i2;
  } else {
   $35 = ($index2|0)<(-1000999);
   if (!($35)) {
    $36 = ((($L)) + 8|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = (($37) + ($index2<<4)|0);
    $$0$i3 = $38;
    break;
   }
   $39 = ($index2|0)==(-1001000);
   if ($39) {
    $40 = ((($L)) + 12|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($41)) + 40|0);
    $$0$i3 = $42;
    break;
   }
   $43 = (-1001000 - ($index2))|0;
   $44 = HEAP32[$1>>2]|0;
   $45 = ((($44)) + 8|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==(22);
   if ($47) {
    $i$0 = 0;
    return ($i$0|0);
   } else {
    $48 = HEAP32[$44>>2]|0;
    $49 = ((($48)) + 6|0);
    $50 = HEAP8[$49>>0]|0;
    $51 = $50&255;
    $52 = ($43|0)>($51|0);
    $53 = (($43) + -1)|0;
    $54 = (((($48)) + 16|0) + ($53<<4)|0);
    $55 = $52 ? 1568 : $54;
    $$0$i3 = $55;
    break;
   }
  }
 } while(0);
 $56 = ($$0$i|0)!=(1568|0);
 $57 = ($$0$i3|0)!=(1568|0);
 $or$cond = $56 & $57;
 if (!($or$cond)) {
  $i$0 = 0;
  return ($i$0|0);
 }
 if ((($op|0) == 1)) {
  $59 = (_luaV_lessthan($L,$$0$i,$$0$i3)|0);
  $i$0 = $59;
  return ($i$0|0);
 } else if ((($op|0) == 2)) {
  $60 = (_luaV_lessequal($L,$$0$i,$$0$i3)|0);
  $i$0 = $60;
  return ($i$0|0);
 } else if ((($op|0) == 0)) {
  $58 = (_luaV_equalobj($L,$$0$i,$$0$i3)|0);
  $i$0 = $58;
  return ($i$0|0);
 } else {
  $i$0 = 0;
  return ($i$0|0);
 }
 return (0)|0;
}
function _lua_stringtonumber($L,$s) {
 $L = $L|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaO_str2num($s,$1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  return ($2|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 16|0);
 HEAP32[$0>>2] = $5;
 return ($2|0);
}
function _lua_tonumberx($L,$idx,$pisnum) {
 $L = $L|0;
 $idx = $idx|0;
 $pisnum = $pisnum|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $n = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $n = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(3);
 if ($31) {
  $32 = +HEAPF64[$$0$i>>3];
  HEAPF64[$n>>3] = $32;
  $36 = 1;
 } else {
  $33 = (_luaV_tonumber_($$0$i,$n)|0);
  $34 = ($33|0)==(0);
  if ($34) {
   HEAPF64[$n>>3] = 0.0;
   $36 = 0;
  } else {
   $36 = $33;
  }
 }
 $35 = ($pisnum|0)==(0|0);
 if ($35) {
  $37 = +HEAPF64[$n>>3];
  STACKTOP = sp;return (+$37);
 }
 HEAP32[$pisnum>>2] = $36;
 $37 = +HEAPF64[$n>>3];
 STACKTOP = sp;return (+$37);
}
function _lua_tointegerx($L,$idx,$pisnum) {
 $L = $L|0;
 $idx = $idx|0;
 $pisnum = $pisnum|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $res = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $res = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(19);
 if ($31) {
  $32 = $$0$i;
  $33 = $32;
  $34 = HEAP32[$33>>2]|0;
  $35 = (($32) + 4)|0;
  $36 = $35;
  $37 = HEAP32[$36>>2]|0;
  $38 = $res;
  $39 = $38;
  HEAP32[$39>>2] = $34;
  $40 = (($38) + 4)|0;
  $41 = $40;
  HEAP32[$41>>2] = $37;
  $49 = 1;
 } else {
  $42 = (_luaV_tointeger_($$0$i,$res)|0);
  $43 = ($42|0)==(0);
  if ($43) {
   $44 = $res;
   $45 = $44;
   HEAP32[$45>>2] = 0;
   $46 = (($44) + 4)|0;
   $47 = $46;
   HEAP32[$47>>2] = 0;
   $49 = 0;
  } else {
   $49 = $42;
  }
 }
 $48 = ($pisnum|0)==(0|0);
 if ($48) {
  $50 = $res;
  $51 = $50;
  $52 = HEAP32[$51>>2]|0;
  $53 = (($50) + 4)|0;
  $54 = $53;
  $55 = HEAP32[$54>>2]|0;
  tempRet0 = ($55);
  STACKTOP = sp;return ($52|0);
 }
 HEAP32[$pisnum>>2] = $49;
 $50 = $res;
 $51 = $50;
 $52 = HEAP32[$51>>2]|0;
 $53 = (($50) + 4)|0;
 $54 = $53;
 $55 = HEAP32[$54>>2]|0;
 tempRet0 = ($55);
 STACKTOP = sp;return ($52|0);
}
function _lua_toboolean($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  $35 = 0;
  $34 = $35&1;
  return ($34|0);
 }
 $32 = ($30|0)==(1);
 if (!($32)) {
  $35 = 1;
  $34 = $35&1;
  return ($34|0);
 }
 $33 = HEAP32[$$0$i>>2]|0;
 $phitmp = ($33|0)!=(0);
 $35 = $phitmp;
 $34 = $35&1;
 return ($34|0);
}
function _lua_tolstring($L,$idx,$len) {
 $L = $L|0;
 $idx = $idx|0;
 $len = $len|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i1 = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $o$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 4)) {
  $o$0 = $$0$i;
 } else if ((($31|0) == 3)) {
  label = 12;
 } else {
  $32 = ($len|0)==(0|0);
  if ($32) {
   $$0 = 0;
   return ($$0|0);
  }
  HEAP32[$len>>2] = 0;
  $$0 = 0;
  return ($$0|0);
 }
 if ((label|0) == 12) {
  $33 = ((($L)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ((($34)) + 12|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = ($36|0)>(0);
  if ($37) {
   _luaC_step($L);
   $$pre = HEAP32[$0>>2]|0;
   $39 = $$pre;
  } else {
   $39 = $1;
  }
  do {
   if ($2) {
    $38 = HEAP32[$39>>2]|0;
    $40 = (($38) + ($idx<<4)|0);
    $41 = ((($L)) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ($40>>>0)<($42>>>0);
    $$luaO_nilobject_$i1 = $43 ? $40 : 1568;
    $$0$i2 = $$luaO_nilobject_$i1;
   } else {
    $44 = ($idx|0)<(-1000999);
    if (!($44)) {
     $45 = ((($L)) + 8|0);
     $46 = HEAP32[$45>>2]|0;
     $47 = (($46) + ($idx<<4)|0);
     $$0$i2 = $47;
     break;
    }
    $48 = ($idx|0)==(-1001000);
    if ($48) {
     $49 = HEAP32[$33>>2]|0;
     $50 = ((($49)) + 40|0);
     $$0$i2 = $50;
     break;
    }
    $51 = (-1001000 - ($idx))|0;
    $52 = HEAP32[$39>>2]|0;
    $53 = ((($52)) + 8|0);
    $54 = HEAP32[$53>>2]|0;
    $55 = ($54|0)==(22);
    if ($55) {
     $$0$i2 = 1568;
    } else {
     $56 = HEAP32[$52>>2]|0;
     $57 = ((($56)) + 6|0);
     $58 = HEAP8[$57>>0]|0;
     $59 = $58&255;
     $60 = ($51|0)>($59|0);
     $61 = (($51) + -1)|0;
     $62 = (((($56)) + 16|0) + ($61<<4)|0);
     $63 = $60 ? 1568 : $62;
     $$0$i2 = $63;
    }
   }
  } while(0);
  _luaO_tostring($L,$$0$i2);
  $o$0 = $$0$i2;
 }
 $64 = ($len|0)==(0|0);
 if ($64) {
  $$pre4 = HEAP32[$o$0>>2]|0;
  $69 = $$pre4;
 } else {
  $65 = HEAP32[$o$0>>2]|0;
  $66 = ((($65)) + 12|0);
  $67 = HEAP32[$66>>2]|0;
  HEAP32[$len>>2] = $67;
  $69 = $65;
 }
 $68 = ((($69)) + 24|0);
 $$0 = $68;
 return ($$0|0);
}
function _lua_rawlen($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0 = 0, $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 7)) {
  $35 = HEAP32[$$0$i>>2]|0;
  $36 = ((($35)) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  $$0 = $37;
  return ($$0|0);
 } else if ((($31|0) == 5)) {
  $38 = HEAP32[$$0$i>>2]|0;
  $39 = (_luaH_getn($38)|0);
  $$0 = $39;
  return ($$0|0);
 } else if ((($31|0) == 4)) {
  $32 = HEAP32[$$0$i>>2]|0;
  $33 = ((($32)) + 12|0);
  $34 = HEAP32[$33>>2]|0;
  $$0 = $34;
  return ($$0|0);
 } else {
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _lua_touserdata($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0 = 0, $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 7)) {
  $32 = HEAP32[$$0$i>>2]|0;
  $33 = ((($32)) + 24|0);
  $$0 = $33;
  return ($$0|0);
 } else if ((($31|0) == 2)) {
  $34 = HEAP32[$$0$i>>2]|0;
  $$0 = $34;
  return ($$0|0);
 } else {
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _lua_tothread($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ($30|0)==(72);
 if (!($31)) {
  $33 = 0;
  return ($33|0);
 }
 $32 = HEAP32[$$0$i>>2]|0;
 $33 = $32;
 return ($33|0);
}
function _lua_topointer($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 63;
 switch ($31|0) {
 case 38:  {
  $34 = HEAP32[$$0$i>>2]|0;
  $$0 = $34;
  return ($$0|0);
  break;
 }
 case 2: case 7:  {
  do {
   if ($2) {
    $37 = HEAP32[$1>>2]|0;
    $38 = (($37) + ($idx<<4)|0);
    $39 = ((($L)) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($38>>>0)<($40>>>0);
    $$luaO_nilobject_$i$i = $41 ? $38 : 1568;
    $$0$i$i = $$luaO_nilobject_$i$i;
   } else {
    $42 = ($idx|0)<(-1000999);
    if (!($42)) {
     $43 = ((($L)) + 8|0);
     $44 = HEAP32[$43>>2]|0;
     $45 = (($44) + ($idx<<4)|0);
     $$0$i$i = $45;
     break;
    }
    $46 = ($idx|0)==(-1001000);
    if ($46) {
     $47 = ((($L)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ((($48)) + 40|0);
     $$0$i$i = $49;
     break;
    }
    $50 = (-1001000 - ($idx))|0;
    $51 = HEAP32[$1>>2]|0;
    $52 = ((($51)) + 8|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = ($53|0)==(22);
    if ($54) {
     $$0$i$i = 1568;
    } else {
     $55 = HEAP32[$51>>2]|0;
     $56 = ((($55)) + 6|0);
     $57 = HEAP8[$56>>0]|0;
     $58 = $57&255;
     $59 = ($50|0)>($58|0);
     $60 = (($50) + -1)|0;
     $61 = (((($55)) + 16|0) + ($60<<4)|0);
     $62 = $59 ? 1568 : $61;
     $$0$i$i = $62;
    }
   }
  } while(0);
  $63 = ((($$0$i$i)) + 8|0);
  $64 = HEAP32[$63>>2]|0;
  $65 = $64 & 15;
  if ((($65|0) == 2)) {
   $68 = HEAP32[$$0$i$i>>2]|0;
   $$0 = $68;
   return ($$0|0);
  } else if ((($65|0) == 7)) {
   $66 = HEAP32[$$0$i$i>>2]|0;
   $67 = ((($66)) + 24|0);
   $$0 = $67;
   return ($$0|0);
  } else {
   $$0 = 0;
   return ($$0|0);
  }
  break;
 }
 case 6:  {
  $33 = HEAP32[$$0$i>>2]|0;
  $$0 = $33;
  return ($$0|0);
  break;
 }
 case 5:  {
  $32 = HEAP32[$$0$i>>2]|0;
  $$0 = $32;
  return ($$0|0);
  break;
 }
 case 22:  {
  $35 = HEAP32[$$0$i>>2]|0;
  $$0 = $35;
  return ($$0|0);
  break;
 }
 case 8:  {
  $36 = HEAP32[$$0$i>>2]|0;
  $$0 = $36;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _lua_pushnil($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($1)) + 16|0);
 HEAP32[$0>>2] = $3;
 return;
}
function _lua_pushnumber($L,$n) {
 $L = $L|0;
 $n = +$n;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAPF64[$1>>3] = $n;
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = 3;
 $3 = ((($1)) + 16|0);
 HEAP32[$0>>2] = $3;
 return;
}
function _lua_pushinteger($L,$0,$1) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3;
 $5 = $4;
 HEAP32[$5>>2] = $0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $1;
 $8 = ((($3)) + 8|0);
 HEAP32[$8>>2] = 19;
 $9 = ((($3)) + 16|0);
 HEAP32[$2>>2] = $9;
 return;
}
function _lua_pushlstring($L,$s,$len) {
 $L = $L|0;
 $s = $s|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaS_newlstr($L,$s,$len)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$7>>2] = $5;
 $8 = ((($5)) + 4|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9&255;
 $11 = $10 | 64;
 $12 = ((($7)) + 8|0);
 HEAP32[$12>>2] = $11;
 $13 = HEAP32[$6>>2]|0;
 $14 = ((($13)) + 16|0);
 HEAP32[$6>>2] = $14;
 $15 = ((($5)) + 24|0);
 return ($15|0);
}
function _lua_pushstring($L,$s) {
 $L = $L|0;
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $1 = ((($L)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ((($2)) + 8|0);
  HEAP32[$3>>2] = 0;
  $4 = ((($2)) + 16|0);
  HEAP32[$1>>2] = $4;
  $$0 = 0;
  return ($$0|0);
 }
 $5 = ((($L)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)>(0);
 if ($9) {
  _luaC_step($L);
 }
 $10 = (_luaS_new($L,$s)|0);
 $11 = ((($L)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 HEAP32[$12>>2] = $10;
 $13 = ((($10)) + 4|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = $15 | 64;
 $17 = ((($12)) + 8|0);
 HEAP32[$17>>2] = $16;
 $18 = HEAP32[$11>>2]|0;
 $19 = ((($18)) + 16|0);
 HEAP32[$11>>2] = $19;
 $20 = ((($10)) + 24|0);
 $$0 = $20;
 return ($$0|0);
}
function _lua_pushvfstring($L,$fmt,$argp) {
 $L = $L|0;
 $fmt = $fmt|0;
 $argp = $argp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 return ($5|0);
}
function _lua_pushfstring($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $argp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $argp = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 HEAP32[$argp>>2] = $varargs;
 $5 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 STACKTOP = sp;return ($5|0);
}
function _lua_pushcclosure($L,$fn,$n) {
 $L = $L|0;
 $fn = $fn|0;
 $n = $n|0;
 var $$in = 0, $$pre$phiZ2D = 0, $$pre3 = 0, $$pre3$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $1 = ((($L)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$2>>2] = $fn;
  $3 = ((($2)) + 8|0);
  HEAP32[$3>>2] = 22;
  $$pre$phiZ2D = $1;
  $21 = HEAP32[$$pre$phiZ2D>>2]|0;
  $22 = ((($21)) + 16|0);
  HEAP32[$$pre$phiZ2D>>2] = $22;
  return;
 }
 $4 = ((($L)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)>(0);
 if ($8) {
  _luaC_step($L);
 }
 $9 = (_luaF_newCclosure($L,$n)|0);
 $10 = ((($9)) + 12|0);
 HEAP32[$10>>2] = $fn;
 $11 = ((($L)) + 8|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (0 - ($n))|0;
 $14 = (($12) + ($13<<4)|0);
 HEAP32[$11>>2] = $14;
 $$in = $n;$18 = $14;
 while(1) {
  $15 = (($$in) + -1)|0;
  $16 = (((($9)) + 16|0) + ($15<<4)|0);
  $17 = (($18) + ($15<<4)|0);
  ;HEAP32[$16>>2]=HEAP32[$17>>2]|0;HEAP32[$16+4>>2]=HEAP32[$17+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$17+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$17+12>>2]|0;
  $19 = ($15|0)==(0);
  $$pre3 = HEAP32[$11>>2]|0;
  if ($19) {
   $$pre3$lcssa = $$pre3;
   break;
  } else {
   $$in = $15;$18 = $$pre3;
  }
 }
 HEAP32[$$pre3$lcssa>>2] = $9;
 $20 = ((($$pre3$lcssa)) + 8|0);
 HEAP32[$20>>2] = 102;
 $$pre$phiZ2D = $11;
 $21 = HEAP32[$$pre$phiZ2D>>2]|0;
 $22 = ((($21)) + 16|0);
 HEAP32[$$pre$phiZ2D>>2] = $22;
 return;
}
function _lua_pushboolean($L,$b) {
 $L = $L|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($b|0)!=(0);
 $3 = $2&1;
 HEAP32[$1>>2] = $3;
 $4 = ((($1)) + 8|0);
 HEAP32[$4>>2] = 1;
 $5 = ((($1)) + 16|0);
 HEAP32[$0>>2] = $5;
 return;
}
function _lua_pushlightuserdata($L,$p) {
 $L = $L|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $p;
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = 2;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 16|0);
 HEAP32[$0>>2] = $4;
 return;
}
function _lua_pushthread($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$1>>2] = $L;
 $2 = ((($1)) + 8|0);
 HEAP32[$2>>2] = 72;
 $3 = HEAP32[$0>>2]|0;
 $4 = ((($3)) + 16|0);
 HEAP32[$0>>2] = $4;
 $5 = ((($L)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 136|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==($L|0);
 $10 = $9&1;
 return ($10|0);
}
function _lua_getglobal($L,$name) {
 $L = $L|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_luaH_getint($3,2,0)|0);
 $5 = ((($L)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 16|0);
 HEAP32[$5>>2] = $7;
 $8 = (_luaS_new($L,$name)|0);
 HEAP32[$6>>2] = $8;
 $9 = ((($8)) + 4|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 | 64;
 $13 = ((($6)) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($14)) + -16|0);
 _luaV_gettable($L,$4,$15,$15);
 $16 = HEAP32[$5>>2]|0;
 $17 = ((($16)) + -8|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 & 15;
 return ($19|0);
}
function _lua_gettable($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + -16|0);
 _luaV_gettable($L,$$0$i,$31,$31);
 $32 = HEAP32[$29>>2]|0;
 $33 = ((($32)) + -8|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 & 15;
 return ($35|0);
}
function _lua_getfield($L,$idx,$k) {
 $L = $L|0;
 $idx = $idx|0;
 $k = $k|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = (_luaS_new($L,$k)|0);
 HEAP32[$30>>2] = $31;
 $32 = ((($31)) + 4|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = $34 | 64;
 $36 = ((($30)) + 8|0);
 HEAP32[$36>>2] = $35;
 $37 = HEAP32[$29>>2]|0;
 $38 = ((($37)) + 16|0);
 HEAP32[$29>>2] = $38;
 _luaV_gettable($L,$$0$i,$37,$37);
 $39 = HEAP32[$29>>2]|0;
 $40 = ((($39)) + -8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 15;
 return ($42|0);
}
function _lua_geti($L,$idx,$0,$1) {
 $L = $L|0;
 $idx = $idx|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($idx|0)>(0);
 do {
  if ($4) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($idx<<4)|0);
   $7 = ((($L)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6>>>0)<($8>>>0);
   $$luaO_nilobject_$i = $9 ? $6 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $10 = ($idx|0)<(-1000999);
   if (!($10)) {
    $11 = ((($L)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($idx<<4)|0);
    $$0$i = $13;
    break;
   }
   $14 = ($idx|0)==(-1001000);
   if ($14) {
    $15 = ((($L)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 40|0);
    $$0$i = $17;
    break;
   }
   $18 = (-1001000 - ($idx))|0;
   $19 = HEAP32[$3>>2]|0;
   $20 = ((($19)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(22);
   if ($22) {
    $$0$i = 1568;
   } else {
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 6|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25&255;
    $27 = ($18|0)>($26|0);
    $28 = (($18) + -1)|0;
    $29 = (((($23)) + 16|0) + ($28<<4)|0);
    $30 = $27 ? 1568 : $29;
    $$0$i = $30;
   }
  }
 } while(0);
 $31 = ((($L)) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = $32;
 $34 = $33;
 HEAP32[$34>>2] = $0;
 $35 = (($33) + 4)|0;
 $36 = $35;
 HEAP32[$36>>2] = $1;
 $37 = ((($32)) + 8|0);
 HEAP32[$37>>2] = 19;
 $38 = ((($32)) + 16|0);
 HEAP32[$31>>2] = $38;
 _luaV_gettable($L,$$0$i,$32,$32);
 $39 = HEAP32[$31>>2]|0;
 $40 = ((($39)) + -8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41 & 15;
 return ($42|0);
}
function _lua_rawget($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + -16|0);
 $32 = HEAP32[$$0$i>>2]|0;
 $33 = (_luaH_get($32,$31)|0);
 ;HEAP32[$31>>2]=HEAP32[$33>>2]|0;HEAP32[$31+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$33+12>>2]|0;
 $34 = HEAP32[$29>>2]|0;
 $35 = ((($34)) + -8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 15;
 return ($37|0);
}
function _lua_rawgeti($L,$idx,$0,$1) {
 $L = $L|0;
 $idx = $idx|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($idx|0)>(0);
 do {
  if ($4) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($idx<<4)|0);
   $7 = ((($L)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6>>>0)<($8>>>0);
   $$luaO_nilobject_$i = $9 ? $6 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $10 = ($idx|0)<(-1000999);
   if (!($10)) {
    $11 = ((($L)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($idx<<4)|0);
    $$0$i = $13;
    break;
   }
   $14 = ($idx|0)==(-1001000);
   if ($14) {
    $15 = ((($L)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 40|0);
    $$0$i = $17;
    break;
   }
   $18 = (-1001000 - ($idx))|0;
   $19 = HEAP32[$3>>2]|0;
   $20 = ((($19)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(22);
   if ($22) {
    $$0$i = 1568;
   } else {
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 6|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25&255;
    $27 = ($18|0)>($26|0);
    $28 = (($18) + -1)|0;
    $29 = (((($23)) + 16|0) + ($28<<4)|0);
    $30 = $27 ? 1568 : $29;
    $$0$i = $30;
   }
  }
 } while(0);
 $31 = ((($L)) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP32[$$0$i>>2]|0;
 $34 = (_luaH_getint($33,$0,$1)|0);
 ;HEAP32[$32>>2]=HEAP32[$34>>2]|0;HEAP32[$32+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$34+12>>2]|0;
 $35 = HEAP32[$31>>2]|0;
 $36 = ((($35)) + 16|0);
 HEAP32[$31>>2] = $36;
 $37 = ((($35)) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = $38 & 15;
 return ($39|0);
}
function _lua_rawgetp($L,$idx,$p) {
 $L = $L|0;
 $idx = $idx|0;
 $p = $p|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $k = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 HEAP32[$k>>2] = $p;
 $29 = ((($k)) + 8|0);
 HEAP32[$29>>2] = 2;
 $30 = ((($L)) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = HEAP32[$$0$i>>2]|0;
 $33 = (_luaH_get($32,$k)|0);
 ;HEAP32[$31>>2]=HEAP32[$33>>2]|0;HEAP32[$31+4>>2]=HEAP32[$33+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$33+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$33+12>>2]|0;
 $34 = HEAP32[$30>>2]|0;
 $35 = ((($34)) + 16|0);
 HEAP32[$30>>2] = $35;
 $36 = ((($34)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 15;
 STACKTOP = sp;return ($38|0);
}
function _lua_createtable($L,$narray,$nrec) {
 $L = $L|0;
 $narray = $narray|0;
 $nrec = $nrec|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaH_new($L)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$7>>2] = $5;
 $8 = ((($7)) + 8|0);
 HEAP32[$8>>2] = 69;
 $9 = HEAP32[$6>>2]|0;
 $10 = ((($9)) + 16|0);
 HEAP32[$6>>2] = $10;
 $11 = ($narray|0)>(0);
 $12 = ($nrec|0)>(0);
 $or$cond = $11 | $12;
 if (!($or$cond)) {
  return;
 }
 _luaH_resize($L,$5,$narray,$nrec);
 return;
}
function _lua_getmetatable($L,$objindex) {
 $L = $L|0;
 $objindex = $objindex|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0 = 0, $mt$0$in = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($objindex|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($objindex<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($objindex|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($objindex<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($objindex|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($objindex))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 if ((($31|0) == 7)) {
  $34 = HEAP32[$$0$i>>2]|0;
  $35 = ((($34)) + 8|0);
  $mt$0$in = $35;
 } else if ((($31|0) == 5)) {
  $32 = HEAP32[$$0$i>>2]|0;
  $33 = ((($32)) + 24|0);
  $mt$0$in = $33;
 } else {
  $36 = ((($L)) + 12|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = (((($37)) + 244|0) + ($31<<2)|0);
  $mt$0$in = $38;
 }
 $mt$0 = HEAP32[$mt$0$in>>2]|0;
 $39 = ($mt$0|0)==(0|0);
 if ($39) {
  $res$0 = 0;
  return ($res$0|0);
 }
 $40 = ((($L)) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 HEAP32[$41>>2] = $mt$0;
 $42 = ((($41)) + 8|0);
 HEAP32[$42>>2] = 69;
 $43 = HEAP32[$40>>2]|0;
 $44 = ((($43)) + 16|0);
 HEAP32[$40>>2] = $44;
 $res$0 = 1;
 return ($res$0|0);
}
function _lua_getuservalue($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$$0$i>>2]|0;
 $32 = ((($31)) + 16|0);
 $33 = $32;
 $34 = $33;
 $35 = HEAP32[$34>>2]|0;
 $36 = (($33) + 4)|0;
 $37 = $36;
 $38 = HEAP32[$37>>2]|0;
 $39 = $30;
 $40 = $39;
 HEAP32[$40>>2] = $35;
 $41 = (($39) + 4)|0;
 $42 = $41;
 HEAP32[$42>>2] = $38;
 $43 = ((($31)) + 6|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = $44&255;
 $46 = ((($30)) + 8|0);
 HEAP32[$46>>2] = $45;
 $47 = HEAP32[$29>>2]|0;
 $48 = ((($47)) + 16|0);
 HEAP32[$29>>2] = $48;
 $49 = ((($47)) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 15;
 return ($51|0);
}
function _lua_setglobal($L,$name) {
 $L = $L|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 40|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_luaH_getint($3,2,0)|0);
 $5 = ((($L)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 16|0);
 HEAP32[$5>>2] = $7;
 $8 = (_luaS_new($L,$name)|0);
 HEAP32[$6>>2] = $8;
 $9 = ((($8)) + 4|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = $10&255;
 $12 = $11 | 64;
 $13 = ((($6)) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$5>>2]|0;
 $15 = ((($14)) + -16|0);
 $16 = ((($14)) + -32|0);
 _luaV_settable($L,$4,$15,$16);
 $17 = HEAP32[$5>>2]|0;
 $18 = ((($17)) + -32|0);
 HEAP32[$5>>2] = $18;
 return;
}
function _lua_setfield($L,$idx,$k) {
 $L = $L|0;
 $idx = $idx|0;
 $k = $k|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + 16|0);
 HEAP32[$29>>2] = $31;
 $32 = (_luaS_new($L,$k)|0);
 HEAP32[$30>>2] = $32;
 $33 = ((($32)) + 4|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = $34&255;
 $36 = $35 | 64;
 $37 = ((($30)) + 8|0);
 HEAP32[$37>>2] = $36;
 $38 = HEAP32[$29>>2]|0;
 $39 = ((($38)) + -16|0);
 $40 = ((($38)) + -32|0);
 _luaV_settable($L,$$0$i,$39,$40);
 $41 = HEAP32[$29>>2]|0;
 $42 = ((($41)) + -32|0);
 HEAP32[$29>>2] = $42;
 return;
}
function _lua_seti($L,$idx,$0,$1) {
 $L = $L|0;
 $idx = $idx|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($idx|0)>(0);
 do {
  if ($4) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($idx<<4)|0);
   $7 = ((($L)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6>>>0)<($8>>>0);
   $$luaO_nilobject_$i = $9 ? $6 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $10 = ($idx|0)<(-1000999);
   if (!($10)) {
    $11 = ((($L)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($idx<<4)|0);
    $$0$i = $13;
    break;
   }
   $14 = ($idx|0)==(-1001000);
   if ($14) {
    $15 = ((($L)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 40|0);
    $$0$i = $17;
    break;
   }
   $18 = (-1001000 - ($idx))|0;
   $19 = HEAP32[$3>>2]|0;
   $20 = ((($19)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(22);
   if ($22) {
    $$0$i = 1568;
   } else {
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 6|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25&255;
    $27 = ($18|0)>($26|0);
    $28 = (($18) + -1)|0;
    $29 = (((($23)) + 16|0) + ($28<<4)|0);
    $30 = $27 ? 1568 : $29;
    $$0$i = $30;
   }
  }
 } while(0);
 $31 = ((($L)) + 8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($32)) + 16|0);
 HEAP32[$31>>2] = $33;
 $34 = $32;
 $35 = $34;
 HEAP32[$35>>2] = $0;
 $36 = (($34) + 4)|0;
 $37 = $36;
 HEAP32[$37>>2] = $1;
 $38 = ((($32)) + 8|0);
 HEAP32[$38>>2] = 19;
 $39 = ((($32)) + -16|0);
 _luaV_settable($L,$$0$i,$32,$39);
 $40 = HEAP32[$31>>2]|0;
 $41 = ((($40)) + -32|0);
 HEAP32[$31>>2] = $41;
 return;
}
function _lua_rawset($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = HEAP32[$$0$i>>2]|0;
 $30 = ((($L)) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + -32|0);
 $33 = (_luaH_set($L,$29,$32)|0);
 $34 = HEAP32[$30>>2]|0;
 $35 = ((($34)) + -16|0);
 ;HEAP32[$33>>2]=HEAP32[$35>>2]|0;HEAP32[$33+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$35+12>>2]|0;
 $36 = ((($29)) + 6|0);
 HEAP8[$36>>0] = 0;
 $37 = HEAP32[$30>>2]|0;
 $38 = ((($37)) + -8|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = $39 & 64;
 $41 = ($40|0)==(0);
 if ($41) {
  $53 = $37;
  $52 = ((($53)) + -32|0);
  HEAP32[$30>>2] = $52;
  return;
 }
 $42 = ((($29)) + 5|0);
 $43 = HEAP8[$42>>0]|0;
 $44 = $43 & 4;
 $45 = ($44<<24>>24)==(0);
 if ($45) {
  $53 = $37;
  $52 = ((($53)) + -32|0);
  HEAP32[$30>>2] = $52;
  return;
 }
 $46 = ((($37)) + -16|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($47)) + 5|0);
 $49 = HEAP8[$48>>0]|0;
 $50 = $49 & 3;
 $51 = ($50<<24>>24)==(0);
 if ($51) {
  $53 = $37;
  $52 = ((($53)) + -32|0);
  HEAP32[$30>>2] = $52;
  return;
 }
 _luaC_barrierback_($L,$29);
 $$pre = HEAP32[$30>>2]|0;
 $53 = $$pre;
 $52 = ((($53)) + -32|0);
 HEAP32[$30>>2] = $52;
 return;
}
function _lua_rawseti($L,$idx,$0,$1) {
 $L = $L|0;
 $idx = $idx|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$pre = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($idx|0)>(0);
 do {
  if ($4) {
   $5 = HEAP32[$3>>2]|0;
   $6 = (($5) + ($idx<<4)|0);
   $7 = ((($L)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($6>>>0)<($8>>>0);
   $$luaO_nilobject_$i = $9 ? $6 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $10 = ($idx|0)<(-1000999);
   if (!($10)) {
    $11 = ((($L)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($idx<<4)|0);
    $$0$i = $13;
    break;
   }
   $14 = ($idx|0)==(-1001000);
   if ($14) {
    $15 = ((($L)) + 12|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 40|0);
    $$0$i = $17;
    break;
   }
   $18 = (-1001000 - ($idx))|0;
   $19 = HEAP32[$3>>2]|0;
   $20 = ((($19)) + 8|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(22);
   if ($22) {
    $$0$i = 1568;
   } else {
    $23 = HEAP32[$19>>2]|0;
    $24 = ((($23)) + 6|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25&255;
    $27 = ($18|0)>($26|0);
    $28 = (($18) + -1)|0;
    $29 = (((($23)) + 16|0) + ($28<<4)|0);
    $30 = $27 ? 1568 : $29;
    $$0$i = $30;
   }
  }
 } while(0);
 $31 = HEAP32[$$0$i>>2]|0;
 $32 = ((($L)) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33)) + -16|0);
 _luaH_setint($L,$31,$0,$1,$34);
 $35 = HEAP32[$32>>2]|0;
 $36 = ((($35)) + -8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 64;
 $39 = ($38|0)==(0);
 if ($39) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  return;
 }
 $40 = ((($31)) + 5|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41 & 4;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  return;
 }
 $44 = ((($35)) + -16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($45)) + 5|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47 & 3;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  return;
 }
 _luaC_barrierback_($L,$31);
 $$pre = HEAP32[$32>>2]|0;
 $51 = $$pre;
 $50 = ((($51)) + -16|0);
 HEAP32[$32>>2] = $50;
 return;
}
function _lua_rawsetp($L,$idx,$p) {
 $L = $L|0;
 $idx = $idx|0;
 $p = $p|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = HEAP32[$$0$i>>2]|0;
 HEAP32[$k>>2] = $p;
 $30 = ((($k)) + 8|0);
 HEAP32[$30>>2] = 2;
 $31 = (_luaH_set($L,$29,$k)|0);
 $32 = ((($L)) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($33)) + -16|0);
 ;HEAP32[$31>>2]=HEAP32[$34>>2]|0;HEAP32[$31+4>>2]=HEAP32[$34+4>>2]|0;HEAP32[$31+8>>2]=HEAP32[$34+8>>2]|0;HEAP32[$31+12>>2]=HEAP32[$34+12>>2]|0;
 $35 = HEAP32[$32>>2]|0;
 $36 = ((($35)) + -8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 64;
 $39 = ($38|0)==(0);
 if ($39) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  STACKTOP = sp;return;
 }
 $40 = ((($29)) + 5|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41 & 4;
 $43 = ($42<<24>>24)==(0);
 if ($43) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  STACKTOP = sp;return;
 }
 $44 = ((($35)) + -16|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ((($45)) + 5|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47 & 3;
 $49 = ($48<<24>>24)==(0);
 if ($49) {
  $51 = $35;
  $50 = ((($51)) + -16|0);
  HEAP32[$32>>2] = $50;
  STACKTOP = sp;return;
 }
 _luaC_barrierback_($L,$29);
 $$pre = HEAP32[$32>>2]|0;
 $51 = $$pre;
 $50 = ((($51)) + -16|0);
 HEAP32[$32>>2] = $50;
 STACKTOP = sp;return;
}
function _lua_setmetatable($L,$objindex) {
 $L = $L|0;
 $objindex = $objindex|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($objindex|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($objindex<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($objindex|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($objindex<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($objindex|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($objindex))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = ((($30)) + -8|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ($32|0)==(0);
 if ($33) {
  $mt$0 = 0;
 } else {
  $34 = ((($30)) + -16|0);
  $35 = HEAP32[$34>>2]|0;
  $mt$0 = $35;
 }
 $36 = ((($$0$i)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = $37 & 15;
 if ((($38|0) == 5)) {
  $39 = HEAP32[$$0$i>>2]|0;
  $40 = ((($39)) + 24|0);
  HEAP32[$40>>2] = $mt$0;
  $41 = ($mt$0|0)==(0|0);
  if ($41) {
   $68 = HEAP32[$29>>2]|0;
   $69 = ((($68)) + -16|0);
   HEAP32[$29>>2] = $69;
   return 1;
  }
  $42 = HEAP32[$$0$i>>2]|0;
  $43 = ((($42)) + 5|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44 & 4;
  $46 = ($45<<24>>24)==(0);
  if ($46) {
   $51 = $42;
  } else {
   $47 = ((($mt$0)) + 5|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = $48 & 3;
   $50 = ($49<<24>>24)==(0);
   if ($50) {
    $51 = $42;
   } else {
    _luaC_barrier_($L,$42,$mt$0);
    $$pre1 = HEAP32[$$0$i>>2]|0;
    $51 = $$pre1;
   }
  }
  _luaC_checkfinalizer($L,$51,$mt$0);
  $68 = HEAP32[$29>>2]|0;
  $69 = ((($68)) + -16|0);
  HEAP32[$29>>2] = $69;
  return 1;
 } else if ((($38|0) == 7)) {
  $52 = HEAP32[$$0$i>>2]|0;
  $53 = ((($52)) + 8|0);
  HEAP32[$53>>2] = $mt$0;
  $54 = ($mt$0|0)==(0|0);
  if ($54) {
   $68 = HEAP32[$29>>2]|0;
   $69 = ((($68)) + -16|0);
   HEAP32[$29>>2] = $69;
   return 1;
  }
  $55 = HEAP32[$$0$i>>2]|0;
  $56 = ((($55)) + 5|0);
  $57 = HEAP8[$56>>0]|0;
  $58 = $57 & 4;
  $59 = ($58<<24>>24)==(0);
  if ($59) {
   $64 = $55;
  } else {
   $60 = ((($mt$0)) + 5|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61 & 3;
   $63 = ($62<<24>>24)==(0);
   if ($63) {
    $64 = $55;
   } else {
    _luaC_barrier_($L,$55,$mt$0);
    $$pre = HEAP32[$$0$i>>2]|0;
    $64 = $$pre;
   }
  }
  _luaC_checkfinalizer($L,$64,$mt$0);
  $68 = HEAP32[$29>>2]|0;
  $69 = ((($68)) + -16|0);
  HEAP32[$29>>2] = $69;
  return 1;
 } else {
  $65 = ((($L)) + 12|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = (((($66)) + 244|0) + ($38<<2)|0);
  HEAP32[$67>>2] = $mt$0;
  $68 = HEAP32[$29>>2]|0;
  $69 = ((($68)) + -16|0);
  HEAP32[$29>>2] = $69;
  return 1;
 }
 return (0)|0;
}
function _lua_setuservalue($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = HEAP32[$$0$i>>2]|0;
 $32 = ((($30)) + -16|0);
 $33 = ((($31)) + 16|0);
 $34 = $32;
 $35 = $34;
 $36 = HEAP32[$35>>2]|0;
 $37 = (($34) + 4)|0;
 $38 = $37;
 $39 = HEAP32[$38>>2]|0;
 $40 = $33;
 $41 = $40;
 HEAP32[$41>>2] = $36;
 $42 = (($40) + 4)|0;
 $43 = $42;
 HEAP32[$43>>2] = $39;
 $44 = ((($30)) + -8|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = $45&255;
 $47 = ((($31)) + 6|0);
 HEAP8[$47>>0] = $46;
 $48 = HEAP32[$29>>2]|0;
 $49 = ((($48)) + -8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = $50 & 64;
 $52 = ($51|0)==(0);
 if ($52) {
  $65 = $48;
  $64 = ((($65)) + -16|0);
  HEAP32[$29>>2] = $64;
  return;
 }
 $53 = HEAP32[$$0$i>>2]|0;
 $54 = ((($53)) + 5|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = $55 & 4;
 $57 = ($56<<24>>24)==(0);
 if ($57) {
  $65 = $48;
  $64 = ((($65)) + -16|0);
  HEAP32[$29>>2] = $64;
  return;
 }
 $58 = ((($48)) + -16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59)) + 5|0);
 $61 = HEAP8[$60>>0]|0;
 $62 = $61 & 3;
 $63 = ($62<<24>>24)==(0);
 if ($63) {
  $65 = $48;
  $64 = ((($65)) + -16|0);
  HEAP32[$29>>2] = $64;
  return;
 }
 _luaC_barrier_($L,$53,$59);
 $$pre = HEAP32[$29>>2]|0;
 $65 = $$pre;
 $64 = ((($65)) + -16|0);
 HEAP32[$29>>2] = $64;
 return;
}
function _lua_callk($L,$nargs,$nresults,$ctx,$k) {
 $L = $L|0;
 $nargs = $nargs|0;
 $nresults = $nresults|0;
 $ctx = $ctx|0;
 $k = $k|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $nargs ^ -1;
 $3 = (($1) + ($2<<4)|0);
 $4 = ($k|0)==(0|0);
 if ($4) {
  label = 4;
 } else {
  $5 = ((($L)) + 104|0);
  $6 = HEAP16[$5>>1]|0;
  $7 = ($6<<16>>16)==(0);
  if ($7) {
   $8 = ((($L)) + 16|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + 16|0);
   HEAP32[$10>>2] = $k;
   $11 = ((($9)) + 24|0);
   HEAP32[$11>>2] = $ctx;
   _luaD_call($L,$3,$nresults,1);
  } else {
   label = 4;
  }
 }
 if ((label|0) == 4) {
  _luaD_call($L,$3,$nresults,0);
 }
 $12 = ($nresults|0)==(-1);
 if (!($12)) {
  return;
 }
 $13 = ((($L)) + 16|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($14)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$0>>2]|0;
 $18 = ($16>>>0)<($17>>>0);
 if (!($18)) {
  return;
 }
 HEAP32[$15>>2] = $17;
 return;
}
function _lua_pcallk($L,$nargs,$nresults,$errfunc,$ctx,$k) {
 $L = $L|0;
 $nargs = $nargs|0;
 $nresults = $nresults|0;
 $errfunc = $errfunc|0;
 $ctx = $ctx|0;
 $k = $k|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $c = 0, $func$0 = 0, $status$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $c = sp;
 $0 = ($errfunc|0)==(0);
 if ($0) {
  $func$0 = 0;
 } else {
  $1 = ((($L)) + 16|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($errfunc|0)>(0);
  do {
   if ($3) {
    $4 = HEAP32[$2>>2]|0;
    $5 = (($4) + ($errfunc<<4)|0);
    $6 = ((($L)) + 8|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = ($5>>>0)<($7>>>0);
    $$luaO_nilobject_$i = $8 ? $5 : 1568;
    $$0$i = $$luaO_nilobject_$i;
   } else {
    $9 = ($errfunc|0)<(-1000999);
    if (!($9)) {
     $10 = ((($L)) + 8|0);
     $11 = HEAP32[$10>>2]|0;
     $12 = (($11) + ($errfunc<<4)|0);
     $$0$i = $12;
     break;
    }
    $13 = ($errfunc|0)==(-1001000);
    if ($13) {
     $14 = ((($L)) + 12|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = ((($15)) + 40|0);
     $$0$i = $16;
     break;
    }
    $17 = (-1001000 - ($errfunc))|0;
    $18 = HEAP32[$2>>2]|0;
    $19 = ((($18)) + 8|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = ($20|0)==(22);
    if ($21) {
     $$0$i = 1568;
    } else {
     $22 = HEAP32[$18>>2]|0;
     $23 = ((($22)) + 6|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24&255;
     $26 = ($17|0)>($25|0);
     $27 = (($17) + -1)|0;
     $28 = (((($22)) + 16|0) + ($27<<4)|0);
     $29 = $26 ? 1568 : $28;
     $$0$i = $29;
    }
   }
  } while(0);
  $30 = ((($L)) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = $$0$i;
  $33 = $31;
  $34 = (($32) - ($33))|0;
  $func$0 = $34;
 }
 $35 = ((($L)) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $nargs ^ -1;
 $38 = (($36) + ($37<<4)|0);
 HEAP32[$c>>2] = $38;
 $39 = ($k|0)==(0|0);
 if ($39) {
  label = 13;
 } else {
  $40 = ((($L)) + 104|0);
  $41 = HEAP16[$40>>1]|0;
  $42 = ($41<<16>>16)==(0);
  if ($42) {
   $50 = ((($L)) + 16|0);
   $51 = HEAP32[$50>>2]|0;
   $52 = ((($51)) + 16|0);
   HEAP32[$52>>2] = $k;
   $53 = ((($51)) + 24|0);
   HEAP32[$53>>2] = $ctx;
   $54 = ((($L)) + 28|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = $38;
   $57 = $55;
   $58 = (($56) - ($57))|0;
   $59 = ((($51)) + 28|0);
   HEAP32[$59>>2] = $58;
   $60 = ((($L)) + 88|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ((($51)) + 20|0);
   HEAP32[$62>>2] = $61;
   HEAP32[$60>>2] = $func$0;
   $63 = ((($51)) + 34|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = $64&255;
   $66 = $65 & 238;
   $67 = ((($L)) + 109|0);
   $68 = HEAP8[$67>>0]|0;
   $69 = $68&255;
   $70 = $69 | $66;
   $71 = $70 | 16;
   $72 = $71&255;
   HEAP8[$63>>0] = $72;
   _luaD_call($L,$38,$nresults,1);
   $73 = HEAP8[$63>>0]|0;
   $74 = $73&255;
   $75 = $74 & 239;
   $76 = $75&255;
   HEAP8[$63>>0] = $76;
   $77 = HEAP32[$62>>2]|0;
   HEAP32[$60>>2] = $77;
   $status$0 = 0;
  } else {
   label = 13;
  }
 }
 if ((label|0) == 13) {
  $43 = ((($c)) + 4|0);
  HEAP32[$43>>2] = $nresults;
  $44 = ((($L)) + 28|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = $38;
  $47 = $45;
  $48 = (($46) - ($47))|0;
  $49 = (_luaD_pcall($L,309,$c,$48,$func$0)|0);
  $status$0 = $49;
 }
 $78 = ($nresults|0)==(-1);
 if (!($78)) {
  STACKTOP = sp;return ($status$0|0);
 }
 $79 = ((($L)) + 16|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ((($80)) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = HEAP32[$35>>2]|0;
 $84 = ($82>>>0)<($83>>>0);
 if (!($84)) {
  STACKTOP = sp;return ($status$0|0);
 }
 HEAP32[$81>>2] = $83;
 STACKTOP = sp;return ($status$0|0);
}
function _lua_load($L,$reader,$data,$chunkname,$mode) {
 $L = $L|0;
 $reader = $reader|0;
 $data = $data|0;
 $chunkname = $chunkname|0;
 $mode = $mode|0;
 var $$chunkname = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $z = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $z = sp;
 $0 = ($chunkname|0)==(0|0);
 $$chunkname = $0 ? 37376 : $chunkname;
 _luaZ_init($L,$z,$reader,$data);
 $1 = (_luaD_protectedparser($L,$z,$$chunkname,$mode)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return ($1|0);
 }
 $3 = ((($L)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 6|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  STACKTOP = sp;return ($1|0);
 }
 $10 = ((($L)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 40|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_luaH_getint($13,2,0)|0);
 $15 = ((($6)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = HEAP32[$16>>2]|0;
 ;HEAP32[$17>>2]=HEAP32[$14>>2]|0;HEAP32[$17+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$17+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$17+12>>2]=HEAP32[$14+12>>2]|0;
 $18 = HEAP32[$15>>2]|0;
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = $21 & 64;
 $23 = ($22|0)!=(0);
 $24 = ((($18)) + 8|0);
 $25 = ($19|0)==($24|0);
 $or$cond = $25 & $23;
 if (!($or$cond)) {
  STACKTOP = sp;return ($1|0);
 }
 _luaC_upvalbarrier_($L,$18);
 STACKTOP = sp;return ($1|0);
}
function _lua_dump($L,$writer,$data,$strip) {
 $L = $L|0;
 $writer = $writer|0;
 $data = $data|0;
 $strip = $strip|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $status$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(70);
 if (!($4)) {
  $status$0 = 1;
  return ($status$0|0);
 }
 $5 = ((($1)) + -16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($6)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (_luaU_dump($L,$8,$writer,$data,$strip)|0);
 $status$0 = $9;
 return ($status$0|0);
}
function _lua_status($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 6|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 return ($2|0);
}
function _lua_gc($L,$what,$data) {
 $L = $L|0;
 $what = $what|0;
 $data = $data|0;
 var $$ = 0, $$data = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 do {
  switch ($what|0) {
  case 6:  {
   $31 = ((($1)) + 124|0);
   $32 = HEAP32[$31>>2]|0;
   HEAP32[$31>>2] = $data;
   $res$0 = $32;
   return ($res$0|0);
   break;
  }
  case 5:  {
   $16 = ((($1)) + 63|0);
   $17 = HEAP8[$16>>0]|0;
   HEAP8[$16>>0] = 1;
   $18 = ($data|0)==(0);
   if ($18) {
    _luaE_setdebt($1,-2000);
    _luaC_step($L);
    HEAP8[$16>>0] = $17;
    $28 = ((($1)) + 61|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($29<<24>>24)==(7);
    $$ = $30&1;
    return ($$|0);
   }
   $19 = $data << 10;
   $20 = ((($1)) + 12|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19))|0;
   _luaE_setdebt($1,$22);
   $23 = HEAP32[$0>>2]|0;
   $24 = ((($23)) + 12|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ($25|0)>(0);
   if ($26) {
    _luaC_step($L);
   }
   HEAP8[$16>>0] = $17;
   $27 = ($22|0)>(0);
   if ($27) {
    $28 = ((($1)) + 61|0);
    $29 = HEAP8[$28>>0]|0;
    $30 = ($29<<24>>24)==(7);
    $$ = $30&1;
    return ($$|0);
   } else {
    $res$0 = 0;
    return ($res$0|0);
   }
   break;
  }
  case 4:  {
   $10 = ((($1)) + 8|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($1)) + 12|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + ($11))|0;
   $15 = $14 & 1023;
   $res$0 = $15;
   return ($res$0|0);
   break;
  }
  case 1:  {
   _luaE_setdebt($1,0);
   $3 = ((($1)) + 63|0);
   HEAP8[$3>>0] = 1;
   $res$0 = 0;
   return ($res$0|0);
   break;
  }
  case 9:  {
   $36 = ((($1)) + 63|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $res$0 = $38;
   return ($res$0|0);
   break;
  }
  case 7:  {
   $33 = ((($1)) + 128|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($data|0)<(40);
   $$data = $35 ? 40 : $data;
   HEAP32[$33>>2] = $$data;
   $res$0 = $34;
   return ($res$0|0);
   break;
  }
  case 0:  {
   $2 = ((($1)) + 63|0);
   HEAP8[$2>>0] = 0;
   $res$0 = 0;
   return ($res$0|0);
   break;
  }
  case 2:  {
   _luaC_fullgc($L,0);
   $res$0 = 0;
   return ($res$0|0);
   break;
  }
  case 3:  {
   $4 = ((($1)) + 8|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ((($1)) + 12|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + ($5))|0;
   $9 = $8 >>> 10;
   $res$0 = $9;
   return ($res$0|0);
   break;
  }
  default: {
   $res$0 = -1;
   return ($res$0|0);
  }
  }
 } while(0);
 return (0)|0;
}
function _lua_error($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaG_errormsg($L);
 // unreachable;
 return (0)|0;
}
function _lua_next($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = HEAP32[$$0$i>>2]|0;
 $30 = ((($L)) + 8|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + -16|0);
 $33 = (_luaH_next($L,$29,$32)|0);
 $34 = ($33|0)==(0);
 $35 = HEAP32[$30>>2]|0;
 $36 = ((($35)) + -16|0);
 $37 = ((($35)) + 16|0);
 $storemerge = $34 ? $36 : $37;
 HEAP32[$30>>2] = $storemerge;
 return ($33|0);
}
function _lua_concat($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(1);
 if ($0) {
  $1 = ((($L)) + 12|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ((($2)) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)>(0);
  if ($5) {
   _luaC_step($L);
  }
  _luaV_concat($L,$n);
  return;
 } else {
  $6 = ($n|0)==(0);
  if (!($6)) {
   return;
  }
  $7 = ((($L)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (_luaS_newlstr($L,37352,0)|0);
  HEAP32[$8>>2] = $9;
  $10 = ((($9)) + 4|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = $12 | 64;
  $14 = ((($8)) + 8|0);
  HEAP32[$14>>2] = $13;
  $15 = HEAP32[$7>>2]|0;
  $16 = ((($15)) + 16|0);
  HEAP32[$7>>2] = $16;
  return;
 }
}
function _lua_len($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $$0$i = 0, $$luaO_nilobject_$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($idx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($idx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($idx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($idx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($idx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($idx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($L)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 _luaV_objlen($L,$30,$$0$i);
 $31 = HEAP32[$29>>2]|0;
 $32 = ((($31)) + 16|0);
 HEAP32[$29>>2] = $32;
 return;
}
function _lua_newuserdata($L,$size) {
 $L = $L|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaS_newudata($L,$size)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$7>>2] = $5;
 $8 = ((($7)) + 8|0);
 HEAP32[$8>>2] = 71;
 $9 = HEAP32[$6>>2]|0;
 $10 = ((($9)) + 16|0);
 HEAP32[$6>>2] = $10;
 $11 = ((($5)) + 24|0);
 return ($11|0);
}
function _lua_getupvalue($L,$funcindex,$n) {
 $L = $L|0;
 $funcindex = $funcindex|0;
 $n = $n|0;
 var $$ = 0, $$0$i = 0, $$0$i1$ph = 0, $$0$i12 = 0, $$luaO_nilobject_$i = 0, $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($funcindex|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($funcindex<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($funcindex|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($funcindex<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($funcindex|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($funcindex))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 63;
 do {
  if ((($31|0) == 6)) {
   $41 = HEAP32[$$0$i>>2]|0;
   $42 = ((($41)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($n|0)>(0);
   if (!($44)) {
    $$0$i12 = 0;
    return ($$0$i12|0);
   }
   $45 = ((($43)) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)<($n|0);
   if ($47) {
    $$0$i12 = 0;
    return ($$0$i12|0);
   } else {
    $48 = (($n) + -1)|0;
    $49 = (((($41)) + 16|0) + ($48<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = HEAP32[$50>>2]|0;
    $52 = ((($43)) + 64|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + ($48<<3)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    $57 = ((($55)) + 24|0);
    $$ = $56 ? 856 : $57;
    $$0$i1$ph = $$;$$ph = $51;
    break;
   }
  } else if ((($31|0) == 38)) {
   $32 = HEAP32[$$0$i>>2]|0;
   $33 = ($n|0)>(0);
   if (!($33)) {
    $$0$i12 = 0;
    return ($$0$i12|0);
   }
   $34 = ((($32)) + 6|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = ($36|0)<($n|0);
   if ($37) {
    $$0$i12 = 0;
    return ($$0$i12|0);
   } else {
    $38 = (($n) + -1)|0;
    $39 = (((($32)) + 16|0) + ($38<<4)|0);
    $40 = $39;
    $$0$i1$ph = 37352;$$ph = $40;
    break;
   }
  } else {
   $$0$i12 = 0;
   return ($$0$i12|0);
  }
 } while(0);
 $58 = ((($L)) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = $$ph;
 ;HEAP32[$59>>2]=HEAP32[$60>>2]|0;HEAP32[$59+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$59+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$59+12>>2]=HEAP32[$60+12>>2]|0;
 $61 = HEAP32[$58>>2]|0;
 $62 = ((($61)) + 16|0);
 HEAP32[$58>>2] = $62;
 $$0$i12 = $$0$i1$ph;
 return ($$0$i12|0);
}
function _lua_setupvalue($L,$funcindex,$n) {
 $L = $L|0;
 $funcindex = $funcindex|0;
 $n = $n|0;
 var $$ = 0, $$0$i = 0, $$0$i2$ph = 0, $$0$i23 = 0, $$luaO_nilobject_$i = 0, $$ph = 0, $$ph5 = 0, $$ph6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($funcindex|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($funcindex<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($funcindex|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($funcindex<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($funcindex|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($funcindex))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 63;
 do {
  if ((($31|0) == 38)) {
   $32 = HEAP32[$$0$i>>2]|0;
   $33 = ($n|0)>(0);
   if (!($33)) {
    $$0$i23 = 0;
    return ($$0$i23|0);
   }
   $34 = ((($32)) + 6|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = ($36|0)<($n|0);
   if ($37) {
    $$0$i23 = 0;
    return ($$0$i23|0);
   } else {
    $38 = (($n) + -1)|0;
    $39 = (((($32)) + 16|0) + ($38<<4)|0);
    $40 = $39;
    $$0$i2$ph = 37352;$$ph = $40;$$ph5 = $32;$$ph6 = 0;
    break;
   }
  } else if ((($31|0) == 6)) {
   $41 = HEAP32[$$0$i>>2]|0;
   $42 = ((($41)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = ($n|0)>(0);
   if (!($44)) {
    $$0$i23 = 0;
    return ($$0$i23|0);
   }
   $45 = ((($43)) + 12|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)<($n|0);
   if ($47) {
    $$0$i23 = 0;
    return ($$0$i23|0);
   } else {
    $48 = (($n) + -1)|0;
    $49 = (((($41)) + 16|0) + ($48<<2)|0);
    $50 = HEAP32[$49>>2]|0;
    $51 = HEAP32[$50>>2]|0;
    $52 = ((($43)) + 64|0);
    $53 = HEAP32[$52>>2]|0;
    $54 = (($53) + ($48<<3)|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = ($55|0)==(0|0);
    $57 = ((($55)) + 24|0);
    $$ = $56 ? 856 : $57;
    $$0$i2$ph = $$;$$ph = $51;$$ph5 = 0;$$ph6 = $50;
    break;
   }
  } else {
   $$0$i23 = 0;
   return ($$0$i23|0);
  }
 } while(0);
 $58 = ((($L)) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59)) + -16|0);
 HEAP32[$58>>2] = $60;
 $61 = $$ph;
 ;HEAP32[$61>>2]=HEAP32[$60>>2]|0;HEAP32[$61+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$61+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$61+12>>2]=HEAP32[$60+12>>2]|0;
 $62 = ($$ph5|0)==(0|0);
 if ($62) {
  $77 = ($$ph6|0)==(0|0);
  if ($77) {
   $$0$i23 = $$0$i2$ph;
   return ($$0$i23|0);
  }
  $78 = HEAP32[$$ph6>>2]|0;
  $79 = ((($78)) + 8|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = $80 & 64;
  $82 = ($81|0)!=(0);
  $83 = ((($$ph6)) + 8|0);
  $84 = ($78|0)==($83|0);
  $or$cond = $84 & $82;
  if (!($or$cond)) {
   $$0$i23 = $$0$i2$ph;
   return ($$0$i23|0);
  }
  _luaC_upvalbarrier_($L,$$ph6);
  $$0$i23 = $$0$i2$ph;
  return ($$0$i23|0);
 }
 $63 = HEAP32[$58>>2]|0;
 $64 = ((($63)) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 & 64;
 $67 = ($66|0)==(0);
 if ($67) {
  $$0$i23 = $$0$i2$ph;
  return ($$0$i23|0);
 }
 $68 = ((($$ph5)) + 5|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69 & 4;
 $71 = ($70<<24>>24)==(0);
 if ($71) {
  $$0$i23 = $$0$i2$ph;
  return ($$0$i23|0);
 }
 $72 = HEAP32[$63>>2]|0;
 $73 = ((($72)) + 5|0);
 $74 = HEAP8[$73>>0]|0;
 $75 = $74 & 3;
 $76 = ($75<<24>>24)==(0);
 if ($76) {
  $$0$i23 = $$0$i2$ph;
  return ($$0$i23|0);
 }
 _luaC_barrier_($L,$$ph5,$72);
 $$0$i23 = $$0$i2$ph;
 return ($$0$i23|0);
}
function _lua_upvalueid($L,$fidx,$n) {
 $L = $L|0;
 $fidx = $fidx|0;
 $n = $n|0;
 var $$0 = 0, $$0$i = 0, $$0$i$i = 0, $$luaO_nilobject_$i = 0, $$luaO_nilobject_$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($fidx|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($fidx<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i = $7 ? $4 : 1568;
   $$0$i = $$luaO_nilobject_$i;
  } else {
   $8 = ($fidx|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($fidx<<4)|0);
    $$0$i = $11;
    break;
   }
   $12 = ($fidx|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i = $15;
    break;
   }
   $16 = (-1001000 - ($fidx))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i = $28;
   }
  }
 } while(0);
 $29 = ((($$0$i)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 63;
 if ((($31|0) == 38)) {
  $62 = HEAP32[$$0$i>>2]|0;
  $63 = (($n) + -1)|0;
  $64 = (((($62)) + 16|0) + ($63<<4)|0);
  $$0 = $64;
  return ($$0|0);
 } else if ((($31|0) == 6)) {
  do {
   if ($2) {
    $32 = HEAP32[$1>>2]|0;
    $33 = (($32) + ($fidx<<4)|0);
    $34 = ((($L)) + 8|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($33>>>0)<($35>>>0);
    $$luaO_nilobject_$i$i = $36 ? $33 : 1568;
    $$0$i$i = $$luaO_nilobject_$i$i;
   } else {
    $37 = ($fidx|0)<(-1000999);
    if (!($37)) {
     $38 = ((($L)) + 8|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + ($fidx<<4)|0);
     $$0$i$i = $40;
     break;
    }
    $41 = ($fidx|0)==(-1001000);
    if ($41) {
     $42 = ((($L)) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ((($43)) + 40|0);
     $$0$i$i = $44;
     break;
    }
    $45 = (-1001000 - ($fidx))|0;
    $46 = HEAP32[$1>>2]|0;
    $47 = ((($46)) + 8|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ($48|0)==(22);
    if ($49) {
     $$0$i$i = 1568;
    } else {
     $50 = HEAP32[$46>>2]|0;
     $51 = ((($50)) + 6|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = $52&255;
     $54 = ($45|0)>($53|0);
     $55 = (($45) + -1)|0;
     $56 = (((($50)) + 16|0) + ($55<<4)|0);
     $57 = $54 ? 1568 : $56;
     $$0$i$i = $57;
    }
   }
  } while(0);
  $58 = HEAP32[$$0$i$i>>2]|0;
  $59 = (($n) + -1)|0;
  $60 = (((($58)) + 16|0) + ($59<<2)|0);
  $61 = HEAP32[$60>>2]|0;
  $$0 = $61;
  return ($$0|0);
 } else {
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _lua_upvaluejoin($L,$fidx1,$n1,$fidx2,$n2) {
 $L = $L|0;
 $fidx1 = $fidx1|0;
 $n1 = $n1|0;
 $fidx2 = $fidx2|0;
 $n2 = $n2|0;
 var $$0$i$i = 0, $$0$i$i3 = 0, $$luaO_nilobject_$i$i = 0, $$luaO_nilobject_$i$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($fidx1|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[$1>>2]|0;
   $4 = (($3) + ($fidx1<<4)|0);
   $5 = ((($L)) + 8|0);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($4>>>0)<($6>>>0);
   $$luaO_nilobject_$i$i = $7 ? $4 : 1568;
   $$0$i$i = $$luaO_nilobject_$i$i;
  } else {
   $8 = ($fidx1|0)<(-1000999);
   if (!($8)) {
    $9 = ((($L)) + 8|0);
    $10 = HEAP32[$9>>2]|0;
    $11 = (($10) + ($fidx1<<4)|0);
    $$0$i$i = $11;
    break;
   }
   $12 = ($fidx1|0)==(-1001000);
   if ($12) {
    $13 = ((($L)) + 12|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ((($14)) + 40|0);
    $$0$i$i = $15;
    break;
   }
   $16 = (-1001000 - ($fidx1))|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ((($17)) + 8|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ($19|0)==(22);
   if ($20) {
    $$0$i$i = 1568;
   } else {
    $21 = HEAP32[$17>>2]|0;
    $22 = ((($21)) + 6|0);
    $23 = HEAP8[$22>>0]|0;
    $24 = $23&255;
    $25 = ($16|0)>($24|0);
    $26 = (($16) + -1)|0;
    $27 = (((($21)) + 16|0) + ($26<<4)|0);
    $28 = $25 ? 1568 : $27;
    $$0$i$i = $28;
   }
  }
 } while(0);
 $29 = HEAP32[$$0$i$i>>2]|0;
 $30 = (($n1) + -1)|0;
 $31 = (((($29)) + 16|0) + ($30<<2)|0);
 $32 = ($fidx2|0)>(0);
 do {
  if ($32) {
   $33 = HEAP32[$1>>2]|0;
   $34 = (($33) + ($fidx2<<4)|0);
   $35 = ((($L)) + 8|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($34>>>0)<($36>>>0);
   $$luaO_nilobject_$i$i2 = $37 ? $34 : 1568;
   $$0$i$i3 = $$luaO_nilobject_$i$i2;
  } else {
   $38 = ($fidx2|0)<(-1000999);
   if (!($38)) {
    $39 = ((($L)) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = (($40) + ($fidx2<<4)|0);
    $$0$i$i3 = $41;
    break;
   }
   $42 = ($fidx2|0)==(-1001000);
   if ($42) {
    $43 = ((($L)) + 12|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ((($44)) + 40|0);
    $$0$i$i3 = $45;
    break;
   }
   $46 = (-1001000 - ($fidx2))|0;
   $47 = HEAP32[$1>>2]|0;
   $48 = ((($47)) + 8|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ($49|0)==(22);
   if ($50) {
    $$0$i$i3 = 1568;
   } else {
    $51 = HEAP32[$47>>2]|0;
    $52 = ((($51)) + 6|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = ($46|0)>($54|0);
    $56 = (($46) + -1)|0;
    $57 = (((($51)) + 16|0) + ($56<<4)|0);
    $58 = $55 ? 1568 : $57;
    $$0$i$i3 = $58;
   }
  }
 } while(0);
 $59 = HEAP32[$$0$i$i3>>2]|0;
 $60 = (($n2) + -1)|0;
 $61 = (((($59)) + 16|0) + ($60<<2)|0);
 $62 = HEAP32[$31>>2]|0;
 _luaC_upvdeccount($L,$62);
 $63 = HEAP32[$61>>2]|0;
 HEAP32[$31>>2] = $63;
 $64 = ((($63)) + 4|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = (($65) + 1)|0;
 HEAP32[$64>>2] = $66;
 $67 = HEAP32[$63>>2]|0;
 $68 = ((($63)) + 8|0);
 $69 = ($67|0)==($68|0);
 if (!($69)) {
  $70 = ((($68)) + 4|0);
  HEAP32[$70>>2] = 1;
 }
 $71 = ((($67)) + 8|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = $72 & 64;
 $74 = ($73|0)!=(0);
 $75 = ((($63)) + 8|0);
 $76 = ($67|0)==($75|0);
 $or$cond = $76 & $74;
 if (!($or$cond)) {
  return;
 }
 _luaC_upvalbarrier_($L,$63);
 return;
}
function _growstack($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 _luaD_growstack($L,$0);
 return;
}
function _f_call($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 $1 = ((($ud)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 _luaD_call($L,$0,$2,0);
 return;
}
function _lua_sethook($L,$func,$mask,$count) {
 $L = $L|0;
 $func = $func|0;
 $mask = $mask|0;
 $count = $count|0;
 var $$func = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($func|0)==(0|0);
 $1 = ($mask|0)==(0);
 $or$cond = $0 | $1;
 $$func = $or$cond ? 0 : $func;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 34|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5 & 2;
 $7 = ($6<<24>>24)==(0);
 if (!($7)) {
  $8 = ((($3)) + 20|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($L)) + 20|0);
  HEAP32[$10>>2] = $9;
 }
 $11 = ((($L)) + 84|0);
 HEAP32[$11>>2] = $$func;
 $12 = ((($L)) + 96|0);
 HEAP32[$12>>2] = $count;
 $13 = ((($L)) + 100|0);
 HEAP32[$13>>2] = $count;
 $14 = $mask&255;
 $15 = $or$cond ? 0 : $14;
 $16 = ((($L)) + 108|0);
 HEAP8[$16>>0] = $15;
 return;
}
function _lua_gethook($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 return ($1|0);
}
function _lua_gethookmask($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 108|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 return ($2|0);
}
function _lua_gethookcount($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 return ($1|0);
}
function _lua_getstack($L,$level,$ar) {
 $L = $L|0;
 $level = $level|0;
 $ar = $ar|0;
 var $$0 = 0, $$01$lcssa = 0, $$014 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$0 = 0, $ci$0$lcssa = 0, $ci$03 = 0;
 var $ci$05 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)<(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = ((($L)) + 16|0);
 $ci$03 = HEAP32[$1>>2]|0;
 $2 = ($level|0)>(0);
 $3 = ((($L)) + 48|0);
 $4 = ($ci$03|0)!=($3|0);
 $5 = $2 & $4;
 if ($5) {
  $$014 = $level;$ci$05 = $ci$03;
  while(1) {
   $6 = (($$014) + -1)|0;
   $7 = ((($ci$05)) + 8|0);
   $ci$0 = HEAP32[$7>>2]|0;
   $8 = ($$014|0)>(1);
   $9 = ($ci$0|0)!=($3|0);
   $10 = $8 & $9;
   if ($10) {
    $$014 = $6;$ci$05 = $ci$0;
   } else {
    $$01$lcssa = $6;$ci$0$lcssa = $ci$0;
    break;
   }
  }
 } else {
  $$01$lcssa = $level;$ci$0$lcssa = $ci$03;
 }
 $11 = ($$01$lcssa|0)!=(0);
 $12 = ($ci$0$lcssa|0)==($3|0);
 $or$cond = $11 | $12;
 if ($or$cond) {
  $$0 = 0;
  return ($$0|0);
 }
 $13 = ((($ar)) + 96|0);
 HEAP32[$13>>2] = $ci$0$lcssa;
 $$0 = 1;
 return ($$0|0);
}
function _lua_getlocal($L,$ar,$n) {
 $L = $L|0;
 $ar = $ar|0;
 $n = $n|0;
 var $$0$i$ph = 0, $$in$i = 0, $$ph = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $8 = 0, $9 = 0, $base$02$i = 0, $base$03$i = 0, $name$0 = 0;
 var $name$1$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ar|0)==(0|0);
 if ($0) {
  $1 = ((($L)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ((($2)) + -8|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)==(70);
  if (!($5)) {
   $name$0 = 0;
   return ($name$0|0);
  }
  $6 = ((($2)) + -16|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 12|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = (_luaF_getlocalname($9,$n,0)|0);
  $name$0 = $10;
  return ($name$0|0);
 }
 $11 = ((($ar)) + 96|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ((($12)) + 34|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14 & 2;
 $16 = ($15<<24>>24)==(0);
 do {
  if ($16) {
   $35 = HEAP32[$12>>2]|0;
   $36 = ((($35)) + 16|0);
   $base$02$i = $36;
   label = 10;
  } else {
   $17 = ($n|0)<(0);
   if (!($17)) {
    $37 = ((($12)) + 16|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = HEAP32[$12>>2]|0;
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($40)) + 12|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = ((($12)) + 20|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = ((($42)) + 48|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = $44;
    $48 = $46;
    $49 = (($47) - ($48))|0;
    $50 = $49 >> 2;
    $51 = (($50) + -1)|0;
    $52 = (_luaF_getlocalname($42,$n,$51)|0);
    $53 = ($52|0)==(0|0);
    if ($53) {
     $base$02$i = $38;
     label = 10;
     break;
    } else {
     $base$03$i = $38;$name$1$i = $52;
     label = 14;
     break;
    }
   }
   $18 = (0 - ($n))|0;
   $19 = HEAP32[$12>>2]|0;
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($20)) + 12|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 6|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24&255;
   $26 = ((($12)) + 16|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $27;
   $29 = $19;
   $30 = (($28) - ($29))|0;
   $31 = $30 >> 4;
   $32 = (($31) - ($25))|0;
   $33 = ($32|0)>($18|0);
   if ($33) {
    $$sum$i$i = (($25) - ($n))|0;
    $34 = (($19) + ($$sum$i$i<<4)|0);
    $$0$i$ph = 888;$$ph = $34;
    break;
   } else {
    $name$0 = 0;
    return ($name$0|0);
   }
  }
 } while(0);
 if ((label|0) == 10) {
  $54 = ((($L)) + 16|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ($55|0)==($12|0);
  if ($56) {
   $57 = ((($L)) + 8|0);
   $$in$i = $57;
  } else {
   $58 = ((($12)) + 12|0);
   $59 = HEAP32[$58>>2]|0;
   $$in$i = $59;
  }
  $60 = HEAP32[$$in$i>>2]|0;
  $61 = $60;
  $62 = $base$02$i;
  $63 = (($61) - ($62))|0;
  $64 = $63 >> 4;
  $65 = ($64|0)>=($n|0);
  $66 = ($n|0)>(0);
  $or$cond$i = $66 & $65;
  if ($or$cond$i) {
   $base$03$i = $base$02$i;$name$1$i = 872;
   label = 14;
  } else {
   $name$0 = 0;
   return ($name$0|0);
  }
 }
 if ((label|0) == 14) {
  $67 = (($n) + -1)|0;
  $68 = (($base$03$i) + ($67<<4)|0);
  $$0$i$ph = $name$1$i;$$ph = $68;
 }
 $69 = ((($L)) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 ;HEAP32[$70>>2]=HEAP32[$$ph>>2]|0;HEAP32[$70+4>>2]=HEAP32[$$ph+4>>2]|0;HEAP32[$70+8>>2]=HEAP32[$$ph+8>>2]|0;HEAP32[$70+12>>2]=HEAP32[$$ph+12>>2]|0;
 $71 = HEAP32[$69>>2]|0;
 $72 = ((($71)) + 16|0);
 HEAP32[$69>>2] = $72;
 $name$0 = $$0$i$ph;
 return ($name$0|0);
}
function _lua_setlocal($L,$ar,$n) {
 $L = $L|0;
 $ar = $ar|0;
 $n = $n|0;
 var $$0$i$ph = 0, $$0$i1 = 0, $$in$i = 0, $$ph = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $base$02$i = 0, $base$03$i = 0, $name$1$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ar)) + 96|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 34|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 2;
 $5 = ($4<<24>>24)==(0);
 do {
  if ($5) {
   $24 = HEAP32[$1>>2]|0;
   $25 = ((($24)) + 16|0);
   $base$02$i = $25;
   label = 7;
  } else {
   $6 = ($n|0)<(0);
   if (!($6)) {
    $26 = ((($1)) + 16|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = HEAP32[$1>>2]|0;
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29)) + 12|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($1)) + 20|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($31)) + 48|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = $33;
    $37 = $35;
    $38 = (($36) - ($37))|0;
    $39 = $38 >> 2;
    $40 = (($39) + -1)|0;
    $41 = (_luaF_getlocalname($31,$n,$40)|0);
    $42 = ($41|0)==(0|0);
    if ($42) {
     $base$02$i = $27;
     label = 7;
     break;
    } else {
     $base$03$i = $27;$name$1$i = $41;
     label = 11;
     break;
    }
   }
   $7 = (0 - ($n))|0;
   $8 = HEAP32[$1>>2]|0;
   $9 = HEAP32[$8>>2]|0;
   $10 = ((($9)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + 6|0);
   $13 = HEAP8[$12>>0]|0;
   $14 = $13&255;
   $15 = ((($1)) + 16|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = $16;
   $18 = $8;
   $19 = (($17) - ($18))|0;
   $20 = $19 >> 4;
   $21 = (($20) - ($14))|0;
   $22 = ($21|0)>($7|0);
   if ($22) {
    $$sum$i$i = (($14) - ($n))|0;
    $23 = (($8) + ($$sum$i$i<<4)|0);
    $$0$i$ph = 888;$$ph = $23;
    break;
   } else {
    $$0$i1 = 0;
    return ($$0$i1|0);
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $43 = ((($L)) + 16|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==($1|0);
  if ($45) {
   $46 = ((($L)) + 8|0);
   $$in$i = $46;
  } else {
   $47 = ((($1)) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   $$in$i = $48;
  }
  $49 = HEAP32[$$in$i>>2]|0;
  $50 = $49;
  $51 = $base$02$i;
  $52 = (($50) - ($51))|0;
  $53 = $52 >> 4;
  $54 = ($53|0)>=($n|0);
  $55 = ($n|0)>(0);
  $or$cond$i = $55 & $54;
  if ($or$cond$i) {
   $base$03$i = $base$02$i;$name$1$i = 872;
   label = 11;
  } else {
   $$0$i1 = 0;
   return ($$0$i1|0);
  }
 }
 if ((label|0) == 11) {
  $56 = (($n) + -1)|0;
  $57 = (($base$03$i) + ($56<<4)|0);
  $$0$i$ph = $name$1$i;$$ph = $57;
 }
 $58 = ((($L)) + 8|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ((($59)) + -16|0);
 ;HEAP32[$$ph>>2]=HEAP32[$60>>2]|0;HEAP32[$$ph+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$$ph+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$$ph+12>>2]=HEAP32[$60+12>>2]|0;
 $61 = HEAP32[$58>>2]|0;
 $62 = ((($61)) + -16|0);
 HEAP32[$58>>2] = $62;
 $$0$i1 = $$0$i$ph;
 return ($$0$i1|0);
}
function _lua_getinfo($L,$what,$ar) {
 $L = $L|0;
 $what = $what|0;
 $ar = $ar|0;
 var $$0 = 0, $$01$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$0 = 0, $func$0 = 0, $i$01$i = 0, $status$0$lcssa$i = 0, $status$02$i = 0, $status$1$i = 0, $storemerge$ph$i = 0, $storemerge3$i = 0, $tm$0$i$i = 0, $v$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $v$i = sp;
 $0 = HEAP8[$what>>0]|0;
 $1 = ($0<<24>>24)==(62);
 if ($1) {
  $2 = ((($L)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($3)) + -16|0);
  $5 = ((($what)) + 1|0);
  HEAP32[$2>>2] = $4;
  $$0 = $5;$ci$0 = 0;$func$0 = $4;
 } else {
  $6 = ((($ar)) + 96|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$7>>2]|0;
  $$0 = $what;$ci$0 = $7;$func$0 = $8;
 }
 $9 = ((($func$0)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 31;
 $12 = ($11|0)==(6);
 if ($12) {
  $13 = HEAP32[$func$0>>2]|0;
  $17 = $13;
 } else {
  $17 = 0;
 }
 $14 = HEAP8[$$0>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L8: do {
  if ($15) {
   $status$0$lcssa$i = 1;
  } else {
   $16 = ($17|0)==(0|0);
   $18 = ((($ar)) + 16|0);
   $19 = ((($ar)) + 24|0);
   $20 = ((($ar)) + 28|0);
   $21 = ((($ar)) + 12|0);
   $22 = ((($ar)) + 36|0);
   $23 = ((($17)) + 4|0);
   $24 = ((($17)) + 12|0);
   $25 = ($ci$0|0)==(0|0);
   $26 = ((($ar)) + 20|0);
   $27 = ((($ci$0)) + 34|0);
   $28 = ((($ci$0)) + 20|0);
   $29 = ((($ar)) + 32|0);
   $30 = ((($ar)) + 34|0);
   $31 = ((($ar)) + 33|0);
   $32 = ((($17)) + 6|0);
   $33 = ((($ar)) + 35|0);
   $34 = ((($ar)) + 8|0);
   $35 = ((($ar)) + 4|0);
   $36 = ((($ci$0)) + 8|0);
   $37 = ((($L)) + 12|0);
   $$01$i = $$0;$39 = $14;$status$02$i = 1;
   while(1) {
    $38 = $39 << 24 >> 24;
    L12: do {
     switch ($38|0) {
     case 108:  {
      if ($25) {
       $75 = -1;
      } else {
       $55 = HEAP8[$27>>0]|0;
       $56 = $55 & 2;
       $57 = ($56<<24>>24)==(0);
       if ($57) {
        $75 = -1;
       } else {
        $58 = HEAP32[$ci$0>>2]|0;
        $59 = HEAP32[$58>>2]|0;
        $60 = ((($59)) + 12|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ((($61)) + 56|0);
        $63 = HEAP32[$62>>2]|0;
        $64 = ($63|0)==(0|0);
        if ($64) {
         $75 = -1;
        } else {
         $65 = HEAP32[$28>>2]|0;
         $66 = ((($61)) + 48|0);
         $67 = HEAP32[$66>>2]|0;
         $68 = $65;
         $69 = $67;
         $70 = (($68) - ($69))|0;
         $71 = $70 >> 2;
         $72 = (($71) + -1)|0;
         $73 = (($63) + ($72<<2)|0);
         $74 = HEAP32[$73>>2]|0;
         $75 = $74;
        }
       }
      }
      HEAP32[$26>>2] = $75;
      $status$1$i = $status$02$i;
      break;
     }
     case 116:  {
      if ($25) {
       $88 = 0;
      } else {
       $84 = HEAP8[$27>>0]|0;
       $85 = $84&255;
       $86 = $85 & 32;
       $88 = $86;
      }
      $87 = $88&255;
      HEAP8[$33>>0] = $87;
      $status$1$i = $status$02$i;
      break;
     }
     case 110:  {
      L24: do {
       if ($25) {
        label = 44;
       } else {
        $89 = HEAP8[$27>>0]|0;
        $90 = $89 & 32;
        $91 = ($90<<24>>24)==(0);
        if ($91) {
         $92 = HEAP32[$36>>2]|0;
         $93 = ((($92)) + 34|0);
         $94 = HEAP8[$93>>0]|0;
         $95 = $94 & 2;
         $96 = ($95<<24>>24)==(0);
         if ($96) {
          label = 44;
         } else {
          $97 = HEAP32[$92>>2]|0;
          $98 = HEAP32[$97>>2]|0;
          $99 = ((($98)) + 12|0);
          $100 = HEAP32[$99>>2]|0;
          $101 = ((($92)) + 20|0);
          $102 = HEAP32[$101>>2]|0;
          $103 = ((($100)) + 48|0);
          $104 = HEAP32[$103>>2]|0;
          $105 = $102;
          $106 = $104;
          $107 = (($105) - ($106))|0;
          $108 = $107 >> 2;
          $109 = (($108) + -1)|0;
          $110 = (($104) + ($109<<2)|0);
          $111 = HEAP32[$110>>2]|0;
          $112 = $94 & 4;
          $113 = ($112<<24>>24)==(0);
          L28: do {
           if ($113) {
            $114 = $111 & 63;
            do {
             switch ($114|0) {
             case 41:  {
              HEAP32[$35>>2] = 944;
              $storemerge$ph$i = 944;
              break L28;
              break;
             }
             case 10: case 8:  {
              $tm$0$i$i = 1;
              break;
             }
             case 24: case 23: case 22: case 21: case 20: case 19: case 18: case 17: case 16: case 15: case 14: case 13:  {
              $115 = (($114) + -7)|0;
              $tm$0$i$i = $115;
              break;
             }
             case 25:  {
              $tm$0$i$i = 18;
              break;
             }
             case 26:  {
              $tm$0$i$i = 19;
              break;
             }
             case 28:  {
              $tm$0$i$i = 4;
              break;
             }
             case 29:  {
              $tm$0$i$i = 22;
              break;
             }
             case 31:  {
              $tm$0$i$i = 5;
              break;
             }
             case 32:  {
              $tm$0$i$i = 20;
              break;
             }
             case 33:  {
              $tm$0$i$i = 21;
              break;
             }
             case 37: case 36:  {
              $120 = $111 >>> 6;
              $121 = $120 & 255;
              $122 = (_getobjname($100,$109,$121,$35)|0);
              HEAP32[$34>>2] = $122;
              $123 = ($122|0)==(0|0);
              if ($123) {
               break L24;
              } else {
               $status$1$i = $status$02$i;
               break L12;
              }
              break;
             }
             default: {
              $tm$0$i$i = 0;
             }
             }
            } while(0);
            $116 = HEAP32[$37>>2]|0;
            $117 = (((($116)) + 148|0) + ($tm$0$i$i<<2)|0);
            $118 = HEAP32[$117>>2]|0;
            $119 = ((($118)) + 24|0);
            HEAP32[$35>>2] = $119;
            $storemerge$ph$i = 960;
           } else {
            HEAP32[$35>>2] = 37376;
            $storemerge$ph$i = 976;
           }
          } while(0);
          HEAP32[$34>>2] = $storemerge$ph$i;
          $status$1$i = $status$02$i;
          break L12;
         }
        } else {
         label = 44;
        }
       }
      } while(0);
      if ((label|0) == 44) {
       label = 0;
       HEAP32[$34>>2] = 0;
      }
      HEAP32[$34>>2] = 37352;
      HEAP32[$35>>2] = 0;
      $status$1$i = $status$02$i;
      break;
     }
     case 117:  {
      if ($16) {
       HEAP8[$29>>0] = 0;
      } else {
       $76 = HEAP8[$32>>0]|0;
       HEAP8[$29>>0] = $76;
       $77 = HEAP8[$23>>0]|0;
       $78 = ($77<<24>>24)==(38);
       if (!($78)) {
        $79 = HEAP32[$24>>2]|0;
        $80 = ((($79)) + 7|0);
        $81 = HEAP8[$80>>0]|0;
        HEAP8[$30>>0] = $81;
        $82 = ((($79)) + 6|0);
        $83 = HEAP8[$82>>0]|0;
        HEAP8[$31>>0] = $83;
        $status$1$i = $status$02$i;
        break L12;
       }
      }
      HEAP8[$30>>0] = 1;
      HEAP8[$31>>0] = 0;
      $status$1$i = $status$02$i;
      break;
     }
     case 83:  {
      if ($16) {
       label = 11;
      } else {
       $40 = HEAP8[$23>>0]|0;
       $41 = ($40<<24>>24)==(38);
       if ($41) {
        label = 11;
       } else {
        $42 = HEAP32[$24>>2]|0;
        $43 = ((($42)) + 72|0);
        $44 = HEAP32[$43>>2]|0;
        $45 = ($44|0)==(0|0);
        $46 = ((($44)) + 24|0);
        $47 = $45 ? 912 : $46;
        HEAP32[$18>>2] = $47;
        $48 = ((($42)) + 36|0);
        $49 = HEAP32[$48>>2]|0;
        HEAP32[$19>>2] = $49;
        $50 = ((($42)) + 40|0);
        $51 = HEAP32[$50>>2]|0;
        HEAP32[$20>>2] = $51;
        $52 = ($49|0)==(0);
        $53 = $52 ? 920 : 928;
        $54 = $47;$storemerge3$i = $53;
       }
      }
      if ((label|0) == 11) {
       label = 0;
       HEAP32[$18>>2] = 904;
       HEAP32[$19>>2] = -1;
       HEAP32[$20>>2] = -1;
       $54 = 904;$storemerge3$i = 936;
      }
      HEAP32[$21>>2] = $storemerge3$i;
      _luaO_chunkid($22,$54,60);
      $status$1$i = $status$02$i;
      break;
     }
     case 102: case 76:  {
      $status$1$i = $status$02$i;
      break;
     }
     default: {
      $status$1$i = 0;
     }
     }
    } while(0);
    $124 = ((($$01$i)) + 1|0);
    $125 = HEAP8[$124>>0]|0;
    $126 = ($125<<24>>24)==(0);
    if ($126) {
     $status$0$lcssa$i = $status$1$i;
     break L8;
    } else {
     $$01$i = $124;$39 = $125;$status$02$i = $status$1$i;
    }
   }
  }
 } while(0);
 $127 = (_strchr($$0,102)|0);
 $128 = ($127|0)==(0|0);
 if (!($128)) {
  $129 = ((($L)) + 8|0);
  $130 = HEAP32[$129>>2]|0;
  ;HEAP32[$130>>2]=HEAP32[$func$0>>2]|0;HEAP32[$130+4>>2]=HEAP32[$func$0+4>>2]|0;HEAP32[$130+8>>2]=HEAP32[$func$0+8>>2]|0;HEAP32[$130+12>>2]=HEAP32[$func$0+12>>2]|0;
  $131 = HEAP32[$129>>2]|0;
  $132 = ((($131)) + 16|0);
  HEAP32[$129>>2] = $132;
 }
 $133 = (_strchr($$0,76)|0);
 $134 = ($133|0)==(0|0);
 if ($134) {
  STACKTOP = sp;return ($status$0$lcssa$i|0);
 }
 $135 = ($17|0)==(0|0);
 if ($135) {
  label = 55;
 } else {
  $136 = ((($17)) + 4|0);
  $137 = HEAP8[$136>>0]|0;
  $138 = ($137<<24>>24)==(38);
  if ($138) {
   label = 55;
  } else {
   $143 = ((($17)) + 12|0);
   $144 = HEAP32[$143>>2]|0;
   $145 = ((($144)) + 56|0);
   $146 = HEAP32[$145>>2]|0;
   $147 = (_luaH_new($L)|0);
   $148 = ((($L)) + 8|0);
   $149 = HEAP32[$148>>2]|0;
   HEAP32[$149>>2] = $147;
   $150 = ((($149)) + 8|0);
   HEAP32[$150>>2] = 69;
   $151 = HEAP32[$148>>2]|0;
   $152 = ((($151)) + 16|0);
   HEAP32[$148>>2] = $152;
   HEAP32[$v$i>>2] = 1;
   $153 = ((($v$i)) + 8|0);
   HEAP32[$153>>2] = 1;
   $154 = HEAP32[$143>>2]|0;
   $155 = ((($154)) + 24|0);
   $156 = HEAP32[$155>>2]|0;
   $157 = ($156|0)>(0);
   if ($157) {
    $i$01$i = 0;
    while(1) {
     $158 = (($146) + ($i$01$i<<2)|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ($159|0)<(0);
     $161 = $160 << 31 >> 31;
     _luaH_setint($L,$147,$159,$161,$v$i);
     $162 = (($i$01$i) + 1)|0;
     $163 = HEAP32[$143>>2]|0;
     $164 = ((($163)) + 24|0);
     $165 = HEAP32[$164>>2]|0;
     $166 = ($162|0)<($165|0);
     if ($166) {
      $i$01$i = $162;
     } else {
      break;
     }
    }
   }
  }
 }
 if ((label|0) == 55) {
  $139 = ((($L)) + 8|0);
  $140 = HEAP32[$139>>2]|0;
  $141 = ((($140)) + 8|0);
  HEAP32[$141>>2] = 0;
  $142 = ((($140)) + 16|0);
  HEAP32[$139>>2] = $142;
 }
 STACKTOP = sp;return ($status$0$lcssa$i|0);
}
function _luaG_typeerror($L,$o,$op) {
 $L = $L|0;
 $o = $o|0;
 $op = $op|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $3 = (($2) + 1)|0;
 $4 = (2872 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_varinfo($L,$o)|0);
 HEAP32[$vararg_buffer>>2] = $op;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $5;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $6;
 _luaG_runerror($L,984,$vararg_buffer);
 // unreachable;
}
function _luaG_runerror($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $argp = 0, $buff$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $buff$i = sp + 32|0;
 $argp = sp + 16|0;
 HEAP32[$argp>>2] = $varargs;
 $0 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 34|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 & 2;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  _luaG_errormsg($L);
  // unreachable;
 }
 $7 = HEAP32[$2>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($8)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($10)) + 56|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if ($13) {
  $30 = -1;
 } else {
  $14 = ((($2)) + 20|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($10)) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $15;
  $19 = $17;
  $20 = (($18) - ($19))|0;
  $21 = $20 >> 2;
  $22 = (($21) + -1)|0;
  $23 = (($12) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $30 = $24;
 }
 $25 = ((($10)) + 72|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ($26|0)==(0|0);
 if ($27) {
  HEAP8[$buff$i>>0] = 63;
  $29 = ((($buff$i)) + 1|0);
  HEAP8[$29>>0] = 0;
 } else {
  $28 = ((($26)) + 24|0);
  _luaO_chunkid($buff$i,$28,60);
 }
 HEAP32[$vararg_buffer>>2] = $buff$i;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $30;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $0;
 (_luaO_pushfstring($L,5672,$vararg_buffer)|0);
 _luaG_errormsg($L);
 // unreachable;
}
function _luaG_concaterror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$off = 0, $0 = 0, $1 = 0, $2 = 0, $p2$p1 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $$off = (($2) + -3)|0;
 $switch = ($$off>>>0)<(2);
 $p2$p1 = $switch ? $p2 : $p1;
 _luaG_typeerror($L,$p2$p1,1016);
 // unreachable;
}
function _luaG_opinterror($L,$p1,$p2,$msg) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $msg = $msg|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $p1$p2 = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(3);
 if ($2) {
  $3 = +HEAPF64[$p1>>3];
  HEAPF64[$temp>>3] = $3;
  $$0 = $p2;
  _luaG_typeerror($L,$$0,$msg);
  // unreachable;
 } else {
  $4 = (_luaV_tonumber_($p1,$temp)|0);
  $5 = ($4|0)==(0);
  $p1$p2 = $5 ? $p1 : $p2;
  $$0 = $p1$p2;
  _luaG_typeerror($L,$$0,$msg);
  // unreachable;
 }
}
function _luaG_tointerror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p1$p2 = 0, $temp = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 8|0;
 $temp = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $p1;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $temp;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $$0 = $p2;
 } else {
  $13 = (_luaV_tointeger_($p1,$temp)|0);
  $14 = ($13|0)==(0);
  $p1$p2 = $14 ? $p1 : $p2;
  $$0 = $p1$p2;
 }
 $15 = (_varinfo($L,$$0)|0);
 HEAP32[$vararg_buffer>>2] = $15;
 _luaG_runerror($L,1032,$vararg_buffer);
 // unreachable;
}
function _luaG_ordererror($L,$p1,$p2) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 $3 = (($2) + 1)|0;
 $4 = (2872 + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($p2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 15;
 $9 = (($8) + 1)|0;
 $10 = (2872 + ($9<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($5|0)==($11|0);
 if ($12) {
  HEAP32[$vararg_buffer>>2] = $5;
  _luaG_runerror($L,1072,$vararg_buffer);
  // unreachable;
 } else {
  HEAP32[$vararg_buffer1>>2] = $5;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $11;
  _luaG_runerror($L,1112,$vararg_buffer1);
  // unreachable;
 }
}
function _luaG_errormsg($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 88|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  _luaD_throw($L,2);
  // unreachable;
 }
 $3 = ((($L)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + ($1)|0);
 $6 = ((($L)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + -16|0);
 ;HEAP32[$7>>2]=HEAP32[$8>>2]|0;HEAP32[$7+4>>2]=HEAP32[$8+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$8+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$8+12>>2]|0;
 $9 = HEAP32[$6>>2]|0;
 $10 = ((($9)) + -16|0);
 ;HEAP32[$10>>2]=HEAP32[$5>>2]|0;HEAP32[$10+4>>2]=HEAP32[$5+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$5+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$5+12>>2]|0;
 $11 = HEAP32[$6>>2]|0;
 $12 = ((($11)) + 16|0);
 HEAP32[$6>>2] = $12;
 $13 = ((($11)) + -16|0);
 _luaD_call($L,$13,1,0);
 _luaD_throw($L,2);
 // unreachable;
}
function _luaG_traceexec($L) {
 $L = $L|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 8;
 $6 = ($5|0)==(0);
 if ($6) {
  $67 = 0;
 } else {
  $7 = ((($L)) + 100|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = ((($L)) + 96|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[$7>>2] = $11;
   $67 = 1;
  } else {
   $67 = 0;
  }
 }
 $12 = ((($1)) + 34|0);
 $13 = HEAP8[$12>>0]|0;
 $14 = $13&255;
 $15 = $14 & 64;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $17 = $14 & 191;
  $18 = $17&255;
  HEAP8[$12>>0] = $18;
  return;
 }
 if ($67) {
  _luaD_hook($L,3,-1);
 }
 $19 = $4 & 4;
 $20 = ($19|0)==(0);
 do {
  if ($20) {
   $$pre = ((($1)) + 20|0);
   $$pre$phi2Z2D = $$pre;$$pre$phiZ2D = $$pre;
  } else {
   $21 = HEAP32[$1>>2]|0;
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 12|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ((($1)) + 20|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = ((($24)) + 48|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = $26;
   $30 = $28;
   $31 = (($29) - ($30))|0;
   $32 = $31 >> 2;
   $33 = (($32) + -1)|0;
   $34 = ((($24)) + 56|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0|0);
   if ($36) {
    $50 = -1;
   } else {
    $37 = (($35) + ($33<<2)|0);
    $38 = HEAP32[$37>>2]|0;
    $50 = $38;
   }
   $39 = ($33|0)==(0);
   if (!($39)) {
    $40 = ((($L)) + 20|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ($26>>>0)>($41>>>0);
    if ($42) {
     if ($36) {
      $51 = -1;
     } else {
      $43 = $41;
      $44 = (($43) - ($30))|0;
      $45 = $44 >> 2;
      $46 = (($45) + -1)|0;
      $47 = (($35) + ($46<<2)|0);
      $48 = HEAP32[$47>>2]|0;
      $51 = $48;
     }
     $49 = ($50|0)==($51|0);
     if ($49) {
      $$pre$phi2Z2D = $25;$$pre$phiZ2D = $25;
      break;
     }
    }
   }
   _luaD_hook($L,2,$50);
   $$pre$phi2Z2D = $25;$$pre$phiZ2D = $25;
  }
 } while(0);
 $52 = HEAP32[$$pre$phiZ2D>>2]|0;
 $53 = ((($L)) + 20|0);
 HEAP32[$53>>2] = $52;
 $54 = ((($L)) + 6|0);
 $55 = HEAP8[$54>>0]|0;
 $56 = ($55<<24>>24)==(1);
 $57 = $52;
 if (!($56)) {
  return;
 }
 if (!($67)) {
  $59 = ((($57)) + -4|0);
  HEAP32[$$pre$phi2Z2D>>2] = $59;
  $60 = HEAP8[$12>>0]|0;
  $61 = $60&255;
  $62 = $61 | 64;
  $63 = $62&255;
  HEAP8[$12>>0] = $63;
  $64 = ((($L)) + 8|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ((($65)) + -16|0);
  HEAP32[$1>>2] = $66;
  _luaD_throw($L,1);
  // unreachable;
 }
 $58 = ((($L)) + 100|0);
 HEAP32[$58>>2] = 1;
 $59 = ((($57)) + -4|0);
 HEAP32[$$pre$phi2Z2D>>2] = $59;
 $60 = HEAP8[$12>>0]|0;
 $61 = $60&255;
 $62 = $61 | 64;
 $63 = $62&255;
 HEAP8[$12>>0] = $63;
 $64 = ((($L)) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = ((($65)) + -16|0);
 HEAP32[$1>>2] = $66;
 _luaD_throw($L,1);
 // unreachable;
}
function _getobjname($p,$lastpc,$reg,$name) {
 $p = $p|0;
 $lastpc = $lastpc|0;
 $reg = $reg|0;
 $name = $name|0;
 var $$0 = 0, $$0$i = 0, $$0$i2 = 0, $$jmptarget$0$i = 0, $$lcssa = 0, $$lcssa101 = 0, $$lcssa96 = 0, $$lcssa97 = 0, $$lcssa98 = 0, $$lcssa99 = 0, $$pc$i$i = 0, $$pc$i3$i = 0, $$pc$i4$i = 0, $$pc$i5$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $exitcond$i = 0, $jmptarget$06$i = 0, $jmptarget$1$i = 0, $lastpc$tr = 0, $notlhs$i = 0, $notrhs$i = 0, $or$cond$not$i = 0, $or$cond1$i = 0, $or$cond2$i = 0, $p$idx = 0, $p$idx$val = 0, $p$idx1 = 0, $p$idx1$val = 0, $pc$08$i = 0, $phitmp = 0, $reg$tr = 0, $setreg$07$i = 0, $setreg$1$i = 0;
 var $setreg$1$i$lcssa = 0, $setreg$1$i$lcssa$lcssa = 0, $setreg$1$i$lcssa$lcssa90 = 0, $setreg$1$i$lcssa$lcssa92 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p)) + 48|0);
 $lastpc$tr = $lastpc;$reg$tr = $reg;
 L1: while(1) {
  $1 = (($reg$tr) + 1)|0;
  $2 = (_luaF_getlocalname($p,$1,$lastpc$tr)|0);
  HEAP32[$name>>2] = $2;
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $$0 = 5776;
   label = 42;
   break;
  }
  $4 = ($lastpc$tr|0)>(0);
  if (!($4)) {
   $$0 = 0;
   label = 42;
   break;
  }
  $5 = HEAP32[$0>>2]|0;
  $jmptarget$06$i = 0;$pc$08$i = 0;$setreg$07$i = -1;
  while(1) {
   $6 = (($5) + ($pc$08$i<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = $7 & 63;
   $9 = $7 >>> 6;
   $10 = $9 & 255;
   switch ($8|0) {
   case 4:  {
    $11 = ($10|0)>($reg$tr|0);
    if ($11) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $12 = $7 >>> 23;
     $13 = (($10) + ($12))|0;
     $14 = ($13|0)<($reg$tr|0);
     if ($14) {
      $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
     } else {
      $15 = ($pc$08$i|0)<($jmptarget$06$i|0);
      $$pc$i$i = $15 ? -1 : $pc$08$i;
      $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i$i;
     }
    }
    break;
   }
   case 30:  {
    $21 = $7 >>> 14;
    $22 = (($pc$08$i) + -131070)|0;
    $23 = (($22) + ($21))|0;
    $notlhs$i = ($pc$08$i|0)<($23|0);
    $notrhs$i = ($23|0)<=($lastpc$tr|0);
    $or$cond$not$i = $notrhs$i & $notlhs$i;
    $24 = ($23|0)>($jmptarget$06$i|0);
    $or$cond1$i = $24 & $or$cond$not$i;
    $$jmptarget$0$i = $or$cond1$i ? $23 : $jmptarget$06$i;
    $jmptarget$1$i = $$jmptarget$0$i;$setreg$1$i = $setreg$07$i;
    break;
   }
   case 41:  {
    $16 = (($10) + 2)|0;
    $17 = ($16|0)>($reg$tr|0);
    if ($17) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $18 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i5$i = $18 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i5$i;
    }
    break;
   }
   case 37: case 36:  {
    $19 = ($10|0)>($reg$tr|0);
    if ($19) {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    } else {
     $20 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i4$i = $20 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i4$i;
    }
    break;
   }
   default: {
    $25 = (1960 + ($8)|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = $26 & 64;
    $28 = ($27<<24>>24)!=(0);
    $29 = ($10|0)==($reg$tr|0);
    $or$cond2$i = $29 & $28;
    if ($or$cond2$i) {
     $30 = ($pc$08$i|0)<($jmptarget$06$i|0);
     $$pc$i3$i = $30 ? -1 : $pc$08$i;
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $$pc$i3$i;
    } else {
     $jmptarget$1$i = $jmptarget$06$i;$setreg$1$i = $setreg$07$i;
    }
   }
   }
   $31 = (($pc$08$i) + 1)|0;
   $exitcond$i = ($31|0)==($lastpc$tr|0);
   if ($exitcond$i) {
    $setreg$1$i$lcssa = $setreg$1$i;
    break;
   } else {
    $jmptarget$06$i = $jmptarget$1$i;$pc$08$i = $31;$setreg$07$i = $setreg$1$i;
   }
  }
  $32 = ($setreg$1$i$lcssa|0)==(-1);
  if ($32) {
   $$0 = 0;
   label = 42;
   break;
  }
  $33 = (($5) + ($setreg$1$i$lcssa<<2)|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = $34 & 63;
  switch ($35|0) {
  case 7: case 6:  {
   $$lcssa = $34;$$lcssa101 = $35;$setreg$1$i$lcssa$lcssa = $setreg$1$i$lcssa;
   label = 20;
   break L1;
   break;
  }
  case 12:  {
   $$lcssa98 = $34;$setreg$1$i$lcssa$lcssa90 = $setreg$1$i$lcssa;
   label = 36;
   break L1;
   break;
  }
  case 0:  {
   break;
  }
  case 5:  {
   $$lcssa97 = $34;
   label = 31;
   break L1;
   break;
  }
  case 1:  {
   $$lcssa99 = $34;
   label = 32;
   break L1;
   break;
  }
  case 2:  {
   $$lcssa96 = $5;$setreg$1$i$lcssa$lcssa92 = $setreg$1$i$lcssa;
   label = 33;
   break L1;
   break;
  }
  default: {
   $$0 = 0;
   label = 42;
   break L1;
  }
  }
  $36 = $34 >>> 23;
  $37 = $34 >>> 6;
  $38 = $37 & 255;
  $39 = ($36>>>0)<($38>>>0);
  if ($39) {
   $lastpc$tr = $setreg$1$i$lcssa;$reg$tr = $36;
  } else {
   $$0 = 0;
   label = 42;
   break;
  }
 }
 if ((label|0) == 20) {
  $40 = $$lcssa >>> 14;
  $41 = $40 & 511;
  $42 = $$lcssa >>> 23;
  $43 = ($$lcssa101|0)==(7);
  if ($43) {
   $44 = (($42) + 1)|0;
   $45 = (_luaF_getlocalname($p,$44,$setreg$1$i$lcssa$lcssa)|0);
   $67 = $45;
  } else {
   $p$idx1 = ((($p)) + 64|0);
   $p$idx1$val = HEAP32[$p$idx1>>2]|0;
   $46 = (($p$idx1$val) + ($42<<3)|0);
   $47 = HEAP32[$46>>2]|0;
   $48 = ($47|0)==(0|0);
   $49 = ((($47)) + 24|0);
   $$0$i2 = $48 ? 37376 : $49;
   $67 = $$0$i2;
  }
  $50 = $40 & 256;
  $51 = ($50|0)==(0);
  if ($51) {
   $62 = (_getobjname($p,$setreg$1$i$lcssa$lcssa,$41,$name)|0);
   $63 = ($62|0)==(0|0);
   if ($63) {
    label = 28;
   } else {
    $64 = HEAP8[$62>>0]|0;
    $65 = ($64<<24>>24)==(99);
    if (!($65)) {
     label = 28;
    }
   }
  } else {
   $52 = $40 & 255;
   $53 = ((($p)) + 44|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (((($54) + ($52<<4)|0)) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = $56 & 15;
   $58 = ($57|0)==(4);
   if ($58) {
    $59 = (($54) + ($52<<4)|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ((($60)) + 24|0);
    HEAP32[$name>>2] = $61;
   } else {
    label = 28;
   }
  }
  if ((label|0) == 28) {
   HEAP32[$name>>2] = 37376;
  }
  $66 = ($67|0)==(0|0);
  if ($66) {
   $$0 = 1176;
   return ($$0|0);
  }
  $68 = (_strcmp($67,5128)|0);
  $69 = ($68|0)==(0);
  $phitmp = $69 ? 1168 : 1176;
  $$0 = $phitmp;
  return ($$0|0);
 }
 else if ((label|0) == 31) {
  $70 = $$lcssa97 >>> 23;
  $p$idx = ((($p)) + 64|0);
  $p$idx$val = HEAP32[$p$idx>>2]|0;
  $71 = (($p$idx$val) + ($70<<3)|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = ($72|0)==(0|0);
  $74 = ((($72)) + 24|0);
  $$0$i = $73 ? 37376 : $74;
  HEAP32[$name>>2] = $$0$i;
  $$0 = 1144;
  return ($$0|0);
 }
 else if ((label|0) == 32) {
  $75 = $$lcssa99 >>> 14;
  $83 = $75;
 }
 else if ((label|0) == 33) {
  $76 = (($setreg$1$i$lcssa$lcssa92) + 1)|0;
  $77 = (($$lcssa96) + ($76<<2)|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = $78 >>> 6;
  $83 = $79;
 }
 else if ((label|0) == 36) {
  $90 = $$lcssa98 >>> 14;
  $91 = $90 & 256;
  $92 = ($91|0)==(0);
  if ($92) {
   $103 = $90 & 511;
   $104 = (_getobjname($p,$setreg$1$i$lcssa$lcssa90,$103,$name)|0);
   $105 = ($104|0)==(0|0);
   if (!($105)) {
    $106 = HEAP8[$104>>0]|0;
    $107 = ($106<<24>>24)==(99);
    if ($107) {
     $$0 = 4056;
     return ($$0|0);
    }
   }
  } else {
   $93 = $90 & 255;
   $94 = ((($p)) + 44|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = (((($95) + ($93<<4)|0)) + 8|0);
   $97 = HEAP32[$96>>2]|0;
   $98 = $97 & 15;
   $99 = ($98|0)==(4);
   if ($99) {
    $100 = (($95) + ($93<<4)|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = ((($101)) + 24|0);
    HEAP32[$name>>2] = $102;
    $$0 = 4056;
    return ($$0|0);
   }
  }
  HEAP32[$name>>2] = 37376;
  $$0 = 4056;
  return ($$0|0);
 }
 else if ((label|0) == 42) {
  return ($$0|0);
 }
 $80 = ((($p)) + 44|0);
 $81 = HEAP32[$80>>2]|0;
 $82 = (((($81) + ($83<<4)|0)) + 8|0);
 $84 = HEAP32[$82>>2]|0;
 $85 = $84 & 15;
 $86 = ($85|0)==(4);
 if (!($86)) {
  $$0 = 0;
  return ($$0|0);
 }
 $87 = (($81) + ($83<<4)|0);
 $88 = HEAP32[$87>>2]|0;
 $89 = ((($88)) + 24|0);
 HEAP32[$name>>2] = $89;
 $$0 = 1184;
 return ($$0|0);
}
function _varinfo($L,$o) {
 $L = $L|0;
 $o = $o|0;
 var $$0$i$i = 0, $$idx$i = 0, $$idx$val$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$i = 0, $i$02$i$lcssa = 0, $kind$03 = 0, $name = 0;
 var $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $name = sp + 8|0;
 HEAP32[$name>>2] = 0;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 34|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 2;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $51 = 37352;
  STACKTOP = sp;return ($51|0);
 }
 $6 = HEAP32[$1>>2]|0;
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($7)) + 6|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 L4: do {
  if ($10) {
   label = 7;
  } else {
   $11 = $9&255;
   $i$02$i = 0;
   while(1) {
    $12 = (((($7)) + 16|0) + ($i$02$i<<2)|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==($o|0);
    if ($15) {
     $i$02$i$lcssa = $i$02$i;
     break;
    }
    $16 = (($i$02$i) + 1)|0;
    $17 = ($16|0)<($11|0);
    if ($17) {
     $i$02$i = $16;
    } else {
     label = 7;
     break L4;
    }
   }
   $18 = ((($7)) + 12|0);
   $19 = HEAP32[$18>>2]|0;
   $$idx$i = ((($19)) + 64|0);
   $$idx$val$i = HEAP32[$$idx$i>>2]|0;
   $20 = (($$idx$val$i) + ($i$02$i$lcssa<<3)|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   $23 = ((($21)) + 24|0);
   $$0$i$i = $22 ? 37376 : $23;
   HEAP32[$name>>2] = $$0$i$i;
   $49 = $$0$i$i;$kind$03 = 1144;
  }
 } while(0);
 do {
  if ((label|0) == 7) {
   $24 = ((($1)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $o;
   $27 = $25;
   $28 = (($26) - ($27))|0;
   $29 = ($28|0)>(-16);
   if (!($29)) {
    $51 = 37352;
    STACKTOP = sp;return ($51|0);
   }
   $30 = ((($1)) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31;
   $33 = (($32) - ($27))|0;
   $34 = ($28|0)<($33|0);
   if (!($34)) {
    $51 = 37352;
    STACKTOP = sp;return ($51|0);
   }
   $35 = ((($7)) + 12|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($1)) + 20|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($36)) + 48|0);
   $40 = HEAP32[$39>>2]|0;
   $41 = $38;
   $42 = $40;
   $43 = (($41) - ($42))|0;
   $44 = $43 >> 2;
   $45 = (($44) + -1)|0;
   $46 = $28 >> 4;
   $47 = (_getobjname($36,$45,$46,$name)|0);
   $48 = ($47|0)==(0|0);
   if ($48) {
    $51 = 37352;
    STACKTOP = sp;return ($51|0);
   } else {
    $$pre = HEAP32[$name>>2]|0;
    $49 = $$pre;$kind$03 = $47;
    break;
   }
  }
 } while(0);
 HEAP32[$vararg_buffer>>2] = $kind$03;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $49;
 $50 = (_luaO_pushfstring($L,1152,$vararg_buffer)|0);
 $51 = $50;
 STACKTOP = sp;return ($51|0);
}
function _luaD_throw($L,$errcode) {
 $L = $L|0;
 $errcode = $errcode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 44|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 160|0);
  HEAP32[$3>>2] = $errcode;
  $4 = HEAP32[$0>>2]|0;
  $5 = ((($4)) + 4|0);
  _longjmp(($5|0),1);
  // unreachable;
 }
 $6 = ((($L)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $errcode&255;
 $9 = ((($L)) + 6|0);
 HEAP8[$9>>0] = $8;
 $10 = ((($7)) + 136|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($11)) + 44|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = ((($11)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + 16|0);
  HEAP32[$15>>2] = $17;
  $18 = ((($L)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($19)) + -16|0);
  ;HEAP32[$16>>2]=HEAP32[$20>>2]|0;HEAP32[$16+4>>2]=HEAP32[$20+4>>2]|0;HEAP32[$16+8>>2]=HEAP32[$20+8>>2]|0;HEAP32[$16+12>>2]=HEAP32[$20+12>>2]|0;
  $21 = HEAP32[$10>>2]|0;
  _luaD_throw($21,$errcode);
  // unreachable;
 }
 $22 = ((($7)) + 132|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  _abort();
  // unreachable;
 }
 $25 = ((($L)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 if ((($errcode|0) == 6)) {
  $34 = (_luaS_newlstr($L,1200,23)|0);
  HEAP32[$26>>2] = $34;
  $35 = ((($34)) + 4|0);
  $36 = HEAP8[$35>>0]|0;
  $37 = $36&255;
  $38 = $37 | 64;
  $39 = ((($26)) + 8|0);
  HEAP32[$39>>2] = $38;
 } else if ((($errcode|0) == 4)) {
  $27 = ((($7)) + 144|0);
  $28 = HEAP32[$27>>2]|0;
  HEAP32[$26>>2] = $28;
  $29 = ((($28)) + 4|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = $31 | 64;
  $33 = ((($26)) + 8|0);
  HEAP32[$33>>2] = $32;
 } else {
  $40 = ((($26)) + -16|0);
  ;HEAP32[$26>>2]=HEAP32[$40>>2]|0;HEAP32[$26+4>>2]=HEAP32[$40+4>>2]|0;HEAP32[$26+8>>2]=HEAP32[$40+8>>2]|0;HEAP32[$26+12>>2]=HEAP32[$40+12>>2]|0;
 }
 $41 = ((($26)) + 16|0);
 HEAP32[$25>>2] = $41;
 $42 = ((($L)) + 16|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ((($43)) + 4|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = ($45>>>0)<($41>>>0);
 if ($46) {
  HEAP32[$44>>2] = $41;
 }
 $47 = HEAP32[$22>>2]|0;
 (FUNCTION_TABLE_ii[$47 & 511]($L)|0);
 _abort();
 // unreachable;
}
function _luaD_rawrunprotected($L,$f,$ud) {
 $L = $L|0;
 $f = $f|0;
 $ud = $ud|0;
 var $$reg2mem22$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $cond1 = 0, $lj = 0, _setjmpTable = 0;
 var _setjmpTableSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 _setjmpTableSize = 4;_setjmpTable = _malloc(40) | 0;HEAP32[_setjmpTable>>2]=0;
 $lj = sp;
 $0 = ((($L)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ((($lj)) + 160|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($L)) + 44|0);
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$lj>>2] = $4;
 HEAP32[$3>>2] = $lj;
 $5 = ((($lj)) + 4|0);
 _setjmpTable = _saveSetjmp($5,1,_setjmpTable|0,_setjmpTableSize|0)|0;_setjmpTableSize = tempRet0;
 __THREW__ = 0;
 $6 = __THREW__; __THREW__ = 0;
 if ((($6|0) != 0) & ((threwValue|0) != 0)) { $7 = _testSetjmp(HEAP32[$6>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($7|0) == 0) { _longjmp($6|0, threwValue|0); } tempRet0 = (threwValue); } else { $7 = -1; };
 $8 = tempRet0;
 $cond = ($7|0)==(1);
 if ($cond) {
  $$reg2mem22$0 = $8;
 } else {
  $$reg2mem22$0 = 0;
 }
 while(1) {
  $9 = ($$reg2mem22$0|0)==(0);
  if (!($9)) {
   label = 6;
   break;
  }
  __THREW__ = 0;
  invoke_vii($f|0,($L|0),($ud|0));
  $10 = __THREW__; __THREW__ = 0;
  if ((($10|0) != 0) & ((threwValue|0) != 0)) { $11 = _testSetjmp(HEAP32[$10>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($11|0) == 0) { _longjmp($10|0, threwValue|0); } tempRet0 = (threwValue); } else { $11 = -1; };
  $12 = tempRet0;
  $cond1 = ($11|0)==(1);
  if ($cond1) {
   $$reg2mem22$0 = $12;
  } else {
   break;
  }
 }
 if ((label|0) == 6) {
  $13 = HEAP32[$lj>>2]|0;
  HEAP32[$3>>2] = $13;
  HEAP16[$0>>1] = $1;
  $14 = HEAP32[$2>>2]|0;
  _free(_setjmpTable|0);
  STACKTOP = sp;return ($14|0);
 }
 $13 = HEAP32[$lj>>2]|0;
 HEAP32[$3>>2] = $13;
 HEAP16[$0>>1] = $1;
 $14 = HEAP32[$2>>2]|0;
 _free(_setjmpTable|0);
 STACKTOP = sp;return ($14|0);
}
function _luaD_reallocstack($L,$newsize) {
 $L = $L|0;
 $newsize = $newsize|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$0$i = 0, $ci$01$i = 0, $ci$02$i = 0, $exitcond = 0;
 var $lim$01 = 0, $up$0$i = 0, $up$03$i = 0, $up$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 92|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($newsize) + 1)|0;
 $5 = ($4>>>0)>(268435455);
 if ($5) {
  _luaM_toobig($L);
  // unreachable;
 }
 $6 = $3 << 4;
 $7 = $newsize << 4;
 $8 = (_luaM_realloc_($L,$1,$6,$7)|0);
 HEAP32[$0>>2] = $8;
 $9 = ($3|0)<($newsize|0);
 if ($9) {
  $lim$01 = $3;
  while(1) {
   $10 = (((($8) + ($lim$01<<4)|0)) + 8|0);
   HEAP32[$10>>2] = 0;
   $11 = (($lim$01) + 1)|0;
   $exitcond = ($11|0)==($newsize|0);
   if ($exitcond) {
    break;
   } else {
    $lim$01 = $11;
   }
  }
 }
 HEAP32[$2>>2] = $newsize;
 $$sum = (($newsize) + -5)|0;
 $12 = (($8) + ($$sum<<4)|0);
 $13 = ((($L)) + 24|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($L)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15;
 $17 = $1;
 $18 = (($16) - ($17))|0;
 $19 = $18 >> 4;
 $20 = (($8) + ($19<<4)|0);
 HEAP32[$14>>2] = $20;
 $21 = ((($L)) + 32|0);
 $up$03$i = HEAP32[$21>>2]|0;
 $22 = ($up$03$i|0)==(0|0);
 if (!($22)) {
  $up$04$i = $up$03$i;
  while(1) {
   $23 = HEAP32[$up$04$i>>2]|0;
   $24 = $23;
   $25 = (($24) - ($17))|0;
   $26 = $25 >> 4;
   $27 = (($8) + ($26<<4)|0);
   HEAP32[$up$04$i>>2] = $27;
   $28 = ((($up$04$i)) + 8|0);
   $up$0$i = HEAP32[$28>>2]|0;
   $29 = ($up$0$i|0)==(0|0);
   if ($29) {
    break;
   } else {
    $up$04$i = $up$0$i;
   }
  }
 }
 $30 = ((($L)) + 16|0);
 $ci$01$i = HEAP32[$30>>2]|0;
 $31 = ($ci$01$i|0)==(0|0);
 if ($31) {
  return;
 } else {
  $ci$02$i = $ci$01$i;
 }
 while(1) {
  $32 = ((($ci$02$i)) + 4|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = $33;
  $35 = (($34) - ($17))|0;
  $36 = $35 >> 4;
  $37 = (($8) + ($36<<4)|0);
  HEAP32[$32>>2] = $37;
  $38 = HEAP32[$ci$02$i>>2]|0;
  $39 = $38;
  $40 = (($39) - ($17))|0;
  $41 = $40 >> 4;
  $42 = (($8) + ($41<<4)|0);
  HEAP32[$ci$02$i>>2] = $42;
  $43 = ((($ci$02$i)) + 34|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44 & 2;
  $46 = ($45<<24>>24)==(0);
  if (!($46)) {
   $47 = ((($ci$02$i)) + 16|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = $48;
   $50 = (($49) - ($17))|0;
   $51 = $50 >> 4;
   $52 = (($8) + ($51<<4)|0);
   HEAP32[$47>>2] = $52;
  }
  $53 = ((($ci$02$i)) + 8|0);
  $ci$0$i = HEAP32[$53>>2]|0;
  $54 = ($ci$0$i|0)==(0|0);
  if ($54) {
   break;
  } else {
   $ci$02$i = $ci$0$i;
  }
 }
 return;
}
function _luaD_growstack($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$ = 0, $$$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 92|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(1000000);
 if ($2) {
  _luaD_throw($L,6);
  // unreachable;
 }
 $3 = ((($L)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($L)) + 28|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $4;
 $8 = $6;
 $9 = (($7) - ($8))|0;
 $10 = $9 >> 4;
 $11 = (($n) + 5)|0;
 $12 = (($11) + ($10))|0;
 $13 = $1 << 1;
 $14 = ($13|0)>(1000000);
 $$ = $14 ? 1000000 : $13;
 $15 = ($$|0)<($12|0);
 $$$ = $15 ? $12 : $$;
 $16 = ($$$|0)>(1000000);
 if ($16) {
  _luaD_reallocstack($L,1000200);
  _luaG_runerror($L,4208,$vararg_buffer);
  // unreachable;
 } else {
  _luaD_reallocstack($L,$$$);
  STACKTOP = sp;return;
 }
}
function _luaD_shrinkstack($L) {
 $L = $L|0;
 var $$ = 0, $$lim$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$0$i = 0, $ci$01$i = 0, $ci$03$i = 0, $lim$0$lcssa$i = 0, $lim$02$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 16|0);
 $ci$01$i = HEAP32[$2>>2]|0;
 $3 = ($ci$01$i|0)==(0|0);
 if ($3) {
  $lim$0$lcssa$i = $1;
 } else {
  $ci$03$i = $ci$01$i;$lim$02$i = $1;
  while(1) {
   $4 = ((($ci$03$i)) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($lim$02$i>>>0)<($5>>>0);
   $$lim$0$i = $6 ? $5 : $lim$02$i;
   $7 = ((($ci$03$i)) + 8|0);
   $ci$0$i = HEAP32[$7>>2]|0;
   $8 = ($ci$0$i|0)==(0|0);
   if ($8) {
    $lim$0$lcssa$i = $$lim$0$i;
    break;
   } else {
    $ci$03$i = $ci$0$i;$lim$02$i = $$lim$0$i;
   }
  }
 }
 $9 = ((($L)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $lim$0$lcssa$i;
 $12 = $10;
 $13 = (($11) - ($12))|0;
 $14 = $13 >> 4;
 $15 = (($14) + 1)|0;
 $16 = (($15|0) / 8)&-1;
 $17 = (($16) + 10)|0;
 $18 = (($17) + ($15))|0;
 $19 = ($18|0)>(1000000);
 $$ = $19 ? 1000000 : $18;
 $20 = ((($L)) + 92|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)>(1000000);
 if ($22) {
  _luaE_freeCI($L);
 } else {
  _luaE_shrinkCI($L);
 }
 $23 = ($13|0)>(15999984);
 if ($23) {
  return;
 }
 $24 = HEAP32[$20>>2]|0;
 $25 = ($$|0)<($24|0);
 if (!($25)) {
  return;
 }
 _luaD_reallocstack($L,$$);
 return;
}
function _luaD_hook($L,$event,$line) {
 $L = $L|0;
 $event = $event|0;
 $line = $line|0;
 var $$$$i = 0, $$$i = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ar = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ar = sp + 4|0;
 $0 = ((($L)) + 84|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  STACKTOP = sp;return;
 }
 $3 = ((($L)) + 109|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  STACKTOP = sp;return;
 }
 $6 = ((($L)) + 16|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($L)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ((($L)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $9;
 $13 = $11;
 $14 = (($12) - ($13))|0;
 $15 = ((($7)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $16;
 $18 = (($17) - ($13))|0;
 HEAP32[$ar>>2] = $event;
 $19 = ((($ar)) + 20|0);
 HEAP32[$19>>2] = $line;
 $20 = ((($ar)) + 96|0);
 HEAP32[$20>>2] = $7;
 $21 = ((($L)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22;
 $24 = $9;
 $25 = (($23) - ($24))|0;
 $26 = ($25|0)<(336);
 do {
  if ($26) {
   $27 = ((($L)) + 92|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)>(1000000);
   if ($29) {
    _luaD_throw($L,6);
    // unreachable;
   }
   $30 = $11;
   $31 = (($24) - ($30))|0;
   $32 = $31 >> 4;
   $33 = (($32) + 25)|0;
   $34 = $28 << 1;
   $35 = ($34|0)>(1000000);
   $$$i = $35 ? 1000000 : $34;
   $36 = ($$$i|0)<($33|0);
   $$$$i = $36 ? $33 : $$$i;
   $37 = ($$$$i|0)>(1000000);
   if ($37) {
    _luaD_reallocstack($L,1000200);
    _luaG_runerror($L,4208,$vararg_buffer);
    // unreachable;
   } else {
    _luaD_reallocstack($L,$$$$i);
    $$pre = HEAP32[$8>>2]|0;
    $39 = $$pre;
    break;
   }
  } else {
   $39 = $9;
  }
 } while(0);
 $38 = ((($39)) + 320|0);
 HEAP32[$15>>2] = $38;
 HEAP8[$3>>0] = 0;
 $40 = ((($7)) + 34|0);
 $41 = HEAP8[$40>>0]|0;
 $42 = $41&255;
 $43 = $42 | 4;
 $44 = $43&255;
 HEAP8[$40>>0] = $44;
 FUNCTION_TABLE_vii[$1 & 511]($L,$ar);
 HEAP8[$3>>0] = 1;
 $45 = HEAP32[$10>>2]|0;
 $46 = (($45) + ($18)|0);
 HEAP32[$15>>2] = $46;
 $47 = (($45) + ($14)|0);
 HEAP32[$8>>2] = $47;
 $48 = HEAP8[$40>>0]|0;
 $49 = $48&255;
 $50 = $49 & 251;
 $51 = $50&255;
 HEAP8[$40>>0] = $51;
 STACKTOP = sp;return;
}
function _luaD_precall($L,$func,$nresults) {
 $L = $L|0;
 $func = $func|0;
 $nresults = $nresults|0;
 var $$$$i = 0, $$$$i$i = 0, $$$$i10 = 0, $$$$i4 = 0, $$$i = 0, $$$i$i = 0, $$$i3 = 0, $$$i9 = 0, $$0 = 0, $$0$i = 0, $$01$in = 0, $$1$i = 0, $$25$i = 0, $$idx2$val = 0, $$lcssa158 = 0, $$lcssa159 = 0, $$lcssa160 = 0, $$lcssa166 = 0, $$lcssa170 = 0, $$lcssa171 = 0;
 var $$lcssa172 = 0, $$lcssa176 = 0, $$phi$trans$insert$i = 0, $$pn = 0, $$pre = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i6 = 0, $$pre3$i = 0, $$promoted = 0, $$sum = 0, $$sum$i = 0, $$sum$i47 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $base$0 = 0;
 var $exitcond$i = 0, $exitcond$i48 = 0, $f$0 = 0, $f$0$in = 0, $func$tr = 0, $func$tr$lcssa = 0, $func$tr$lcssa153 = 0, $func$tr$lcssa154 = 0, $hook$0$i = 0, $i$03$i = 0, $i$03$i$lcssa = 0, $i$11$i = 0, $n$0$lcssa = 0, $n$049 = 0, $p$01$i = 0, $res$04$i = 0, $res$04$i$lcssa = 0, $res$1$lcssa$i = 0, $res$12$i = 0, $scevgep = 0;
 var $scevgep$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($L)) + 28|0);
 $1 = ((($L)) + 24|0);
 $2 = ((($L)) + 8|0);
 $3 = ((($L)) + 92|0);
 $func$tr = $func;
 while(1) {
  $4 = HEAP32[$0>>2]|0;
  $5 = $func$tr;
  $6 = $4;
  $7 = (($5) - ($6))|0;
  $8 = ((($func$tr)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 & 63;
  if ((($10|0) == 22)) {
   $$lcssa158 = $4;$$lcssa170 = $7;$func$tr$lcssa = $func$tr;
   label = 3;
   break;
  } else if ((($10|0) == 38)) {
   $$lcssa159 = $4;$$lcssa171 = $7;$func$tr$lcssa153 = $func$tr;
   label = 4;
   break;
  } else if ((($10|0) == 6)) {
   $$lcssa160 = $4;$$lcssa166 = $5;$$lcssa172 = $7;$func$tr$lcssa154 = $func$tr;
   label = 30;
   break;
  }
  $217 = HEAP32[$1>>2]|0;
  $218 = HEAP32[$2>>2]|0;
  $219 = $217;
  $220 = $218;
  $221 = (($219) - ($220))|0;
  $222 = ($221|0)<(32);
  if ($222) {
   $223 = HEAP32[$3>>2]|0;
   $224 = ($223|0)>(1000000);
   if ($224) {
    label = 63;
    break;
   }
   $225 = $4;
   $226 = (($220) - ($225))|0;
   $227 = $226 >> 4;
   $228 = (($227) + 6)|0;
   $229 = $223 << 1;
   $230 = ($229|0)>(1000000);
   $$$i9 = $230 ? 1000000 : $229;
   $231 = ($$$i9|0)<($228|0);
   $$$$i10 = $231 ? $228 : $$$i9;
   $232 = ($$$$i10|0)>(1000000);
   if ($232) {
    label = 65;
    break;
   }
   _luaD_reallocstack($L,$$$$i10);
   $$pre = HEAP32[$0>>2]|0;
   $234 = $$pre;
  } else {
   $234 = $4;
  }
  $233 = (($234) + ($7)|0);
  $235 = (_luaT_gettmbyobj($L,$233,23)|0);
  $236 = ((($235)) + 8|0);
  $237 = HEAP32[$236>>2]|0;
  $238 = $237 & 15;
  $239 = ($238|0)==(6);
  if (!($239)) {
   $$lcssa176 = $233;
   label = 68;
   break;
  }
  $240 = HEAP32[$2>>2]|0;
  $241 = ($240>>>0)>($233>>>0);
  if ($241) {
   $p$01$i = $240;
   while(1) {
    $242 = ((($p$01$i)) + -16|0);
    ;HEAP32[$p$01$i>>2]=HEAP32[$242>>2]|0;HEAP32[$p$01$i+4>>2]=HEAP32[$242+4>>2]|0;HEAP32[$p$01$i+8>>2]=HEAP32[$242+8>>2]|0;HEAP32[$p$01$i+12>>2]=HEAP32[$242+12>>2]|0;
    $243 = ($242>>>0)>($233>>>0);
    if ($243) {
     $p$01$i = $242;
    } else {
     break;
    }
   }
   $$pre$i13 = HEAP32[$2>>2]|0;
   $245 = $$pre$i13;
  } else {
   $245 = $240;
  }
  $244 = ((($245)) + 16|0);
  HEAP32[$2>>2] = $244;
  ;HEAP32[$233>>2]=HEAP32[$235>>2]|0;HEAP32[$233+4>>2]=HEAP32[$235+4>>2]|0;HEAP32[$233+8>>2]=HEAP32[$235+8>>2]|0;HEAP32[$233+12>>2]=HEAP32[$235+12>>2]|0;
  $func$tr = $233;
 }
 if ((label|0) == 3) {
  $22 = $$lcssa158;$41 = $$lcssa170;$f$0$in = $func$tr$lcssa;
 }
 else if ((label|0) == 4) {
  $11 = HEAP32[$func$tr$lcssa153>>2]|0;
  $12 = ((($11)) + 12|0);
  $22 = $$lcssa159;$41 = $$lcssa171;$f$0$in = $12;
 }
 else if ((label|0) == 30) {
  $95 = HEAP32[$func$tr$lcssa154>>2]|0;
  $96 = ((($95)) + 12|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = HEAP32[$2>>2]|0;
  $99 = $98;
  $100 = (($99) - ($$lcssa166))|0;
  $101 = $100 >> 4;
  $102 = (($101) + -1)|0;
  $103 = HEAP32[$1>>2]|0;
  $104 = $103;
  $105 = (($104) - ($99))|0;
  $106 = $105 >> 4;
  $107 = ((($97)) + 8|0);
  $108 = HEAP8[$107>>0]|0;
  $109 = $108&255;
  $110 = ($106|0)>($109|0);
  do {
   if (!($110)) {
    $111 = HEAP32[$3>>2]|0;
    $112 = ($111|0)>(1000000);
    if ($112) {
     _luaD_throw($L,6);
     // unreachable;
    }
    $113 = $$lcssa160;
    $114 = (($99) - ($113))|0;
    $115 = $114 >> 4;
    $116 = (($109) + 5)|0;
    $117 = (($116) + ($115))|0;
    $118 = $111 << 1;
    $119 = ($118|0)>(1000000);
    $$$i3 = $119 ? 1000000 : $118;
    $120 = ($$$i3|0)<($117|0);
    $$$$i4 = $120 ? $117 : $$$i3;
    $121 = ($$$$i4|0)>(1000000);
    if ($121) {
     _luaD_reallocstack($L,1000200);
     _luaG_runerror($L,4208,$vararg_buffer1);
     // unreachable;
    } else {
     _luaD_reallocstack($L,$$$$i4);
     break;
    }
   }
  } while(0);
  $122 = ((($97)) + 6|0);
  $123 = HEAP8[$122>>0]|0;
  $124 = $123&255;
  $125 = ($101|0)>($124|0);
  if ($125) {
   $n$0$lcssa = $102;
  } else {
   $$promoted = HEAP32[$2>>2]|0;
   $126 = (($124) + 1)|0;
   $127 = (($126) - ($101))|0;
   $129 = $$promoted;$n$049 = $102;
   while(1) {
    $128 = ((($129)) + 16|0);
    $130 = ((($129)) + 8|0);
    HEAP32[$130>>2] = 0;
    $131 = (($n$049) + 1)|0;
    $132 = ($131|0)<($124|0);
    if ($132) {
     $129 = $128;$n$049 = $131;
    } else {
     break;
    }
   }
   $scevgep = (($$promoted) + ($127<<4)|0);
   HEAP32[$2>>2] = $scevgep;
   $n$0$lcssa = $124;
  }
  $133 = ((($97)) + 7|0);
  $134 = HEAP8[$133>>0]|0;
  $135 = ($134<<24>>24)==(0);
  if ($135) {
   $136 = HEAP32[$0>>2]|0;
   $$sum = (($$lcssa172) + 16)|0;
   $137 = (($136) + ($$sum)|0);
   $$pn = $136;$base$0 = $137;
  } else {
   $$idx2$val = HEAP8[$107>>0]|0;
   $138 = HEAP32[$1>>2]|0;
   $139 = HEAP32[$2>>2]|0;
   $140 = $138;
   $141 = $139;
   $142 = (($140) - ($141))|0;
   $143 = $142 >> 4;
   $144 = $$idx2$val&255;
   $145 = ($143|0)>($144|0);
   do {
    if ($145) {
     $160 = $139;
    } else {
     $146 = HEAP32[$3>>2]|0;
     $147 = ($146|0)>(1000000);
     if ($147) {
      _luaD_throw($L,6);
      // unreachable;
     }
     $148 = HEAP32[$0>>2]|0;
     $149 = $148;
     $150 = (($141) - ($149))|0;
     $151 = $150 >> 4;
     $152 = (($144) + 5)|0;
     $153 = (($152) + ($151))|0;
     $154 = $146 << 1;
     $155 = ($154|0)>(1000000);
     $$$i$i = $155 ? 1000000 : $154;
     $156 = ($$$i$i|0)<($153|0);
     $$$$i$i = $156 ? $153 : $$$i$i;
     $157 = ($$$$i$i|0)>(1000000);
     if ($157) {
      _luaD_reallocstack($L,1000200);
      _luaG_runerror($L,4208,$vararg_buffer3);
      // unreachable;
     } else {
      _luaD_reallocstack($L,$$$$i$i);
      $$pre$i6 = HEAP32[$2>>2]|0;
      $160 = $$pre$i6;
      break;
     }
    }
   } while(0);
   $158 = ($123<<24>>24)==(0);
   if (!($158)) {
    $159 = ((($160)) + 16|0);
    HEAP32[$2>>2] = $159;
    $$sum$i47 = (0 - ($n$0$lcssa))|0;
    $161 = (($160) + ($$sum$i47<<4)|0);
    ;HEAP32[$160>>2]=HEAP32[$161>>2]|0;HEAP32[$160+4>>2]=HEAP32[$161+4>>2]|0;HEAP32[$160+8>>2]=HEAP32[$161+8>>2]|0;HEAP32[$160+12>>2]=HEAP32[$161+12>>2]|0;
    $162 = (((($160) + ($$sum$i47<<4)|0)) + 8|0);
    HEAP32[$162>>2] = 0;
    $exitcond$i48 = ($123<<24>>24)==(1);
    if (!($exitcond$i48)) {
     $164 = 1;
     while(1) {
      $$pre3$i = HEAP32[$2>>2]|0;
      $163 = ((($$pre3$i)) + 16|0);
      HEAP32[$2>>2] = $163;
      $$sum$i = (($164) - ($n$0$lcssa))|0;
      $165 = (($160) + ($$sum$i<<4)|0);
      ;HEAP32[$$pre3$i>>2]=HEAP32[$165>>2]|0;HEAP32[$$pre3$i+4>>2]=HEAP32[$165+4>>2]|0;HEAP32[$$pre3$i+8>>2]=HEAP32[$165+8>>2]|0;HEAP32[$$pre3$i+12>>2]=HEAP32[$165+12>>2]|0;
      $166 = (((($160) + ($$sum$i<<4)|0)) + 8|0);
      HEAP32[$166>>2] = 0;
      $167 = (($164) + 1)|0;
      $exitcond$i = ($167|0)==($124|0);
      if ($exitcond$i) {
       break;
      } else {
       $164 = $167;
      }
     }
    }
   }
   $168 = HEAP32[$0>>2]|0;
   $$pn = $168;$base$0 = $160;
  }
  $$01$in = (($$pn) + ($$lcssa172)|0);
  $169 = ((($L)) + 16|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ((($170)) + 12|0);
  $172 = HEAP32[$171>>2]|0;
  $173 = ($172|0)==(0|0);
  if ($173) {
   $174 = (_luaE_extendCI($L)|0);
   $175 = $174;
  } else {
   $175 = $172;
  }
  HEAP32[$169>>2] = $175;
  $176 = $nresults&65535;
  $177 = ((($175)) + 32|0);
  HEAP16[$177>>1] = $176;
  HEAP32[$175>>2] = $$01$in;
  $178 = ((($175)) + 16|0);
  HEAP32[$178>>2] = $base$0;
  $179 = HEAP8[$107>>0]|0;
  $180 = $179&255;
  $181 = (($base$0) + ($180<<4)|0);
  $182 = ((($175)) + 4|0);
  HEAP32[$182>>2] = $181;
  $183 = ((($97)) + 48|0);
  $184 = HEAP32[$183>>2]|0;
  $185 = ((($175)) + 20|0);
  HEAP32[$185>>2] = $184;
  $186 = ((($175)) + 34|0);
  HEAP8[$186>>0] = 2;
  $187 = $181;
  HEAP32[$2>>2] = $187;
  $188 = ((($L)) + 12|0);
  $189 = HEAP32[$188>>2]|0;
  $190 = ((($189)) + 12|0);
  $191 = HEAP32[$190>>2]|0;
  $192 = ($191|0)>(0);
  if ($192) {
   _luaC_step($L);
  }
  $193 = ((($L)) + 108|0);
  $194 = HEAP8[$193>>0]|0;
  $195 = $194 & 1;
  $196 = ($195<<24>>24)==(0);
  if ($196) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $197 = HEAP32[$185>>2]|0;
  $198 = ((($197)) + 4|0);
  HEAP32[$185>>2] = $198;
  $199 = ((($175)) + 8|0);
  $200 = HEAP32[$199>>2]|0;
  $201 = ((($200)) + 34|0);
  $202 = HEAP8[$201>>0]|0;
  $203 = $202 & 2;
  $204 = ($203<<24>>24)==(0);
  if ($204) {
   $hook$0$i = 0;
  } else {
   $205 = ((($200)) + 20|0);
   $206 = HEAP32[$205>>2]|0;
   $207 = ((($206)) + -4|0);
   $208 = HEAP32[$207>>2]|0;
   $209 = $208 & 63;
   $210 = ($209|0)==(37);
   if ($210) {
    $211 = HEAP8[$186>>0]|0;
    $212 = $211&255;
    $213 = $212 | 32;
    $214 = $213&255;
    HEAP8[$186>>0] = $214;
    $hook$0$i = 4;
   } else {
    $hook$0$i = 0;
   }
  }
  _luaD_hook($L,$hook$0$i,-1);
  $215 = HEAP32[$185>>2]|0;
  $216 = ((($215)) + -4|0);
  HEAP32[$185>>2] = $216;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 63) {
  _luaD_throw($L,6);
  // unreachable;
 }
 else if ((label|0) == 65) {
  _luaD_reallocstack($L,1000200);
  _luaG_runerror($L,4208,$vararg_buffer5);
  // unreachable;
 }
 else if ((label|0) == 68) {
  _luaG_typeerror($L,$$lcssa176,7904);
  // unreachable;
 }
 $f$0 = HEAP32[$f$0$in>>2]|0;
 $13 = HEAP32[$1>>2]|0;
 $14 = HEAP32[$2>>2]|0;
 $15 = $13;
 $16 = $14;
 $17 = (($15) - ($16))|0;
 $18 = ($17|0)<(336);
 do {
  if ($18) {
   $19 = HEAP32[$3>>2]|0;
   $20 = ($19|0)>(1000000);
   if ($20) {
    _luaD_throw($L,6);
    // unreachable;
   }
   $21 = $22;
   $23 = (($16) - ($21))|0;
   $24 = $23 >> 4;
   $25 = (($24) + 25)|0;
   $26 = $19 << 1;
   $27 = ($26|0)>(1000000);
   $$$i = $27 ? 1000000 : $26;
   $28 = ($$$i|0)<($25|0);
   $$$$i = $28 ? $25 : $$$i;
   $29 = ($$$$i|0)>(1000000);
   if ($29) {
    _luaD_reallocstack($L,1000200);
    _luaG_runerror($L,4208,$vararg_buffer);
    // unreachable;
   } else {
    _luaD_reallocstack($L,$$$$i);
    break;
   }
  }
 } while(0);
 $30 = ((($L)) + 16|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($31)) + 12|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ($33|0)==(0|0);
 if ($34) {
  $35 = (_luaE_extendCI($L)|0);
  $36 = $35;
 } else {
  $36 = $33;
 }
 HEAP32[$30>>2] = $36;
 $37 = $nresults&65535;
 $38 = ((($36)) + 32|0);
 HEAP16[$38>>1] = $37;
 $39 = HEAP32[$0>>2]|0;
 $40 = (($39) + ($41)|0);
 HEAP32[$36>>2] = $40;
 $42 = HEAP32[$2>>2]|0;
 $43 = ((($42)) + 320|0);
 $44 = ((($36)) + 4|0);
 HEAP32[$44>>2] = $43;
 $45 = ((($36)) + 34|0);
 HEAP8[$45>>0] = 0;
 $46 = ((($L)) + 12|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($47)) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($49|0)>(0);
 if ($50) {
  _luaC_step($L);
 }
 $51 = ((($L)) + 108|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = $52 & 1;
 $54 = ($53<<24>>24)==(0);
 if (!($54)) {
  _luaD_hook($L,0,-1);
 }
 $55 = (FUNCTION_TABLE_ii[$f$0 & 511]($L)|0);
 $56 = HEAP32[$2>>2]|0;
 $57 = (0 - ($55))|0;
 $58 = (($56) + ($57<<4)|0);
 $59 = HEAP32[$30>>2]|0;
 $60 = HEAP8[$51>>0]|0;
 $61 = $60&255;
 $62 = $61 & 6;
 $63 = ($62|0)==(0);
 if ($63) {
  $$phi$trans$insert$i = ((($59)) + 8|0);
  $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
  $$1$i = $58;$81 = $$pre$i;
 } else {
  $64 = $61 & 2;
  $65 = ($64|0)==(0);
  if ($65) {
   $$0$i = $58;
  } else {
   $66 = HEAP32[$0>>2]|0;
   $67 = $58;
   $68 = $66;
   $69 = (($67) - ($68))|0;
   _luaD_hook($L,1,-1);
   $70 = HEAP32[$0>>2]|0;
   $71 = (($70) + ($69)|0);
   $$0$i = $71;
  }
  $72 = ((($59)) + 8|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = ((($73)) + 20|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = ((($L)) + 20|0);
  HEAP32[$76>>2] = $75;
  $77 = $73;
  $$1$i = $$0$i;$81 = $77;
 }
 $78 = HEAP32[$59>>2]|0;
 $79 = ((($59)) + 32|0);
 $80 = HEAP16[$79>>1]|0;
 HEAP32[$30>>2] = $81;
 $82 = ($80<<16>>16)==(0);
 L95: do {
  if ($82) {
   $res$1$lcssa$i = $78;
  } else {
   $83 = $80 << 16 >> 16;
   $$25$i = $$1$i;$i$03$i = $83;$res$04$i = $78;
   while(1) {
    $85 = HEAP32[$2>>2]|0;
    $86 = ($$25$i>>>0)<($85>>>0);
    if (!($86)) {
     $i$03$i$lcssa = $i$03$i;$res$04$i$lcssa = $res$04$i;
     break;
    }
    $87 = ((($res$04$i)) + 16|0);
    $88 = ((($$25$i)) + 16|0);
    ;HEAP32[$res$04$i>>2]=HEAP32[$$25$i>>2]|0;HEAP32[$res$04$i+4>>2]=HEAP32[$$25$i+4>>2]|0;HEAP32[$res$04$i+8>>2]=HEAP32[$$25$i+8>>2]|0;HEAP32[$res$04$i+12>>2]=HEAP32[$$25$i+12>>2]|0;
    $89 = (($i$03$i) + -1)|0;
    $90 = ($89|0)==(0);
    if ($90) {
     $res$1$lcssa$i = $87;
     break L95;
    } else {
     $$25$i = $88;$i$03$i = $89;$res$04$i = $87;
    }
   }
   $84 = ($i$03$i$lcssa|0)>(0);
   if ($84) {
    $i$11$i = $i$03$i$lcssa;$res$12$i = $res$04$i$lcssa;
    while(1) {
     $91 = (($i$11$i) + -1)|0;
     $92 = ((($res$12$i)) + 16|0);
     $93 = ((($res$12$i)) + 8|0);
     HEAP32[$93>>2] = 0;
     $94 = ($i$11$i|0)>(1);
     if ($94) {
      $i$11$i = $91;$res$12$i = $92;
     } else {
      break;
     }
    }
    $scevgep$i = (($res$04$i$lcssa) + ($i$03$i$lcssa<<4)|0);
    $res$1$lcssa$i = $scevgep$i;
   } else {
    $res$1$lcssa$i = $res$04$i$lcssa;
   }
  }
 } while(0);
 HEAP32[$2>>2] = $res$1$lcssa$i;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _luaD_poscall($L,$firstResult) {
 $L = $L|0;
 $firstResult = $firstResult|0;
 var $$0 = 0, $$1 = 0, $$25 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $i$03$lcssa = 0, $i$11 = 0, $res$04 = 0, $res$04$lcssa = 0, $res$1$lcssa = 0, $res$12 = 0, $scevgep = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 6;
 $6 = ($5|0)==(0);
 if ($6) {
  $$phi$trans$insert = ((($1)) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $$1 = $firstResult;$26 = $$pre;
 } else {
  $7 = $4 & 2;
  $8 = ($7|0)==(0);
  if ($8) {
   $$0 = $firstResult;
  } else {
   $9 = ((($L)) + 28|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = $firstResult;
   $12 = $10;
   $13 = (($11) - ($12))|0;
   _luaD_hook($L,1,-1);
   $14 = HEAP32[$9>>2]|0;
   $15 = (($14) + ($13)|0);
   $$0 = $15;
  }
  $16 = ((($1)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ((($17)) + 20|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ((($L)) + 20|0);
  HEAP32[$20>>2] = $19;
  $21 = $17;
  $$1 = $$0;$26 = $21;
 }
 $22 = HEAP32[$1>>2]|0;
 $23 = ((($1)) + 32|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = $24 << 16 >> 16;
 HEAP32[$0>>2] = $26;
 $27 = ((($L)) + 8|0);
 $28 = ($24<<16>>16)==(0);
 if ($28) {
  $res$1$lcssa = $22;
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 } else {
  $$25 = $$1;$i$03 = $25;$res$04 = $22;
 }
 while(1) {
  $30 = HEAP32[$27>>2]|0;
  $31 = ($$25>>>0)<($30>>>0);
  if (!($31)) {
   $i$03$lcssa = $i$03;$res$04$lcssa = $res$04;
   break;
  }
  $32 = ((($res$04)) + 16|0);
  $33 = ((($$25)) + 16|0);
  ;HEAP32[$res$04>>2]=HEAP32[$$25>>2]|0;HEAP32[$res$04+4>>2]=HEAP32[$$25+4>>2]|0;HEAP32[$res$04+8>>2]=HEAP32[$$25+8>>2]|0;HEAP32[$res$04+12>>2]=HEAP32[$$25+12>>2]|0;
  $34 = (($i$03) + -1)|0;
  $35 = ($34|0)==(0);
  if ($35) {
   $res$1$lcssa = $32;
   label = 12;
   break;
  } else {
   $$25 = $33;$i$03 = $34;$res$04 = $32;
  }
 }
 if ((label|0) == 12) {
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 }
 $29 = ($i$03$lcssa|0)>(0);
 if ($29) {
  $i$11 = $i$03$lcssa;$res$12 = $res$04$lcssa;
 } else {
  $res$1$lcssa = $res$04$lcssa;
  HEAP32[$27>>2] = $res$1$lcssa;
  $40 = (($25) + 1)|0;
  return ($40|0);
 }
 while(1) {
  $36 = (($i$11) + -1)|0;
  $37 = ((($res$12)) + 16|0);
  $38 = ((($res$12)) + 8|0);
  HEAP32[$38>>2] = 0;
  $39 = ($i$11|0)>(1);
  if ($39) {
   $i$11 = $36;$res$12 = $37;
  } else {
   break;
  }
 }
 $scevgep = (($res$04$lcssa) + ($i$03$lcssa<<4)|0);
 $res$1$lcssa = $scevgep;
 HEAP32[$27>>2] = $res$1$lcssa;
 $40 = (($25) + 1)|0;
 return ($40|0);
}
function _luaD_call($L,$func,$nResults,$allowyield) {
 $L = $L|0;
 $func = $func|0;
 $nResults = $nResults|0;
 $allowyield = $allowyield|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 $3 = ($2&65535)>(199);
 if ($3) {
  $4 = ($2<<16>>16)==(200);
  if ($4) {
   _luaG_runerror($L,1224,$vararg_buffer);
   // unreachable;
  }
  $5 = ($2&65535)>(224);
  if ($5) {
   _luaD_throw($L,6);
   // unreachable;
  }
 }
 $6 = ($allowyield|0)!=(0);
 if (!($6)) {
  $7 = ((($L)) + 104|0);
  $8 = HEAP16[$7>>1]|0;
  $9 = (($8) + 1)<<16>>16;
  HEAP16[$7>>1] = $9;
 }
 $10 = (_luaD_precall($L,$func,$nResults)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  _luaV_execute($L);
 }
 if ($6) {
  $15 = HEAP16[$0>>1]|0;
  $16 = (($15) + -1)<<16>>16;
  HEAP16[$0>>1] = $16;
  STACKTOP = sp;return;
 }
 $12 = ((($L)) + 104|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = (($13) + -1)<<16>>16;
 HEAP16[$12>>1] = $14;
 $15 = HEAP16[$0>>1]|0;
 $16 = (($15) + -1)<<16>>16;
 HEAP16[$0>>1] = $16;
 STACKTOP = sp;return;
}
function _lua_resume($L,$from,$nargs) {
 $L = $L|0;
 $from = $from|0;
 $nargs = $nargs|0;
 var $$$i$i = 0, $$cast = 0, $$lcssa = 0, $$lcssa30 = 0, $$lim$0$i$i$i = 0, $$lim$0$i$i$i$lcssa = 0, $$pre = 0, $$sum$i = 0, $$sum3$i = 0, $$sum4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ci$0$i$i = 0, $ci$0$i$i$i = 0, $ci$01$i$i = 0;
 var $ci$02$i$i = 0, $ci$02$i$i$lcssa = 0, $ci$03$i$i$i = 0, $lim$02$i$i$i = 0, $phitmp = 0, $status = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $status = sp;
 $0 = ((($L)) + 104|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($from|0)==(0|0);
 if ($2) {
  $8 = 1;
 } else {
  $3 = ((($from)) + 106|0);
  $4 = HEAP16[$3>>1]|0;
  $5 = $4&65535;
  $6 = (($5) + 1)|0;
  $phitmp = $6&65535;
  $8 = $phitmp;
 }
 $7 = ((($L)) + 106|0);
 HEAP16[$7>>1] = $8;
 HEAP16[$0>>1] = 0;
 $9 = ((($L)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = (0 - ($nargs))|0;
 $12 = (($10) + ($11<<4)|0);
 $13 = (_luaD_rawrunprotected($L,310,$12)|0);
 HEAP32[$status>>2] = $13;
 $14 = ($13|0)==(-1);
 if ($14) {
  HEAP32[$status>>2] = 2;
  $105 = 2;
  HEAP16[$0>>1] = $1;
  $103 = HEAP16[$7>>1]|0;
  $104 = (($103) + -1)<<16>>16;
  HEAP16[$7>>1] = $104;
  STACKTOP = sp;return ($105|0);
 }
 $15 = ($13|0)>(1);
 if (!($15)) {
  $105 = $13;
  HEAP16[$0>>1] = $1;
  $103 = HEAP16[$7>>1]|0;
  $104 = (($103) + -1)<<16>>16;
  HEAP16[$7>>1] = $104;
  STACKTOP = sp;return ($105|0);
 }
 $16 = ((($L)) + 16|0);
 $17 = ((($L)) + 28|0);
 $18 = ((($L)) + 109|0);
 $19 = ((($L)) + 92|0);
 $20 = ((($L)) + 88|0);
 $21 = ((($L)) + 12|0);
 $106 = $13;
 L11: while(1) {
  $ci$01$i$i = HEAP32[$16>>2]|0;
  $22 = ($ci$01$i$i|0)==(0|0);
  if ($22) {
   $80 = $106;
   break;
  } else {
   $ci$02$i$i = $ci$01$i$i;
  }
  while(1) {
   $23 = ((($ci$02$i$i)) + 34|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 16;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    $$lcssa = $23;$ci$02$i$i$lcssa = $ci$02$i$i;
    break;
   }
   $27 = ((($ci$02$i$i)) + 8|0);
   $ci$0$i$i = HEAP32[$27>>2]|0;
   $28 = ($ci$0$i$i|0)==(0|0);
   if ($28) {
    $$lcssa30 = $106;
    label = 23;
    break L11;
   } else {
    $ci$02$i$i = $ci$0$i$i;
   }
  }
  $29 = HEAP32[$17>>2]|0;
  $30 = ((($ci$02$i$i$lcssa)) + 28|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($29) + ($31)|0);
  _luaF_close($L,$32);
  if ((($106|0) == 4)) {
   $33 = HEAP32[$21>>2]|0;
   $34 = ((($33)) + 144|0);
   $35 = HEAP32[$34>>2]|0;
   HEAP32[$32>>2] = $35;
   $36 = ((($35)) + 4|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = $38 | 64;
   $$sum4$i = (($31) + 8)|0;
   $40 = (($29) + ($$sum4$i)|0);
   HEAP32[$40>>2] = $39;
  } else if ((($106|0) == 6)) {
   $41 = (_luaS_newlstr($L,1200,23)|0);
   HEAP32[$32>>2] = $41;
   $42 = ((($41)) + 4|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = $43&255;
   $45 = $44 | 64;
   $$sum$i = (($31) + 8)|0;
   $46 = (($29) + ($$sum$i)|0);
   HEAP32[$46>>2] = $45;
  } else {
   $47 = HEAP32[$9>>2]|0;
   $48 = ((($47)) + -16|0);
   ;HEAP32[$32>>2]=HEAP32[$48>>2]|0;HEAP32[$32+4>>2]=HEAP32[$48+4>>2]|0;HEAP32[$32+8>>2]=HEAP32[$48+8>>2]|0;HEAP32[$32+12>>2]=HEAP32[$48+12>>2]|0;
  }
  $$sum3$i = (($31) + 16)|0;
  $49 = (($29) + ($$sum3$i)|0);
  HEAP32[$9>>2] = $49;
  HEAP32[$16>>2] = $ci$02$i$i$lcssa;
  $50 = HEAP8[$$lcssa>>0]|0;
  $51 = $50&255;
  $52 = $51 & 1;
  $53 = $52&255;
  HEAP8[$18>>0] = $53;
  HEAP16[$0>>1] = 0;
  $ci$03$i$i$i = $ci$02$i$i$lcssa;$lim$02$i$i$i = $49;
  while(1) {
   $54 = ((($ci$03$i$i$i)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ($lim$02$i$i$i>>>0)<($55>>>0);
   $$lim$0$i$i$i = $56 ? $55 : $lim$02$i$i$i;
   $57 = ((($ci$03$i$i$i)) + 8|0);
   $ci$0$i$i$i = HEAP32[$57>>2]|0;
   $58 = ($ci$0$i$i$i|0)==(0|0);
   if ($58) {
    $$lim$0$i$i$i$lcssa = $$lim$0$i$i$i;
    break;
   } else {
    $ci$03$i$i$i = $ci$0$i$i$i;$lim$02$i$i$i = $$lim$0$i$i$i;
   }
  }
  $59 = HEAP32[$17>>2]|0;
  $60 = $$lim$0$i$i$i$lcssa;
  $61 = $59;
  $62 = (($60) - ($61))|0;
  $63 = $62 >> 4;
  $64 = (($63) + 1)|0;
  $65 = (($64|0) / 8)&-1;
  $66 = (($65) + 10)|0;
  $67 = (($66) + ($64))|0;
  $68 = ($67|0)>(1000000);
  $$$i$i = $68 ? 1000000 : $67;
  $69 = HEAP32[$19>>2]|0;
  $70 = ($69|0)>(1000000);
  if ($70) {
   _luaE_freeCI($L);
  } else {
   _luaE_shrinkCI($L);
  }
  $71 = ($62|0)>(15999984);
  if (!($71)) {
   $72 = HEAP32[$19>>2]|0;
   $73 = ($$$i$i|0)<($72|0);
   if ($73) {
    _luaD_reallocstack($L,$$$i$i);
   }
  }
  $74 = ((($ci$02$i$i$lcssa)) + 20|0);
  $75 = HEAP32[$74>>2]|0;
  HEAP32[$20>>2] = $75;
  $76 = (_luaD_rawrunprotected($L,311,$status)|0);
  HEAP32[$status>>2] = $76;
  $77 = ($76|0)>(1);
  if ($77) {
   $106 = $76;
  } else {
   $105 = $76;
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  HEAP16[$0>>1] = $1;
  $103 = HEAP16[$7>>1]|0;
  $104 = (($103) + -1)<<16>>16;
  HEAP16[$7>>1] = $104;
  STACKTOP = sp;return ($105|0);
 }
 if ((label|0) == 23) {
  $78 = ($$lcssa30|0)>(1);
  if ($78) {
   $80 = $$lcssa30;
  } else {
   $105 = $$lcssa30;
   HEAP16[$0>>1] = $1;
   $103 = HEAP16[$7>>1]|0;
   $104 = (($103) + -1)<<16>>16;
   HEAP16[$7>>1] = $104;
   STACKTOP = sp;return ($105|0);
  }
 }
 $79 = $80&255;
 $81 = ((($L)) + 6|0);
 HEAP8[$81>>0] = $79;
 $82 = HEAP32[$9>>2]|0;
 if ((($80|0) == 4)) {
  $83 = ((($L)) + 12|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = ((($84)) + 144|0);
  $86 = HEAP32[$85>>2]|0;
  HEAP32[$82>>2] = $86;
  $87 = ((($86)) + 4|0);
  $88 = HEAP8[$87>>0]|0;
  $89 = $88&255;
  $90 = $89 | 64;
  $91 = ((($82)) + 8|0);
  HEAP32[$91>>2] = $90;
 } else if ((($80|0) == 6)) {
  $92 = (_luaS_newlstr($L,1200,23)|0);
  HEAP32[$82>>2] = $92;
  $93 = ((($92)) + 4|0);
  $94 = HEAP8[$93>>0]|0;
  $95 = $94&255;
  $96 = $95 | 64;
  $97 = ((($82)) + 8|0);
  HEAP32[$97>>2] = $96;
 } else {
  $98 = ((($82)) + -16|0);
  ;HEAP32[$82>>2]=HEAP32[$98>>2]|0;HEAP32[$82+4>>2]=HEAP32[$98+4>>2]|0;HEAP32[$82+8>>2]=HEAP32[$98+8>>2]|0;HEAP32[$82+12>>2]=HEAP32[$98+12>>2]|0;
 }
 $99 = ((($82)) + 16|0);
 HEAP32[$9>>2] = $99;
 $$cast = $99;
 $100 = ((($L)) + 16|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ((($101)) + 4|0);
 HEAP32[$102>>2] = $$cast;
 $$pre = HEAP32[$status>>2]|0;
 $105 = $$pre;
 HEAP16[$0>>1] = $1;
 $103 = HEAP16[$7>>1]|0;
 $104 = (($103) + -1)<<16>>16;
 HEAP16[$7>>1] = $104;
 STACKTOP = sp;return ($105|0);
}
function _lua_isyieldable($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 104|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ($1<<16>>16)==(0);
 $3 = $2&1;
 return ($3|0);
}
function _lua_yieldk($L,$nresults,$ctx,$k) {
 $L = $L|0;
 $nresults = $nresults|0;
 $ctx = $ctx|0;
 $k = $k|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 104|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = ($3<<16>>16)==(0);
 if (!($4)) {
  $5 = ((($L)) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ((($6)) + 136|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = ($8|0)==($L|0);
  if ($9) {
   _luaG_runerror($L,1296,$vararg_buffer1);
   // unreachable;
  } else {
   _luaG_runerror($L,1248,$vararg_buffer);
   // unreachable;
  }
 }
 $10 = ((($L)) + 6|0);
 HEAP8[$10>>0] = 1;
 $11 = HEAP32[$1>>2]|0;
 $12 = ((($L)) + 28|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $11;
 $15 = $13;
 $16 = (($14) - ($15))|0;
 $17 = ((($1)) + 28|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($1)) + 34|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19 & 2;
 $21 = ($20<<24>>24)==(0);
 if (!($21)) {
  STACKTOP = sp;return 0;
 }
 $22 = ((($1)) + 16|0);
 HEAP32[$22>>2] = $k;
 $23 = ($k|0)==(0|0);
 if ($23) {
  $25 = ((($L)) + 8|0);
  $26 = HEAP32[$25>>2]|0;
  $$sum = $nresults ^ -1;
  $27 = (($26) + ($$sum<<4)|0);
  HEAP32[$1>>2] = $27;
  _luaD_throw($L,1);
  // unreachable;
 }
 $24 = ((($1)) + 24|0);
 HEAP32[$24>>2] = $ctx;
 $25 = ((($L)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $$sum = $nresults ^ -1;
 $27 = (($26) + ($$sum<<4)|0);
 HEAP32[$1>>2] = $27;
 _luaD_throw($L,1);
 // unreachable;
 return (0)|0;
}
function _luaD_pcall($L,$func,$u,$old_top,$ef) {
 $L = $L|0;
 $func = $func|0;
 $u = $u|0;
 $old_top = $old_top|0;
 $ef = $ef|0;
 var $$$i = 0, $$lim$0$i$i = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $ci$0$i$i = 0, $ci$03$i$i = 0, $lim$0$lcssa$i$i = 0, $lim$02$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 109|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ((($L)) + 104|0);
 $5 = HEAP16[$4>>1]|0;
 $6 = ((($L)) + 88|0);
 $7 = HEAP32[$6>>2]|0;
 HEAP32[$6>>2] = $ef;
 $8 = (_luaD_rawrunprotected($L,$func,$u)|0);
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 $10 = ((($L)) + 28|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = (($11) + ($old_top)|0);
 _luaF_close($L,$12);
 if ((($8|0) == 6)) {
  $22 = (_luaS_newlstr($L,1200,23)|0);
  HEAP32[$12>>2] = $22;
  $23 = ((($22)) + 4|0);
  $24 = HEAP8[$23>>0]|0;
  $25 = $24&255;
  $26 = $25 | 64;
  $$sum = (($old_top) + 8)|0;
  $27 = (($11) + ($$sum)|0);
  HEAP32[$27>>2] = $26;
 } else if ((($8|0) == 4)) {
  $13 = ((($L)) + 12|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 144|0);
  $16 = HEAP32[$15>>2]|0;
  HEAP32[$12>>2] = $16;
  $17 = ((($16)) + 4|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $19 | 64;
  $$sum2 = (($old_top) + 8)|0;
  $21 = (($11) + ($$sum2)|0);
  HEAP32[$21>>2] = $20;
 } else {
  $28 = ((($L)) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + -16|0);
  ;HEAP32[$12>>2]=HEAP32[$30>>2]|0;HEAP32[$12+4>>2]=HEAP32[$30+4>>2]|0;HEAP32[$12+8>>2]=HEAP32[$30+8>>2]|0;HEAP32[$12+12>>2]=HEAP32[$30+12>>2]|0;
 }
 $$sum1 = (($old_top) + 16)|0;
 $31 = (($11) + ($$sum1)|0);
 $32 = ((($L)) + 8|0);
 HEAP32[$32>>2] = $31;
 HEAP32[$0>>2] = $1;
 HEAP8[$2>>0] = $3;
 HEAP16[$4>>1] = $5;
 $33 = ($1|0)==(0);
 if ($33) {
  $lim$0$lcssa$i$i = $31;
 } else {
  $34 = $1;
  $ci$03$i$i = $34;$lim$02$i$i = $31;
  while(1) {
   $35 = ((($ci$03$i$i)) + 4|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ($lim$02$i$i>>>0)<($36>>>0);
   $$lim$0$i$i = $37 ? $36 : $lim$02$i$i;
   $38 = ((($ci$03$i$i)) + 8|0);
   $ci$0$i$i = HEAP32[$38>>2]|0;
   $39 = ($ci$0$i$i|0)==(0|0);
   if ($39) {
    $lim$0$lcssa$i$i = $$lim$0$i$i;
    break;
   } else {
    $ci$03$i$i = $ci$0$i$i;$lim$02$i$i = $$lim$0$i$i;
   }
  }
 }
 $40 = HEAP32[$10>>2]|0;
 $41 = $lim$0$lcssa$i$i;
 $42 = $40;
 $43 = (($41) - ($42))|0;
 $44 = $43 >> 4;
 $45 = (($44) + 1)|0;
 $46 = (($45|0) / 8)&-1;
 $47 = (($46) + 10)|0;
 $48 = (($47) + ($45))|0;
 $49 = ($48|0)>(1000000);
 $$$i = $49 ? 1000000 : $48;
 $50 = ((($L)) + 92|0);
 $51 = HEAP32[$50>>2]|0;
 $52 = ($51|0)>(1000000);
 if ($52) {
  _luaE_freeCI($L);
 } else {
  _luaE_shrinkCI($L);
 }
 $53 = ($43|0)>(15999984);
 if ($53) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 $54 = HEAP32[$50>>2]|0;
 $55 = ($$$i|0)<($54|0);
 if (!($55)) {
  HEAP32[$6>>2] = $7;
  return ($8|0);
 }
 _luaD_reallocstack($L,$$$i);
 HEAP32[$6>>2] = $7;
 return ($8|0);
}
function _luaD_protectedparser($L,$z,$name,$mode) {
 $L = $L|0;
 $z = $z|0;
 $name = $name|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $p = sp;
 $0 = ((($L)) + 104|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 HEAP32[$p>>2] = $z;
 $3 = ((($p)) + 56|0);
 HEAP32[$3>>2] = $name;
 $4 = ((($p)) + 52|0);
 HEAP32[$4>>2] = $mode;
 $5 = ((($p)) + 16|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($p)) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($p)) + 28|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($p)) + 36|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($p)) + 40|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($p)) + 48|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($p)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($p)) + 12|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($L)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($L)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = $14;
 $18 = $16;
 $19 = (($17) - ($18))|0;
 $20 = ((($L)) + 88|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (_luaD_pcall($L,312,$p,$19,$21)|0);
 $23 = HEAP32[$11>>2]|0;
 $24 = HEAP32[$12>>2]|0;
 $25 = (_luaM_realloc_($L,$23,$24,0)|0);
 HEAP32[$11>>2] = $25;
 HEAP32[$12>>2] = 0;
 $26 = HEAP32[$5>>2]|0;
 $27 = HEAP32[$6>>2]|0;
 $28 = $27 << 1;
 (_luaM_realloc_($L,$26,$28,0)|0);
 $29 = HEAP32[$7>>2]|0;
 $30 = HEAP32[$8>>2]|0;
 $31 = $30 << 4;
 (_luaM_realloc_($L,$29,$31,0)|0);
 $32 = HEAP32[$9>>2]|0;
 $33 = HEAP32[$10>>2]|0;
 $34 = $33 << 4;
 (_luaM_realloc_($L,$32,$34,0)|0);
 $35 = HEAP16[$0>>1]|0;
 $36 = (($35) + -1)<<16>>16;
 HEAP16[$0>>1] = $36;
 STACKTOP = sp;return ($22|0);
}
function _resume($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $$0$i = 0, $$0$i9 = 0, $$1$i = 0, $$1$i10 = 0, $$25$i = 0, $$25$i13 = 0, $$phi$trans$insert$i = 0, $$phi$trans$insert$i5 = 0, $$pre = 0, $$pre$i = 0, $$pre$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0;
 var $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0;
 var $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $firstArg$0 = 0, $i$03$i = 0, $i$03$i$lcssa = 0, $i$03$i15 = 0, $i$03$i15$lcssa = 0, $i$11$i = 0, $i$11$i18 = 0, $res$04$i = 0, $res$04$i$lcssa = 0;
 var $res$04$i14 = 0, $res$04$i14$lcssa = 0, $res$1$lcssa$i = 0, $res$1$lcssa$i22 = 0, $res$12$i = 0, $res$12$i17 = 0, $scevgep$i = 0, $scevgep$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1&65535)>(199);
 if ($4) {
  _resume_error($L,1224,$ud);
  // unreachable;
 }
 $5 = ((($L)) + 6|0);
 $6 = HEAP8[$5>>0]|0;
 if ((($6<<24>>24) == 1)) {
  HEAP8[$5>>0] = 0;
  $12 = ((($L)) + 28|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($3)) + 28|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + ($15)|0);
  HEAP32[$3>>2] = $16;
  $17 = ((($3)) + 34|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18 & 2;
  $20 = ($19<<24>>24)==(0);
  if ($20) {
   $21 = ((($3)) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0|0);
   if ($23) {
    $36 = $3;$firstArg$0 = $ud;
   } else {
    $24 = ((($3)) + 24|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = (FUNCTION_TABLE_iiii[$22 & 511]($L,1,$25)|0);
    $27 = ((($L)) + 8|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = (0 - ($26))|0;
    $30 = (($28) + ($29<<4)|0);
    $$pre = HEAP32[$2>>2]|0;
    $36 = $$pre;$firstArg$0 = $30;
   }
   $31 = ((($L)) + 108|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = $33 & 6;
   $35 = ($34|0)==(0);
   if ($35) {
    $$phi$trans$insert$i = ((($36)) + 8|0);
    $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$1$i = $firstArg$0;$54 = $$pre$i;
   } else {
    $37 = $33 & 2;
    $38 = ($37|0)==(0);
    if ($38) {
     $$0$i = $firstArg$0;
    } else {
     $39 = HEAP32[$12>>2]|0;
     $40 = $firstArg$0;
     $41 = $39;
     $42 = (($40) - ($41))|0;
     _luaD_hook($L,1,-1);
     $43 = HEAP32[$12>>2]|0;
     $44 = (($43) + ($42)|0);
     $$0$i = $44;
    }
    $45 = ((($36)) + 8|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = ((($46)) + 20|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = ((($L)) + 20|0);
    HEAP32[$49>>2] = $48;
    $50 = $46;
    $$1$i = $$0$i;$54 = $50;
   }
   $51 = HEAP32[$36>>2]|0;
   $52 = ((($36)) + 32|0);
   $53 = HEAP16[$52>>1]|0;
   HEAP32[$2>>2] = $54;
   $55 = ((($L)) + 8|0);
   $56 = ($53<<16>>16)==(0);
   L19: do {
    if ($56) {
     $res$1$lcssa$i = $51;
    } else {
     $57 = $53 << 16 >> 16;
     $$25$i = $$1$i;$i$03$i = $57;$res$04$i = $51;
     while(1) {
      $59 = HEAP32[$55>>2]|0;
      $60 = ($$25$i>>>0)<($59>>>0);
      if (!($60)) {
       $i$03$i$lcssa = $i$03$i;$res$04$i$lcssa = $res$04$i;
       break;
      }
      $61 = ((($res$04$i)) + 16|0);
      $62 = ((($$25$i)) + 16|0);
      ;HEAP32[$res$04$i>>2]=HEAP32[$$25$i>>2]|0;HEAP32[$res$04$i+4>>2]=HEAP32[$$25$i+4>>2]|0;HEAP32[$res$04$i+8>>2]=HEAP32[$$25$i+8>>2]|0;HEAP32[$res$04$i+12>>2]=HEAP32[$$25$i+12>>2]|0;
      $63 = (($i$03$i) + -1)|0;
      $64 = ($63|0)==(0);
      if ($64) {
       $res$1$lcssa$i = $61;
       break L19;
      } else {
       $$25$i = $62;$i$03$i = $63;$res$04$i = $61;
      }
     }
     $58 = ($i$03$i$lcssa|0)>(0);
     if ($58) {
      $i$11$i = $i$03$i$lcssa;$res$12$i = $res$04$i$lcssa;
      while(1) {
       $65 = (($i$11$i) + -1)|0;
       $66 = ((($res$12$i)) + 16|0);
       $67 = ((($res$12$i)) + 8|0);
       HEAP32[$67>>2] = 0;
       $68 = ($i$11$i|0)>(1);
       if ($68) {
        $i$11$i = $65;$res$12$i = $66;
       } else {
        break;
       }
      }
      $scevgep$i = (($res$04$i$lcssa) + ($i$03$i$lcssa<<4)|0);
      $res$1$lcssa$i = $scevgep$i;
     } else {
      $res$1$lcssa$i = $res$04$i$lcssa;
     }
    }
   } while(0);
   HEAP32[$55>>2] = $res$1$lcssa$i;
  } else {
   _luaV_execute($L);
  }
  $69 = HEAP32[$2>>2]|0;
  $70 = ((($L)) + 48|0);
  $71 = ($69|0)==($70|0);
  if ($71) {
   return;
  }
  $72 = ((($L)) + 8|0);
  $73 = ((($L)) + 108|0);
  $74 = ((($L)) + 20|0);
  $75 = ((($L)) + 88|0);
  $77 = $69;
  while(1) {
   $76 = ((($77)) + 34|0);
   $78 = HEAP8[$76>>0]|0;
   $79 = $78 & 2;
   $80 = ($79<<24>>24)==(0);
   if ($80) {
    $81 = $78&255;
    $82 = $81 & 16;
    $83 = ($82|0)==(0);
    if (!($83)) {
     $84 = $81 & 239;
     $85 = $84&255;
     HEAP8[$76>>0] = $85;
     $86 = ((($77)) + 20|0);
     $87 = HEAP32[$86>>2]|0;
     HEAP32[$75>>2] = $87;
    }
    $88 = ((($77)) + 32|0);
    $89 = HEAP16[$88>>1]|0;
    $90 = ($89<<16>>16)==(-1);
    if ($90) {
     $91 = ((($77)) + 4|0);
     $92 = HEAP32[$91>>2]|0;
     $93 = HEAP32[$72>>2]|0;
     $94 = ($92>>>0)<($93>>>0);
     if ($94) {
      HEAP32[$91>>2] = $93;
     }
    }
    $95 = ((($77)) + 16|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($77)) + 24|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (FUNCTION_TABLE_iiii[$96 & 511]($L,1,$98)|0);
    $100 = HEAP32[$72>>2]|0;
    $101 = (0 - ($99))|0;
    $102 = (($100) + ($101<<4)|0);
    $103 = HEAP32[$2>>2]|0;
    $104 = HEAP8[$73>>0]|0;
    $105 = $104&255;
    $106 = $105 & 6;
    $107 = ($106|0)==(0);
    if ($107) {
     $$phi$trans$insert$i5 = ((($103)) + 8|0);
     $$pre$i7 = HEAP32[$$phi$trans$insert$i5>>2]|0;
     $$1$i10 = $102;$124 = $$pre$i7;
    } else {
     $108 = $105 & 2;
     $109 = ($108|0)==(0);
     if ($109) {
      $$0$i9 = $102;
     } else {
      $110 = HEAP32[$12>>2]|0;
      $111 = $102;
      $112 = $110;
      $113 = (($111) - ($112))|0;
      _luaD_hook($L,1,-1);
      $114 = HEAP32[$12>>2]|0;
      $115 = (($114) + ($113)|0);
      $$0$i9 = $115;
     }
     $116 = ((($103)) + 8|0);
     $117 = HEAP32[$116>>2]|0;
     $118 = ((($117)) + 20|0);
     $119 = HEAP32[$118>>2]|0;
     HEAP32[$74>>2] = $119;
     $120 = $117;
     $$1$i10 = $$0$i9;$124 = $120;
    }
    $121 = HEAP32[$103>>2]|0;
    $122 = ((($103)) + 32|0);
    $123 = HEAP16[$122>>1]|0;
    HEAP32[$2>>2] = $124;
    $125 = ($123<<16>>16)==(0);
    L52: do {
     if ($125) {
      $res$1$lcssa$i22 = $121;
     } else {
      $126 = $123 << 16 >> 16;
      $$25$i13 = $$1$i10;$i$03$i15 = $126;$res$04$i14 = $121;
      while(1) {
       $128 = HEAP32[$72>>2]|0;
       $129 = ($$25$i13>>>0)<($128>>>0);
       if (!($129)) {
        $i$03$i15$lcssa = $i$03$i15;$res$04$i14$lcssa = $res$04$i14;
        break;
       }
       $130 = ((($res$04$i14)) + 16|0);
       $131 = ((($$25$i13)) + 16|0);
       ;HEAP32[$res$04$i14>>2]=HEAP32[$$25$i13>>2]|0;HEAP32[$res$04$i14+4>>2]=HEAP32[$$25$i13+4>>2]|0;HEAP32[$res$04$i14+8>>2]=HEAP32[$$25$i13+8>>2]|0;HEAP32[$res$04$i14+12>>2]=HEAP32[$$25$i13+12>>2]|0;
       $132 = (($i$03$i15) + -1)|0;
       $133 = ($132|0)==(0);
       if ($133) {
        $res$1$lcssa$i22 = $130;
        break L52;
       } else {
        $$25$i13 = $131;$i$03$i15 = $132;$res$04$i14 = $130;
       }
      }
      $127 = ($i$03$i15$lcssa|0)>(0);
      if ($127) {
       $i$11$i18 = $i$03$i15$lcssa;$res$12$i17 = $res$04$i14$lcssa;
       while(1) {
        $134 = (($i$11$i18) + -1)|0;
        $135 = ((($res$12$i17)) + 16|0);
        $136 = ((($res$12$i17)) + 8|0);
        HEAP32[$136>>2] = 0;
        $137 = ($i$11$i18|0)>(1);
        if ($137) {
         $i$11$i18 = $134;$res$12$i17 = $135;
        } else {
         break;
        }
       }
       $scevgep$i20 = (($res$04$i14$lcssa) + ($i$03$i15$lcssa<<4)|0);
       $res$1$lcssa$i22 = $scevgep$i20;
      } else {
       $res$1$lcssa$i22 = $res$04$i14$lcssa;
      }
     }
    } while(0);
    HEAP32[$72>>2] = $res$1$lcssa$i22;
   } else {
    _luaV_finishOp($L);
    _luaV_execute($L);
   }
   $138 = HEAP32[$2>>2]|0;
   $139 = ($138|0)==($70|0);
   if ($139) {
    break;
   } else {
    $77 = $138;
   }
  }
  return;
 } else if ((($6<<24>>24) == 0)) {
  $7 = ((($L)) + 48|0);
  $8 = ($3|0)==($7|0);
  if (!($8)) {
   _resume_error($L,1408,$ud);
   // unreachable;
  }
  $9 = ((($ud)) + -16|0);
  $10 = (_luaD_precall($L,$9,-1)|0);
  $11 = ($10|0)==(0);
  if (!($11)) {
   return;
  }
  _luaV_execute($L);
  return;
 } else {
  _resume_error($L,7336,$ud);
  // unreachable;
 }
}
function _unroll($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($ud|0)==(0|0);
 if (!($0)) {
  $1 = HEAP32[$ud>>2]|0;
  _finishCcall($L,$1);
 }
 $2 = ((($L)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($L)) + 48|0);
 $5 = ($3|0)==($4|0);
 if ($5) {
  return;
 } else {
  $7 = $3;
 }
 while(1) {
  $6 = ((($7)) + 34|0);
  $8 = HEAP8[$6>>0]|0;
  $9 = $8 & 2;
  $10 = ($9<<24>>24)==(0);
  if ($10) {
   _finishCcall($L,1);
  } else {
   _luaV_finishOp($L);
   _luaV_execute($L);
  }
  $11 = HEAP32[$2>>2]|0;
  $12 = ($11|0)==($4|0);
  if ($12) {
   break;
  } else {
   $7 = $11;
  }
 }
 return;
}
function _f_parser($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cl$0 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$ud>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = ($1|0)==(0);
 if ($3) {
  $9 = (_luaZ_fill($0)|0);
  $11 = $9;
 } else {
  $4 = ((($0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 1|0);
  HEAP32[$4>>2] = $6;
  $7 = HEAP8[$5>>0]|0;
  $8 = $7&255;
  $11 = $8;
 }
 $10 = ($11|0)==(27);
 $12 = ((($ud)) + 52|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($10) {
  if (!($14)) {
   $15 = (_strchr($13,98)|0);
   $16 = ($15|0)==(0|0);
   if ($16) {
    HEAP32[$vararg_buffer>>2] = 1392;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $13;
    (_luaO_pushfstring($L,1344,$vararg_buffer)|0);
    _luaD_throw($L,3);
    // unreachable;
   }
  }
  $17 = HEAP32[$ud>>2]|0;
  $18 = ((($ud)) + 4|0);
  $19 = ((($ud)) + 56|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (_luaU_undump($L,$17,$18,$20)|0);
  $cl$0 = $21;
  _luaF_initupvals($L,$cl$0);
  STACKTOP = sp;return;
 } else {
  if (!($14)) {
   $22 = (_strchr($13,116)|0);
   $23 = ($22|0)==(0|0);
   if ($23) {
    HEAP32[$vararg_buffer2>>2] = 1400;
    $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
    HEAP32[$vararg_ptr5>>2] = $13;
    (_luaO_pushfstring($L,1344,$vararg_buffer2)|0);
    _luaD_throw($L,3);
    // unreachable;
   }
  }
  $24 = HEAP32[$ud>>2]|0;
  $25 = ((($ud)) + 4|0);
  $26 = ((($ud)) + 16|0);
  $27 = ((($ud)) + 56|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (_luaY_parser($L,$24,$25,$26,$28,$11)|0);
  $cl$0 = $29;
  _luaF_initupvals($L,$cl$0);
  STACKTOP = sp;return;
 }
}
function _finishCcall($L,$status) {
 $L = $L|0;
 $status = $status|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 34|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 16;
 $6 = ($5|0)==(0);
 if (!($6)) {
  $7 = $4 & 239;
  $8 = $7&255;
  HEAP8[$2>>0] = $8;
  $9 = ((($1)) + 20|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ((($L)) + 88|0);
  HEAP32[$11>>2] = $10;
 }
 $12 = ((($1)) + 32|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = ($13<<16>>16)==(-1);
 if ($14) {
  $15 = ((($1)) + 4|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($L)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($16>>>0)<($18>>>0);
  if ($19) {
   HEAP32[$15>>2] = $18;
   $$pre$phiZ2D = $17;
  } else {
   $$pre$phiZ2D = $17;
  }
 } else {
  $$pre = ((($L)) + 8|0);
  $$pre$phiZ2D = $$pre;
 }
 $20 = ((($1)) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($1)) + 24|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = (FUNCTION_TABLE_iiii[$21 & 511]($L,$status,$23)|0);
 $25 = HEAP32[$$pre$phiZ2D>>2]|0;
 $26 = (0 - ($24))|0;
 $27 = (($25) + ($26<<4)|0);
 (_luaD_poscall($L,$27)|0);
 return;
}
function _resume_error($L,$msg,$firstArg) {
 $L = $L|0;
 $msg = $msg|0;
 $firstArg = $firstArg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 HEAP32[$0>>2] = $firstArg;
 $1 = (_luaS_new($L,$msg)|0);
 HEAP32[$firstArg>>2] = $1;
 $2 = ((($1)) + 4|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 | 64;
 $6 = ((($firstArg)) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$0>>2]|0;
 $8 = ((($7)) + 16|0);
 HEAP32[$0>>2] = $8;
 _luaD_throw($L,-1);
 // unreachable;
}
function _luaU_dump($L,$f,$w,$data,$strip) {
 $L = $L|0;
 $f = $f|0;
 $w = $w|0;
 $data = $data|0;
 $strip = $strip|0;
 var $$ph21$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $D = 0, $x$i = 0, $x$i$i = 0, $x$i1$i = 0, $x$i10$i = 0, $x$i12$i = 0, $x$i4$i = 0, $x$i6$i = 0, $x$i8$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp + 43|0;
 $0 = sp + 8|0;
 $1 = sp;
 $x$i12$i = sp + 42|0;
 $x$i10$i = sp + 41|0;
 $x$i8$i = sp + 40|0;
 $x$i6$i = sp + 39|0;
 $x$i4$i = sp + 38|0;
 $x$i1$i = sp + 37|0;
 $x$i$i = sp + 36|0;
 $D = sp + 16|0;
 HEAP32[$D>>2] = $L;
 $2 = ((($D)) + 4|0);
 HEAP32[$2>>2] = $w;
 $3 = ((($D)) + 8|0);
 HEAP32[$3>>2] = $data;
 $4 = ((($D)) + 12|0);
 HEAP32[$4>>2] = $strip;
 $5 = ((($D)) + 16|0);
 $6 = (FUNCTION_TABLE_iiiii[$w & 511]($L,3320,4,$data)|0);
 HEAP32[$5>>2] = $6;
 HEAP8[$x$i$i>>0] = 83;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (FUNCTION_TABLE_iiiii[$w & 511]($L,$x$i$i,1,$data)|0);
  HEAP32[$5>>2] = $8;
  HEAP8[$x$i1$i>>0] = 0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = HEAP32[$2>>2]|0;
   $11 = HEAP32[$D>>2]|0;
   $12 = HEAP32[$3>>2]|0;
   $13 = (FUNCTION_TABLE_iiiii[$10 & 511]($11,$x$i1$i,1,$12)|0);
   HEAP32[$5>>2] = $13;
   $14 = ($13|0)==(0);
   if ($14) {
    $15 = HEAP32[$2>>2]|0;
    $16 = HEAP32[$D>>2]|0;
    $17 = HEAP32[$3>>2]|0;
    $18 = (FUNCTION_TABLE_iiiii[$15 & 511]($16,3384,6,$17)|0);
    HEAP32[$5>>2] = $18;
    HEAP8[$x$i4$i>>0] = 4;
    $19 = ($18|0)==(0);
    if ($19) {
     $20 = HEAP32[$2>>2]|0;
     $21 = HEAP32[$D>>2]|0;
     $22 = HEAP32[$3>>2]|0;
     $23 = (FUNCTION_TABLE_iiiii[$20 & 511]($21,$x$i4$i,1,$22)|0);
     HEAP32[$5>>2] = $23;
     HEAP8[$x$i6$i>>0] = 4;
     $24 = ($23|0)==(0);
     if ($24) {
      $25 = HEAP32[$2>>2]|0;
      $26 = HEAP32[$D>>2]|0;
      $27 = HEAP32[$3>>2]|0;
      $28 = (FUNCTION_TABLE_iiiii[$25 & 511]($26,$x$i6$i,1,$27)|0);
      HEAP32[$5>>2] = $28;
      HEAP8[$x$i8$i>>0] = 4;
      $29 = ($28|0)==(0);
      if ($29) {
       $30 = HEAP32[$2>>2]|0;
       $31 = HEAP32[$D>>2]|0;
       $32 = HEAP32[$3>>2]|0;
       $33 = (FUNCTION_TABLE_iiiii[$30 & 511]($31,$x$i8$i,1,$32)|0);
       HEAP32[$5>>2] = $33;
       HEAP8[$x$i10$i>>0] = 8;
       $34 = ($33|0)==(0);
       if ($34) {
        $35 = HEAP32[$2>>2]|0;
        $36 = HEAP32[$D>>2]|0;
        $37 = HEAP32[$3>>2]|0;
        $38 = (FUNCTION_TABLE_iiiii[$35 & 511]($36,$x$i10$i,1,$37)|0);
        HEAP32[$5>>2] = $38;
        HEAP8[$x$i12$i>>0] = 8;
        $39 = ($38|0)==(0);
        if ($39) {
         $44 = HEAP32[$2>>2]|0;
         $45 = HEAP32[$D>>2]|0;
         $46 = HEAP32[$3>>2]|0;
         $47 = (FUNCTION_TABLE_iiiii[$44 & 511]($45,$x$i12$i,1,$46)|0);
         HEAP32[$5>>2] = $47;
         $48 = $1;
         $49 = $48;
         HEAP32[$49>>2] = 22136;
         $50 = (($48) + 4)|0;
         $51 = $50;
         HEAP32[$51>>2] = 0;
         $52 = ($47|0)==(0);
         if ($52) {
          $53 = HEAP32[$2>>2]|0;
          $54 = HEAP32[$D>>2]|0;
          $55 = HEAP32[$3>>2]|0;
          $56 = (FUNCTION_TABLE_iiiii[$53 & 511]($54,$1,8,$55)|0);
          HEAP32[$5>>2] = $56;
          HEAPF64[$0>>3] = 370.5;
          $57 = ($56|0)==(0);
          if ($57) {
           $58 = HEAP32[$2>>2]|0;
           $59 = HEAP32[$D>>2]|0;
           $60 = HEAP32[$3>>2]|0;
           $61 = (FUNCTION_TABLE_iiiii[$58 & 511]($59,$0,8,$60)|0);
           HEAP32[$5>>2] = $61;
           $66 = $61;$80 = $0;
          } else {
           $66 = $56;$80 = $0;
          }
         } else {
          $$ph21$i = $1;$79 = $47;
          label = 18;
         }
        } else {
         $78 = $38;
         label = 16;
        }
       } else {
        $77 = $33;
        label = 14;
       }
      } else {
       $76 = $28;
       label = 12;
      }
     } else {
      $75 = $23;
      label = 10;
     }
    } else {
     $74 = $18;
     label = 8;
    }
   } else {
    $73 = $13;
    label = 6;
   }
  } else {
   $72 = $8;
   label = 4;
  }
 } else {
  HEAP8[$x$i1$i>>0] = 0;
  $72 = $6;
  label = 4;
 }
 if ((label|0) == 4) {
  $73 = $72;
  label = 6;
 }
 if ((label|0) == 6) {
  HEAP8[$x$i4$i>>0] = 4;
  $74 = $73;
  label = 8;
 }
 if ((label|0) == 8) {
  HEAP8[$x$i6$i>>0] = 4;
  $75 = $74;
  label = 10;
 }
 if ((label|0) == 10) {
  HEAP8[$x$i8$i>>0] = 4;
  $76 = $75;
  label = 12;
 }
 if ((label|0) == 12) {
  HEAP8[$x$i10$i>>0] = 8;
  $77 = $76;
  label = 14;
 }
 if ((label|0) == 14) {
  HEAP8[$x$i12$i>>0] = 8;
  $78 = $77;
  label = 16;
 }
 if ((label|0) == 16) {
  $40 = $1;
  $41 = $40;
  HEAP32[$41>>2] = 22136;
  $42 = (($40) + 4)|0;
  $43 = $42;
  HEAP32[$43>>2] = 0;
  $$ph21$i = $1;$79 = $78;
  label = 18;
 }
 if ((label|0) == 18) {
  HEAPF64[$0>>3] = 370.5;
  $66 = $79;$80 = $0;
 }
 $62 = ((($f)) + 12|0);
 $63 = HEAP32[$62>>2]|0;
 $64 = $63&255;
 HEAP8[$x$i>>0] = $64;
 $65 = ($66|0)==(0);
 if (!($65)) {
  _DumpFunction($f,0,$D);
  $71 = HEAP32[$5>>2]|0;
  STACKTOP = sp;return ($71|0);
 }
 $67 = HEAP32[$2>>2]|0;
 $68 = HEAP32[$D>>2]|0;
 $69 = HEAP32[$3>>2]|0;
 $70 = (FUNCTION_TABLE_iiiii[$67 & 511]($68,$x$i,1,$69)|0);
 HEAP32[$5>>2] = $70;
 _DumpFunction($f,0,$D);
 $71 = HEAP32[$5>>2]|0;
 STACKTOP = sp;return ($71|0);
}
function _DumpFunction($f,$psource,$D) {
 $f = $f|0;
 $psource = $psource|0;
 $D = $D|0;
 var $$ph50 = 0, $$pr$i = 0, $$pr$i22 = 0, $$pr30$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i23 = 0, $$pre$i1 = 0, $$pre$i10$i = 0, $$pre$i20 = 0, $$pre$i31 = 0, $$pre$phi49Z2D = 0, $$pre$phiZ2D = 0, $$pre$pre$phiZZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0;
 var $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0;
 var $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0;
 var $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0.0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0;
 var $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0;
 var $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0;
 var $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0;
 var $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0;
 var $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0;
 var $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0;
 var $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0;
 var $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0;
 var $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0;
 var $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0;
 var $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0;
 var $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0;
 var $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0;
 var $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0;
 var $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0;
 var $464 = 0, $465 = 0, $466 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i26 = 0, $exitcond$i33 = 0, $exitcond35$i = 0, $i$0$i48 = 0, $i$012$i = 0, $i$03$i = 0, $i$032$i = 0, $i$131$i = 0, $size$i = 0, $size$i$i = 0, $size$i$i16 = 0, $size$i9$i = 0, $x$i = 0, $x$i$i = 0, $x$i$i17 = 0, $x$i$i28 = 0, $x$i1$i = 0;
 var $x$i1$i27 = 0, $x$i10 = 0, $x$i15$i = 0, $x$i18$i = 0, $x$i21$i = 0, $x$i24$i = 0, $x$i27$i = 0, $x$i3$i = 0, $x$i36 = 0, $x$i39 = 0, $x$i42 = 0, $x$i45 = 0, $x$i6$i = 0, $x$i7 = 0, $x$i9$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i45 = sp + 95|0;
 $x$i42 = sp + 94|0;
 $x$i39 = sp + 93|0;
 $x$i36 = sp + 92|0;
 $0 = sp + 72|0;
 $x$i1$i27 = sp + 91|0;
 $x$i$i28 = sp + 90|0;
 $1 = sp + 68|0;
 $x$i9$i = sp + 89|0;
 $x$i6$i = sp + 88|0;
 $x$i3$i = sp + 87|0;
 $size$i$i16 = sp + 64|0;
 $2 = sp + 8|0;
 $3 = sp;
 $x$i1$i = sp + 86|0;
 $x$i$i17 = sp + 85|0;
 $4 = sp + 60|0;
 $5 = sp + 56|0;
 $x$i10 = sp + 84|0;
 $x$i7 = sp + 83|0;
 $x$i = sp + 82|0;
 $6 = sp + 52|0;
 $7 = sp + 48|0;
 $size$i = sp + 44|0;
 $x$i27$i = sp + 81|0;
 $x$i24$i = sp + 80|0;
 $x$i21$i = sp + 79|0;
 $x$i18$i = sp + 78|0;
 $x$i15$i = sp + 77|0;
 $x$i$i = sp + 76|0;
 $size$i9$i = sp + 40|0;
 $8 = sp + 36|0;
 $9 = sp + 32|0;
 $10 = sp + 28|0;
 $size$i$i = sp + 24|0;
 $11 = sp + 20|0;
 $12 = sp + 16|0;
 $13 = ((($D)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = ((($f)) + 72|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($psource|0);
  if ($18) {
   label = 3;
  } else {
   $28 = ($17|0)==(0|0);
   do {
    if ($28) {
     HEAP8[$x$i39>>0] = 0;
     $29 = ((($D)) + 16|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0);
     if ($31) {
      $32 = ((($D)) + 4|0);
      $33 = HEAP32[$32>>2]|0;
      $34 = HEAP32[$D>>2]|0;
      $35 = ((($D)) + 8|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (FUNCTION_TABLE_iiiii[$33 & 511]($34,$x$i39,1,$36)|0);
      HEAP32[$29>>2] = $37;
      $448 = $37;
     } else {
      $448 = $30;
     }
     $$pre$pre$phiZZ2D = $29;$449 = $448;
    } else {
     $38 = ((($17)) + 12|0);
     $39 = HEAP32[$38>>2]|0;
     $40 = (($39) + 1)|0;
     HEAP32[$size$i>>2] = $40;
     $41 = ($40>>>0)<(255);
     if ($41) {
      $42 = $40&255;
      HEAP8[$x$i42>>0] = $42;
      $43 = ((($D)) + 16|0);
      $44 = HEAP32[$43>>2]|0;
      $45 = ($44|0)==(0);
      if ($45) {
       $46 = ((($D)) + 4|0);
       $47 = HEAP32[$46>>2]|0;
       $48 = HEAP32[$D>>2]|0;
       $49 = ((($D)) + 8|0);
       $50 = HEAP32[$49>>2]|0;
       $51 = (FUNCTION_TABLE_iiiii[$47 & 511]($48,$x$i42,1,$50)|0);
       HEAP32[$43>>2] = $51;
       $450 = $51;
      } else {
       $450 = $44;
      }
      $$pre$phi49Z2D = $43;$69 = $450;$71 = $40;
     } else {
      HEAP8[$x$i45>>0] = -1;
      $52 = ((($D)) + 16|0);
      $53 = HEAP32[$52>>2]|0;
      $54 = ($53|0)==(0);
      if (!($54)) {
       $$pre$pre$phiZZ2D = $52;$449 = $53;
       break;
      }
      $55 = ((($D)) + 4|0);
      $56 = HEAP32[$55>>2]|0;
      $57 = HEAP32[$D>>2]|0;
      $58 = ((($D)) + 8|0);
      $59 = HEAP32[$58>>2]|0;
      $60 = (FUNCTION_TABLE_iiiii[$56 & 511]($57,$x$i45,1,$59)|0);
      HEAP32[$52>>2] = $60;
      $61 = ($60|0)==(0);
      if (!($61)) {
       $$pre$pre$phiZZ2D = $52;$449 = $60;
       break;
      }
      $62 = ((($D)) + 4|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = HEAP32[$D>>2]|0;
      $65 = ((($D)) + 8|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = (FUNCTION_TABLE_iiiii[$63 & 511]($64,$size$i,4,$66)|0);
      HEAP32[$52>>2] = $67;
      $$pre$i1 = HEAP32[$size$i>>2]|0;
      $$pre$phi49Z2D = $52;$69 = $67;$71 = $$pre$i1;
     }
     $68 = ($69|0)==(0);
     if ($68) {
      $70 = (($71) + -1)|0;
      $72 = ((($17)) + 24|0);
      $73 = ((($D)) + 4|0);
      $74 = HEAP32[$73>>2]|0;
      $75 = HEAP32[$D>>2]|0;
      $76 = ((($D)) + 8|0);
      $77 = HEAP32[$76>>2]|0;
      $78 = (FUNCTION_TABLE_iiiii[$74 & 511]($75,$72,$70,$77)|0);
      HEAP32[$$pre$phi49Z2D>>2] = $78;
      $$pre$pre$phiZZ2D = $$pre$phi49Z2D;$449 = $78;
     } else {
      $$pre$pre$phiZZ2D = $$pre$phi49Z2D;$449 = $69;
     }
    }
   } while(0);
   $$pre$phiZ2D = $$pre$pre$phiZZ2D;$82 = $449;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  HEAP8[$x$i36>>0] = 0;
  $19 = ((($D)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = ((($D)) + 4|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = HEAP32[$D>>2]|0;
   $25 = ((($D)) + 8|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (FUNCTION_TABLE_iiiii[$23 & 511]($24,$x$i36,1,$26)|0);
   HEAP32[$19>>2] = $27;
   $447 = $27;
  } else {
   $447 = $20;
  }
  $$pre$phiZ2D = $19;$82 = $447;
 }
 $79 = ((($f)) + 36|0);
 $80 = HEAP32[$79>>2]|0;
 HEAP32[$7>>2] = $80;
 $81 = ($82|0)==(0);
 if ($81) {
  $83 = ((($D)) + 4|0);
  $84 = HEAP32[$83>>2]|0;
  $85 = HEAP32[$D>>2]|0;
  $86 = ((($D)) + 8|0);
  $87 = HEAP32[$86>>2]|0;
  $88 = (FUNCTION_TABLE_iiiii[$84 & 511]($85,$7,4,$87)|0);
  HEAP32[$$pre$phiZ2D>>2] = $88;
  $92 = $88;
 } else {
  $92 = $82;
 }
 $89 = ((($f)) + 40|0);
 $90 = HEAP32[$89>>2]|0;
 HEAP32[$6>>2] = $90;
 $91 = ($92|0)==(0);
 if ($91) {
  $93 = ((($D)) + 4|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = HEAP32[$D>>2]|0;
  $96 = ((($D)) + 8|0);
  $97 = HEAP32[$96>>2]|0;
  $98 = (FUNCTION_TABLE_iiiii[$94 & 511]($95,$6,4,$97)|0);
  HEAP32[$$pre$phiZ2D>>2] = $98;
  $102 = $98;
 } else {
  $102 = $92;
 }
 $99 = ((($f)) + 6|0);
 $100 = HEAP8[$99>>0]|0;
 HEAP8[$x$i>>0] = $100;
 $101 = ($102|0)==(0);
 if ($101) {
  $103 = ((($D)) + 4|0);
  $104 = HEAP32[$103>>2]|0;
  $105 = HEAP32[$D>>2]|0;
  $106 = ((($D)) + 8|0);
  $107 = HEAP32[$106>>2]|0;
  $108 = (FUNCTION_TABLE_iiiii[$104 & 511]($105,$x$i,1,$107)|0);
  HEAP32[$$pre$phiZ2D>>2] = $108;
  $112 = $108;
 } else {
  $112 = $102;
 }
 $109 = ((($f)) + 7|0);
 $110 = HEAP8[$109>>0]|0;
 HEAP8[$x$i7>>0] = $110;
 $111 = ($112|0)==(0);
 if ($111) {
  $113 = ((($D)) + 4|0);
  $114 = HEAP32[$113>>2]|0;
  $115 = HEAP32[$D>>2]|0;
  $116 = ((($D)) + 8|0);
  $117 = HEAP32[$116>>2]|0;
  $118 = (FUNCTION_TABLE_iiiii[$114 & 511]($115,$x$i7,1,$117)|0);
  HEAP32[$$pre$phiZ2D>>2] = $118;
  $122 = $118;
 } else {
  $122 = $112;
 }
 $119 = ((($f)) + 8|0);
 $120 = HEAP8[$119>>0]|0;
 HEAP8[$x$i10>>0] = $120;
 $121 = ($122|0)==(0);
 if ($121) {
  $123 = ((($D)) + 4|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = HEAP32[$D>>2]|0;
  $126 = ((($D)) + 8|0);
  $127 = HEAP32[$126>>2]|0;
  $128 = (FUNCTION_TABLE_iiiii[$124 & 511]($125,$x$i10,1,$127)|0);
  HEAP32[$$pre$phiZ2D>>2] = $128;
  $132 = $128;
 } else {
  $132 = $122;
 }
 $129 = ((($f)) + 20|0);
 $130 = HEAP32[$129>>2]|0;
 HEAP32[$5>>2] = $130;
 $131 = ($132|0)==(0);
 if ($131) {
  $133 = ((($D)) + 4|0);
  $134 = HEAP32[$133>>2]|0;
  $135 = HEAP32[$D>>2]|0;
  $136 = ((($D)) + 8|0);
  $137 = HEAP32[$136>>2]|0;
  $138 = (FUNCTION_TABLE_iiiii[$134 & 511]($135,$5,4,$137)|0);
  HEAP32[$$pre$phiZ2D>>2] = $138;
  $139 = ($138|0)==(0);
  if ($139) {
   $142 = HEAP32[$129>>2]|0;
   $143 = $142 << 2;
   $144 = ((($f)) + 48|0);
   $145 = HEAP32[$144>>2]|0;
   $146 = HEAP32[$133>>2]|0;
   $147 = HEAP32[$D>>2]|0;
   $148 = HEAP32[$136>>2]|0;
   $149 = (FUNCTION_TABLE_iiiii[$146 & 511]($147,$145,$143,$148)|0);
   HEAP32[$$pre$phiZ2D>>2] = $149;
   $150 = ((($f)) + 16|0);
   $151 = HEAP32[$150>>2]|0;
   HEAP32[$4>>2] = $151;
   $152 = ($149|0)==(0);
   if ($152) {
    $153 = ((($D)) + 4|0);
    $154 = HEAP32[$153>>2]|0;
    $155 = HEAP32[$D>>2]|0;
    $156 = ((($D)) + 8|0);
    $157 = HEAP32[$156>>2]|0;
    $158 = (FUNCTION_TABLE_iiiii[$154 & 511]($155,$4,4,$157)|0);
    HEAP32[$$pre$phiZ2D>>2] = $158;
    $160 = $151;$451 = $4;$452 = $158;
   } else {
    $160 = $151;$451 = $4;$452 = $149;
   }
  } else {
   $$ph50 = $138;
   label = 34;
  }
 } else {
  $$ph50 = $132;
  label = 34;
 }
 if ((label|0) == 34) {
  $140 = ((($f)) + 16|0);
  $141 = HEAP32[$140>>2]|0;
  HEAP32[$4>>2] = $141;
  $160 = $141;$451 = $4;$452 = $$ph50;
 }
 $159 = ($160|0)>(0);
 L52: do {
  if ($159) {
   $161 = ((($f)) + 44|0);
   $162 = ((($D)) + 4|0);
   $163 = ((($D)) + 8|0);
   $171 = $452;$i$012$i = 0;
   while(1) {
    $164 = HEAP32[$161>>2]|0;
    $165 = (($164) + ($i$012$i<<4)|0);
    $166 = (((($164) + ($i$012$i<<4)|0)) + 8|0);
    $167 = HEAP32[$166>>2]|0;
    $168 = $167 & 63;
    $169 = $168&255;
    HEAP8[$x$i$i17>>0] = $169;
    $170 = ($171|0)==(0);
    if ($170) {
     $172 = HEAP32[$162>>2]|0;
     $173 = HEAP32[$D>>2]|0;
     $174 = HEAP32[$163>>2]|0;
     $175 = (FUNCTION_TABLE_iiiii[$172 & 511]($173,$x$i$i17,1,$174)|0);
     HEAP32[$$pre$phiZ2D>>2] = $175;
     $$pre$i20 = HEAP32[$166>>2]|0;
     $177 = $$pre$i20;$181 = $175;
    } else {
     $177 = $167;$181 = $171;
    }
    $176 = $177 & 63;
    switch ($176|0) {
    case 1:  {
     $178 = HEAP32[$165>>2]|0;
     $179 = $178&255;
     HEAP8[$x$i1$i>>0] = $179;
     $180 = ($181|0)==(0);
     if ($180) {
      $182 = HEAP32[$162>>2]|0;
      $183 = HEAP32[$D>>2]|0;
      $184 = HEAP32[$163>>2]|0;
      $185 = (FUNCTION_TABLE_iiiii[$182 & 511]($183,$x$i1$i,1,$184)|0);
      HEAP32[$$pre$phiZ2D>>2] = $185;
      $454 = $185;
     } else {
      $454 = $181;
     }
     $453 = $454;
     break;
    }
    case 3:  {
     $186 = +HEAPF64[$165>>3];
     HEAPF64[$3>>3] = $186;
     $187 = ($181|0)==(0);
     if ($187) {
      $188 = HEAP32[$162>>2]|0;
      $189 = HEAP32[$D>>2]|0;
      $190 = HEAP32[$163>>2]|0;
      $191 = (FUNCTION_TABLE_iiiii[$188 & 511]($189,$3,8,$190)|0);
      HEAP32[$$pre$phiZ2D>>2] = $191;
      $455 = $191;
     } else {
      $455 = $181;
     }
     $453 = $455;
     break;
    }
    case 19:  {
     $192 = $165;
     $193 = $192;
     $194 = HEAP32[$193>>2]|0;
     $195 = (($192) + 4)|0;
     $196 = $195;
     $197 = HEAP32[$196>>2]|0;
     $198 = $2;
     $199 = $198;
     HEAP32[$199>>2] = $194;
     $200 = (($198) + 4)|0;
     $201 = $200;
     HEAP32[$201>>2] = $197;
     $202 = ($181|0)==(0);
     if ($202) {
      $203 = HEAP32[$162>>2]|0;
      $204 = HEAP32[$D>>2]|0;
      $205 = HEAP32[$163>>2]|0;
      $206 = (FUNCTION_TABLE_iiiii[$203 & 511]($204,$2,8,$205)|0);
      HEAP32[$$pre$phiZ2D>>2] = $206;
      $456 = $206;
     } else {
      $456 = $181;
     }
     $453 = $456;
     break;
    }
    case 4: case 20:  {
     $207 = HEAP32[$165>>2]|0;
     $208 = ($207|0)==(0|0);
     do {
      if ($208) {
       HEAP8[$x$i3$i>>0] = 0;
       $209 = ($181|0)==(0);
       if ($209) {
        $210 = HEAP32[$162>>2]|0;
        $211 = HEAP32[$D>>2]|0;
        $212 = HEAP32[$163>>2]|0;
        $213 = (FUNCTION_TABLE_iiiii[$210 & 511]($211,$x$i3$i,1,$212)|0);
        HEAP32[$$pre$phiZ2D>>2] = $213;
        $457 = $213;
       } else {
        $457 = $181;
       }
       $458 = $457;
      } else {
       $214 = ((($207)) + 12|0);
       $215 = HEAP32[$214>>2]|0;
       $216 = (($215) + 1)|0;
       HEAP32[$size$i$i16>>2] = $216;
       $217 = ($216>>>0)<(255);
       if ($217) {
        $218 = $216&255;
        HEAP8[$x$i6$i>>0] = $218;
        $219 = ($181|0)==(0);
        if ($219) {
         $220 = HEAP32[$162>>2]|0;
         $221 = HEAP32[$D>>2]|0;
         $222 = HEAP32[$163>>2]|0;
         $223 = (FUNCTION_TABLE_iiiii[$220 & 511]($221,$x$i6$i,1,$222)|0);
         HEAP32[$$pre$phiZ2D>>2] = $223;
         $$pr$i22 = $223;
        } else {
         $$pr$i22 = $181;
        }
        $235 = $$pr$i22;$237 = $216;
       } else {
        HEAP8[$x$i9$i>>0] = -1;
        $224 = ($181|0)==(0);
        if (!($224)) {
         $458 = $181;
         break;
        }
        $225 = HEAP32[$162>>2]|0;
        $226 = HEAP32[$D>>2]|0;
        $227 = HEAP32[$163>>2]|0;
        $228 = (FUNCTION_TABLE_iiiii[$225 & 511]($226,$x$i9$i,1,$227)|0);
        HEAP32[$$pre$phiZ2D>>2] = $228;
        $229 = ($228|0)==(0);
        if (!($229)) {
         $458 = $228;
         break;
        }
        $230 = HEAP32[$162>>2]|0;
        $231 = HEAP32[$D>>2]|0;
        $232 = HEAP32[$163>>2]|0;
        $233 = (FUNCTION_TABLE_iiiii[$230 & 511]($231,$size$i$i16,4,$232)|0);
        HEAP32[$$pre$phiZ2D>>2] = $233;
        $$pre$i$i23 = HEAP32[$size$i$i16>>2]|0;
        $235 = $233;$237 = $$pre$i$i23;
       }
       $234 = ($235|0)==(0);
       if ($234) {
        $236 = (($237) + -1)|0;
        $238 = ((($207)) + 24|0);
        $239 = HEAP32[$162>>2]|0;
        $240 = HEAP32[$D>>2]|0;
        $241 = HEAP32[$163>>2]|0;
        $242 = (FUNCTION_TABLE_iiiii[$239 & 511]($240,$238,$236,$241)|0);
        HEAP32[$$pre$phiZ2D>>2] = $242;
        $458 = $242;
       } else {
        $458 = $235;
       }
      }
     } while(0);
     $453 = $458;
     break;
    }
    default: {
     $453 = $181;
    }
    }
    $243 = (($i$012$i) + 1)|0;
    $exitcond$i26 = ($243|0)==($160|0);
    if ($exitcond$i26) {
     $247 = $453;
     break L52;
    } else {
     $171 = $453;$i$012$i = $243;
    }
   }
  } else {
   $247 = $452;
  }
 } while(0);
 $244 = ((($f)) + 12|0);
 $245 = HEAP32[$244>>2]|0;
 HEAP32[$1>>2] = $245;
 $246 = ($247|0)==(0);
 if ($246) {
  $248 = ((($D)) + 4|0);
  $249 = HEAP32[$248>>2]|0;
  $250 = HEAP32[$D>>2]|0;
  $251 = ((($D)) + 8|0);
  $252 = HEAP32[$251>>2]|0;
  $253 = (FUNCTION_TABLE_iiiii[$249 & 511]($250,$1,4,$252)|0);
  HEAP32[$$pre$phiZ2D>>2] = $253;
  $459 = $253;
 } else {
  $459 = $247;
 }
 $254 = ($245|0)>(0);
 if ($254) {
  $255 = ((($f)) + 64|0);
  $256 = ((($D)) + 4|0);
  $257 = ((($D)) + 8|0);
  $262 = $459;$i$03$i = 0;
  while(1) {
   $258 = HEAP32[$255>>2]|0;
   $259 = (((($258) + ($i$03$i<<3)|0)) + 4|0);
   $260 = HEAP8[$259>>0]|0;
   HEAP8[$x$i$i28>>0] = $260;
   $261 = ($262|0)==(0);
   if ($261) {
    $263 = HEAP32[$256>>2]|0;
    $264 = HEAP32[$D>>2]|0;
    $265 = HEAP32[$257>>2]|0;
    $266 = (FUNCTION_TABLE_iiiii[$263 & 511]($264,$x$i$i28,1,$265)|0);
    HEAP32[$$pre$phiZ2D>>2] = $266;
    $$pre$i31 = HEAP32[$255>>2]|0;
    $268 = $$pre$i31;$271 = $266;
   } else {
    $268 = $258;$271 = $262;
   }
   $267 = (((($268) + ($i$03$i<<3)|0)) + 5|0);
   $269 = HEAP8[$267>>0]|0;
   HEAP8[$x$i1$i27>>0] = $269;
   $270 = ($271|0)==(0);
   if ($270) {
    $272 = HEAP32[$256>>2]|0;
    $273 = HEAP32[$D>>2]|0;
    $274 = HEAP32[$257>>2]|0;
    $275 = (FUNCTION_TABLE_iiiii[$272 & 511]($273,$x$i1$i27,1,$274)|0);
    HEAP32[$$pre$phiZ2D>>2] = $275;
    $460 = $275;
   } else {
    $460 = $271;
   }
   $276 = (($i$03$i) + 1)|0;
   $exitcond$i33 = ($276|0)==($245|0);
   if ($exitcond$i33) {
    $280 = $460;
    break;
   } else {
    $262 = $460;$i$03$i = $276;
   }
  }
 } else {
  $280 = $459;
 }
 $277 = ((($f)) + 28|0);
 $278 = HEAP32[$277>>2]|0;
 HEAP32[$0>>2] = $278;
 $279 = ($280|0)==(0);
 if ($279) {
  $281 = ((($D)) + 4|0);
  $282 = HEAP32[$281>>2]|0;
  $283 = HEAP32[$D>>2]|0;
  $284 = ((($D)) + 8|0);
  $285 = HEAP32[$284>>2]|0;
  $286 = (FUNCTION_TABLE_iiiii[$282 & 511]($283,$0,4,$285)|0);
  HEAP32[$$pre$phiZ2D>>2] = $286;
 }
 $287 = ($278|0)>(0);
 if ($287) {
  $288 = ((($f)) + 52|0);
  $289 = ((($f)) + 72|0);
  $i$0$i48 = 0;
  while(1) {
   $290 = HEAP32[$288>>2]|0;
   $291 = (($290) + ($i$0$i48<<2)|0);
   $292 = HEAP32[$291>>2]|0;
   $293 = HEAP32[$289>>2]|0;
   _DumpFunction($292,$293,$D);
   $294 = (($i$0$i48) + 1)|0;
   $exitcond = ($294|0)==($278|0);
   if ($exitcond) {
    break;
   } else {
    $i$0$i48 = $294;
   }
  }
 }
 $295 = HEAP32[$13>>2]|0;
 $296 = ($295|0)==(0);
 if ($296) {
  $297 = ((($f)) + 24|0);
  $298 = HEAP32[$297>>2]|0;
  $299 = $298;
 } else {
  $299 = 0;
 }
 HEAP32[$12>>2] = $299;
 $300 = HEAP32[$$pre$phiZ2D>>2]|0;
 $301 = ($300|0)==(0);
 if ($301) {
  $302 = ((($D)) + 4|0);
  $303 = HEAP32[$302>>2]|0;
  $304 = HEAP32[$D>>2]|0;
  $305 = ((($D)) + 8|0);
  $306 = HEAP32[$305>>2]|0;
  $307 = (FUNCTION_TABLE_iiiii[$303 & 511]($304,$12,4,$306)|0);
  HEAP32[$$pre$phiZ2D>>2] = $307;
  $308 = ($307|0)==(0);
  if ($308) {
   $309 = $299 << 2;
   $310 = ((($f)) + 56|0);
   $311 = HEAP32[$310>>2]|0;
   $312 = HEAP32[$302>>2]|0;
   $313 = HEAP32[$D>>2]|0;
   $314 = HEAP32[$305>>2]|0;
   $315 = (FUNCTION_TABLE_iiiii[$312 & 511]($313,$311,$309,$314)|0);
   HEAP32[$$pre$phiZ2D>>2] = $315;
   $322 = $315;
  } else {
   $322 = $307;
  }
 } else {
  $322 = $300;
 }
 $316 = HEAP32[$13>>2]|0;
 $317 = ($316|0)==(0);
 if ($317) {
  $318 = ((($f)) + 32|0);
  $319 = HEAP32[$318>>2]|0;
  $320 = $319;
 } else {
  $320 = 0;
 }
 HEAP32[$11>>2] = $320;
 $321 = ($322|0)==(0);
 if ($321) {
  $323 = ((($D)) + 4|0);
  $324 = HEAP32[$323>>2]|0;
  $325 = HEAP32[$D>>2]|0;
  $326 = ((($D)) + 8|0);
  $327 = HEAP32[$326>>2]|0;
  $328 = (FUNCTION_TABLE_iiiii[$324 & 511]($325,$11,4,$327)|0);
  HEAP32[$$pre$phiZ2D>>2] = $328;
  $461 = $328;
 } else {
  $461 = $322;
 }
 $329 = ($320|0)>(0);
 if ($329) {
  $330 = ((($f)) + 60|0);
  $331 = ((($D)) + 4|0);
  $332 = ((($D)) + 8|0);
  $338 = $461;$i$032$i = 0;
  while(1) {
   $333 = HEAP32[$330>>2]|0;
   $334 = (($333) + (($i$032$i*12)|0)|0);
   $335 = HEAP32[$334>>2]|0;
   $336 = ($335|0)==(0|0);
   do {
    if ($336) {
     HEAP8[$x$i$i>>0] = 0;
     $337 = ($338|0)==(0);
     if ($337) {
      $339 = HEAP32[$331>>2]|0;
      $340 = HEAP32[$D>>2]|0;
      $341 = HEAP32[$332>>2]|0;
      $342 = (FUNCTION_TABLE_iiiii[$339 & 511]($340,$x$i$i,1,$341)|0);
      HEAP32[$$pre$phiZ2D>>2] = $342;
      $462 = $342;
     } else {
      $462 = $338;
     }
     $376 = $462;
    } else {
     $343 = ((($335)) + 12|0);
     $344 = HEAP32[$343>>2]|0;
     $345 = (($344) + 1)|0;
     HEAP32[$size$i$i>>2] = $345;
     $346 = ($345>>>0)<(255);
     if ($346) {
      $347 = $345&255;
      HEAP8[$x$i15$i>>0] = $347;
      $348 = ($338|0)==(0);
      if ($348) {
       $349 = HEAP32[$331>>2]|0;
       $350 = HEAP32[$D>>2]|0;
       $351 = HEAP32[$332>>2]|0;
       $352 = (FUNCTION_TABLE_iiiii[$349 & 511]($350,$x$i15$i,1,$351)|0);
       HEAP32[$$pre$phiZ2D>>2] = $352;
       $$pr$i = $352;
      } else {
       $$pr$i = $338;
      }
      $364 = $$pr$i;$366 = $345;
     } else {
      HEAP8[$x$i18$i>>0] = -1;
      $353 = ($338|0)==(0);
      if (!($353)) {
       $376 = $338;
       break;
      }
      $354 = HEAP32[$331>>2]|0;
      $355 = HEAP32[$D>>2]|0;
      $356 = HEAP32[$332>>2]|0;
      $357 = (FUNCTION_TABLE_iiiii[$354 & 511]($355,$x$i18$i,1,$356)|0);
      HEAP32[$$pre$phiZ2D>>2] = $357;
      $358 = ($357|0)==(0);
      if (!($358)) {
       $376 = $357;
       break;
      }
      $359 = HEAP32[$331>>2]|0;
      $360 = HEAP32[$D>>2]|0;
      $361 = HEAP32[$332>>2]|0;
      $362 = (FUNCTION_TABLE_iiiii[$359 & 511]($360,$size$i$i,4,$361)|0);
      HEAP32[$$pre$phiZ2D>>2] = $362;
      $$pre$i$i = HEAP32[$size$i$i>>2]|0;
      $364 = $362;$366 = $$pre$i$i;
     }
     $363 = ($364|0)==(0);
     if (!($363)) {
      $376 = $364;
      break;
     }
     $365 = (($366) + -1)|0;
     $367 = ((($335)) + 24|0);
     $368 = HEAP32[$331>>2]|0;
     $369 = HEAP32[$D>>2]|0;
     $370 = HEAP32[$332>>2]|0;
     $371 = (FUNCTION_TABLE_iiiii[$368 & 511]($369,$367,$365,$370)|0);
     HEAP32[$$pre$phiZ2D>>2] = $371;
     $376 = $371;
    }
   } while(0);
   $372 = HEAP32[$330>>2]|0;
   $373 = (((($372) + (($i$032$i*12)|0)|0)) + 4|0);
   $374 = HEAP32[$373>>2]|0;
   HEAP32[$10>>2] = $374;
   $375 = ($376|0)==(0);
   if ($375) {
    $377 = HEAP32[$331>>2]|0;
    $378 = HEAP32[$D>>2]|0;
    $379 = HEAP32[$332>>2]|0;
    $380 = (FUNCTION_TABLE_iiiii[$377 & 511]($378,$10,4,$379)|0);
    HEAP32[$$pre$phiZ2D>>2] = $380;
    $$pre$i = HEAP32[$330>>2]|0;
    $382 = $$pre$i;$385 = $380;
   } else {
    $382 = $372;$385 = $376;
   }
   $381 = (((($382) + (($i$032$i*12)|0)|0)) + 8|0);
   $383 = HEAP32[$381>>2]|0;
   HEAP32[$9>>2] = $383;
   $384 = ($385|0)==(0);
   if ($384) {
    $386 = HEAP32[$331>>2]|0;
    $387 = HEAP32[$D>>2]|0;
    $388 = HEAP32[$332>>2]|0;
    $389 = (FUNCTION_TABLE_iiiii[$386 & 511]($387,$9,4,$388)|0);
    HEAP32[$$pre$phiZ2D>>2] = $389;
    $463 = $389;
   } else {
    $463 = $385;
   }
   $390 = (($i$032$i) + 1)|0;
   $exitcond35$i = ($390|0)==($320|0);
   if ($exitcond35$i) {
    $396 = $463;
    break;
   } else {
    $338 = $463;$i$032$i = $390;
   }
  }
 } else {
  $396 = $461;
 }
 $391 = HEAP32[$13>>2]|0;
 $392 = ($391|0)==(0);
 if ($392) {
  $393 = HEAP32[$244>>2]|0;
  $394 = $393;
 } else {
  $394 = 0;
 }
 HEAP32[$8>>2] = $394;
 $395 = ($396|0)==(0);
 if ($395) {
  $397 = ((($D)) + 4|0);
  $398 = HEAP32[$397>>2]|0;
  $399 = HEAP32[$D>>2]|0;
  $400 = ((($D)) + 8|0);
  $401 = HEAP32[$400>>2]|0;
  $402 = (FUNCTION_TABLE_iiiii[$398 & 511]($399,$8,4,$401)|0);
  HEAP32[$$pre$phiZ2D>>2] = $402;
  $464 = $402;
 } else {
  $464 = $396;
 }
 $403 = ($394|0)>(0);
 if (!($403)) {
  STACKTOP = sp;return;
 }
 $404 = ((($f)) + 64|0);
 $405 = ((($D)) + 4|0);
 $406 = ((($D)) + 8|0);
 $412 = $464;$i$131$i = 0;
 while(1) {
  $407 = HEAP32[$404>>2]|0;
  $408 = (($407) + ($i$131$i<<3)|0);
  $409 = HEAP32[$408>>2]|0;
  $410 = ($409|0)==(0|0);
  do {
   if ($410) {
    HEAP8[$x$i21$i>>0] = 0;
    $411 = ($412|0)==(0);
    if ($411) {
     $413 = HEAP32[$405>>2]|0;
     $414 = HEAP32[$D>>2]|0;
     $415 = HEAP32[$406>>2]|0;
     $416 = (FUNCTION_TABLE_iiiii[$413 & 511]($414,$x$i21$i,1,$415)|0);
     HEAP32[$$pre$phiZ2D>>2] = $416;
     $465 = $416;
    } else {
     $465 = $412;
    }
    $466 = $465;
   } else {
    $417 = ((($409)) + 12|0);
    $418 = HEAP32[$417>>2]|0;
    $419 = (($418) + 1)|0;
    HEAP32[$size$i9$i>>2] = $419;
    $420 = ($419>>>0)<(255);
    if ($420) {
     $421 = $419&255;
     HEAP8[$x$i24$i>>0] = $421;
     $422 = ($412|0)==(0);
     if ($422) {
      $423 = HEAP32[$405>>2]|0;
      $424 = HEAP32[$D>>2]|0;
      $425 = HEAP32[$406>>2]|0;
      $426 = (FUNCTION_TABLE_iiiii[$423 & 511]($424,$x$i24$i,1,$425)|0);
      HEAP32[$$pre$phiZ2D>>2] = $426;
      $$pr30$i = $426;
     } else {
      $$pr30$i = $412;
     }
     $438 = $$pr30$i;$440 = $419;
    } else {
     HEAP8[$x$i27$i>>0] = -1;
     $427 = ($412|0)==(0);
     if (!($427)) {
      $466 = $412;
      break;
     }
     $428 = HEAP32[$405>>2]|0;
     $429 = HEAP32[$D>>2]|0;
     $430 = HEAP32[$406>>2]|0;
     $431 = (FUNCTION_TABLE_iiiii[$428 & 511]($429,$x$i27$i,1,$430)|0);
     HEAP32[$$pre$phiZ2D>>2] = $431;
     $432 = ($431|0)==(0);
     if (!($432)) {
      $466 = $431;
      break;
     }
     $433 = HEAP32[$405>>2]|0;
     $434 = HEAP32[$D>>2]|0;
     $435 = HEAP32[$406>>2]|0;
     $436 = (FUNCTION_TABLE_iiiii[$433 & 511]($434,$size$i9$i,4,$435)|0);
     HEAP32[$$pre$phiZ2D>>2] = $436;
     $$pre$i10$i = HEAP32[$size$i9$i>>2]|0;
     $438 = $436;$440 = $$pre$i10$i;
    }
    $437 = ($438|0)==(0);
    if (!($437)) {
     $466 = $438;
     break;
    }
    $439 = (($440) + -1)|0;
    $441 = ((($409)) + 24|0);
    $442 = HEAP32[$405>>2]|0;
    $443 = HEAP32[$D>>2]|0;
    $444 = HEAP32[$406>>2]|0;
    $445 = (FUNCTION_TABLE_iiiii[$442 & 511]($443,$441,$439,$444)|0);
    HEAP32[$$pre$phiZ2D>>2] = $445;
    $466 = $445;
   }
  } while(0);
  $446 = (($i$131$i) + 1)|0;
  $exitcond$i = ($446|0)==($394|0);
  if ($exitcond$i) {
   break;
  } else {
   $412 = $466;$i$131$i = $446;
  }
 }
 STACKTOP = sp;return;
}
function _luaF_newCclosure($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $n << 4;
 $1 = (($0) + 16)|0;
 $2 = (_luaC_newobj($L,38,$1)|0);
 $3 = $n&255;
 $4 = ((($2)) + 6|0);
 HEAP8[$4>>0] = $3;
 return ($2|0);
}
function _luaF_newLclosure($L,$n) {
 $L = $L|0;
 $n = $n|0;
 var $$in = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $n << 2;
 $1 = (($0) + 16)|0;
 $2 = (_luaC_newobj($L,6,$1)|0);
 $3 = ((($2)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = $n&255;
 $5 = ((($2)) + 6|0);
 HEAP8[$5>>0] = $4;
 $6 = ($n|0)==(0);
 if ($6) {
  return ($2|0);
 }
 $7 = ((($2)) + 16|0);
 $$in = $n;
 while(1) {
  $8 = (($$in) + -1)|0;
  $9 = (($7) + ($8<<2)|0);
  HEAP32[$9>>2] = 0;
  $10 = ($8|0)==(0);
  if ($10) {
   break;
  } else {
   $$in = $8;
  }
 }
 return ($2|0);
}
function _luaF_initupvals($L,$cl) {
 $L = $L|0;
 $cl = $cl|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($cl)) + 6|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  return;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $3 = (_luaM_realloc_($L,0,0,24)|0);
  $4 = ((($3)) + 4|0);
  HEAP32[$4>>2] = 1;
  $5 = ((($3)) + 8|0);
  HEAP32[$3>>2] = $5;
  $6 = ((($3)) + 16|0);
  HEAP32[$6>>2] = 0;
  $7 = (((($cl)) + 16|0) + ($i$01<<2)|0);
  HEAP32[$7>>2] = $3;
  $8 = (($i$01) + 1)|0;
  $9 = HEAP8[$0>>0]|0;
  $10 = $9&255;
  $11 = ($8|0)<($10|0);
  if ($11) {
   $i$01 = $8;
  } else {
   break;
  }
 }
 return;
}
function _luaF_findupval($L,$level) {
 $L = $L|0;
 $level = $level|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $pp$0$lcssa = 0, $pp$03 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 L1: do {
  if ($2) {
   $pp$0$lcssa = $0;
  } else {
   $4 = $1;$pp$03 = $0;
   while(1) {
    $3 = HEAP32[$4>>2]|0;
    $5 = ($3>>>0)<($level>>>0);
    if ($5) {
     $pp$0$lcssa = $pp$03;
     break L1;
    }
    $6 = ($3|0)==($level|0);
    if ($6) {
     $$0 = $4;
     break;
    }
    $7 = ((($4)) + 8|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = ($8|0)==(0|0);
    if ($9) {
     $pp$0$lcssa = $7;
     break L1;
    } else {
     $4 = $8;$pp$03 = $7;
    }
   }
   return ($$0|0);
  }
 } while(0);
 $10 = (_luaM_realloc_($L,0,0,24)|0);
 $11 = ((($10)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[$pp$0$lcssa>>2]|0;
 $13 = ((($10)) + 8|0);
 HEAP32[$13>>2] = $12;
 $14 = ((($10)) + 12|0);
 HEAP32[$14>>2] = 1;
 HEAP32[$pp$0$lcssa>>2] = $10;
 HEAP32[$10>>2] = $level;
 $15 = ((($L)) + 40|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==($L|0);
 if (!($17)) {
  $$0 = $10;
  return ($$0|0);
 }
 $18 = ((($L)) + 12|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ((($19)) + 104|0);
 $21 = HEAP32[$20>>2]|0;
 HEAP32[$15>>2] = $21;
 HEAP32[$20>>2] = $L;
 $$0 = $10;
 return ($$0|0);
}
function _luaF_close($L,$level) {
 $L = $L|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 $4 = $1;
 while(1) {
  $3 = HEAP32[$4>>2]|0;
  $5 = ($3>>>0)<($level>>>0);
  if ($5) {
   label = 9;
   break;
  }
  $6 = ((($4)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$0>>2] = $7;
  $8 = ((($4)) + 4|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   (_luaM_realloc_($L,$4,24,0)|0);
  } else {
   ;HEAP32[$6>>2]=HEAP32[$3>>2]|0;HEAP32[$6+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$3+12>>2]|0;
   HEAP32[$4>>2] = $6;
   $11 = ((($4)) + 16|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 & 64;
   $14 = ($13|0)==(0);
   if (!($14)) {
    _luaC_upvalbarrier_($L,$4);
   }
  }
  $15 = HEAP32[$0>>2]|0;
  $16 = ($15|0)==(0|0);
  if ($16) {
   label = 9;
   break;
  } else {
   $4 = $15;
  }
 }
 if ((label|0) == 9) {
  return;
 }
}
function _luaF_newproto($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaC_newobj($L,9,80)|0);
 $1 = ((($0)) + 44|0);
 $2 = ((($0)) + 68|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 64|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 12|0);
 $5 = ((($0)) + 6|0);
 ;HEAP32[$4>>2]=0|0;HEAP32[$4+4>>2]=0|0;HEAP32[$4+8>>2]=0|0;HEAP32[$4+12>>2]=0|0;HEAP32[$4+16>>2]=0|0;
 ;HEAP32[$1>>2]=0|0;HEAP32[$1+4>>2]=0|0;HEAP32[$1+8>>2]=0|0;HEAP32[$1+12>>2]=0|0;
 HEAP8[$5>>0] = 0;
 $6 = ((($0)) + 7|0);
 HEAP8[$6>>0] = 0;
 $7 = ((($0)) + 8|0);
 HEAP8[$7>>0] = 0;
 $8 = ((($0)) + 60|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 32|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 36|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 40|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($0)) + 72|0);
 HEAP32[$12>>2] = 0;
 return ($0|0);
}
function _luaF_freeproto($L,$f) {
 $L = $L|0;
 $f = $f|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $3 << 2;
 (_luaM_realloc_($L,$1,$4,0)|0);
 $5 = ((($f)) + 52|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($f)) + 28|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 (_luaM_realloc_($L,$6,$9,0)|0);
 $10 = ((($f)) + 44|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($f)) + 16|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = $13 << 4;
 (_luaM_realloc_($L,$11,$14,0)|0);
 $15 = ((($f)) + 56|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ((($f)) + 24|0);
 $18 = HEAP32[$17>>2]|0;
 $19 = $18 << 2;
 (_luaM_realloc_($L,$16,$19,0)|0);
 $20 = ((($f)) + 60|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ((($f)) + 32|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = ($23*12)|0;
 (_luaM_realloc_($L,$21,$24,0)|0);
 $25 = ((($f)) + 64|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = ((($f)) + 12|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = $28 << 3;
 (_luaM_realloc_($L,$26,$29,0)|0);
 (_luaM_realloc_($L,$f,80,0)|0);
 return;
}
function _luaF_getlocalname($f,$local_number,$pc) {
 $f = $f|0;
 $local_number = $local_number|0;
 $pc = $pc|0;
 var $$0 = 0, $$013 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$04 = 0, $i$04$lcssa11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>(0);
 if (!($2)) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = ((($f)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $$013 = $local_number;$i$04 = 0;
 while(1) {
  $5 = (((($4) + (($i$04*12)|0)|0)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)>($pc|0);
  if ($7) {
   $$0 = 0;
   label = 8;
   break;
  }
  $8 = (((($4) + (($i$04*12)|0)|0)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)>($pc|0);
  if ($10) {
   $11 = (($$013) + -1)|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $i$04$lcssa11 = $i$04;
    label = 6;
    break;
   } else {
    $$1 = $11;
   }
  } else {
   $$1 = $$013;
  }
  $16 = (($i$04) + 1)|0;
  $17 = ($16|0)<($1|0);
  if ($17) {
   $$013 = $$1;$i$04 = $16;
  } else {
   $$0 = 0;
   label = 8;
   break;
  }
 }
 if ((label|0) == 6) {
  $13 = (($4) + (($i$04$lcssa11*12)|0)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ((($14)) + 24|0);
  $$0 = $15;
  return ($$0|0);
 }
 else if ((label|0) == 8) {
  return ($$0|0);
 }
 return (0)|0;
}
function _luaC_barrier_($L,$o,$v) {
 $L = $L|0;
 $o = $o|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 61|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3&255)<(2);
 if ($4) {
  _reallymarkobject($1,$v);
  return;
 } else {
  $5 = ((($o)) + 5|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = $7 & 248;
  $9 = ((($1)) + 60|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $11 & 3;
  $13 = $12 | $8;
  $14 = $13&255;
  HEAP8[$5>>0] = $14;
  return;
 }
}
function _luaC_barrierback_($L,$t) {
 $L = $L|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 251;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 80|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($t)) + 28|0);
 HEAP32[$9>>2] = $8;
 HEAP32[$7>>2] = $t;
 return;
}
function _luaC_upvalbarrier_($L,$uv) {
 $L = $L|0;
 $uv = $uv|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$uv>>2]|0;
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 61|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5&255)<(2);
 $7 = ($3|0)!=(0|0);
 $or$cond = $7 & $6;
 if (!($or$cond)) {
  return;
 }
 $8 = ((($3)) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 3;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  return;
 }
 _reallymarkobject($1,$3);
 return;
}
function _luaC_fix($L,$o) {
 $L = $L|0;
 $o = $o|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($o)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 & 252;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = HEAP32[$o>>2]|0;
 $8 = ((($1)) + 64|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($1)) + 100|0);
 $10 = HEAP32[$9>>2]|0;
 HEAP32[$o>>2] = $10;
 HEAP32[$9>>2] = $o;
 return;
}
function _luaC_newobj($L,$tt,$sz) {
 $L = $L|0;
 $tt = $tt|0;
 $sz = $sz|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $tt & 15;
 $3 = (_luaM_realloc_($L,0,$2,$sz)|0);
 $4 = ((($1)) + 60|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = $5&255;
 $7 = $6 & 3;
 $8 = $7&255;
 $9 = ((($3)) + 5|0);
 HEAP8[$9>>0] = $8;
 $10 = $tt&255;
 $11 = ((($3)) + 4|0);
 HEAP8[$11>>0] = $10;
 $12 = ((($1)) + 64|0);
 $13 = HEAP32[$12>>2]|0;
 HEAP32[$3>>2] = $13;
 HEAP32[$12>>2] = $3;
 return ($3|0);
}
function _luaC_upvdeccount($L,$uv) {
 $L = $L|0;
 $uv = $uv|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($uv)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 HEAP32[$0>>2] = $2;
 $3 = ($2|0)==(0);
 if (!($3)) {
  return;
 }
 $4 = HEAP32[$uv>>2]|0;
 $5 = ((($uv)) + 8|0);
 $6 = ($4|0)==($5|0);
 if (!($6)) {
  return;
 }
 (_luaM_realloc_($L,$uv,24,0)|0);
 return;
}
function _luaC_checkfinalizer($L,$o,$mt) {
 $L = $L|0;
 $o = $o|0;
 $mt = $mt|0;
 var $$lcssa = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond2 = 0, $p$0 = 0, $p$0$lcssa = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($o)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 & 8;
 $5 = ($4<<24>>24)!=(0);
 $6 = ($mt|0)==(0|0);
 $or$cond2 = $6 | $5;
 if ($or$cond2) {
  return;
 }
 $7 = ((($mt)) + 6|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8 & 4;
 $10 = ($9<<24>>24)==(0);
 if (!($10)) {
  return;
 }
 $11 = ((($1)) + 156|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (_luaT_gettm($mt,2,$12)|0);
 $phitmp = ($13|0)==(0|0);
 if ($phitmp) {
  return;
 }
 $14 = ((($1)) + 61|0);
 $15 = HEAP8[$14>>0]|0;
 $$off = (($15) + -2)<<24>>24;
 $16 = ($$off&255)<(4);
 if ($16) {
  $17 = HEAP8[$2>>0]|0;
  $18 = $17&255;
  $19 = $18 & 248;
  $20 = ((($1)) + 60|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = $21&255;
  $23 = $22 & 3;
  $24 = $23 | $19;
  $25 = $24&255;
  HEAP8[$2>>0] = $25;
  $26 = ((($1)) + 68|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)==($o|0);
  if ($28) {
   while(1) {
    $29 = (_sweeplist($L,$27,1)|0);
    $30 = ($29|0)==($27|0);
    if (!($30)) {
     $$lcssa = $29;
     break;
    }
   }
   HEAP32[$26>>2] = $$lcssa;
  }
 }
 $31 = ((($1)) + 64|0);
 $p$0 = $31;
 while(1) {
  $32 = HEAP32[$p$0>>2]|0;
  $33 = ($32|0)==($o|0);
  if ($33) {
   $p$0$lcssa = $p$0;
   break;
  } else {
   $p$0 = $32;
  }
 }
 $34 = HEAP32[$o>>2]|0;
 HEAP32[$p$0$lcssa>>2] = $34;
 $35 = ((($1)) + 72|0);
 $36 = HEAP32[$35>>2]|0;
 HEAP32[$o>>2] = $36;
 HEAP32[$35>>2] = $o;
 $37 = HEAP8[$2>>0]|0;
 $38 = $37&255;
 $39 = $38 | 8;
 $40 = $39&255;
 HEAP8[$2>>0] = $40;
 return;
}
function _luaC_freeallobjects($L) {
 $L = $L|0;
 var $$0$i$i = 0, $$0$i$i$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lastnext$03$us$us$i = 0, $lastnext$03$us$us$i$phi = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 96|0);
 $$0$i$i = $2;
 while(1) {
  $3 = HEAP32[$$0$i$i>>2]|0;
  $4 = ($3|0)==(0|0);
  if ($4) {
   $$0$i$i$lcssa = $$0$i$i;
   break;
  } else {
   $$0$i$i = $3;
  }
 }
 $5 = ((($1)) + 72|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $14 = $1;
 } else {
  $9 = $6;$lastnext$03$us$us$i = $$0$i$i$lcssa;
  while(1) {
   $8 = HEAP32[$9>>2]|0;
   HEAP32[$5>>2] = $8;
   $10 = HEAP32[$lastnext$03$us$us$i>>2]|0;
   HEAP32[$9>>2] = $10;
   HEAP32[$lastnext$03$us$us$i>>2] = $9;
   $11 = HEAP32[$5>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    break;
   } else {
    $lastnext$03$us$us$i$phi = $9;$9 = $11;$lastnext$03$us$us$i = $lastnext$03$us$us$i$phi;
   }
  }
  $$pre = HEAP32[$0>>2]|0;
  $14 = $$pre;
 }
 $13 = ((($14)) + 96|0);
 $15 = HEAP32[$13>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  while(1) {
   _GCTM($L,0);
   $17 = HEAP32[$13>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    break;
   }
  }
 }
 $19 = ((($1)) + 60|0);
 HEAP8[$19>>0] = 3;
 $20 = ((($1)) + 62|0);
 HEAP8[$20>>0] = 0;
 (_sweeplist($L,$5,-1)|0);
 $21 = ((($1)) + 64|0);
 (_sweeplist($L,$21,-1)|0);
 $22 = ((($1)) + 100|0);
 (_sweeplist($L,$22,-1)|0);
 return;
}
function _luaC_step($L) {
 $L = $L|0;
 var $$$i = 0, $$$neg$i = 0, $$idx = 0, $$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$lcssa = 0, $$op$i = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $debt$0 = 0, $i$04$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $$idx = ((($1)) + 12|0);
 $$idx$val = HEAP32[$$idx>>2]|0;
 $$idx1 = ((($1)) + 128|0);
 $$idx1$val = HEAP32[$$idx1>>2]|0;
 $2 = (($$idx$val|0) / 200)&-1;
 $3 = (($2) + 1)|0;
 $4 = ((($1)) + 63|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  _luaE_setdebt($1,-20000);
  return;
 }
 $7 = (2147483647 / ($$idx1$val|0))&-1;
 $8 = ($3|0)<($7|0);
 $9 = Math_imul($3, $$idx1$val)|0;
 $$$i = $8 ? $9 : 2147483647;
 $10 = ((($1)) + 61|0);
 $debt$0 = $$$i;
 while(1) {
  $11 = (_singlestep($L)|0);
  $12 = (($debt$0) - ($11))|0;
  $13 = ($12|0)>(-2000);
  $14 = HEAP8[$10>>0]|0;
  $15 = ($14<<24>>24)==(7);
  if (!($13)) {
   label = 6;
   break;
  }
  if ($15) {
   break;
  } else {
   $debt$0 = $12;
  }
 }
 if ((label|0) == 6) {
  if (!($15)) {
   $29 = HEAP32[$$idx1>>2]|0;
   $30 = (($12|0) / ($29|0))&-1;
   $31 = ($30*200)|0;
   _luaE_setdebt($1,$31);
   $32 = HEAP32[$0>>2]|0;
   $33 = ((($32)) + 96|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(0|0);
   $$pre6 = ((($32)) + 120|0);
   L11: do {
    if ($35) {
     $42 = 0;
    } else {
     $i$04$i = 0;
     while(1) {
      $36 = HEAP32[$$pre6>>2]|0;
      $37 = ($i$04$i>>>0)<($36>>>0);
      if (!($37)) {
       $$lcssa = $36;
       break;
      }
      _GCTM($L,1);
      $38 = (($i$04$i) + 1)|0;
      $39 = HEAP32[$33>>2]|0;
      $40 = ($39|0)==(0|0);
      if ($40) {
       $42 = 0;
       break L11;
      } else {
       $i$04$i = $38;
      }
     }
     $41 = $$lcssa << 1;
     $42 = $41;
    }
   } while(0);
   HEAP32[$$pre6>>2] = $42;
   return;
  }
 }
 $16 = ((($1)) + 20|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17>>>0) / 100)&-1;
 $19 = ((($1)) + 124|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (2147483647 / ($18>>>0))&-1;
 $22 = ($20|0)<($21|0);
 $23 = ((($1)) + 8|0);
 $24 = HEAP32[$23>>2]|0;
 $25 = HEAP32[$$idx>>2]|0;
 $26 = (($25) + ($24))|0;
 $27 = (0 - ($18))|0;
 $$op$i = Math_imul($20, $27)|0;
 $$$neg$i = $22 ? $$op$i : -2147483647;
 $28 = (($26) + ($$$neg$i))|0;
 _luaE_setdebt($1,$28);
 return;
}
function _luaC_fullgc($L,$isemergency) {
 $L = $L|0;
 $isemergency = $isemergency|0;
 var $$$neg$i = 0, $$lcssa = 0, $$op$i = 0, $$phi$trans$insert = 0, $$phi$trans$insert12 = 0, $$phi$trans$insert15 = 0, $$phi$trans$insert9 = 0, $$pn = 0, $$pre = 0, $$pre10 = 0, $$pre11 = 0, $$pre13 = 0, $$pre14 = 0, $$pre16 = 0, $$pre7 = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($isemergency|0)==(0);
 if (!($2)) {
  $3 = ((($1)) + 62|0);
  HEAP8[$3>>0] = 1;
 }
 $4 = ((($1)) + 61|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5&255)<(2);
 if ($6) {
  HEAP8[$4>>0] = 2;
  $7 = ((($1)) + 64|0);
  while(1) {
   $8 = (_sweeplist($L,$7,1)|0);
   $9 = ($8|0)==($7|0);
   if (!($9)) {
    $$lcssa = $8;
    break;
   }
  }
  $10 = ((($1)) + 68|0);
  HEAP32[$10>>2] = $$lcssa;
  $$pre = HEAP32[$0>>2]|0;
  $$phi$trans$insert = ((($$pre)) + 61|0);
  $$pre7 = HEAP8[$$phi$trans$insert>>0]|0;
  $12 = $$pre;$14 = $$pre7;
 } else {
  $12 = $1;$14 = $5;
 }
 $11 = ((($12)) + 61|0);
 $13 = ($14<<24>>24)==(7);
 if ($13) {
  $18 = $12;$20 = 7;
 } else {
  while(1) {
   (_singlestep($L)|0);
   $15 = HEAP8[$11>>0]|0;
   $16 = ($15<<24>>24)==(7);
   if ($16) {
    break;
   }
  }
  $$pre8 = HEAP32[$0>>2]|0;
  $$phi$trans$insert9 = ((($$pre8)) + 61|0);
  $$pre10 = HEAP8[$$phi$trans$insert9>>0]|0;
  $18 = $$pre8;$20 = $$pre10;
 }
 $17 = ((($18)) + 61|0);
 $19 = $20&255;
 $21 = 1 << $19;
 $22 = $21 & -129;
 $23 = ($22|0)==(0);
 if ($23) {
  while(1) {
   (_singlestep($L)|0);
   $24 = HEAP8[$17>>0]|0;
   $25 = $24&255;
   $26 = 1 << $25;
   $27 = $26 & -129;
   $28 = ($27|0)==(0);
   if (!($28)) {
    break;
   }
  }
  $$pre11 = HEAP32[$0>>2]|0;
  $$phi$trans$insert12 = ((($$pre11)) + 61|0);
  $$pre13 = HEAP8[$$phi$trans$insert12>>0]|0;
  $30 = $$pre11;$32 = $$pre13;
 } else {
  $30 = $18;$32 = $20;
 }
 $29 = ((($30)) + 61|0);
 $31 = ($32<<24>>24)==(6);
 if ($31) {
  $$pn = $30;
  label = 16;
 } else {
  while(1) {
   (_singlestep($L)|0);
   $33 = HEAP8[$29>>0]|0;
   $34 = ($33<<24>>24)==(6);
   if ($34) {
    break;
   }
  }
  $$pre14 = HEAP32[$0>>2]|0;
  $$phi$trans$insert15 = ((($$pre14)) + 61|0);
  $$pre16 = HEAP8[$$phi$trans$insert15>>0]|0;
  $phitmp = ($$pre16<<24>>24)==(7);
  if (!($phitmp)) {
   $$pn = $$pre14;
   label = 16;
  }
 }
 if ((label|0) == 16) {
  $35 = ((($$pn)) + 61|0);
  while(1) {
   (_singlestep($L)|0);
   $36 = HEAP8[$35>>0]|0;
   $37 = ($36<<24>>24)==(7);
   if ($37) {
    break;
   }
  }
 }
 $38 = ((($1)) + 62|0);
 HEAP8[$38>>0] = 0;
 $39 = ((($1)) + 20|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40>>>0) / 100)&-1;
 $42 = ((($1)) + 124|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = (2147483647 / ($41>>>0))&-1;
 $45 = ($43|0)<($44|0);
 $46 = ((($1)) + 8|0);
 $47 = HEAP32[$46>>2]|0;
 $48 = ((($1)) + 12|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = (($49) + ($47))|0;
 $51 = (0 - ($41))|0;
 $$op$i = Math_imul($43, $51)|0;
 $$$neg$i = $45 ? $$op$i : -2147483647;
 $52 = (($50) + ($$$neg$i))|0;
 _luaE_setdebt($1,$52);
 return;
}
function _reallymarkobject($g,$o) {
 $g = $g|0;
 $o = $o|0;
 var $$0 = 0, $$0$lcssa81 = 0, $$0$lcssa82 = 0, $$0$lcssa83 = 0, $$0$lcssa84 = 0, $$0$lcssa85 = 0, $$0$lcssa86 = 0, $$lcssa87 = 0, $$lcssa93 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre26 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 16|0);
 $$phi$trans$insert = ((($o)) + 5|0);
 $$pre = HEAP8[$$phi$trans$insert>>0]|0;
 $$0 = $o;$3 = $$pre;
 L1: while(1) {
  $1 = ((($$0)) + 5|0);
  $2 = $3&255;
  $4 = $2 & 252;
  $5 = $4&255;
  HEAP8[$1>>0] = $5;
  $6 = ((($$0)) + 4|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  switch ($8|0) {
  case 6:  {
   $$0$lcssa82 = $$0;
   label = 9;
   break L1;
   break;
  }
  case 8:  {
   $$0$lcssa85 = $$0;
   label = 12;
   break L1;
   break;
  }
  case 7:  {
   break;
  }
  case 5:  {
   $$0$lcssa84 = $$0;
   label = 11;
   break L1;
   break;
  }
  case 9:  {
   $$0$lcssa86 = $$0;
   label = 13;
   break L1;
   break;
  }
  case 38:  {
   $$0$lcssa83 = $$0;
   label = 10;
   break L1;
   break;
  }
  case 20: case 4:  {
   $$0$lcssa81 = $$0;$$lcssa87 = $1;$$lcssa93 = $4;
   label = 3;
   break L1;
   break;
  }
  default: {
   label = 14;
   break L1;
  }
  }
  $16 = ((($$0)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $24 = $5;
  } else {
   $19 = ((($17)) + 5|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20 & 3;
   $22 = ($21<<24>>24)==(0);
   if ($22) {
    $24 = $5;
   } else {
    _reallymarkobject($g,$17);
    $$pre26 = HEAP8[$1>>0]|0;
    $24 = $$pre26;
   }
  }
  $23 = $24&255;
  $25 = $23 | 4;
  $26 = $25&255;
  HEAP8[$1>>0] = $26;
  $27 = ((($$0)) + 12|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = (($28) + 24)|0;
  $30 = HEAP32[$0>>2]|0;
  $31 = (($29) + ($30))|0;
  HEAP32[$0>>2] = $31;
  $32 = ((($$0)) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($$0)) + 6|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35 & 64;
  $37 = ($36<<24>>24)==(0);
  if ($37) {
   label = 14;
   break;
  }
  $38 = ((($33)) + 5|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 & 3;
  $41 = ($40<<24>>24)==(0);
  if ($41) {
   label = 14;
   break;
  } else {
   $$0 = $33;$3 = $39;
  }
 }
 if ((label|0) == 3) {
  $9 = $$lcssa93 | 4;
  $10 = $9&255;
  HEAP8[$$lcssa87>>0] = $10;
  $11 = ((($$0$lcssa81)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + 25)|0;
  $14 = HEAP32[$0>>2]|0;
  $15 = (($13) + ($14))|0;
  HEAP32[$0>>2] = $15;
  return;
 }
 else if ((label|0) == 9) {
  $42 = ((($g)) + 76|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = ((($$0$lcssa82)) + 8|0);
  HEAP32[$44>>2] = $43;
  HEAP32[$42>>2] = $$0$lcssa82;
  return;
 }
 else if ((label|0) == 10) {
  $45 = ((($g)) + 76|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($$0$lcssa83)) + 8|0);
  HEAP32[$47>>2] = $46;
  HEAP32[$45>>2] = $$0$lcssa83;
  return;
 }
 else if ((label|0) == 11) {
  $48 = ((($g)) + 76|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ((($$0$lcssa84)) + 28|0);
  HEAP32[$50>>2] = $49;
  HEAP32[$48>>2] = $$0$lcssa84;
  return;
 }
 else if ((label|0) == 12) {
  $51 = ((($g)) + 76|0);
  $52 = HEAP32[$51>>2]|0;
  $53 = ((($$0$lcssa85)) + 36|0);
  HEAP32[$53>>2] = $52;
  HEAP32[$51>>2] = $$0$lcssa85;
  return;
 }
 else if ((label|0) == 13) {
  $54 = ((($g)) + 76|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($$0$lcssa86)) + 76|0);
  HEAP32[$56>>2] = $55;
  HEAP32[$54>>2] = $$0$lcssa86;
  return;
 }
 else if ((label|0) == 14) {
  return;
 }
}
function _sweeplist($L,$p,$count) {
 $L = $L|0;
 $p = $p|0;
 $count = $count|0;
 var $$0$be = 0, $$0$lcssa = 0, $$07 = 0, $$1 = 0, $$15 = 0, $$18 = 0, $$lcssa$i$i = 0, $$lcssa3 = 0, $$pre$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i$i = 0, $not$ = 0, $not$26 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 60|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 ^ 3;
 $6 = $4 & 3;
 $7 = HEAP32[$p>>2]|0;
 $8 = ($7|0)==(0|0);
 $9 = ($count|0)!=(0);
 $not$26 = $8 ^ 1;
 $10 = $9 & $not$26;
 if (!($10)) {
  $$0$lcssa = $p;$$lcssa3 = $8;
  $61 = $$lcssa3 ? 0 : $$0$lcssa;
  return ($61|0);
 }
 $$15 = (($count) + -1)|0;
 $$07 = $p;$$18 = $$15;$12 = $7;
 while(1) {
  $11 = ((($12)) + 5|0);
  $13 = HEAP8[$11>>0]|0;
  $14 = $13&255;
  $15 = $14 ^ 3;
  $16 = $15 & $5;
  $17 = ($16|0)==(0);
  L6: do {
   if ($17) {
    $18 = HEAP32[$12>>2]|0;
    HEAP32[$$07>>2] = $18;
    $19 = ((($12)) + 4|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    switch ($21|0) {
    case 7:  {
     $47 = ((($12)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = (($48) + 24)|0;
     (_luaM_realloc_($L,$12,$49,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 9:  {
     _luaF_freeproto($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 20:  {
     break;
    }
    case 6:  {
     $22 = ((($12)) + 6|0);
     $23 = HEAP8[$22>>0]|0;
     $24 = $23&255;
     $25 = ($23<<24>>24)==(0);
     if ($25) {
      $$lcssa$i$i = $24;
     } else {
      $62 = $23;$i$01$i$i = 0;
      while(1) {
       $26 = (((($12)) + 16|0) + ($i$01$i$i<<2)|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ($27|0)==(0|0);
       if ($28) {
        $38 = $62;
       } else {
        $29 = ((($27)) + 4|0);
        $30 = HEAP32[$29>>2]|0;
        $31 = (($30) + -1)|0;
        HEAP32[$29>>2] = $31;
        $32 = ($31|0)==(0);
        if ($32) {
         $33 = HEAP32[$27>>2]|0;
         $34 = ((($27)) + 8|0);
         $35 = ($33|0)==($34|0);
         if ($35) {
          (_luaM_realloc_($L,$27,24,0)|0);
          $$pre$i$i = HEAP8[$22>>0]|0;
          $38 = $$pre$i$i;
         } else {
          $38 = $62;
         }
        } else {
         $38 = $62;
        }
       }
       $36 = (($i$01$i$i) + 1)|0;
       $37 = $38&255;
       $39 = ($36|0)<($37|0);
       if ($39) {
        $62 = $38;$i$01$i$i = $36;
       } else {
        $$lcssa$i$i = $37;
        break;
       }
      }
     }
     $40 = $$lcssa$i$i << 2;
     $41 = (($40) + 16)|0;
     (_luaM_realloc_($L,$12,$41,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 8:  {
     _luaE_freethread($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 5:  {
     _luaH_free($L,$12);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 38:  {
     $42 = ((($12)) + 6|0);
     $43 = HEAP8[$42>>0]|0;
     $44 = $43&255;
     $45 = $44 << 4;
     $46 = (($45) + 16)|0;
     (_luaM_realloc_($L,$12,$46,0)|0);
     $$0$be = $$07;
     break L6;
     break;
    }
    case 4:  {
     _luaS_remove($L,$12);
     break;
    }
    default: {
     $$0$be = $$07;
     break L6;
    }
    }
    $50 = ((($12)) + 12|0);
    $51 = HEAP32[$50>>2]|0;
    $52 = (($51) + 25)|0;
    (_luaM_realloc_($L,$12,$52,0)|0);
    $$0$be = $$07;
   } else {
    $53 = $14 & 248;
    $54 = $53 | $6;
    $55 = $54&255;
    HEAP8[$11>>0] = $55;
    $$0$be = $12;
   }
  } while(0);
  $56 = HEAP32[$$0$be>>2]|0;
  $57 = ($56|0)==(0|0);
  $58 = ($$18|0)!=(0);
  $not$ = $57 ^ 1;
  $59 = $not$ << 31 >> 31;
  $$1 = (($59) + ($$18))|0;
  $60 = $58 & $not$;
  if ($60) {
   $$07 = $$0$be;$$18 = $$1;$12 = $56;
  } else {
   $$0$lcssa = $$0$be;$$lcssa3 = $57;
   break;
  }
 }
 $61 = $$lcssa3 ? 0 : $$0$lcssa;
 return ($61|0);
}
function _GCTM($L,$propagateerrors) {
 $L = $L|0;
 $propagateerrors = $propagateerrors|0;
 var $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, $status$0 = 0, $v = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 16|0;
 $v = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 96|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 HEAP32[$2>>2] = $4;
 $5 = ((($1)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$3>>2] = $6;
 HEAP32[$5>>2] = $3;
 $7 = ((($3)) + 5|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 247;
 $11 = $10&255;
 HEAP8[$7>>0] = $11;
 $12 = ((($1)) + 61|0);
 $13 = HEAP8[$12>>0]|0;
 $$off$i = (($13) + -2)<<24>>24;
 $14 = ($$off$i&255)<(4);
 if ($14) {
  $15 = $9 & 240;
  $16 = ((($1)) + 60|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 3;
  $20 = $19 | $15;
  $21 = $20&255;
  HEAP8[$7>>0] = $21;
 }
 HEAP32[$v>>2] = $3;
 $22 = ((($3)) + 4|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = $23&255;
 $25 = $24 | 64;
 $26 = ((($v)) + 8|0);
 HEAP32[$26>>2] = $25;
 $27 = (_luaT_gettmbyobj($L,$v,2)|0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  STACKTOP = sp;return;
 }
 $29 = ((($27)) + 8|0);
 $30 = HEAP32[$29>>2]|0;
 $31 = $30 & 15;
 $32 = ($31|0)==(6);
 if (!($32)) {
  STACKTOP = sp;return;
 }
 $33 = ((($L)) + 109|0);
 $34 = HEAP8[$33>>0]|0;
 $35 = ((($1)) + 63|0);
 $36 = HEAP8[$35>>0]|0;
 HEAP8[$33>>0] = 0;
 HEAP8[$35>>0] = 0;
 $37 = ((($L)) + 8|0);
 $38 = HEAP32[$37>>2]|0;
 ;HEAP32[$38>>2]=HEAP32[$27>>2]|0;HEAP32[$38+4>>2]=HEAP32[$27+4>>2]|0;HEAP32[$38+8>>2]=HEAP32[$27+8>>2]|0;HEAP32[$38+12>>2]=HEAP32[$27+12>>2]|0;
 $39 = HEAP32[$37>>2]|0;
 $40 = ((($39)) + 16|0);
 ;HEAP32[$40>>2]=HEAP32[$v>>2]|0;HEAP32[$40+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$40+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$40+12>>2]=HEAP32[$v+12>>2]|0;
 $41 = HEAP32[$37>>2]|0;
 $42 = ((($41)) + 32|0);
 HEAP32[$37>>2] = $42;
 $43 = ((($L)) + 28|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = $41;
 $46 = $44;
 $47 = (($45) - ($46))|0;
 $48 = (_luaD_pcall($L,313,0,$47,0)|0);
 HEAP8[$33>>0] = $34;
 HEAP8[$35>>0] = $36;
 $49 = ($48|0)!=(0);
 $50 = ($propagateerrors|0)!=(0);
 $or$cond = $50 & $49;
 if (!($or$cond)) {
  STACKTOP = sp;return;
 }
 $51 = ($48|0)==(2);
 if (!($51)) {
  $status$0 = $48;
  _luaD_throw($L,$status$0);
  // unreachable;
 }
 $52 = HEAP32[$37>>2]|0;
 $53 = ((($52)) + -8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = $54 & 15;
 $56 = ($55|0)==(4);
 if ($56) {
  $57 = ((($52)) + -16|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ((($58)) + 24|0);
  $60 = $59;
 } else {
  $60 = 1448;
 }
 HEAP32[$vararg_buffer>>2] = $60;
 (_luaO_pushfstring($L,1464,$vararg_buffer)|0);
 $status$0 = 5;
 _luaD_throw($L,$status$0);
 // unreachable;
}
function _singlestep($L) {
 $L = $L|0;
 var $$0 = 0, $$0$i$i$i = 0, $$0$i$i$i$lcssa = 0, $$02$i$i = 0, $$02$i16$i = 0, $$lcssa = 0, $$lcssa81 = 0, $$lcssa82 = 0, $$lcssa84 = 0, $$lcssa86 = 0, $$lcssa87 = 0, $$lcssa90 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0;
 var $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0;
 var $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0;
 var $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0;
 var $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0;
 var $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0;
 var $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0;
 var $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $changed$0$ph$i$i = 0, $changed$0$ph$i$i$lcssa = 0, $changed$0$ph$i7$i = 0, $changed$0$ph$i7$i$lcssa = 0, $i$0$i$i = 0, $i$02$i = 0, $i$04$i = 0, $i$04$i$lcssa = 0, $lastnext$0$ph5$i$i = 0, $lastnext$03$i$i = 0, $lastnext$03$i$i$lcssa = 0, $lastnext$03$i$i$phi = 0, $n$01$i$i = 0, $n$01$i18$i = 0, $next$0$i$i = 0, $next$0$i10$i = 0, $next$0$ph$i$i = 0, $next$0$ph$i8$i = 0;
 var $o$0$i$i = 0, $o$0$i$i4 = 0, $o$01$i$i = 0, $o$01$i$i2 = 0, $o$02$i$i = 0, $o$02$i$i3 = 0, $p$0$ph4$i$i = 0, $p$0$ph5$i$i = 0, $uv$0$i$i = 0, $uv$02$i$i = 0, $uv$03$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 61|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 switch ($4|0) {
 case 1:  {
  $40 = ((($1)) + 76|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ($41|0)==(0|0);
  if ($42) {
   $46 = $1;
  } else {
   while(1) {
    _propagatemark($1);
    $43 = HEAP32[$40>>2]|0;
    $44 = ($43|0)==(0|0);
    if ($44) {
     break;
    }
   }
   $$pre = HEAP32[$0>>2]|0;
   $46 = $$pre;
  }
  $45 = ((($46)) + 80|0);
  $47 = HEAP32[$45>>2]|0;
  $48 = ((($46)) + 61|0);
  HEAP8[$48>>0] = 8;
  $49 = ((($46)) + 16|0);
  HEAP32[$49>>2] = 0;
  $50 = ((($L)) + 5|0);
  $51 = HEAP8[$50>>0]|0;
  $52 = $51 & 3;
  $53 = ($52<<24>>24)==(0);
  if (!($53)) {
   _reallymarkobject($46,$L);
  }
  $54 = ((($46)) + 48|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = $55 & 64;
  $57 = ($56|0)==(0);
  if (!($57)) {
   $58 = ((($46)) + 40|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = ((($59)) + 5|0);
   $61 = HEAP8[$60>>0]|0;
   $62 = $61 & 3;
   $63 = ($62<<24>>24)==(0);
   if (!($63)) {
    _reallymarkobject($46,$59);
   }
  }
  _markmt($46);
  $64 = ((($46)) + 104|0);
  $65 = HEAP32[$64>>2]|0;
  $66 = ($65|0)==(0|0);
  L15: do {
   if (!($66)) {
    $347 = $65;$p$0$ph5$i$i = $64;
    while(1) {
     $70 = $347;
     while(1) {
      $69 = ((($70)) + 5|0);
      $71 = HEAP8[$69>>0]|0;
      $72 = $71 & 7;
      $73 = ($72<<24>>24)==(0);
      $74 = ((($70)) + 32|0);
      if ($73) {
       $75 = HEAP32[$74>>2]|0;
       $76 = ($75|0)==(0|0);
       if (!($76)) {
        $$lcssa87 = $70;
        break;
       }
      }
      $80 = ((($70)) + 40|0);
      $81 = HEAP32[$80>>2]|0;
      HEAP32[$p$0$ph5$i$i>>2] = $81;
      HEAP32[$80>>2] = $70;
      $uv$02$i$i = HEAP32[$74>>2]|0;
      $82 = ($uv$02$i$i|0)==(0|0);
      if (!($82)) {
       $uv$03$i$i = $uv$02$i$i;
       while(1) {
        $83 = ((($uv$03$i$i)) + 8|0);
        $84 = ((($83)) + 4|0);
        $85 = HEAP32[$84>>2]|0;
        $86 = ($85|0)==(0);
        if (!($86)) {
         $87 = HEAP32[$uv$03$i$i>>2]|0;
         $88 = ((($87)) + 8|0);
         $89 = HEAP32[$88>>2]|0;
         $90 = $89 & 64;
         $91 = ($90|0)==(0);
         if (!($91)) {
          $92 = HEAP32[$87>>2]|0;
          $93 = ((($92)) + 5|0);
          $94 = HEAP8[$93>>0]|0;
          $95 = $94 & 3;
          $96 = ($95<<24>>24)==(0);
          if (!($96)) {
           _reallymarkobject($46,$92);
          }
         }
         HEAP32[$84>>2] = 0;
        }
        $uv$0$i$i = HEAP32[$83>>2]|0;
        $97 = ($uv$0$i$i|0)==(0|0);
        if ($97) {
         break;
        } else {
         $uv$03$i$i = $uv$0$i$i;
        }
       }
      }
      $67 = HEAP32[$p$0$ph5$i$i>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       break L15;
      } else {
       $70 = $67;
      }
     }
     $77 = ((($$lcssa87)) + 40|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = ($78|0)==(0|0);
     if ($79) {
      break;
     } else {
      $347 = $78;$p$0$ph5$i$i = $77;
     }
    }
   }
  } while(0);
  $98 = ((($46)) + 76|0);
  $99 = HEAP32[$98>>2]|0;
  $100 = ($99|0)==(0|0);
  if (!($100)) {
   while(1) {
    _propagatemark($46);
    $101 = HEAP32[$98>>2]|0;
    $102 = ($101|0)==(0|0);
    if ($102) {
     break;
    }
   }
  }
  $103 = HEAP32[$49>>2]|0;
  HEAP32[$98>>2] = $47;
  $104 = ($47|0)==(0);
  if (!($104)) {
   while(1) {
    _propagatemark($46);
    $105 = HEAP32[$98>>2]|0;
    $106 = ($105|0)==(0|0);
    if ($106) {
     break;
    }
   }
  }
  HEAP32[$49>>2] = 0;
  $107 = ((($46)) + 88|0);
  while(1) {
   $108 = HEAP32[$107>>2]|0;
   HEAP32[$107>>2] = 0;
   $changed$0$ph$i$i = 0;$next$0$ph$i$i = $108;
   L46: while(1) {
    $next$0$i$i = $next$0$ph$i$i;
    while(1) {
     $109 = ($next$0$i$i|0)==(0|0);
     if ($109) {
      $changed$0$ph$i$i$lcssa = $changed$0$ph$i$i;
      break L46;
     }
     $110 = ((($next$0$i$i)) + 28|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = (_traverseephemeron($46,$next$0$i$i)|0);
     $113 = ($112|0)==(0);
     if ($113) {
      $next$0$i$i = $111;
     } else {
      $$lcssa86 = $111;
      break;
     }
    }
    $114 = HEAP32[$98>>2]|0;
    $115 = ($114|0)==(0|0);
    if ($115) {
     $changed$0$ph$i$i = 1;$next$0$ph$i$i = $$lcssa86;
     continue;
    }
    while(1) {
     _propagatemark($46);
     $116 = HEAP32[$98>>2]|0;
     $117 = ($116|0)==(0|0);
     if ($117) {
      $changed$0$ph$i$i = 1;$next$0$ph$i$i = $$lcssa86;
      continue L46;
     }
    }
   }
   $118 = ($changed$0$ph$i$i$lcssa|0)==(0);
   if ($118) {
    break;
   }
  }
  $119 = ((($46)) + 84|0);
  $120 = HEAP32[$119>>2]|0;
  _clearvalues($46,$120,0);
  $121 = ((($46)) + 92|0);
  $122 = HEAP32[$121>>2]|0;
  _clearvalues($46,$122,0);
  $123 = HEAP32[$119>>2]|0;
  $124 = HEAP32[$121>>2]|0;
  $125 = HEAP32[$49>>2]|0;
  $126 = ((($46)) + 96|0);
  $$0$i$i$i = $126;
  while(1) {
   $127 = HEAP32[$$0$i$i$i>>2]|0;
   $128 = ($127|0)==(0|0);
   if ($128) {
    $$0$i$i$i$lcssa = $$0$i$i$i;
    break;
   } else {
    $$0$i$i$i = $127;
   }
  }
  $129 = (($125) + ($103))|0;
  $130 = ((($46)) + 72|0);
  $131 = HEAP32[$130>>2]|0;
  $132 = ($131|0)==(0|0);
  L59: do {
   if (!($132)) {
    $348 = $131;$lastnext$0$ph5$i$i = $$0$i$i$i$lcssa;$p$0$ph4$i$i = $130;
    while(1) {
     $136 = $348;$lastnext$03$i$i = $lastnext$0$ph5$i$i;
     while(1) {
      $135 = ((($136)) + 5|0);
      $137 = HEAP8[$135>>0]|0;
      $138 = $137 & 3;
      $139 = ($138<<24>>24)==(0);
      if ($139) {
       $$lcssa84 = $136;$lastnext$03$i$i$lcssa = $lastnext$03$i$i;
       break;
      }
      $140 = HEAP32[$136>>2]|0;
      HEAP32[$p$0$ph4$i$i>>2] = $140;
      $141 = HEAP32[$lastnext$03$i$i>>2]|0;
      HEAP32[$136>>2] = $141;
      HEAP32[$lastnext$03$i$i>>2] = $136;
      $142 = HEAP32[$p$0$ph4$i$i>>2]|0;
      $143 = ($142|0)==(0|0);
      if ($143) {
       break L59;
      } else {
       $lastnext$03$i$i$phi = $136;$136 = $142;$lastnext$03$i$i = $lastnext$03$i$i$phi;
      }
     }
     $133 = HEAP32[$$lcssa84>>2]|0;
     $134 = ($133|0)==(0|0);
     if ($134) {
      break;
     } else {
      $348 = $133;$lastnext$0$ph5$i$i = $lastnext$03$i$i$lcssa;$p$0$ph4$i$i = $$lcssa84;
     }
    }
   }
  } while(0);
  $144 = ((($46)) + 120|0);
  HEAP32[$144>>2] = 1;
  $o$01$i$i2 = HEAP32[$126>>2]|0;
  $145 = ($o$01$i$i2|0)==(0|0);
  if (!($145)) {
   $o$02$i$i3 = $o$01$i$i2;
   while(1) {
    $146 = ((($o$02$i$i3)) + 5|0);
    $147 = HEAP8[$146>>0]|0;
    $148 = $147 & 3;
    $149 = ($148<<24>>24)==(0);
    if (!($149)) {
     _reallymarkobject($46,$o$02$i$i3);
    }
    $o$0$i$i4 = HEAP32[$o$02$i$i3>>2]|0;
    $150 = ($o$0$i$i4|0)==(0|0);
    if ($150) {
     break;
    } else {
     $o$02$i$i3 = $o$0$i$i4;
    }
   }
  }
  $151 = HEAP32[$98>>2]|0;
  $152 = ($151|0)==(0|0);
  if (!($152)) {
   while(1) {
    _propagatemark($46);
    $153 = HEAP32[$98>>2]|0;
    $154 = ($153|0)==(0|0);
    if ($154) {
     break;
    }
   }
  }
  HEAP32[$49>>2] = 0;
  while(1) {
   $155 = HEAP32[$107>>2]|0;
   HEAP32[$107>>2] = 0;
   $changed$0$ph$i7$i = 0;$next$0$ph$i8$i = $155;
   L80: while(1) {
    $next$0$i10$i = $next$0$ph$i8$i;
    while(1) {
     $156 = ($next$0$i10$i|0)==(0|0);
     if ($156) {
      $changed$0$ph$i7$i$lcssa = $changed$0$ph$i7$i;
      break L80;
     }
     $157 = ((($next$0$i10$i)) + 28|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = (_traverseephemeron($46,$next$0$i10$i)|0);
     $160 = ($159|0)==(0);
     if ($160) {
      $next$0$i10$i = $158;
     } else {
      $$lcssa82 = $158;
      break;
     }
    }
    $161 = HEAP32[$98>>2]|0;
    $162 = ($161|0)==(0|0);
    if ($162) {
     $changed$0$ph$i7$i = 1;$next$0$ph$i8$i = $$lcssa82;
     continue;
    }
    while(1) {
     _propagatemark($46);
     $163 = HEAP32[$98>>2]|0;
     $164 = ($163|0)==(0|0);
     if ($164) {
      $changed$0$ph$i7$i = 1;$next$0$ph$i8$i = $$lcssa82;
      continue L80;
     }
    }
   }
   $165 = ($changed$0$ph$i7$i$lcssa|0)==(0);
   if ($165) {
    break;
   }
  }
  $166 = HEAP32[$107>>2]|0;
  $167 = ($166|0)==(0|0);
  if (!($167)) {
   $$02$i$i = $166;
   while(1) {
    $168 = ((($$02$i$i)) + 7|0);
    $169 = HEAP8[$168>>0]|0;
    $170 = $169&255;
    $171 = 1 << $170;
    $172 = ((($$02$i$i)) + 16|0);
    $173 = HEAP32[$172>>2]|0;
    $174 = (($173) + ($171<<5)|0);
    $175 = ($169<<24>>24)==(31);
    if (!($175)) {
     $n$01$i$i = $173;
     while(1) {
      $176 = ((($n$01$i$i)) + 8|0);
      $177 = HEAP32[$176>>2]|0;
      $178 = ($177|0)==(0);
      do {
       if (!($178)) {
        $179 = ((($n$01$i$i)) + 24|0);
        $180 = HEAP32[$179>>2]|0;
        $181 = $180 & 64;
        $182 = ($181|0)==(0);
        if (!($182)) {
         $183 = ((($n$01$i$i)) + 16|0);
         $184 = $180 & 15;
         $185 = ($184|0)==(4);
         $186 = HEAP32[$183>>2]|0;
         if (!($185)) {
          $192 = ((($186)) + 5|0);
          $193 = HEAP8[$192>>0]|0;
          $194 = $193 & 3;
          $195 = ($194<<24>>24)==(0);
          if ($195) {
           break;
          }
          HEAP32[$176>>2] = 0;
          HEAP32[$179>>2] = 10;
          break;
         }
         $187 = ($186|0)==(0|0);
         if ($187) {
          break;
         }
         $188 = ((($186)) + 5|0);
         $189 = HEAP8[$188>>0]|0;
         $190 = $189 & 3;
         $191 = ($190<<24>>24)==(0);
         if ($191) {
          break;
         }
         _reallymarkobject($46,$186);
        }
       }
      } while(0);
      $196 = ((($n$01$i$i)) + 32|0);
      $197 = ($196>>>0)<($174>>>0);
      if ($197) {
       $n$01$i$i = $196;
      } else {
       break;
      }
     }
    }
    $198 = ((($$02$i$i)) + 28|0);
    $199 = HEAP32[$198>>2]|0;
    $200 = ($199|0)==(0|0);
    if ($200) {
     break;
    } else {
     $$02$i$i = $199;
    }
   }
  }
  $201 = HEAP32[$121>>2]|0;
  $202 = ($201|0)==(0|0);
  if (!($202)) {
   $$02$i16$i = $201;
   while(1) {
    $203 = ((($$02$i16$i)) + 7|0);
    $204 = HEAP8[$203>>0]|0;
    $205 = $204&255;
    $206 = 1 << $205;
    $207 = ((($$02$i16$i)) + 16|0);
    $208 = HEAP32[$207>>2]|0;
    $209 = (($208) + ($206<<5)|0);
    $210 = ($204<<24>>24)==(31);
    if (!($210)) {
     $n$01$i18$i = $208;
     while(1) {
      $211 = ((($n$01$i18$i)) + 8|0);
      $212 = HEAP32[$211>>2]|0;
      $213 = ($212|0)==(0);
      do {
       if (!($213)) {
        $214 = ((($n$01$i18$i)) + 24|0);
        $215 = HEAP32[$214>>2]|0;
        $216 = $215 & 64;
        $217 = ($216|0)==(0);
        if (!($217)) {
         $218 = ((($n$01$i18$i)) + 16|0);
         $219 = $215 & 15;
         $220 = ($219|0)==(4);
         $221 = HEAP32[$218>>2]|0;
         if (!($220)) {
          $227 = ((($221)) + 5|0);
          $228 = HEAP8[$227>>0]|0;
          $229 = $228 & 3;
          $230 = ($229<<24>>24)==(0);
          if ($230) {
           break;
          }
          HEAP32[$211>>2] = 0;
          HEAP32[$214>>2] = 10;
          break;
         }
         $222 = ($221|0)==(0|0);
         if ($222) {
          break;
         }
         $223 = ((($221)) + 5|0);
         $224 = HEAP8[$223>>0]|0;
         $225 = $224 & 3;
         $226 = ($225<<24>>24)==(0);
         if ($226) {
          break;
         }
         _reallymarkobject($46,$221);
        }
       }
      } while(0);
      $231 = ((($n$01$i18$i)) + 32|0);
      $232 = ($231>>>0)<($209>>>0);
      if ($232) {
       $n$01$i18$i = $231;
      } else {
       break;
      }
     }
    }
    $233 = ((($$02$i16$i)) + 28|0);
    $234 = HEAP32[$233>>2]|0;
    $235 = ($234|0)==(0|0);
    if ($235) {
     break;
    } else {
     $$02$i16$i = $234;
    }
   }
  }
  $236 = HEAP32[$119>>2]|0;
  _clearvalues($46,$236,$123);
  $237 = HEAP32[$121>>2]|0;
  _clearvalues($46,$237,$124);
  $238 = ((($46)) + 60|0);
  $239 = HEAP8[$238>>0]|0;
  $240 = $239&255;
  $241 = $240 ^ 3;
  $242 = $241&255;
  HEAP8[$238>>0] = $242;
  $243 = HEAP32[$49>>2]|0;
  $244 = HEAP32[$0>>2]|0;
  $245 = ((($244)) + 61|0);
  HEAP8[$245>>0] = 2;
  $246 = ((($244)) + 64|0);
  $i$0$i$i = 0;
  while(1) {
   $247 = (($i$0$i$i) + 1)|0;
   $248 = (_sweeplist($L,$246,1)|0);
   $249 = ($248|0)==($246|0);
   if ($249) {
    $i$0$i$i = $247;
   } else {
    $$lcssa = $247;$$lcssa81 = $248;
    break;
   }
  }
  $250 = (($129) + ($243))|0;
  $251 = ((($244)) + 68|0);
  HEAP32[$251>>2] = $$lcssa81;
  $252 = ((($1)) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  $254 = ((($1)) + 12|0);
  $255 = HEAP32[$254>>2]|0;
  $256 = (($255) + ($253))|0;
  $257 = ((($1)) + 20|0);
  HEAP32[$257>>2] = $256;
  $258 = ($$lcssa*6)|0;
  $259 = (($250) + ($258))|0;
  $$0 = $259;
  return ($$0|0);
  break;
 }
 case 7:  {
  $5 = ((($1)) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 << 2;
  $8 = ((($1)) + 16|0);
  HEAP32[$8>>2] = $7;
  $9 = ((($1)) + 76|0);
  $10 = ((($1)) + 136|0);
  ;HEAP32[$9>>2]=0|0;HEAP32[$9+4>>2]=0|0;HEAP32[$9+8>>2]=0|0;HEAP32[$9+12>>2]=0|0;HEAP32[$9+16>>2]=0|0;
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(0|0);
  if (!($12)) {
   $13 = ((($11)) + 5|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 3;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    _reallymarkobject($1,$11);
   }
  }
  $17 = ((($1)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 64;
  $20 = ($19|0)==(0);
  if (!($20)) {
   $21 = ((($1)) + 40|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ((($22)) + 5|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 3;
   $26 = ($25<<24>>24)==(0);
   if (!($26)) {
    _reallymarkobject($1,$22);
   }
  }
  _markmt($1);
  $27 = ((($1)) + 96|0);
  $o$01$i$i = HEAP32[$27>>2]|0;
  $28 = ($o$01$i$i|0)==(0|0);
  if (!($28)) {
   $o$02$i$i = $o$01$i$i;
   while(1) {
    $29 = ((($o$02$i$i)) + 5|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30 & 3;
    $32 = ($31<<24>>24)==(0);
    if (!($32)) {
     _reallymarkobject($1,$o$02$i$i);
    }
    $o$0$i$i = HEAP32[$o$02$i$i>>2]|0;
    $33 = ($o$0$i$i|0)==(0|0);
    if ($33) {
     break;
    } else {
     $o$02$i$i = $o$0$i$i;
    }
   }
  }
  HEAP8[$2>>0] = 0;
  $34 = HEAP32[$8>>2]|0;
  $$0 = $34;
  return ($$0|0);
  break;
 }
 case 0:  {
  $35 = ((($1)) + 16|0);
  HEAP32[$35>>2] = 0;
  _propagatemark($1);
  $36 = ((($1)) + 76|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0|0);
  if ($38) {
   HEAP8[$2>>0] = 1;
  }
  $39 = HEAP32[$35>>2]|0;
  $$0 = $39;
  return ($$0|0);
  break;
 }
 case 3:  {
  $273 = ((($1)) + 96|0);
  $274 = ((($1)) + 68|0);
  $275 = HEAP32[$274>>2]|0;
  $276 = ($275|0)==(0|0);
  if (!($276)) {
   $277 = ((($1)) + 12|0);
   $278 = HEAP32[$277>>2]|0;
   $279 = (_sweeplist($L,$275,83)|0);
   HEAP32[$274>>2] = $279;
   $280 = HEAP32[$277>>2]|0;
   $281 = (($280) - ($278))|0;
   $282 = ((($1)) + 20|0);
   $283 = HEAP32[$282>>2]|0;
   $284 = (($281) + ($283))|0;
   HEAP32[$282>>2] = $284;
   $285 = ($279|0)==(0|0);
   if (!($285)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 4;
  HEAP32[$274>>2] = $273;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 4:  {
  $286 = ((($1)) + 68|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  if (!($288)) {
   $289 = ((($1)) + 12|0);
   $290 = HEAP32[$289>>2]|0;
   $291 = (_sweeplist($L,$287,83)|0);
   HEAP32[$286>>2] = $291;
   $292 = HEAP32[$289>>2]|0;
   $293 = (($292) - ($290))|0;
   $294 = ((($1)) + 20|0);
   $295 = HEAP32[$294>>2]|0;
   $296 = (($293) + ($295))|0;
   HEAP32[$294>>2] = $296;
   $297 = ($291|0)==(0|0);
   if (!($297)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 5;
  HEAP32[$286>>2] = 0;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 6:  {
  $332 = ((($1)) + 96|0);
  $333 = HEAP32[$332>>2]|0;
  $334 = ($333|0)==(0|0);
  if (!($334)) {
   $335 = ((($1)) + 62|0);
   $336 = HEAP8[$335>>0]|0;
   $337 = ($336<<24>>24)==(1);
   if (!($337)) {
    $338 = ((($1)) + 120|0);
    $i$04$i = 0;
    while(1) {
     $339 = HEAP32[$338>>2]|0;
     $340 = ($i$04$i>>>0)<($339>>>0);
     if (!($340)) {
      $$lcssa90 = $339;$i$04$i$lcssa = $i$04$i;
      label = 116;
      break;
     }
     _GCTM($L,1);
     $341 = (($i$04$i) + 1)|0;
     $342 = HEAP32[$332>>2]|0;
     $343 = ($342|0)==(0|0);
     if ($343) {
      $345 = 0;$i$02$i = $341;
      break;
     } else {
      $i$04$i = $341;
     }
    }
    if ((label|0) == 116) {
     $344 = $$lcssa90 << 1;
     $345 = $344;$i$02$i = $i$04$i$lcssa;
    }
    HEAP32[$338>>2] = $345;
    $346 = ($i$02$i*6)|0;
    $$0 = $346;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 7;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 2:  {
  $260 = ((($1)) + 72|0);
  $261 = ((($1)) + 68|0);
  $262 = HEAP32[$261>>2]|0;
  $263 = ($262|0)==(0|0);
  if (!($263)) {
   $264 = ((($1)) + 12|0);
   $265 = HEAP32[$264>>2]|0;
   $266 = (_sweeplist($L,$262,83)|0);
   HEAP32[$261>>2] = $266;
   $267 = HEAP32[$264>>2]|0;
   $268 = (($267) - ($265))|0;
   $269 = ((($1)) + 20|0);
   $270 = HEAP32[$269>>2]|0;
   $271 = (($268) + ($270))|0;
   HEAP32[$269>>2] = $271;
   $272 = ($266|0)==(0|0);
   if (!($272)) {
    $$0 = 498;
    return ($$0|0);
   }
  }
  HEAP8[$2>>0] = 3;
  HEAP32[$261>>2] = $260;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 case 5:  {
  $298 = ((($1)) + 136|0);
  $299 = HEAP32[$298>>2]|0;
  $300 = ((($299)) + 5|0);
  $301 = HEAP8[$300>>0]|0;
  $302 = $301&255;
  $303 = $302 & 248;
  $304 = ((($1)) + 60|0);
  $305 = HEAP8[$304>>0]|0;
  $306 = $305&255;
  $307 = $306 & 3;
  $308 = $307 | $303;
  $309 = $308&255;
  HEAP8[$300>>0] = $309;
  $310 = ((($1)) + 62|0);
  $311 = HEAP8[$310>>0]|0;
  $312 = ($311<<24>>24)==(1);
  if (!($312)) {
   $313 = ((($1)) + 12|0);
   $314 = HEAP32[$313>>2]|0;
   $315 = ((($1)) + 108|0);
   $316 = HEAP32[$315>>2]|0;
   $317 = ((($1)) + 116|0);
   $318 = HEAP32[$317>>2]|0;
   $319 = (_luaM_realloc_($L,$316,$318,0)|0);
   HEAP32[$315>>2] = $319;
   HEAP32[$317>>2] = 0;
   $320 = ((($1)) + 28|0);
   $321 = HEAP32[$320>>2]|0;
   $322 = ((($1)) + 32|0);
   $323 = HEAP32[$322>>2]|0;
   $324 = (($323|0) / 4)&-1;
   $325 = ($321|0)<($324|0);
   if ($325) {
    $326 = (($323|0) / 2)&-1;
    _luaS_resize($L,$326);
   }
   $327 = HEAP32[$313>>2]|0;
   $328 = (($327) - ($314))|0;
   $329 = ((($1)) + 20|0);
   $330 = HEAP32[$329>>2]|0;
   $331 = (($328) + ($330))|0;
   HEAP32[$329>>2] = $331;
  }
  HEAP8[$2>>0] = 6;
  $$0 = 0;
  return ($$0|0);
  break;
 }
 default: {
  $$0 = 0;
  return ($$0|0);
 }
 }
 return (0)|0;
}
function _markmt($g) {
 $g = $g|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 244|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 5|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4 & 3;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   _reallymarkobject($g,$1);
  }
 }
 $7 = ((($g)) + 248|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0|0);
 if (!($9)) {
  $10 = ((($8)) + 5|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 & 3;
  $13 = ($12<<24>>24)==(0);
  if (!($13)) {
   _reallymarkobject($g,$8);
  }
 }
 $14 = ((($g)) + 252|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($15|0)==(0|0);
 if (!($16)) {
  $17 = ((($15)) + 5|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18 & 3;
  $20 = ($19<<24>>24)==(0);
  if (!($20)) {
   _reallymarkobject($g,$15);
  }
 }
 $21 = ((($g)) + 256|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  $24 = ((($22)) + 5|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 & 3;
  $27 = ($26<<24>>24)==(0);
  if (!($27)) {
   _reallymarkobject($g,$22);
  }
 }
 $28 = ((($g)) + 260|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ($29|0)==(0|0);
 if (!($30)) {
  $31 = ((($29)) + 5|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32 & 3;
  $34 = ($33<<24>>24)==(0);
  if (!($34)) {
   _reallymarkobject($g,$29);
  }
 }
 $35 = ((($g)) + 264|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  $38 = ((($36)) + 5|0);
  $39 = HEAP8[$38>>0]|0;
  $40 = $39 & 3;
  $41 = ($40<<24>>24)==(0);
  if (!($41)) {
   _reallymarkobject($g,$36);
  }
 }
 $42 = ((($g)) + 268|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = ($43|0)==(0|0);
 if (!($44)) {
  $45 = ((($43)) + 5|0);
  $46 = HEAP8[$45>>0]|0;
  $47 = $46 & 3;
  $48 = ($47<<24>>24)==(0);
  if (!($48)) {
   _reallymarkobject($g,$43);
  }
 }
 $49 = ((($g)) + 272|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ($50|0)==(0|0);
 if (!($51)) {
  $52 = ((($50)) + 5|0);
  $53 = HEAP8[$52>>0]|0;
  $54 = $53 & 3;
  $55 = ($54<<24>>24)==(0);
  if (!($55)) {
   _reallymarkobject($g,$50);
  }
 }
 $56 = ((($g)) + 276|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($57|0)==(0|0);
 if ($58) {
  return;
 }
 $59 = ((($57)) + 5|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 3;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  return;
 }
 _reallymarkobject($g,$57);
 return;
}
function _propagatemark($g) {
 $g = $g|0;
 var $$0$i$i$i = 0, $$lcssa$i = 0, $$lcssa$i12 = 0, $$lcssa$i4 = 0, $$lcssa35 = 0, $$ph8$i = 0, $$ph9$i = 0, $$pr$pre$i = 0, $$pr7$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i3 = 0, $$pre$i6 = 0, $$pre$i8 = 0, $$pre20$i = 0, $$pre21$i = 0, $$pre22$i = 0, $$pre23$i = 0, $$pre7$i$i = 0, $$pre8$i$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $hasclears$0$$i$i = 0, $hasclears$0$lcssa$i$i = 0, $hasclears$03$i$i = 0, $hasclears$1$i$i = 0, $i$01$i = 0, $i$01$i1 = 0, $i$016$i = 0, $i$03$i$i = 0, $i$113$i = 0, $i$210$i = 0, $i$39$i = 0, $n$01$i$i = 0, $n$01$i1$i = 0, $not$$i$i = 0, $o$0$lcssa$i = 0, $o$02$i = 0, $o$11$i = 0, $size$0 = 0;
 var $tmp$i = 0, $tmp1$i = 0, $tmp2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 76|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 5|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = $4 | 4;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 4|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 switch ($9|0) {
 case 5:  {
  $10 = ((($1)) + 28|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[$0>>2] = $11;
  $12 = ((($1)) + 24|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  do {
   if ($14) {
    label = 35;
   } else {
    $15 = ((($13)) + 6|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = $16 & 8;
    $18 = ($17<<24>>24)==(0);
    if ($18) {
     $19 = ((($g)) + 160|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = (_luaT_gettm($13,3,$20)|0);
     $$pr$pre$i = HEAP32[$12>>2]|0;
     $22 = ($$pr$pre$i|0)==(0|0);
     if ($22) {
      $$ph9$i = $21;
     } else {
      $$ph8$i = $21;$$pr7$i = $$pr$pre$i;
      label = 5;
     }
    } else {
     $$ph8$i = 0;$$pr7$i = $13;
     label = 5;
    }
    if ((label|0) == 5) {
     $23 = ((($$pr7$i)) + 5|0);
     $24 = HEAP8[$23>>0]|0;
     $25 = $24 & 3;
     $26 = ($25<<24>>24)==(0);
     if ($26) {
      $$ph9$i = $$ph8$i;
     } else {
      _reallymarkobject($g,$$pr7$i);
      $$ph9$i = $$ph8$i;
     }
    }
    $27 = ($$ph9$i|0)==(0|0);
    if ($27) {
     label = 35;
    } else {
     $28 = ((($$ph9$i)) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = $29 & 15;
     $31 = ($30|0)==(4);
     if ($31) {
      $32 = HEAP32[$$ph9$i>>2]|0;
      $33 = ((($32)) + 24|0);
      $34 = (_strchr($33,107)|0);
      $35 = (_strchr($33,118)|0);
      $36 = ($34|0)!=(0|0);
      $37 = ($35|0)!=(0|0);
      $38 = $36 | $37;
      if ($38) {
       $39 = HEAP8[$2>>0]|0;
       $40 = $39&255;
       $41 = $40 & 251;
       $42 = $41&255;
       HEAP8[$2>>0] = $42;
       if ($36) {
        if ($37) {
         $100 = ((($g)) + 92|0);
         $101 = HEAP32[$100>>2]|0;
         HEAP32[$10>>2] = $101;
         HEAP32[$100>>2] = $1;
         break;
        } else {
         (_traverseephemeron($g,$1)|0);
         break;
        }
       }
       $43 = ((($1)) + 7|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44&255;
       $46 = 1 << $45;
       $47 = ((($1)) + 16|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = (($48) + ($46<<5)|0);
       $50 = ((($1)) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = ($51|0)!=(0);
       $53 = $52&1;
       $54 = ($44<<24>>24)==(31);
       if ($54) {
        $hasclears$0$lcssa$i$i = $53;
       } else {
        $hasclears$03$i$i = $53;$n$01$i$i = $48;
        while(1) {
         $55 = ((($n$01$i$i)) + 8|0);
         $56 = HEAP32[$55>>2]|0;
         $57 = ($56|0)==(0);
         $58 = ((($n$01$i$i)) + 24|0);
         $59 = HEAP32[$58>>2]|0;
         $60 = $59 & 64;
         $61 = ($60|0)==(0);
         if ($57) {
          if ($61) {
           $hasclears$1$i$i = $hasclears$03$i$i;
          } else {
           $62 = ((($n$01$i$i)) + 16|0);
           $63 = HEAP32[$62>>2]|0;
           $64 = ((($63)) + 5|0);
           $65 = HEAP8[$64>>0]|0;
           $66 = $65 & 3;
           $67 = ($66<<24>>24)==(0);
           if ($67) {
            $hasclears$1$i$i = $hasclears$03$i$i;
           } else {
            HEAP32[$58>>2] = 10;
            $hasclears$1$i$i = $hasclears$03$i$i;
           }
          }
         } else {
          if (!($61)) {
           $68 = ((($n$01$i$i)) + 16|0);
           $69 = HEAP32[$68>>2]|0;
           $70 = ((($69)) + 5|0);
           $71 = HEAP8[$70>>0]|0;
           $72 = $71 & 3;
           $73 = ($72<<24>>24)==(0);
           if (!($73)) {
            _reallymarkobject($g,$69);
           }
          }
          $74 = ($hasclears$03$i$i|0)==(0);
          if ($74) {
           $75 = HEAP32[$55>>2]|0;
           $76 = $75 & 64;
           $77 = ($76|0)==(0);
           do {
            if ($77) {
             $$0$i$i$i = 0;
            } else {
             $78 = $75 & 15;
             $79 = ($78|0)==(4);
             $80 = HEAP32[$n$01$i$i>>2]|0;
             if (!($79)) {
              $86 = ((($80)) + 5|0);
              $87 = HEAP8[$86>>0]|0;
              $88 = $87&255;
              $89 = $88 & 3;
              $$0$i$i$i = $89;
              break;
             }
             $81 = ($80|0)==(0|0);
             if ($81) {
              $$0$i$i$i = 0;
             } else {
              $82 = ((($80)) + 5|0);
              $83 = HEAP8[$82>>0]|0;
              $84 = $83 & 3;
              $85 = ($84<<24>>24)==(0);
              if ($85) {
               $$0$i$i$i = 0;
              } else {
               _reallymarkobject($g,$80);
               $$0$i$i$i = 0;
              }
             }
            }
           } while(0);
           $not$$i$i = ($$0$i$i$i|0)!=(0);
           $hasclears$0$$i$i = $not$$i$i&1;
           $hasclears$1$i$i = $hasclears$0$$i$i;
          } else {
           $hasclears$1$i$i = $hasclears$03$i$i;
          }
         }
         $90 = ((($n$01$i$i)) + 32|0);
         $91 = ($90>>>0)<($49>>>0);
         if ($91) {
          $hasclears$03$i$i = $hasclears$1$i$i;$n$01$i$i = $90;
         } else {
          $hasclears$0$lcssa$i$i = $hasclears$1$i$i;
          break;
         }
        }
       }
       $92 = ((($g)) + 61|0);
       $93 = HEAP8[$92>>0]|0;
       $94 = ($93<<24>>24)==(0);
       if ($94) {
        $95 = ((($g)) + 80|0);
        $96 = HEAP32[$95>>2]|0;
        HEAP32[$10>>2] = $96;
        HEAP32[$95>>2] = $1;
        break;
       }
       $97 = ($hasclears$0$lcssa$i$i|0)==(0);
       if (!($97)) {
        $98 = ((($g)) + 84|0);
        $99 = HEAP32[$98>>2]|0;
        HEAP32[$10>>2] = $99;
        HEAP32[$98>>2] = $1;
       }
      } else {
       label = 35;
      }
     } else {
      label = 35;
     }
    }
   }
  } while(0);
  if ((label|0) == 35) {
   $102 = ((($1)) + 7|0);
   $103 = HEAP8[$102>>0]|0;
   $104 = $103&255;
   $105 = 1 << $104;
   $106 = ((($1)) + 16|0);
   $107 = HEAP32[$106>>2]|0;
   $108 = (($107) + ($105<<5)|0);
   $109 = ((($1)) + 8|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ($110|0)==(0);
   if ($111) {
    $128 = $107;
   } else {
    $112 = ((($1)) + 12|0);
    $373 = $110;$i$03$i$i = 0;
    while(1) {
     $113 = HEAP32[$112>>2]|0;
     $114 = (((($113) + ($i$03$i$i<<4)|0)) + 8|0);
     $115 = HEAP32[$114>>2]|0;
     $116 = $115 & 64;
     $117 = ($116|0)==(0);
     if ($117) {
      $126 = $373;
     } else {
      $118 = (($113) + ($i$03$i$i<<4)|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ((($119)) + 5|0);
      $121 = HEAP8[$120>>0]|0;
      $122 = $121 & 3;
      $123 = ($122<<24>>24)==(0);
      if ($123) {
       $126 = $373;
      } else {
       _reallymarkobject($g,$119);
       $$pre$i$i = HEAP32[$109>>2]|0;
       $126 = $$pre$i$i;
      }
     }
     $124 = (($i$03$i$i) + 1)|0;
     $125 = ($124>>>0)<($126>>>0);
     if ($125) {
      $373 = $126;$i$03$i$i = $124;
     } else {
      break;
     }
    }
    $$pre7$i$i = HEAP32[$106>>2]|0;
    $128 = $$pre7$i$i;
   }
   $127 = ($128>>>0)<($108>>>0);
   if ($127) {
    $n$01$i1$i = $128;
    while(1) {
     $129 = ((($n$01$i1$i)) + 8|0);
     $130 = HEAP32[$129>>2]|0;
     $131 = ($130|0)==(0);
     $132 = ((($n$01$i1$i)) + 24|0);
     $133 = HEAP32[$132>>2]|0;
     $134 = $133 & 64;
     $135 = ($134|0)==(0);
     if ($131) {
      if (!($135)) {
       $136 = ((($n$01$i1$i)) + 16|0);
       $137 = HEAP32[$136>>2]|0;
       $138 = ((($137)) + 5|0);
       $139 = HEAP8[$138>>0]|0;
       $140 = $139 & 3;
       $141 = ($140<<24>>24)==(0);
       if (!($141)) {
        HEAP32[$132>>2] = 10;
       }
      }
     } else {
      if ($135) {
       $149 = $130;
      } else {
       $142 = ((($n$01$i1$i)) + 16|0);
       $143 = HEAP32[$142>>2]|0;
       $144 = ((($143)) + 5|0);
       $145 = HEAP8[$144>>0]|0;
       $146 = $145 & 3;
       $147 = ($146<<24>>24)==(0);
       if ($147) {
        $149 = $130;
       } else {
        _reallymarkobject($g,$143);
        $$pre8$i$i = HEAP32[$129>>2]|0;
        $149 = $$pre8$i$i;
       }
      }
      $148 = $149 & 64;
      $150 = ($148|0)==(0);
      if (!($150)) {
       $151 = HEAP32[$n$01$i1$i>>2]|0;
       $152 = ((($151)) + 5|0);
       $153 = HEAP8[$152>>0]|0;
       $154 = $153 & 3;
       $155 = ($154<<24>>24)==(0);
       if (!($155)) {
        _reallymarkobject($g,$151);
       }
      }
     }
     $156 = ((($n$01$i1$i)) + 32|0);
     $157 = ($156>>>0)<($108>>>0);
     if ($157) {
      $n$01$i1$i = $156;
     } else {
      break;
     }
    }
   }
  }
  $158 = ((($1)) + 8|0);
  $159 = HEAP32[$158>>2]|0;
  $160 = $159 << 4;
  $161 = (($160) + 32)|0;
  $162 = ((($1)) + 7|0);
  $163 = HEAP8[$162>>0]|0;
  $164 = $163&255;
  $165 = 32 << $164;
  $166 = (($161) + ($165))|0;
  $size$0 = $166;
  break;
 }
 case 6:  {
  $167 = ((($1)) + 8|0);
  $168 = HEAP32[$167>>2]|0;
  HEAP32[$0>>2] = $168;
  $169 = ((($1)) + 12|0);
  $170 = HEAP32[$169>>2]|0;
  $171 = ($170|0)==(0|0);
  if (!($171)) {
   $172 = ((($170)) + 5|0);
   $173 = HEAP8[$172>>0]|0;
   $174 = $173 & 3;
   $175 = ($174<<24>>24)==(0);
   if (!($175)) {
    _reallymarkobject($g,$170);
   }
  }
  $176 = ((($1)) + 6|0);
  $177 = HEAP8[$176>>0]|0;
  $178 = $177&255;
  $179 = ($177<<24>>24)==(0);
  if ($179) {
   $$lcssa$i = $178;
  } else {
   $180 = ((($g)) + 61|0);
   $374 = $177;$i$01$i = 0;
   while(1) {
    $181 = (((($1)) + 16|0) + ($i$01$i<<2)|0);
    $182 = HEAP32[$181>>2]|0;
    $183 = ($182|0)==(0|0);
    do {
     if ($183) {
      $201 = $374;
     } else {
      $184 = HEAP32[$182>>2]|0;
      $185 = ((($182)) + 8|0);
      $186 = ($184|0)==($185|0);
      if (!($186)) {
       $187 = HEAP8[$180>>0]|0;
       $188 = ($187<<24>>24)==(8);
       if (!($188)) {
        $189 = ((($185)) + 4|0);
        HEAP32[$189>>2] = 1;
        $201 = $374;
        break;
       }
      }
      $190 = ((($184)) + 8|0);
      $191 = HEAP32[$190>>2]|0;
      $192 = $191 & 64;
      $193 = ($192|0)==(0);
      if ($193) {
       $201 = $374;
      } else {
       $194 = HEAP32[$184>>2]|0;
       $195 = ((($194)) + 5|0);
       $196 = HEAP8[$195>>0]|0;
       $197 = $196 & 3;
       $198 = ($197<<24>>24)==(0);
       if ($198) {
        $201 = $374;
       } else {
        _reallymarkobject($g,$194);
        $$pre$i = HEAP8[$176>>0]|0;
        $201 = $$pre$i;
       }
      }
     }
    } while(0);
    $199 = (($i$01$i) + 1)|0;
    $200 = $201&255;
    $202 = ($199|0)<($200|0);
    if ($202) {
     $374 = $201;$i$01$i = $199;
    } else {
     $$lcssa$i = $200;
     break;
    }
   }
  }
  $203 = $$lcssa$i << 2;
  $204 = (($203) + 16)|0;
  $size$0 = $204;
  break;
 }
 case 38:  {
  $205 = ((($1)) + 8|0);
  $206 = HEAP32[$205>>2]|0;
  HEAP32[$0>>2] = $206;
  $207 = ((($1)) + 6|0);
  $208 = HEAP8[$207>>0]|0;
  $209 = $208&255;
  $210 = ($208<<24>>24)==(0);
  if ($210) {
   $$lcssa$i4 = $209;
  } else {
   $375 = $208;$i$01$i1 = 0;
   while(1) {
    $211 = (((((($1)) + 16|0) + ($i$01$i1<<4)|0)) + 8|0);
    $212 = HEAP32[$211>>2]|0;
    $213 = $212 & 64;
    $214 = ($213|0)==(0);
    if ($214) {
     $223 = $375;
    } else {
     $215 = (((($1)) + 16|0) + ($i$01$i1<<4)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ((($216)) + 5|0);
     $218 = HEAP8[$217>>0]|0;
     $219 = $218 & 3;
     $220 = ($219<<24>>24)==(0);
     if ($220) {
      $223 = $375;
     } else {
      _reallymarkobject($g,$216);
      $$pre$i3 = HEAP8[$207>>0]|0;
      $223 = $$pre$i3;
     }
    }
    $221 = (($i$01$i1) + 1)|0;
    $222 = $223&255;
    $224 = ($221|0)<($222|0);
    if ($224) {
     $375 = $223;$i$01$i1 = $221;
    } else {
     $$lcssa$i4 = $222;
     break;
    }
   }
  }
  $225 = $$lcssa$i4 << 4;
  $226 = (($225) + 16)|0;
  $size$0 = $226;
  break;
 }
 case 9:  {
  $277 = ((($1)) + 76|0);
  $278 = HEAP32[$277>>2]|0;
  HEAP32[$0>>2] = $278;
  $279 = ((($1)) + 68|0);
  $280 = HEAP32[$279>>2]|0;
  $281 = ($280|0)==(0|0);
  if (!($281)) {
   $282 = ((($280)) + 5|0);
   $283 = HEAP8[$282>>0]|0;
   $284 = $283 & 3;
   $285 = ($284<<24>>24)==(0);
   if (!($285)) {
    HEAP32[$279>>2] = 0;
   }
  }
  $286 = ((($1)) + 72|0);
  $287 = HEAP32[$286>>2]|0;
  $288 = ($287|0)==(0|0);
  if (!($288)) {
   $289 = ((($287)) + 5|0);
   $290 = HEAP8[$289>>0]|0;
   $291 = $290 & 3;
   $292 = ($291<<24>>24)==(0);
   if (!($292)) {
    _reallymarkobject($g,$287);
   }
  }
  $293 = ((($1)) + 16|0);
  $294 = HEAP32[$293>>2]|0;
  $295 = ($294|0)>(0);
  if ($295) {
   $296 = ((($1)) + 44|0);
   $377 = $294;$i$016$i = 0;
   while(1) {
    $301 = HEAP32[$296>>2]|0;
    $302 = (((($301) + ($i$016$i<<4)|0)) + 8|0);
    $303 = HEAP32[$302>>2]|0;
    $304 = $303 & 64;
    $305 = ($304|0)==(0);
    if ($305) {
     $314 = $377;
    } else {
     $306 = (($301) + ($i$016$i<<4)|0);
     $307 = HEAP32[$306>>2]|0;
     $308 = ((($307)) + 5|0);
     $309 = HEAP8[$308>>0]|0;
     $310 = $309 & 3;
     $311 = ($310<<24>>24)==(0);
     if ($311) {
      $314 = $377;
     } else {
      _reallymarkobject($g,$307);
      $$pre$i8 = HEAP32[$293>>2]|0;
      $314 = $$pre$i8;
     }
    }
    $312 = (($i$016$i) + 1)|0;
    $313 = ($312|0)<($314|0);
    if ($313) {
     $377 = $314;$i$016$i = $312;
    } else {
     break;
    }
   }
  }
  $297 = ((($1)) + 12|0);
  $298 = HEAP32[$297>>2]|0;
  $299 = ($298|0)>(0);
  if ($299) {
   $300 = ((($1)) + 64|0);
   $378 = $298;$i$113$i = 0;
   while(1) {
    $319 = HEAP32[$300>>2]|0;
    $320 = (($319) + ($i$113$i<<3)|0);
    $321 = HEAP32[$320>>2]|0;
    $322 = ($321|0)==(0|0);
    if ($322) {
     $329 = $378;
    } else {
     $323 = ((($321)) + 5|0);
     $324 = HEAP8[$323>>0]|0;
     $325 = $324 & 3;
     $326 = ($325<<24>>24)==(0);
     if ($326) {
      $329 = $378;
     } else {
      _reallymarkobject($g,$321);
      $$pre20$i = HEAP32[$297>>2]|0;
      $329 = $$pre20$i;
     }
    }
    $327 = (($i$113$i) + 1)|0;
    $328 = ($327|0)<($329|0);
    if ($328) {
     $378 = $329;$i$113$i = $327;
    } else {
     break;
    }
   }
  }
  $315 = ((($1)) + 28|0);
  $316 = HEAP32[$315>>2]|0;
  $317 = ($316|0)>(0);
  if ($317) {
   $318 = ((($1)) + 52|0);
   $380 = $316;$i$210$i = 0;
   while(1) {
    $334 = HEAP32[$318>>2]|0;
    $335 = (($334) + ($i$210$i<<2)|0);
    $336 = HEAP32[$335>>2]|0;
    $337 = ($336|0)==(0|0);
    if ($337) {
     $344 = $380;
    } else {
     $338 = ((($336)) + 5|0);
     $339 = HEAP8[$338>>0]|0;
     $340 = $339 & 3;
     $341 = ($340<<24>>24)==(0);
     if ($341) {
      $344 = $380;
     } else {
      _reallymarkobject($g,$336);
      $$pre21$i = HEAP32[$315>>2]|0;
      $344 = $$pre21$i;
     }
    }
    $342 = (($i$210$i) + 1)|0;
    $343 = ($342|0)<($344|0);
    if ($343) {
     $380 = $344;$i$210$i = $342;
    } else {
     $379 = $344;
     break;
    }
   }
  } else {
   $379 = $316;
  }
  $330 = ((($1)) + 32|0);
  $331 = HEAP32[$330>>2]|0;
  $332 = ($331|0)>(0);
  if ($332) {
   $333 = ((($1)) + 60|0);
   $381 = $331;$i$39$i = 0;
   while(1) {
    $345 = HEAP32[$333>>2]|0;
    $346 = (($345) + (($i$39$i*12)|0)|0);
    $347 = HEAP32[$346>>2]|0;
    $348 = ($347|0)==(0|0);
    if ($348) {
     $355 = $381;
    } else {
     $349 = ((($347)) + 5|0);
     $350 = HEAP8[$349>>0]|0;
     $351 = $350 & 3;
     $352 = ($351<<24>>24)==(0);
     if ($352) {
      $355 = $381;
     } else {
      _reallymarkobject($g,$347);
      $$pre22$i = HEAP32[$330>>2]|0;
      $355 = $$pre22$i;
     }
    }
    $353 = (($i$39$i) + 1)|0;
    $354 = ($353|0)<($355|0);
    if ($354) {
     $381 = $355;$i$39$i = $353;
    } else {
     $$lcssa35 = $355;
     break;
    }
   }
   $$pre23$i = HEAP32[$315>>2]|0;
   $$lcssa$i12 = $$lcssa35;$365 = $$pre23$i;
  } else {
   $$lcssa$i12 = $331;$365 = $379;
  }
  $356 = ((($1)) + 20|0);
  $357 = HEAP32[$356>>2]|0;
  $358 = HEAP32[$293>>2]|0;
  $359 = $358 << 4;
  $360 = ((($1)) + 24|0);
  $361 = HEAP32[$360>>2]|0;
  $362 = ($$lcssa$i12*12)|0;
  $363 = HEAP32[$297>>2]|0;
  $364 = $363 << 3;
  $tmp$i = (($357) + ($365))|0;
  $tmp1$i = (($tmp$i) + ($361))|0;
  $tmp2$i = $tmp1$i << 2;
  $366 = (($362) + 80)|0;
  $367 = (($366) + ($359))|0;
  $368 = (($367) + ($364))|0;
  $369 = (($368) + ($tmp2$i))|0;
  $size$0 = $369;
  break;
 }
 case 8:  {
  $227 = ((($1)) + 36|0);
  $228 = HEAP32[$227>>2]|0;
  HEAP32[$0>>2] = $228;
  $229 = ((($g)) + 80|0);
  $230 = HEAP32[$229>>2]|0;
  HEAP32[$227>>2] = $230;
  HEAP32[$229>>2] = $1;
  $231 = $4 & 251;
  $232 = $231&255;
  HEAP8[$2>>0] = $232;
  $233 = ((($1)) + 28|0);
  $234 = HEAP32[$233>>2]|0;
  $235 = ($234|0)==(0|0);
  if ($235) {
   $size$0 = 1;
  } else {
   $236 = ((($1)) + 8|0);
   $237 = HEAP32[$236>>2]|0;
   $238 = ($234>>>0)<($237>>>0);
   if ($238) {
    $376 = $237;$o$02$i = $234;
    while(1) {
     $239 = ((($o$02$i)) + 8|0);
     $240 = HEAP32[$239>>2]|0;
     $241 = $240 & 64;
     $242 = ($241|0)==(0);
     if ($242) {
      $250 = $376;
     } else {
      $243 = HEAP32[$o$02$i>>2]|0;
      $244 = ((($243)) + 5|0);
      $245 = HEAP8[$244>>0]|0;
      $246 = $245 & 3;
      $247 = ($246<<24>>24)==(0);
      if ($247) {
       $250 = $376;
      } else {
       _reallymarkobject($g,$243);
       $$pre$i6 = HEAP32[$236>>2]|0;
       $250 = $$pre$i6;
      }
     }
     $248 = ((($o$02$i)) + 16|0);
     $249 = ($248>>>0)<($250>>>0);
     if ($249) {
      $376 = $250;$o$02$i = $248;
     } else {
      $o$0$lcssa$i = $248;
      break;
     }
    }
   } else {
    $o$0$lcssa$i = $234;
   }
   $251 = ((($g)) + 61|0);
   $252 = HEAP8[$251>>0]|0;
   $253 = ($252<<24>>24)==(8);
   if ($253) {
    $254 = HEAP32[$233>>2]|0;
    $255 = ((($1)) + 92|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = (($254) + ($256<<4)|0);
    $258 = ($o$0$lcssa$i>>>0)<($257>>>0);
    if ($258) {
     $o$11$i = $o$0$lcssa$i;
     while(1) {
      $259 = ((($o$11$i)) + 8|0);
      HEAP32[$259>>2] = 0;
      $260 = ((($o$11$i)) + 16|0);
      $261 = ($260>>>0)<($257>>>0);
      if ($261) {
       $o$11$i = $260;
      } else {
       break;
      }
     }
    }
    $262 = ((($1)) + 40|0);
    $263 = HEAP32[$262>>2]|0;
    $264 = ($263|0)==($1|0);
    if ($264) {
     $265 = ((($1)) + 32|0);
     $266 = HEAP32[$265>>2]|0;
     $267 = ($266|0)==(0|0);
     if (!($267)) {
      $268 = ((($g)) + 104|0);
      $269 = HEAP32[$268>>2]|0;
      HEAP32[$262>>2] = $269;
      HEAP32[$268>>2] = $1;
     }
    }
   } else {
    $270 = ((($g)) + 62|0);
    $271 = HEAP8[$270>>0]|0;
    $272 = ($271<<24>>24)==(1);
    if (!($272)) {
     _luaD_shrinkstack($1);
    }
   }
   $273 = ((($1)) + 92|0);
   $274 = HEAP32[$273>>2]|0;
   $275 = $274 << 4;
   $276 = (($275) + 112)|0;
   $size$0 = $276;
  }
  break;
 }
 default: {
  return;
 }
 }
 $370 = ((($g)) + 16|0);
 $371 = HEAP32[$370>>2]|0;
 $372 = (($371) + ($size$0))|0;
 HEAP32[$370>>2] = $372;
 return;
}
function _traverseephemeron($g,$h) {
 $g = $g|0;
 $h = $h|0;
 var $$pre = 0, $$pre17 = 0, $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $9 = 0, $hasclears$0$lcssa = 0, $hasclears$01 = 0, $hasclears$1 = 0, $hasww$0$ = 0, $hasww$0$lcssa = 0, $hasww$03 = 0, $hasww$1 = 0, $i$012 = 0, $marked$0$lcssa = 0, $marked$011 = 0, $marked$1 = 0, $marked$1$lcssa = 0;
 var $marked$2$lcssa = 0, $marked$27 = 0, $marked$3 = 0, $n$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($h)) + 7|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = 1 << $2;
 $4 = ((($h)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($3<<5)|0);
 $7 = ((($h)) + 8|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  $26 = $5;$marked$0$lcssa = 0;
 } else {
  $10 = ((($h)) + 12|0);
  $84 = $8;$i$012 = 0;$marked$011 = 0;
  while(1) {
   $11 = HEAP32[$10>>2]|0;
   $12 = (((($11) + ($i$012<<4)|0)) + 8|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = $13 & 64;
   $15 = ($14|0)==(0);
   if ($15) {
    $24 = $84;$marked$1 = $marked$011;
   } else {
    $16 = (($11) + ($i$012<<4)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($17)) + 5|0);
    $19 = HEAP8[$18>>0]|0;
    $20 = $19 & 3;
    $21 = ($20<<24>>24)==(0);
    if ($21) {
     $24 = $84;$marked$1 = $marked$011;
    } else {
     _reallymarkobject($g,$17);
     $$pre = HEAP32[$7>>2]|0;
     $24 = $$pre;$marked$1 = 1;
    }
   }
   $22 = (($i$012) + 1)|0;
   $23 = ($22>>>0)<($24>>>0);
   if ($23) {
    $84 = $24;$i$012 = $22;$marked$011 = $marked$1;
   } else {
    $marked$1$lcssa = $marked$1;
    break;
   }
  }
  $$pre17 = HEAP32[$4>>2]|0;
  $26 = $$pre17;$marked$0$lcssa = $marked$1$lcssa;
 }
 $25 = ($26>>>0)<($6>>>0);
 if ($25) {
  $hasclears$01 = 0;$hasww$03 = 0;$marked$27 = $marked$0$lcssa;$n$05 = $26;
  while(1) {
   $27 = ((($n$05)) + 8|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = ($28|0)==(0);
   $30 = ((($n$05)) + 24|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = $31 & 64;
   $33 = ($32|0)==(0);
   L14: do {
    if ($29) {
     if ($33) {
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
     } else {
      $34 = ((($n$05)) + 16|0);
      $35 = HEAP32[$34>>2]|0;
      $36 = ((($35)) + 5|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = $37 & 3;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
      } else {
       HEAP32[$30>>2] = 10;
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
      }
     }
    } else {
     do {
      if ($33) {
       $50 = $28;
       label = 18;
      } else {
       $40 = ((($n$05)) + 16|0);
       $41 = $31 & 15;
       $42 = ($41|0)==(4);
       $43 = HEAP32[$40>>2]|0;
       if ($42) {
        $44 = ($43|0)==(0|0);
        if ($44) {
         $50 = $28;
         label = 18;
         break;
        }
        $45 = ((($43)) + 5|0);
        $46 = HEAP8[$45>>0]|0;
        $47 = $46 & 3;
        $48 = ($47<<24>>24)==(0);
        if ($48) {
         $50 = $28;
         label = 18;
         break;
        }
        _reallymarkobject($g,$43);
        $$pre18 = HEAP32[$27>>2]|0;
        $50 = $$pre18;
        label = 18;
        break;
       }
       $52 = ((($43)) + 5|0);
       $53 = HEAP8[$52>>0]|0;
       $54 = $53 & 3;
       $55 = ($54<<24>>24)==(0);
       $56 = $28 & 64;
       $57 = ($56|0)==(0);
       if ($55) {
        if ($57) {
         $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
         break L14;
        } else {
         break;
        }
       }
       if ($57) {
        $hasclears$1 = 1;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
        break L14;
       }
       $58 = HEAP32[$n$05>>2]|0;
       $59 = ((($58)) + 5|0);
       $60 = HEAP8[$59>>0]|0;
       $61 = $60 & 3;
       $62 = ($61<<24>>24)==(0);
       $hasww$0$ = $62 ? $hasww$03 : 1;
       $hasclears$1 = 1;$hasww$1 = $hasww$0$;$marked$3 = $marked$27;
       break L14;
      }
     } while(0);
     if ((label|0) == 18) {
      label = 0;
      $49 = $50 & 64;
      $51 = ($49|0)==(0);
      if ($51) {
       $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
       break;
      }
     }
     $63 = HEAP32[$n$05>>2]|0;
     $64 = ((($63)) + 5|0);
     $65 = HEAP8[$64>>0]|0;
     $66 = $65 & 3;
     $67 = ($66<<24>>24)==(0);
     if ($67) {
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = $marked$27;
     } else {
      _reallymarkobject($g,$63);
      $hasclears$1 = $hasclears$01;$hasww$1 = $hasww$03;$marked$3 = 1;
     }
    }
   } while(0);
   $68 = ((($n$05)) + 32|0);
   $69 = ($68>>>0)<($6>>>0);
   if ($69) {
    $hasclears$01 = $hasclears$1;$hasww$03 = $hasww$1;$marked$27 = $marked$3;$n$05 = $68;
   } else {
    $hasclears$0$lcssa = $hasclears$1;$hasww$0$lcssa = $hasww$1;$marked$2$lcssa = $marked$3;
    break;
   }
  }
 } else {
  $hasclears$0$lcssa = 0;$hasww$0$lcssa = 0;$marked$2$lcssa = $marked$0$lcssa;
 }
 $70 = ((($g)) + 61|0);
 $71 = HEAP8[$70>>0]|0;
 $72 = ($71<<24>>24)==(0);
 if ($72) {
  $73 = ((($g)) + 80|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ((($h)) + 28|0);
  HEAP32[$75>>2] = $74;
  HEAP32[$73>>2] = $h;
  return ($marked$2$lcssa|0);
 }
 $76 = ($hasww$0$lcssa|0)==(0);
 if (!($76)) {
  $77 = ((($g)) + 88|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((($h)) + 28|0);
  HEAP32[$79>>2] = $78;
  HEAP32[$77>>2] = $h;
  return ($marked$2$lcssa|0);
 }
 $80 = ($hasclears$0$lcssa|0)==(0);
 if ($80) {
  return ($marked$2$lcssa|0);
 }
 $81 = ((($g)) + 92|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = ((($h)) + 28|0);
 HEAP32[$83>>2] = $82;
 HEAP32[$81>>2] = $h;
 return ($marked$2$lcssa|0);
}
function _clearvalues($g,$l,$f) {
 $g = $g|0;
 $l = $l|0;
 $f = $f|0;
 var $$06 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $n$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l|0)==($f|0);
 if ($0) {
  return;
 } else {
  $$06 = $l;
 }
 while(1) {
  $1 = ((($$06)) + 7|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2&255;
  $4 = 1 << $3;
  $5 = ((($$06)) + 16|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($4<<5)|0);
  $8 = ((($$06)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0);
  if ($10) {
   $21 = $6;
  } else {
   $11 = ((($$06)) + 12|0);
   $i$01 = 0;
   while(1) {
    $12 = HEAP32[$11>>2]|0;
    $13 = (($12) + ($i$01<<4)|0);
    $14 = (_iscleared($g,$13)|0);
    $15 = ($14|0)==(0);
    if (!($15)) {
     $16 = (((($12) + ($i$01<<4)|0)) + 8|0);
     HEAP32[$16>>2] = 0;
    }
    $17 = (($i$01) + 1)|0;
    $18 = HEAP32[$8>>2]|0;
    $19 = ($17>>>0)<($18>>>0);
    if ($19) {
     $i$01 = $17;
    } else {
     break;
    }
   }
   $$pre = HEAP32[$5>>2]|0;
   $21 = $$pre;
  }
  $20 = ($21>>>0)<($7>>>0);
  if ($20) {
   $n$02 = $21;
   while(1) {
    $22 = ((($n$02)) + 8|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(0);
    if (!($24)) {
     $25 = (_iscleared($g,$n$02)|0);
     $26 = ($25|0)==(0);
     if (!($26)) {
      HEAP32[$22>>2] = 0;
      $27 = ((($n$02)) + 24|0);
      $28 = HEAP32[$27>>2]|0;
      $29 = $28 & 64;
      $30 = ($29|0)==(0);
      if (!($30)) {
       $31 = ((($n$02)) + 16|0);
       $32 = HEAP32[$31>>2]|0;
       $33 = ((($32)) + 5|0);
       $34 = HEAP8[$33>>0]|0;
       $35 = $34 & 3;
       $36 = ($35<<24>>24)==(0);
       if (!($36)) {
        HEAP32[$27>>2] = 10;
       }
      }
     }
    }
    $37 = ((($n$02)) + 32|0);
    $38 = ($37>>>0)<($7>>>0);
    if ($38) {
     $n$02 = $37;
    } else {
     break;
    }
   }
  }
  $39 = ((($$06)) + 28|0);
  $40 = HEAP32[$39>>2]|0;
  $41 = ($40|0)==($f|0);
  if ($41) {
   break;
  } else {
   $$06 = $40;
  }
 }
 return;
}
function _iscleared($g,$o) {
 $g = $g|0;
 $o = $o|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 64;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = $1 & 15;
 $5 = ($4|0)==(4);
 $6 = HEAP32[$o>>2]|0;
 if (!($5)) {
  $12 = ((($6)) + 5|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = $13&255;
  $15 = $14 & 3;
  $$0 = $15;
  return ($$0|0);
 }
 $7 = ($6|0)==(0|0);
 if ($7) {
  $$0 = 0;
  return ($$0|0);
 }
 $8 = ((($6)) + 5|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = $9 & 3;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  $$0 = 0;
  return ($$0|0);
 }
 _reallymarkobject($g,$6);
 $$0 = 0;
 return ($$0|0);
}
function _dothecall($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + -32|0);
 _luaD_call($L,$2,0,0);
 return;
}
function _luaM_growaux_($L,$block,$size,$size_elems,$limit,$what) {
 $L = $L|0;
 $block = $block|0;
 $size = $size|0;
 $size_elems = $size_elems|0;
 $limit = $limit|0;
 $what = $what|0;
 var $$ = 0, $$neg$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newblock$0$i = 0, $newsize$0 = 0, $or$cond$i = 0, $osize$op$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[$size>>2]|0;
 $1 = (($limit|0) / 2)&-1;
 $2 = ($0|0)<($1|0);
 if ($2) {
  $4 = $0 << 1;
  $5 = ($4|0)<(4);
  $$ = $5 ? 4 : $4;
  $newsize$0 = $$;
 } else {
  $3 = ($0|0)<($limit|0);
  if ($3) {
   $newsize$0 = $limit;
  } else {
   HEAP32[$vararg_buffer>>2] = $what;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $limit;
   _luaG_runerror($L,1496,$vararg_buffer);
   // unreachable;
  }
 }
 $6 = (($newsize$0) + 1)|0;
 $7 = (4294967295 / ($size_elems>>>0))&-1;
 $8 = ($6>>>0)>($7>>>0);
 if ($8) {
  _luaM_toobig($L);
  // unreachable;
 }
 $9 = Math_imul($0, $size_elems)|0;
 $10 = Math_imul($newsize$0, $size_elems)|0;
 $11 = ((($L)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($block|0)!=(0|0);
 $14 = HEAP32[$12>>2]|0;
 $15 = ((($12)) + 4|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (FUNCTION_TABLE_iiiii[$14 & 511]($16,$block,$9,$10)|0);
 $18 = ($17|0)==(0|0);
 $19 = ($10|0)!=(0);
 $or$cond$i = $19 & $18;
 if ($or$cond$i) {
  _luaC_fullgc($L,1);
  $20 = HEAP32[$12>>2]|0;
  $21 = HEAP32[$15>>2]|0;
  $22 = (FUNCTION_TABLE_iiiii[$20 & 511]($21,$block,$9,$10)|0);
  $23 = ($22|0)==(0|0);
  if ($23) {
   _luaD_throw($L,4);
   // unreachable;
  } else {
   $newblock$0$i = $22;
  }
 } else {
  $newblock$0$i = $17;
 }
 $24 = ((($12)) + 12|0);
 $25 = HEAP32[$24>>2]|0;
 $osize$op$i = (0 - ($9))|0;
 $$neg$i = $13 ? $osize$op$i : 0;
 $26 = (($$neg$i) + ($10))|0;
 $27 = (($26) + ($25))|0;
 HEAP32[$24>>2] = $27;
 HEAP32[$size>>2] = $newsize$0;
 STACKTOP = sp;return ($newblock$0$i|0);
}
function _luaM_toobig($L) {
 $L = $L|0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 _luaG_runerror($L,1528,$vararg_buffer);
 // unreachable;
}
function _luaM_realloc_($L,$block,$osize,$nsize) {
 $L = $L|0;
 $block = $block|0;
 $osize = $osize|0;
 $nsize = $nsize|0;
 var $$neg = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $newblock$0 = 0, $or$cond = 0;
 var $osize$op = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($block|0)!=(0|0);
 $3 = HEAP32[$1>>2]|0;
 $4 = ((($1)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiiii[$3 & 511]($5,$block,$osize,$nsize)|0);
 $7 = ($6|0)==(0|0);
 $8 = ($nsize|0)!=(0);
 $or$cond = $8 & $7;
 if ($or$cond) {
  _luaC_fullgc($L,1);
  $9 = HEAP32[$1>>2]|0;
  $10 = HEAP32[$4>>2]|0;
  $11 = (FUNCTION_TABLE_iiiii[$9 & 511]($10,$block,$osize,$nsize)|0);
  $12 = ($11|0)==(0|0);
  if ($12) {
   _luaD_throw($L,4);
   // unreachable;
  } else {
   $newblock$0 = $11;
  }
 } else {
  $newblock$0 = $6;
 }
 $13 = ((($1)) + 12|0);
 $14 = HEAP32[$13>>2]|0;
 $osize$op = (0 - ($osize))|0;
 $$neg = $2 ? $osize$op : 0;
 $15 = (($$neg) + ($nsize))|0;
 $16 = (($15) + ($14))|0;
 HEAP32[$13>>2] = $16;
 return ($newblock$0|0);
}
function _luaO_int2fb($x) {
 $x = $x|0;
 var $$0$lcssa = 0, $$01 = 0, $$02 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $e$0$lcssa = 0, $e$03 = 0, $phitmp = 0, $phitmp$lcssa = 0, $phitmp5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x>>>0)<(8);
 if ($0) {
  $$01 = $x;
  return ($$01|0);
 }
 $1 = ($x>>>0)>(15);
 if ($1) {
  $$02 = $x;$e$03 = 1;
  while(1) {
   $2 = (($$02) + 1)|0;
   $3 = $2 >>> 1;
   $phitmp = (($e$03) + 1)|0;
   $4 = ($2>>>0)>(31);
   if ($4) {
    $$02 = $3;$e$03 = $phitmp;
   } else {
    $$lcssa = $3;$phitmp$lcssa = $phitmp;
    break;
   }
  }
  $phitmp5 = $phitmp$lcssa << 3;
  $$0$lcssa = $$lcssa;$e$0$lcssa = $phitmp5;
 } else {
  $$0$lcssa = $x;$e$0$lcssa = 8;
 }
 $5 = (($$0$lcssa) + -8)|0;
 $6 = $e$0$lcssa | $5;
 $$01 = $6;
 return ($$01|0);
}
function _luaO_fb2int($x) {
 $x = $x|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x >>> 3;
 $1 = $0 & 31;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = $x;
  return ($$0|0);
 }
 $3 = $x & 7;
 $4 = $3 | 8;
 $5 = (($1) + -1)|0;
 $6 = $4 << $5;
 $$0 = $6;
 return ($$0|0);
}
function _luaO_ceillog2($x) {
 $x = $x|0;
 var $$0$lcssa = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $l$0$lcssa = 0, $l$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($x) + -1)|0;
 $1 = ($0>>>0)>(255);
 if ($1) {
  $$01 = $0;$l$02 = 0;
  while(1) {
   $2 = (($l$02) + 8)|0;
   $3 = $$01 >>> 8;
   $4 = ($$01>>>0)>(65535);
   if ($4) {
    $$01 = $3;$l$02 = $2;
   } else {
    $$0$lcssa = $3;$l$0$lcssa = $2;
    break;
   }
  }
 } else {
  $$0$lcssa = $0;$l$0$lcssa = 0;
 }
 $5 = (1584 + ($$0$lcssa)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = (($7) + ($l$0$lcssa))|0;
 return ($8|0);
}
function _luaO_arith($L,$op,$p1,$p2,$res) {
 $L = $L|0;
 $op = $op|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 var $$0$i1 = 0.0, $$0$i5 = 0.0, $$pre = 0.0, $$pre10 = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0.0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0.0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0.0, $132 = 0.0, $133 = 0.0, $134 = 0.0, $135 = 0.0, $136 = 0.0, $137 = 0.0, $138 = 0.0, $139 = 0.0, $14 = 0, $140 = 0.0, $141 = 0.0, $142 = 0.0, $143 = 0, $144 = 0.0, $145 = 0, $146 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0.0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0.0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i1 = 0, $i2 = 0, $m$0$i4 = 0.0, $n1 = 0, $n12 = 0, $n2 = 0, $n23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i1 = sp + 40|0;
 $i2 = sp + 32|0;
 $n1 = sp + 24|0;
 $n2 = sp + 16|0;
 $n12 = sp + 8|0;
 $n23 = sp;
 L1: do {
  switch ($op|0) {
  case 4: case 5:  {
   $67 = ((($p1)) + 8|0);
   $68 = HEAP32[$67>>2]|0;
   $69 = ($68|0)==(3);
   if ($69) {
    $70 = +HEAPF64[$p1>>3];
    HEAPF64[$n1>>3] = $70;
   } else {
    $71 = (_luaV_tonumber_($p1,$n1)|0);
    $72 = ($71|0)==(0);
    if ($72) {
     break L1;
    }
   }
   $73 = ((($p2)) + 8|0);
   $74 = HEAP32[$73>>2]|0;
   $75 = ($74|0)==(3);
   if ($75) {
    $76 = +HEAPF64[$p2>>3];
    HEAPF64[$n2>>3] = $76;
    $81 = $76;
   } else {
    $77 = (_luaV_tonumber_($p2,$n2)|0);
    $78 = ($77|0)==(0);
    if ($78) {
     break L1;
    }
    $$pre = +HEAPF64[$n2>>3];
    $81 = $$pre;
   }
   $79 = +HEAPF64[$n1>>3];
   if ((($op|0) == 5)) {
    $80 = $79 / $81;
    $$0$i1 = $80;
   } else if ((($op|0) == 4)) {
    $82 = (+Math_pow((+$79),(+$81)));
    $$0$i1 = $82;
   } else {
    $$0$i1 = 0.0;
   }
   HEAPF64[$res>>3] = $$0$i1;
   $83 = ((($res)) + 8|0);
   HEAP32[$83>>2] = 3;
   STACKTOP = sp;return;
   break;
  }
  case 13: case 11: case 10: case 9: case 8: case 7:  {
   $0 = ((($p1)) + 8|0);
   $1 = HEAP32[$0>>2]|0;
   $2 = ($1|0)==(19);
   if ($2) {
    $3 = $p1;
    $4 = $3;
    $5 = HEAP32[$4>>2]|0;
    $6 = (($3) + 4)|0;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = $i1;
    $10 = $9;
    HEAP32[$10>>2] = $5;
    $11 = (($9) + 4)|0;
    $12 = $11;
    HEAP32[$12>>2] = $8;
   } else {
    $13 = (_luaV_tointeger_($p1,$i1)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     break L1;
    }
   }
   $15 = ((($p2)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(19);
   if ($17) {
    $18 = $p2;
    $19 = $18;
    $20 = HEAP32[$19>>2]|0;
    $21 = (($18) + 4)|0;
    $22 = $21;
    $23 = HEAP32[$22>>2]|0;
    $24 = $i2;
    $25 = $24;
    HEAP32[$25>>2] = $20;
    $26 = (($24) + 4)|0;
    $27 = $26;
    HEAP32[$27>>2] = $23;
    $43 = $20;$45 = $23;
   } else {
    $28 = (_luaV_tointeger_($p2,$i2)|0);
    $29 = ($28|0)==(0);
    if ($29) {
     break L1;
    }
    $30 = $i2;
    $31 = $30;
    $32 = HEAP32[$31>>2]|0;
    $33 = (($30) + 4)|0;
    $34 = $33;
    $35 = HEAP32[$34>>2]|0;
    $43 = $32;$45 = $35;
   }
   $36 = $i1;
   $37 = $36;
   $38 = HEAP32[$37>>2]|0;
   $39 = (($36) + 4)|0;
   $40 = $39;
   $41 = HEAP32[$40>>2]|0;
   switch ($op|0) {
   case 12:  {
    $56 = (_i64Subtract(0,0,($38|0),($41|0))|0);
    $57 = tempRet0;
    $62 = $56;$65 = $57;
    break;
   }
   case 9:  {
    $48 = $43 ^ $38;
    $49 = $45 ^ $41;
    $62 = $48;$65 = $49;
    break;
   }
   case 13:  {
    $58 = $38 ^ -1;
    $59 = $41 ^ -1;
    $62 = $58;$65 = $59;
    break;
   }
   case 10:  {
    $50 = (_luaV_shiftl($38,$41,$43,$45)|0);
    $51 = tempRet0;
    $62 = $50;$65 = $51;
    break;
   }
   case 7:  {
    $42 = $43 & $38;
    $44 = $45 & $41;
    $62 = $42;$65 = $44;
    break;
   }
   case 11:  {
    $52 = (_i64Subtract(0,0,($43|0),($45|0))|0);
    $53 = tempRet0;
    $54 = (_luaV_shiftl($38,$41,$52,$53)|0);
    $55 = tempRet0;
    $62 = $54;$65 = $55;
    break;
   }
   case 8:  {
    $46 = $43 | $38;
    $47 = $45 | $41;
    $62 = $46;$65 = $47;
    break;
   }
   default: {
    $62 = 0;$65 = 0;
   }
   }
   $60 = $res;
   $61 = $60;
   HEAP32[$61>>2] = $62;
   $63 = (($60) + 4)|0;
   $64 = $63;
   HEAP32[$64>>2] = $65;
   $66 = ((($res)) + 8|0);
   HEAP32[$66>>2] = 19;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $84 = ((($p1)) + 8|0);
   $85 = HEAP32[$84>>2]|0;
   if ((($85|0) == 3)) {
    $122 = +HEAPF64[$p1>>3];
    HEAPF64[$n12>>3] = $122;
   } else if ((($85|0) == 19)) {
    $86 = ((($p2)) + 8|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(19);
    if ($88) {
     $89 = $p1;
     $90 = $89;
     $91 = HEAP32[$90>>2]|0;
     $92 = (($89) + 4)|0;
     $93 = $92;
     $94 = HEAP32[$93>>2]|0;
     $95 = $p2;
     $96 = $95;
     $97 = HEAP32[$96>>2]|0;
     $98 = (($95) + 4)|0;
     $99 = $98;
     $100 = HEAP32[$99>>2]|0;
     switch ($op|0) {
     case 12:  {
      $111 = (_i64Subtract(0,0,($91|0),($94|0))|0);
      $112 = tempRet0;
      $117 = $111;$120 = $112;
      break;
     }
     case 13:  {
      $113 = $91 ^ -1;
      $114 = $94 ^ -1;
      $117 = $113;$120 = $114;
      break;
     }
     case 2:  {
      $105 = (___muldi3(($97|0),($100|0),($91|0),($94|0))|0);
      $106 = tempRet0;
      $117 = $105;$120 = $106;
      break;
     }
     case 0:  {
      $101 = (_i64Add(($97|0),($100|0),($91|0),($94|0))|0);
      $102 = tempRet0;
      $117 = $101;$120 = $102;
      break;
     }
     case 1:  {
      $103 = (_i64Subtract(($91|0),($94|0),($97|0),($100|0))|0);
      $104 = tempRet0;
      $117 = $103;$120 = $104;
      break;
     }
     case 3:  {
      $107 = (_luaV_mod($L,$91,$94,$97,$100)|0);
      $108 = tempRet0;
      $117 = $107;$120 = $108;
      break;
     }
     case 6:  {
      $109 = (_luaV_div($L,$91,$94,$97,$100)|0);
      $110 = tempRet0;
      $117 = $109;$120 = $110;
      break;
     }
     default: {
      $117 = 0;$120 = 0;
     }
     }
     $115 = $res;
     $116 = $115;
     HEAP32[$116>>2] = $117;
     $118 = (($115) + 4)|0;
     $119 = $118;
     HEAP32[$119>>2] = $120;
     $121 = ((($res)) + 8|0);
     HEAP32[$121>>2] = 19;
     STACKTOP = sp;return;
    } else {
     label = 41;
    }
   } else {
    label = 41;
   }
   if ((label|0) == 41) {
    $123 = (_luaV_tonumber_($p1,$n12)|0);
    $124 = ($123|0)==(0);
    if ($124) {
     break L1;
    }
   }
   $125 = ((($p2)) + 8|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = ($126|0)==(3);
   if ($127) {
    $128 = +HEAPF64[$p2>>3];
    HEAPF64[$n23>>3] = $128;
    $133 = $128;
   } else {
    $129 = (_luaV_tonumber_($p2,$n23)|0);
    $130 = ($129|0)==(0);
    if ($130) {
     break L1;
    }
    $$pre10 = +HEAPF64[$n23>>3];
    $133 = $$pre10;
   }
   $131 = +HEAPF64[$n12>>3];
   switch ($op|0) {
   case 6:  {
    $138 = $131 / $133;
    $139 = (+Math_floor((+$138)));
    $$0$i5 = $139;
    break;
   }
   case 12:  {
    $140 = -$131;
    $$0$i5 = $140;
    break;
   }
   case 3:  {
    $141 = (+_fmod($131,$133));
    $142 = $133 * $141;
    $143 = $142 < 0.0;
    $144 = $133 + $141;
    $m$0$i4 = $143 ? $144 : $141;
    $$0$i5 = $m$0$i4;
    break;
   }
   case 0:  {
    $132 = $131 + $133;
    $$0$i5 = $132;
    break;
   }
   case 1:  {
    $134 = $131 - $133;
    $$0$i5 = $134;
    break;
   }
   case 2:  {
    $135 = $131 * $133;
    $$0$i5 = $135;
    break;
   }
   case 5:  {
    $136 = $131 / $133;
    $$0$i5 = $136;
    break;
   }
   case 4:  {
    $137 = (+Math_pow((+$131),(+$133)));
    $$0$i5 = $137;
    break;
   }
   default: {
    $$0$i5 = 0.0;
   }
   }
   HEAPF64[$res>>3] = $$0$i5;
   $145 = ((($res)) + 8|0);
   HEAP32[$145>>2] = 3;
   STACKTOP = sp;return;
  }
  }
 } while(0);
 $146 = (($op) + 6)|0;
 _luaT_trybinTM($L,$p1,$p2,$res,$146);
 STACKTOP = sp;return;
}
function _luaO_hexavalue($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + 1)|0;
 $1 = (4864 + ($0)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2 & 2;
 $4 = ($3<<24>>24)==(0);
 $5 = (($c) + -48)|0;
 $6 = $c | 32;
 $7 = (($6) + -87)|0;
 $$0 = $4 ? $7 : $5;
 return ($$0|0);
}
function _luaO_str2num($s,$o) {
 $s = $s|0;
 $o = $o|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i2$i = 0, $$lcssa = 0, $$lcssa$i = 0, $$lcssa1$i = 0, $$lcssa67 = 0, $$lcssa7 = 0, $$lcssa77 = 0, $$lcssa78 = 0, $$lcssa8 = 0, $$ph$i = 0, $$ph$i$pn = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0;
 var $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0;
 var $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0;
 var $e$0 = 0, $empty$2$ph$i = 0, $endptr$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i$not = 0, $storemerge$i = 0, $storemerge$i$lcssa = 0, $storemerge111$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $endptr$i = sp;
 $storemerge$i = $s;
 while(1) {
  $0 = HEAP8[$storemerge$i>>0]|0;
  $1 = $0&255;
  $2 = (($1) + 1)|0;
  $3 = (4864 + ($2)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4 & 8;
  $6 = ($5<<24>>24)==(0);
  $7 = ((($storemerge$i)) + 1|0);
  if ($6) {
   $$lcssa77 = $0;$$lcssa78 = $7;$storemerge$i$lcssa = $storemerge$i;
   break;
  } else {
   $storemerge$i = $7;
  }
 }
 if ((($$lcssa77<<24>>24) == 43)) {
  $$0$i$i = 0;$9 = $$lcssa78;
 } else if ((($$lcssa77<<24>>24) == 45)) {
  $$0$i$i = 1;$9 = $$lcssa78;
 } else {
  $$0$i$i = 0;$9 = $storemerge$i$lcssa;
 }
 $8 = HEAP8[$9>>0]|0;
 $10 = ($8<<24>>24)==(48);
 if ($10) {
  $11 = ((($9)) + 1|0);
  $12 = HEAP8[$11>>0]|0;
  if ((($12<<24>>24) == 88) | (($12<<24>>24) == 120)) {
   $19 = ((($9)) + 2|0);
   $20 = HEAP8[$19>>0]|0;
   $21 = $20&255;
   $22 = (($21) + 1)|0;
   $23 = (4864 + ($22)|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = $24 & 16;
   $26 = ($25<<24>>24)==(0);
   if ($26) {
    $$ph$i = $19;$125 = $20;$28 = $24;$86 = 0;$87 = 0;$empty$2$ph$i = 1;
   } else {
    $30 = 0;$31 = 0;$35 = $20;$storemerge111$i = $19;
    while(1) {
     $32 = (_bitshift64Shl(($30|0),($31|0),4)|0);
     $33 = tempRet0;
     $34 = $35 << 24 >> 24;
     $36 = (($34) + 1)|0;
     $37 = (4864 + ($36)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = $38 & 2;
     $40 = ($39<<24>>24)==(0);
     $41 = (($34) + -48)|0;
     $42 = $34 | 32;
     $43 = (($42) + -87)|0;
     $$0$i2$i = $40 ? $43 : $41;
     $44 = ($$0$i2$i|0)<(0);
     $45 = $44 << 31 >> 31;
     $46 = (_i64Add(($$0$i2$i|0),($45|0),($32|0),($33|0))|0);
     $47 = tempRet0;
     $48 = ((($storemerge111$i)) + 1|0);
     $49 = HEAP8[$48>>0]|0;
     $50 = $49&255;
     $51 = (($50) + 1)|0;
     $52 = (4864 + ($51)|0);
     $53 = HEAP8[$52>>0]|0;
     $54 = $53 & 16;
     $55 = ($54<<24>>24)==(0);
     if ($55) {
      $$ph$i = $48;$125 = $49;$28 = $53;$86 = $46;$87 = $47;$empty$2$ph$i = 0;
      break;
     } else {
      $30 = $46;$31 = $47;$35 = $49;$storemerge111$i = $48;
     }
    }
   }
  } else {
   label = 8;
  }
 } else {
  label = 8;
 }
 if ((label|0) == 8) {
  $13 = $8&255;
  $14 = (($13) + 1)|0;
  $15 = (4864 + ($14)|0);
  $16 = HEAP8[$15>>0]|0;
  $17 = $16 & 2;
  $18 = ($17<<24>>24)==(0);
  if ($18) {
   $$ph$i = $9;$125 = $8;$28 = $16;$86 = 0;$87 = 0;$empty$2$ph$i = 1;
  } else {
   $56 = 0;$57 = 0;$61 = $8;$69 = $9;
   while(1) {
    $58 = (___muldi3(($56|0),($57|0),10,0)|0);
    $59 = tempRet0;
    $60 = $61 << 24 >> 24;
    $62 = ($60|0)<(0);
    $63 = $62 << 31 >> 31;
    $64 = (_i64Add(($60|0),($63|0),-48,-1)|0);
    $65 = tempRet0;
    $66 = (_i64Add(($64|0),($65|0),($58|0),($59|0))|0);
    $67 = tempRet0;
    $68 = ((($69)) + 1|0);
    $70 = HEAP8[$68>>0]|0;
    $71 = $70&255;
    $72 = (($71) + 1)|0;
    $73 = (4864 + ($72)|0);
    $74 = HEAP8[$73>>0]|0;
    $75 = $74 & 2;
    $76 = ($75<<24>>24)==(0);
    if ($76) {
     $$ph$i = $68;$125 = $70;$28 = $74;$86 = $66;$87 = $67;$empty$2$ph$i = 0;
     break;
    } else {
     $56 = $66;$57 = $67;$61 = $70;$69 = $68;
    }
   }
  }
 }
 $27 = $28 & 8;
 $29 = ($27<<24>>24)==(0);
 if ($29) {
  $$lcssa7 = $125;$$lcssa8 = $$ph$i;
 } else {
  $$ph$i$pn = $$ph$i;
  while(1) {
   $77 = ((($$ph$i$pn)) + 1|0);
   $$pre$i = HEAP8[$77>>0]|0;
   $78 = $$pre$i&255;
   $79 = (($78) + 1)|0;
   $80 = (4864 + ($79)|0);
   $81 = HEAP8[$80>>0]|0;
   $82 = $81 & 8;
   $83 = ($82<<24>>24)==(0);
   if ($83) {
    $$lcssa7 = $$pre$i;$$lcssa8 = $77;
    break;
   } else {
    $$ph$i$pn = $77;
   }
  }
 }
 $notlhs = ($empty$2$ph$i|0)!=(0);
 $notrhs = ($$lcssa7<<24>>24)!=(0);
 $or$cond$i$not = $notrhs | $notlhs;
 $84 = ($$lcssa8|0)==(0|0);
 $or$cond = $or$cond$i$not | $84;
 do {
  if ($or$cond) {
   $97 = (_strpbrk($s,1840)|0);
   $98 = ($97|0)==(0|0);
   if ($98) {
    $99 = (+_strtod($s,$endptr$i));
    $100 = HEAP32[$endptr$i>>2]|0;
    $101 = ($100|0)==($s|0);
    if (!($101)) {
     $102 = HEAP8[$100>>0]|0;
     $103 = $102&255;
     $104 = (($103) + 1)|0;
     $105 = (4864 + ($104)|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = $106 & 8;
     $108 = ($107<<24>>24)==(0);
     if ($108) {
      $$lcssa$i = $100;$$lcssa1$i = $102;
     } else {
      $110 = $100;
      while(1) {
       $109 = ((($110)) + 1|0);
       $111 = HEAP8[$109>>0]|0;
       $112 = $111&255;
       $113 = (($112) + 1)|0;
       $114 = (4864 + ($113)|0);
       $115 = HEAP8[$114>>0]|0;
       $116 = $115 & 8;
       $117 = ($116<<24>>24)==(0);
       if ($117) {
        $$lcssa = $109;$$lcssa67 = $111;
        break;
       } else {
        $110 = $109;
       }
      }
      HEAP32[$endptr$i>>2] = $$lcssa;
      $$lcssa$i = $$lcssa;$$lcssa1$i = $$lcssa67;
     }
     $118 = ($$lcssa1$i<<24>>24)==(0);
     if ($118) {
      $119 = ($$lcssa$i|0)==(0|0);
      if ($119) {
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      } else {
       HEAPF64[$o>>3] = $99;
       $120 = ((($o)) + 8|0);
       HEAP32[$120>>2] = 3;
       $e$0 = $$lcssa$i;
       break;
      }
     }
    }
   }
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $85 = ($$0$i$i|0)!=(0);
   $88 = (_i64Subtract(0,0,($86|0),($87|0))|0);
   $89 = tempRet0;
   $90 = $85 ? $88 : $86;
   $91 = $85 ? $89 : $87;
   $92 = $o;
   $93 = $92;
   HEAP32[$93>>2] = $90;
   $94 = (($92) + 4)|0;
   $95 = $94;
   HEAP32[$95>>2] = $91;
   $96 = ((($o)) + 8|0);
   HEAP32[$96>>2] = 19;
   $e$0 = $$lcssa8;
  }
 } while(0);
 $121 = $e$0;
 $122 = $s;
 $123 = (1 - ($122))|0;
 $124 = (($123) + ($121))|0;
 $$0 = $124;
 STACKTOP = sp;return ($$0|0);
}
function _luaO_utf8esc($buff,$x) {
 $buff = $buff|0;
 $x = $x|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa11 = 0, $$lcssa12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $mfb$0 = 0, $n$0 = 0, $n$0$lcssa = 0, $n$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($x>>>0)<(128);
 if ($0) {
  $1 = $x&255;
  $2 = ((($buff)) + 7|0);
  HEAP8[$2>>0] = $1;
  $n$1 = 1;
  return ($n$1|0);
 } else {
  $$0 = $x;$mfb$0 = 63;$n$0 = 1;
 }
 while(1) {
  $3 = $$0 & 63;
  $4 = $3 | 128;
  $5 = $4&255;
  $6 = (($n$0) + 1)|0;
  $7 = (8 - ($n$0))|0;
  $8 = (($buff) + ($7)|0);
  HEAP8[$8>>0] = $5;
  $9 = $$0 >>> 6;
  $10 = $mfb$0 >>> 1;
  $11 = ($9>>>0)>($10>>>0);
  if ($11) {
   $$0 = $9;$mfb$0 = $10;$n$0 = $6;
  } else {
   $$lcssa = $6;$$lcssa11 = $9;$$lcssa12 = $10;$n$0$lcssa = $n$0;
   break;
  }
 }
 $12 = $$lcssa12 << 1;
 $13 = $12 ^ 254;
 $14 = $13 | $$lcssa11;
 $15 = $14&255;
 $16 = (7 - ($n$0$lcssa))|0;
 $17 = (($buff) + ($16)|0);
 HEAP8[$17>>0] = $15;
 $n$1 = $$lcssa;
 return ($n$1|0);
}
function _luaO_tostring($L,$obj) {
 $L = $L|0;
 $obj = $obj|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff = 0, $len$0 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $buff = sp + 16|0;
 $0 = ((($obj)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $obj;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = $vararg_buffer;
  $10 = $9;
  HEAP32[$10>>2] = $5;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $13 = (_sprintf($buff,8680,$vararg_buffer)|0);
  $len$0 = $13;
 } else {
  $14 = +HEAPF64[$obj>>3];
  HEAPF64[$vararg_buffer1>>3] = $14;
  $15 = (_sprintf($buff,8688,$vararg_buffer1)|0);
  $16 = (_strspn($buff,1848)|0);
  $17 = (($buff) + ($16)|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = ($18<<24>>24)==(0);
  if ($19) {
   $20 = (($15) + 1)|0;
   $21 = (($buff) + ($15)|0);
   HEAP8[$21>>0] = 46;
   $22 = (($15) + 2)|0;
   $23 = (($buff) + ($20)|0);
   HEAP8[$23>>0] = 48;
   $len$0 = $22;
  } else {
   $len$0 = $15;
  }
 }
 $24 = (_luaS_newlstr($L,$buff,$len$0)|0);
 HEAP32[$obj>>2] = $24;
 $25 = ((($24)) + 4|0);
 $26 = HEAP8[$25>>0]|0;
 $27 = $26&255;
 $28 = $27 | 64;
 HEAP32[$0>>2] = $28;
 STACKTOP = sp;return;
}
function _luaO_pushvfstring($L,$fmt,$argp) {
 $L = $L|0;
 $fmt = $fmt|0;
 $argp = $argp|0;
 var $$ = 0, $$0$i = 0, $$0$lcssa = 0, $$017 = 0, $$lcssa = 0, $$lcssa13 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$pre = 0, $$pre28 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0.0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0.0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0.0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0.0, $99 = 0;
 var $arglist_current = 0, $arglist_current14 = 0, $arglist_current2 = 0, $arglist_current23 = 0, $arglist_current32 = 0, $arglist_current38 = 0, $arglist_current5 = 0, $arglist_next = 0, $arglist_next15 = 0, $arglist_next24 = 0, $arglist_next3 = 0, $arglist_next33 = 0, $arglist_next39 = 0, $arglist_next6 = 0, $buff = 0, $buff$i = 0, $buff3 = 0, $buff4 = 0, $expanded = 0, $expanded43 = 0;
 var $expanded45 = 0, $expanded46 = 0, $expanded47 = 0, $expanded49 = 0, $expanded50 = 0, $expanded52 = 0, $expanded53 = 0, $expanded54 = 0, $expanded56 = 0, $expanded57 = 0, $expanded59 = 0, $expanded60 = 0, $expanded61 = 0, $expanded63 = 0, $expanded64 = 0, $expanded66 = 0, $expanded67 = 0, $expanded68 = 0, $expanded70 = 0, $expanded71 = 0;
 var $expanded73 = 0, $expanded74 = 0, $expanded75 = 0, $expanded77 = 0, $expanded78 = 0, $expanded80 = 0, $expanded81 = 0, $expanded82 = 0, $expanded84 = 0, $expanded85 = 0, $expanded87 = 0, $expanded88 = 0, $expanded89 = 0, $len$0$i = 0, $len$0$i2 = 0, $len$0$i5 = 0, $mfb$0$i = 0, $n$0$i = 0, $n$0$i$lcssa = 0, $n$0$lcssa = 0;
 var $n$016 = 0, $n$1$i = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer16 = 0, $vararg_buffer19 = 0, $vararg_buffer25 = 0, $vararg_buffer28 = 0, $vararg_buffer34 = 0, $vararg_buffer40 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer40 = sp + 64|0;
 $vararg_buffer34 = sp + 56|0;
 $vararg_buffer28 = sp + 48|0;
 $vararg_buffer25 = sp + 40|0;
 $vararg_buffer19 = sp + 32|0;
 $vararg_buffer16 = sp + 24|0;
 $vararg_buffer10 = sp + 16|0;
 $vararg_buffer7 = sp + 8|0;
 $vararg_buffer = sp;
 $buff$i = sp + 106|0;
 $buff = sp + 104|0;
 $buff3 = sp + 80|0;
 $buff4 = sp + 72|0;
 $0 = (_strchr($fmt,37)|0);
 $1 = ($0|0)==(0|0);
 $2 = ((($L)) + 24|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($L)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $3;
 $7 = $5;
 $8 = (($6) - ($7))|0;
 L1: do {
  if ($1) {
   $$0$lcssa = $fmt;$$lcssa13 = $8;$286 = $5;$n$0$lcssa = 0;
  } else {
   $9 = ((($buff4)) + 7|0);
   $$017 = $fmt;$11 = $8;$13 = $0;$287 = $5;$n$016 = 0;
   L3: while(1) {
    $10 = ($11|0)<(48);
    if ($10) {
     _luaD_growstack($L,2);
     $$pre = HEAP32[$4>>2]|0;
     $17 = $$pre;
    } else {
     $17 = $287;
    }
    $12 = $13;
    $14 = $$017;
    $15 = (($12) - ($14))|0;
    $16 = ((($17)) + 16|0);
    HEAP32[$4>>2] = $16;
    $18 = (_luaS_newlstr($L,$$017,$15)|0);
    HEAP32[$17>>2] = $18;
    $19 = ((($18)) + 4|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $21 | 64;
    $23 = ((($17)) + 8|0);
    HEAP32[$23>>2] = $22;
    $24 = ((($13)) + 1|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = $25 << 24 >> 24;
    L8: do {
     switch ($26|0) {
     case 115:  {
      $arglist_current = HEAP32[$argp>>2]|0;
      $27 = $arglist_current;
      $28 = ((0) + 4|0);
      $expanded43 = $28;
      $expanded = (($expanded43) - 1)|0;
      $29 = (($27) + ($expanded))|0;
      $30 = ((0) + 4|0);
      $expanded47 = $30;
      $expanded46 = (($expanded47) - 1)|0;
      $expanded45 = $expanded46 ^ -1;
      $31 = $29 & $expanded45;
      $32 = $31;
      $33 = HEAP32[$32>>2]|0;
      $arglist_next = ((($32)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next;
      $34 = ($33|0)==(0|0);
      $$ = $34 ? 73112 : $33;
      $35 = (_strlen(($$|0))|0);
      $36 = HEAP32[$4>>2]|0;
      $37 = ((($36)) + 16|0);
      HEAP32[$4>>2] = $37;
      $38 = (_luaS_newlstr($L,$$,$35)|0);
      HEAP32[$36>>2] = $38;
      $39 = ((($38)) + 4|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = $40&255;
      $42 = $41 | 64;
      $43 = ((($36)) + 8|0);
      HEAP32[$43>>2] = $42;
      break;
     }
     case 99:  {
      $arglist_current2 = HEAP32[$argp>>2]|0;
      $44 = $arglist_current2;
      $45 = ((0) + 4|0);
      $expanded50 = $45;
      $expanded49 = (($expanded50) - 1)|0;
      $46 = (($44) + ($expanded49))|0;
      $47 = ((0) + 4|0);
      $expanded54 = $47;
      $expanded53 = (($expanded54) - 1)|0;
      $expanded52 = $expanded53 ^ -1;
      $48 = $46 & $expanded52;
      $49 = $48;
      $50 = HEAP32[$49>>2]|0;
      $arglist_next3 = ((($49)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next3;
      $51 = $50&255;
      HEAP8[$buff>>0] = $51;
      $52 = $50 & 255;
      $53 = (($52) + 1)|0;
      $54 = (4864 + ($53)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = $55 & 4;
      $57 = ($56<<24>>24)==(0);
      if ($57) {
       HEAP32[$vararg_buffer>>2] = $52;
       (_luaO_pushfstring($L,1864,$vararg_buffer)|0);
       break L8;
      } else {
       $58 = HEAP32[$4>>2]|0;
       $59 = ((($58)) + 16|0);
       HEAP32[$4>>2] = $59;
       $60 = (_luaS_newlstr($L,$buff,1)|0);
       HEAP32[$58>>2] = $60;
       $61 = ((($60)) + 4|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = $62&255;
       $64 = $63 | 64;
       $65 = ((($58)) + 8|0);
       HEAP32[$65>>2] = $64;
       break L8;
      }
      break;
     }
     case 73:  {
      $113 = HEAP32[$4>>2]|0;
      $114 = ((($113)) + 16|0);
      HEAP32[$4>>2] = $114;
      $arglist_current14 = HEAP32[$argp>>2]|0;
      $115 = $arglist_current14;
      $116 = ((0) + 8|0);
      $expanded64 = $116;
      $expanded63 = (($expanded64) - 1)|0;
      $117 = (($115) + ($expanded63))|0;
      $118 = ((0) + 8|0);
      $expanded68 = $118;
      $expanded67 = (($expanded68) - 1)|0;
      $expanded66 = $expanded67 ^ -1;
      $119 = $117 & $expanded66;
      $120 = $119;
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $arglist_next15 = ((($120)) + 8|0);
      HEAP32[$argp>>2] = $arglist_next15;
      $127 = $113;
      $128 = $127;
      HEAP32[$128>>2] = $123;
      $129 = (($127) + 4)|0;
      $130 = $129;
      HEAP32[$130>>2] = $126;
      $131 = ((($113)) + 8|0);
      HEAP32[$131>>2] = 19;
      $132 = HEAP32[$4>>2]|0;
      $133 = ((($132)) + -16|0);
      $134 = ((($132)) + -8|0);
      $135 = HEAP32[$134>>2]|0;
      $136 = ($135|0)==(19);
      if ($136) {
       $137 = $133;
       $138 = $137;
       $139 = HEAP32[$138>>2]|0;
       $140 = (($137) + 4)|0;
       $141 = $140;
       $142 = HEAP32[$141>>2]|0;
       $143 = $vararg_buffer16;
       $144 = $143;
       HEAP32[$144>>2] = $139;
       $145 = (($143) + 4)|0;
       $146 = $145;
       HEAP32[$146>>2] = $142;
       $147 = (_sprintf($buff$i,8680,$vararg_buffer16)|0);
       $len$0$i2 = $147;
      } else {
       $148 = +HEAPF64[$133>>3];
       HEAPF64[$vararg_buffer19>>3] = $148;
       $149 = (_sprintf($buff$i,8688,$vararg_buffer19)|0);
       $150 = (_strspn($buff$i,1848)|0);
       $151 = (($buff$i) + ($150)|0);
       $152 = HEAP8[$151>>0]|0;
       $153 = ($152<<24>>24)==(0);
       if ($153) {
        $154 = (($149) + 1)|0;
        $155 = (($buff$i) + ($149)|0);
        HEAP8[$155>>0] = 46;
        $156 = (($149) + 2)|0;
        $157 = (($buff$i) + ($154)|0);
        HEAP8[$157>>0] = 48;
        $len$0$i2 = $156;
       } else {
        $len$0$i2 = $149;
       }
      }
      $158 = (_luaS_newlstr($L,$buff$i,$len$0$i2)|0);
      HEAP32[$133>>2] = $158;
      $159 = ((($158)) + 4|0);
      $160 = HEAP8[$159>>0]|0;
      $161 = $160&255;
      $162 = $161 | 64;
      HEAP32[$134>>2] = $162;
      break;
     }
     case 100:  {
      $66 = HEAP32[$4>>2]|0;
      $67 = ((($66)) + 16|0);
      HEAP32[$4>>2] = $67;
      $arglist_current5 = HEAP32[$argp>>2]|0;
      $68 = $arglist_current5;
      $69 = ((0) + 4|0);
      $expanded57 = $69;
      $expanded56 = (($expanded57) - 1)|0;
      $70 = (($68) + ($expanded56))|0;
      $71 = ((0) + 4|0);
      $expanded61 = $71;
      $expanded60 = (($expanded61) - 1)|0;
      $expanded59 = $expanded60 ^ -1;
      $72 = $70 & $expanded59;
      $73 = $72;
      $74 = HEAP32[$73>>2]|0;
      $arglist_next6 = ((($73)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next6;
      $75 = ($74|0)<(0);
      $76 = $75 << 31 >> 31;
      $77 = $66;
      $78 = $77;
      HEAP32[$78>>2] = $74;
      $79 = (($77) + 4)|0;
      $80 = $79;
      HEAP32[$80>>2] = $76;
      $81 = ((($66)) + 8|0);
      HEAP32[$81>>2] = 19;
      $82 = HEAP32[$4>>2]|0;
      $83 = ((($82)) + -16|0);
      $84 = ((($82)) + -8|0);
      $85 = HEAP32[$84>>2]|0;
      $86 = ($85|0)==(19);
      if ($86) {
       $87 = $83;
       $88 = $87;
       $89 = HEAP32[$88>>2]|0;
       $90 = (($87) + 4)|0;
       $91 = $90;
       $92 = HEAP32[$91>>2]|0;
       $93 = $vararg_buffer7;
       $94 = $93;
       HEAP32[$94>>2] = $89;
       $95 = (($93) + 4)|0;
       $96 = $95;
       HEAP32[$96>>2] = $92;
       $97 = (_sprintf($buff$i,8680,$vararg_buffer7)|0);
       $len$0$i = $97;
      } else {
       $98 = +HEAPF64[$83>>3];
       HEAPF64[$vararg_buffer10>>3] = $98;
       $99 = (_sprintf($buff$i,8688,$vararg_buffer10)|0);
       $100 = (_strspn($buff$i,1848)|0);
       $101 = (($buff$i) + ($100)|0);
       $102 = HEAP8[$101>>0]|0;
       $103 = ($102<<24>>24)==(0);
       if ($103) {
        $104 = (($99) + 1)|0;
        $105 = (($buff$i) + ($99)|0);
        HEAP8[$105>>0] = 46;
        $106 = (($99) + 2)|0;
        $107 = (($buff$i) + ($104)|0);
        HEAP8[$107>>0] = 48;
        $len$0$i = $106;
       } else {
        $len$0$i = $99;
       }
      }
      $108 = (_luaS_newlstr($L,$buff$i,$len$0$i)|0);
      HEAP32[$83>>2] = $108;
      $109 = ((($108)) + 4|0);
      $110 = HEAP8[$109>>0]|0;
      $111 = $110&255;
      $112 = $111 | 64;
      HEAP32[$84>>2] = $112;
      break;
     }
     case 37:  {
      $253 = HEAP32[$4>>2]|0;
      $254 = ((($253)) + 16|0);
      HEAP32[$4>>2] = $254;
      $255 = (_luaS_newlstr($L,1880,1)|0);
      HEAP32[$253>>2] = $255;
      $256 = ((($255)) + 4|0);
      $257 = HEAP8[$256>>0]|0;
      $258 = $257&255;
      $259 = $258 | 64;
      $260 = ((($253)) + 8|0);
      HEAP32[$260>>2] = $259;
      break;
     }
     case 102:  {
      $163 = HEAP32[$4>>2]|0;
      $164 = ((($163)) + 16|0);
      HEAP32[$4>>2] = $164;
      $arglist_current23 = HEAP32[$argp>>2]|0;
      $165 = $arglist_current23;
      $166 = ((0) + 8|0);
      $expanded71 = $166;
      $expanded70 = (($expanded71) - 1)|0;
      $167 = (($165) + ($expanded70))|0;
      $168 = ((0) + 8|0);
      $expanded75 = $168;
      $expanded74 = (($expanded75) - 1)|0;
      $expanded73 = $expanded74 ^ -1;
      $169 = $167 & $expanded73;
      $170 = $169;
      $171 = +HEAPF64[$170>>3];
      $arglist_next24 = ((($170)) + 8|0);
      HEAP32[$argp>>2] = $arglist_next24;
      HEAPF64[$163>>3] = $171;
      $172 = ((($163)) + 8|0);
      HEAP32[$172>>2] = 3;
      $173 = HEAP32[$4>>2]|0;
      $174 = ((($173)) + -16|0);
      $175 = ((($173)) + -8|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(19);
      if ($177) {
       $178 = $174;
       $179 = $178;
       $180 = HEAP32[$179>>2]|0;
       $181 = (($178) + 4)|0;
       $182 = $181;
       $183 = HEAP32[$182>>2]|0;
       $184 = $vararg_buffer25;
       $185 = $184;
       HEAP32[$185>>2] = $180;
       $186 = (($184) + 4)|0;
       $187 = $186;
       HEAP32[$187>>2] = $183;
       $188 = (_sprintf($buff$i,8680,$vararg_buffer25)|0);
       $len$0$i5 = $188;
      } else {
       $189 = +HEAPF64[$174>>3];
       HEAPF64[$vararg_buffer28>>3] = $189;
       $190 = (_sprintf($buff$i,8688,$vararg_buffer28)|0);
       $191 = (_strspn($buff$i,1848)|0);
       $192 = (($buff$i) + ($191)|0);
       $193 = HEAP8[$192>>0]|0;
       $194 = ($193<<24>>24)==(0);
       if ($194) {
        $195 = (($190) + 1)|0;
        $196 = (($buff$i) + ($190)|0);
        HEAP8[$196>>0] = 46;
        $197 = (($190) + 2)|0;
        $198 = (($buff$i) + ($195)|0);
        HEAP8[$198>>0] = 48;
        $len$0$i5 = $197;
       } else {
        $len$0$i5 = $190;
       }
      }
      $199 = (_luaS_newlstr($L,$buff$i,$len$0$i5)|0);
      HEAP32[$174>>2] = $199;
      $200 = ((($199)) + 4|0);
      $201 = HEAP8[$200>>0]|0;
      $202 = $201&255;
      $203 = $202 | 64;
      HEAP32[$175>>2] = $203;
      break;
     }
     case 85:  {
      $arglist_current38 = HEAP32[$argp>>2]|0;
      $220 = $arglist_current38;
      $221 = ((0) + 4|0);
      $expanded85 = $221;
      $expanded84 = (($expanded85) - 1)|0;
      $222 = (($220) + ($expanded84))|0;
      $223 = ((0) + 4|0);
      $expanded89 = $223;
      $expanded88 = (($expanded89) - 1)|0;
      $expanded87 = $expanded88 ^ -1;
      $224 = $222 & $expanded87;
      $225 = $224;
      $226 = HEAP32[$225>>2]|0;
      $arglist_next39 = ((($225)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next39;
      $227 = ($226>>>0)<(128);
      if ($227) {
       $228 = $226&255;
       HEAP8[$9>>0] = $228;
       $n$1$i = 1;
      } else {
       $$0$i = $226;$mfb$0$i = 63;$n$0$i = 1;
       while(1) {
        $229 = $$0$i & 63;
        $230 = $229 | 128;
        $231 = $230&255;
        $232 = (($n$0$i) + 1)|0;
        $233 = (8 - ($n$0$i))|0;
        $234 = (($buff4) + ($233)|0);
        HEAP8[$234>>0] = $231;
        $235 = $$0$i >>> 6;
        $236 = $mfb$0$i >>> 1;
        $237 = ($235>>>0)>($236>>>0);
        if ($237) {
         $$0$i = $235;$mfb$0$i = $236;$n$0$i = $232;
        } else {
         $$lcssa = $232;$$lcssa53 = $235;$$lcssa54 = $236;$n$0$i$lcssa = $n$0$i;
         break;
        }
       }
       $238 = $$lcssa54 << 1;
       $239 = $238 ^ 254;
       $240 = $239 | $$lcssa53;
       $241 = $240&255;
       $242 = (7 - ($n$0$i$lcssa))|0;
       $243 = (($buff4) + ($242)|0);
       HEAP8[$243>>0] = $241;
       $n$1$i = $$lcssa;
      }
      $$sum = (8 - ($n$1$i))|0;
      $244 = (($buff4) + ($$sum)|0);
      $245 = HEAP32[$4>>2]|0;
      $246 = ((($245)) + 16|0);
      HEAP32[$4>>2] = $246;
      $247 = (_luaS_newlstr($L,$244,$n$1$i)|0);
      HEAP32[$245>>2] = $247;
      $248 = ((($247)) + 4|0);
      $249 = HEAP8[$248>>0]|0;
      $250 = $249&255;
      $251 = $250 | 64;
      $252 = ((($245)) + 8|0);
      HEAP32[$252>>2] = $251;
      break;
     }
     case 112:  {
      $arglist_current32 = HEAP32[$argp>>2]|0;
      $204 = $arglist_current32;
      $205 = ((0) + 4|0);
      $expanded78 = $205;
      $expanded77 = (($expanded78) - 1)|0;
      $206 = (($204) + ($expanded77))|0;
      $207 = ((0) + 4|0);
      $expanded82 = $207;
      $expanded81 = (($expanded82) - 1)|0;
      $expanded80 = $expanded81 ^ -1;
      $208 = $206 & $expanded80;
      $209 = $208;
      $210 = HEAP32[$209>>2]|0;
      $arglist_next33 = ((($209)) + 4|0);
      HEAP32[$argp>>2] = $arglist_next33;
      HEAP32[$vararg_buffer34>>2] = $210;
      $211 = (_sprintf($buff3,1872,$vararg_buffer34)|0);
      $212 = HEAP32[$4>>2]|0;
      $213 = ((($212)) + 16|0);
      HEAP32[$4>>2] = $213;
      $214 = (_luaS_newlstr($L,$buff3,$211)|0);
      HEAP32[$212>>2] = $214;
      $215 = ((($214)) + 4|0);
      $216 = HEAP8[$215>>0]|0;
      $217 = $216&255;
      $218 = $217 | 64;
      $219 = ((($212)) + 8|0);
      HEAP32[$219>>2] = $218;
      break;
     }
     default: {
      $$lcssa55 = $26;
      break L3;
     }
     }
    } while(0);
    $261 = (($n$016) + 2)|0;
    $262 = ((($13)) + 2|0);
    $263 = (_strchr($262,37)|0);
    $264 = ($263|0)==(0|0);
    $265 = HEAP32[$2>>2]|0;
    $266 = HEAP32[$4>>2]|0;
    $267 = $265;
    $268 = $266;
    $269 = (($267) - ($268))|0;
    if ($264) {
     $$0$lcssa = $262;$$lcssa13 = $269;$286 = $266;$n$0$lcssa = $261;
     break L1;
    } else {
     $$017 = $262;$11 = $269;$13 = $263;$287 = $266;$n$016 = $261;
    }
   }
   HEAP32[$vararg_buffer40>>2] = $$lcssa55;
   _luaG_runerror($L,1888,$vararg_buffer40);
   // unreachable;
  }
 } while(0);
 $270 = ($$lcssa13|0)<(32);
 if ($270) {
  _luaD_growstack($L,1);
  $$pre28 = HEAP32[$4>>2]|0;
  $273 = $$pre28;
 } else {
  $273 = $286;
 }
 $271 = (_strlen(($$0$lcssa|0))|0);
 $272 = ((($273)) + 16|0);
 HEAP32[$4>>2] = $272;
 $274 = (_luaS_newlstr($L,$$0$lcssa,$271)|0);
 HEAP32[$273>>2] = $274;
 $275 = ((($274)) + 4|0);
 $276 = HEAP8[$275>>0]|0;
 $277 = $276&255;
 $278 = $277 | 64;
 $279 = ((($273)) + 8|0);
 HEAP32[$279>>2] = $278;
 $280 = ($n$0$lcssa|0)>(0);
 if (!($280)) {
  $282 = HEAP32[$4>>2]|0;
  $283 = ((($282)) + -16|0);
  $284 = HEAP32[$283>>2]|0;
  $285 = ((($284)) + 24|0);
  STACKTOP = sp;return ($285|0);
 }
 $281 = $n$0$lcssa | 1;
 _luaV_concat($L,$281);
 $282 = HEAP32[$4>>2]|0;
 $283 = ((($282)) + -16|0);
 $284 = HEAP32[$283>>2]|0;
 $285 = ((($284)) + 24|0);
 STACKTOP = sp;return ($285|0);
}
function _luaO_pushfstring($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $argp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $argp = sp;
 HEAP32[$argp>>2] = $varargs;
 $0 = (_luaO_pushvfstring($L,$fmt,$argp)|0);
 STACKTOP = sp;return ($0|0);
}
function _luaO_chunkid($out,$source,$bufflen) {
 $out = $out|0;
 $source = $source|0;
 $bufflen = $bufflen|0;
 var $$0 = 0, $$l$0 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $$sum3$pn = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$0 = 0, $or$cond = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 $0 = (_strlen(($source|0))|0);
 $1 = HEAP8[$source>>0]|0;
 if ((($1<<24>>24) == 61)) {
  $2 = ($0>>>0)>($bufflen>>>0);
  $3 = ((($source)) + 1|0);
  if ($2) {
   $4 = (($bufflen) + -1)|0;
   _memcpy(($out|0),($3|0),($4|0))|0;
   $5 = (($out) + ($4)|0);
   HEAP8[$5>>0] = 0;
   return;
  } else {
   _memcpy(($out|0),($3|0),($0|0))|0;
   return;
  }
 } else if ((($1<<24>>24) == 64)) {
  $6 = ($0>>>0)>($bufflen>>>0);
  if ($6) {
   ;HEAP8[$out>>0]=HEAP8[5848>>0]|0;HEAP8[$out+1>>0]=HEAP8[5848+1>>0]|0;HEAP8[$out+2>>0]=HEAP8[5848+2>>0]|0;
   $8 = ((($out)) + 3|0);
   $9 = (($bufflen) + -3)|0;
   $10 = (4 - ($bufflen))|0;
   $$sum5 = (($10) + ($0))|0;
   $11 = (($source) + ($$sum5)|0);
   _memcpy(($8|0),($11|0),($9|0))|0;
   return;
  } else {
   $7 = ((($source)) + 1|0);
   _memcpy(($out|0),($7|0),($0|0))|0;
   return;
  }
 } else {
  $12 = (_strchr($source,10)|0);
  dest=$out; src=1936; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $13 = ((($out)) + 9|0);
  $14 = (($bufflen) + -15)|0;
  $15 = ($0>>>0)<($14>>>0);
  $16 = ($12|0)==(0|0);
  $or$cond = $15 & $16;
  if ($or$cond) {
   _memcpy(($13|0),($source|0),($0|0))|0;
   $$sum3 = (($0) + 9)|0;
   $$sum3$pn = $$sum3;
  } else {
   $17 = $12;
   $18 = $source;
   $19 = (($17) - ($18))|0;
   $l$0 = $16 ? $0 : $19;
   $20 = ($l$0>>>0)>($14>>>0);
   $$l$0 = $20 ? $14 : $l$0;
   _memcpy(($13|0),($source|0),($$l$0|0))|0;
   $$sum = (($$l$0) + 9)|0;
   $21 = (($out) + ($$sum)|0);
   ;HEAP8[$21>>0]=HEAP8[5848>>0]|0;HEAP8[$21+1>>0]=HEAP8[5848+1>>0]|0;HEAP8[$21+2>>0]=HEAP8[5848+2>>0]|0;
   $$sum2 = (($$l$0) + 12)|0;
   $$sum3$pn = $$sum2;
  }
  $$0 = (($out) + ($$sum3$pn)|0);
  ;HEAP8[$$0>>0]=HEAP8[1952>>0]|0;HEAP8[$$0+1>>0]=HEAP8[1952+1>>0]|0;HEAP8[$$0+2>>0]=HEAP8[1952+2>>0]|0;
  return;
 }
}
function _luaY_parser($L,$z,$buff,$dyd,$name,$firstchar) {
 $L = $L|0;
 $z = $z|0;
 $buff = $buff|0;
 $dyd = $dyd|0;
 $name = $name|0;
 $firstchar = $firstchar|0;
 var $$pr$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $bl$i = 0, $funcstate = 0, $lexstate = 0, $ls$idx$val$i$i = 0, $v$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 176|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl$i = sp + 160|0;
 $v$i = sp + 88|0;
 $lexstate = sp;
 $funcstate = sp + 112|0;
 $0 = (_luaF_newLclosure($L,1)|0);
 $1 = ((($L)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$2>>2] = $0;
 $3 = ((($2)) + 8|0);
 HEAP32[$3>>2] = 70;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 16|0);
 HEAP32[$1>>2] = $5;
 $6 = ((($L)) + 24|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7;
 $9 = $5;
 $10 = (($8) - ($9))|0;
 $11 = ($10|0)<(16);
 if ($11) {
  _luaD_growstack($L,0);
 }
 $12 = (_luaH_new($L)|0);
 $13 = ((($lexstate)) + 64|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$1>>2]|0;
 HEAP32[$14>>2] = $12;
 $15 = ((($14)) + 8|0);
 HEAP32[$15>>2] = 69;
 $16 = HEAP32[$1>>2]|0;
 $17 = ((($16)) + 16|0);
 HEAP32[$1>>2] = $17;
 $18 = HEAP32[$6>>2]|0;
 $19 = $18;
 $20 = $17;
 $21 = (($19) - ($20))|0;
 $22 = ($21|0)<(16);
 if ($22) {
  _luaD_growstack($L,0);
 }
 $23 = (_luaF_newproto($L)|0);
 $24 = ((($0)) + 12|0);
 HEAP32[$24>>2] = $23;
 HEAP32[$funcstate>>2] = $23;
 $25 = (_luaS_new($L,$name)|0);
 $26 = ((($23)) + 72|0);
 HEAP32[$26>>2] = $25;
 $27 = ((($lexstate)) + 60|0);
 HEAP32[$27>>2] = $buff;
 $28 = ((($lexstate)) + 68|0);
 HEAP32[$28>>2] = $dyd;
 $29 = ((($dyd)) + 28|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($dyd)) + 16|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($dyd)) + 4|0);
 HEAP32[$31>>2] = 0;
 _luaX_setinput($L,$lexstate,$z,$25,$firstchar);
 $32 = ((($lexstate)) + 48|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = ((($funcstate)) + 4|0);
 HEAP32[$34>>2] = $33;
 $35 = ((($funcstate)) + 8|0);
 HEAP32[$35>>2] = $lexstate;
 HEAP32[$32>>2] = $funcstate;
 $36 = ((($funcstate)) + 16|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($funcstate)) + 20|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($funcstate)) + 24|0);
 HEAP32[$38>>2] = -1;
 $39 = ((($funcstate)) + 28|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($funcstate)) + 32|0);
 HEAP32[$40>>2] = 0;
 $41 = ((($funcstate)) + 40|0);
 ;HEAP32[$41>>2]=0|0;HEAP8[$41+4>>0]=0|0;
 $42 = HEAP32[$28>>2]|0;
 $43 = ((($42)) + 4|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($funcstate)) + 36|0);
 HEAP32[$45>>2] = $44;
 $46 = ((($funcstate)) + 12|0);
 $47 = ((($lexstate)) + 72|0);
 $48 = HEAP32[$47>>2]|0;
 HEAP32[$26>>2] = $48;
 $49 = ((($23)) + 8|0);
 HEAP8[$49>>0] = 2;
 $50 = ((($bl$i)) + 14|0);
 HEAP8[$50>>0] = 0;
 $51 = ((($bl$i)) + 12|0);
 HEAP8[$51>>0] = 0;
 $52 = ((($42)) + 28|0);
 $53 = HEAP32[$52>>2]|0;
 $54 = ((($bl$i)) + 4|0);
 HEAP32[$54>>2] = $53;
 $55 = ((($42)) + 16|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($bl$i)) + 8|0);
 HEAP32[$57>>2] = $56;
 $58 = ((($bl$i)) + 13|0);
 HEAP8[$58>>0] = 0;
 HEAP32[$bl$i>>2] = 0;
 HEAP32[$46>>2] = $bl$i;
 $59 = ((($23)) + 7|0);
 HEAP8[$59>>0] = 1;
 $60 = ((($v$i)) + 16|0);
 HEAP32[$60>>2] = -1;
 $61 = ((($v$i)) + 20|0);
 HEAP32[$61>>2] = -1;
 HEAP32[$v$i>>2] = 8;
 $62 = ((($v$i)) + 8|0);
 HEAP32[$62>>2] = 0;
 $63 = ((($lexstate)) + 76|0);
 $64 = HEAP32[$63>>2]|0;
 (_newupvalue($funcstate,$64,$v$i)|0);
 _luaX_next($lexstate);
 $65 = ((($lexstate)) + 16|0);
 L7: while(1) {
  $ls$idx$val$i$i = HEAP32[$65>>2]|0;
  switch ($ls$idx$val$i$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   $68 = $ls$idx$val$i$i;
   break L7;
   break;
  }
  default: {
  }
  }
  $66 = ($ls$idx$val$i$i|0)==(274);
  _statement($lexstate);
  if ($66) {
   label = 8;
   break;
  }
 }
 if ((label|0) == 8) {
  $$pr$i = HEAP32[$65>>2]|0;
  $68 = $$pr$i;
 }
 $67 = ($68|0)==(289);
 if ($67) {
  _close_func($lexstate);
  $69 = HEAP32[$1>>2]|0;
  $70 = ((($69)) + -16|0);
  HEAP32[$1>>2] = $70;
  STACKTOP = sp;return ($0|0);
 } else {
  _error_expected($lexstate,289);
  // unreachable;
 }
 return (0)|0;
}
function _newupvalue($fs,$name,$v) {
 $fs = $fs|0;
 $name = $name|0;
 $v = $v|0;
 var $$pre = 0, $$pre3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $oldsize$01 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$fs>>2]|0;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($fs)) + 43|0);
 $4 = HEAP8[$3>>0]|0;
 $5 = $4&255;
 $6 = (($5) + 1)|0;
 $7 = ($6>>>0)>(255);
 if ($7) {
  $8 = ((($fs)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ((($9)) + 52|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ((($0)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0);
  if ($14) {
   $16 = 2208;
   HEAP32[$vararg_buffer1>>2] = 2712;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 255;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $16;
   $17 = (_luaO_pushfstring($11,2224,$vararg_buffer1)|0);
   $18 = HEAP32[$8>>2]|0;
   _luaX_syntaxerror($18,$17);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $13;
  $15 = (_luaO_pushfstring($11,2184,$vararg_buffer)|0);
  $16 = $15;
  HEAP32[$vararg_buffer1>>2] = 2712;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 255;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $16;
  $17 = (_luaO_pushfstring($11,2224,$vararg_buffer1)|0);
  $18 = HEAP32[$8>>2]|0;
  _luaX_syntaxerror($18,$17);
  // unreachable;
 }
 $19 = ($5|0)<($2|0);
 if ($19) {
  $28 = $2;
 } else {
  $20 = ((($fs)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ((($21)) + 52|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($0)) + 64|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (_luaM_growaux_($23,$25,$1,8,255,2712)|0);
  HEAP32[$24>>2] = $26;
  $$pre = HEAP32[$1>>2]|0;
  $28 = $$pre;
 }
 $27 = ($2|0)<($28|0);
 $29 = ((($0)) + 64|0);
 $30 = HEAP32[$29>>2]|0;
 if ($27) {
  $oldsize$01 = $2;
  while(1) {
   $31 = (($oldsize$01) + 1)|0;
   $32 = (($30) + ($oldsize$01<<3)|0);
   HEAP32[$32>>2] = 0;
   $33 = ($31|0)<($28|0);
   if ($33) {
    $oldsize$01 = $31;
   } else {
    break;
   }
  }
 }
 $34 = HEAP32[$v>>2]|0;
 $35 = ($34|0)==(8);
 $36 = $35&1;
 $37 = HEAP8[$3>>0]|0;
 $38 = $37&255;
 $39 = (((($30) + ($38<<3)|0)) + 4|0);
 HEAP8[$39>>0] = $36;
 $40 = ((($v)) + 8|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = $41&255;
 $43 = (((($30) + ($38<<3)|0)) + 5|0);
 HEAP8[$43>>0] = $42;
 $44 = (($30) + ($38<<3)|0);
 HEAP32[$44>>2] = $name;
 $45 = ((($0)) + 5|0);
 $46 = HEAP8[$45>>0]|0;
 $47 = $46 & 4;
 $48 = ($47<<24>>24)==(0);
 if ($48) {
  $58 = $37;
  $57 = (($58) + 1)<<24>>24;
  HEAP8[$3>>0] = $57;
  $59 = $58&255;
  STACKTOP = sp;return ($59|0);
 }
 $49 = ((($name)) + 5|0);
 $50 = HEAP8[$49>>0]|0;
 $51 = $50 & 3;
 $52 = ($51<<24>>24)==(0);
 if ($52) {
  $58 = $37;
  $57 = (($58) + 1)<<24>>24;
  HEAP8[$3>>0] = $57;
  $59 = $58&255;
  STACKTOP = sp;return ($59|0);
 }
 $53 = ((($fs)) + 8|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($54)) + 52|0);
 $56 = HEAP32[$55>>2]|0;
 _luaC_barrier_($56,$0,$name);
 $$pre3 = HEAP8[$3>>0]|0;
 $58 = $$pre3;
 $57 = (($58) + 1)<<24>>24;
 HEAP8[$3>>0] = $57;
 $59 = $58&255;
 STACKTOP = sp;return ($59|0);
}
function _statement($ls) {
 $ls = $ls|0;
 var $$$i$i = 0, $$$i$i$i = 0, $$01$i$i42 = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx$val$i$i31 = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i$i = 0, $$idx$val$idx$i$i36 = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i$i = 0, $$idx$val$idx$val$i$i37 = 0, $$idx1$i = 0, $$idx1$i$i = 0, $$idx1$i$i32 = 0, $$idx1$val$i = 0, $$idx1$val$i$i = 0, $$idx1$val$i$i33 = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i$i = 0;
 var $$idx1$val$idx$i$i38 = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i$i = 0, $$idx1$val$idx$val$i$i39 = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i$i = 0, $$idx1$val$idx$val$idx$val$i$i41 = 0, $$idx2$i = 0, $$idx2$i$i = 0, $$idx2$i$i34 = 0, $$idx2$val$i = 0, $$idx2$val$i$i = 0, $$idx2$val$i$i35 = 0, $$lcssa166 = 0, $$lcssa169 = 0, $$lcssa170 = 0, $$lcssa172 = 0, $$off$i = 0, $$pre = 0, $$pre$i$i = 0;
 var $$pre111 = 0, $$pre112 = 0, $$pre113 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0;
 var $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b$i = 0, $b$i21 = 0, $bl$i = 0;
 var $bl$i$i = 0, $bl$i$i2 = 0, $bl$i8 = 0, $bl$i9 = 0, $bl1$i = 0, $bl2$i = 0, $e$i = 0, $e$i$i = 0, $e$i48 = 0, $e$i70 = 0, $e$i71 = 0, $e$i72 = 0, $escapelist$i = 0, $first$0$i = 0, $i$0$ph1$i$i = 0, $i$02$i$i = 0, $i$02$i$i$lcssa = 0, $ismethod$0$i$i = 0, $key$i$i$i = 0, $ls$idx = 0;
 var $ls$idx$val = 0, $ls$idx$val$i = 0, $ls$idx$val$i$i = 0, $ls$idx$val$i$i$i = 0, $ls$idx$val$i$i$i20 = 0, $ls$idx$val$i$i$i4 = 0, $ls$idx$val$i$i12 = 0, $ls$idx$val$i$i15 = 0, $ls$idx$val$i29 = 0, $ls$idx$val$i50 = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $ls$idx1$val$i = 0, $ls$idx1$val$i115 = 0, $ls$idx1$val$i116 = 0, $n$0$i$i$lcssa = 0, $n$0$i$i53$lcssa = 0, $n$0$i$i5397 = 0, $n$0$i$i91 = 0, $n$0$i$lcssa = 0;
 var $n$0$i87 = 0, $nret$0$i = 0, $nvars$0$i$i$lcssa = 0, $nvars$0$i$i88 = 0, $nvars$0$i$i88$lcssa165 = 0, $nvars$0$i95 = 0, $or$cond$i = 0, $phitmp = 0, $switch$i = 0, $v$i = 0, $v$i$i = 0, $v$i$i13 = 0, $v$i59 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer16 = 0, $vararg_buffer21 = 0, $vararg_buffer26 = 0, $vararg_buffer31 = 0;
 var $vararg_buffer6 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr19 = 0, $vararg_ptr20 = 0, $vararg_ptr24 = 0, $vararg_ptr25 = 0, $vararg_ptr29 = 0, $vararg_ptr30 = 0, $vararg_ptr34 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 560|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer31 = sp + 424|0;
 $vararg_buffer26 = sp + 408|0;
 $vararg_buffer21 = sp + 392|0;
 $vararg_buffer16 = sp + 376|0;
 $vararg_buffer11 = sp + 360|0;
 $vararg_buffer6 = sp + 344|0;
 $vararg_buffer1 = sp + 328|0;
 $vararg_buffer = sp + 320|0;
 $e$i72 = sp + 296|0;
 $e$i71 = sp + 272|0;
 $e$i70 = sp + 248|0;
 $v$i59 = sp + 216|0;
 $e$i48 = sp + 192|0;
 $e$i = sp + 168|0;
 $b$i21 = sp + 144|0;
 $key$i$i$i = sp + 120|0;
 $v$i = sp + 96|0;
 $b$i = sp + 72|0;
 $v$i$i13 = sp + 48|0;
 $bl1$i = sp + 536|0;
 $bl2$i = sp + 520|0;
 $e$i$i = sp + 24|0;
 $bl$i9 = sp + 504|0;
 $bl$i8 = sp + 488|0;
 $v$i$i = sp;
 $bl$i$i2 = sp + 472|0;
 $bl$i = sp + 456|0;
 $bl$i$i = sp + 440|0;
 $escapelist$i = sp + 432|0;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $2 = ((($ls$idx1$val)) + 106|0);
 $3 = HEAP16[$2>>1]|0;
 $4 = (($3) + 1)<<16>>16;
 HEAP16[$2>>1] = $4;
 $5 = ($4&65535)>(200);
 if ($5) {
  $6 = ((($ls$idx$val)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ((($7)) + 52|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = HEAP32[$ls$idx$val>>2]|0;
  $11 = ((($10)) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   $15 = 2208;
   HEAP32[$vararg_buffer1>>2] = 2256;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $15;
   $16 = (_luaO_pushfstring($9,2224,$vararg_buffer1)|0);
   $17 = HEAP32[$6>>2]|0;
   _luaX_syntaxerror($17,$16);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $12;
  $14 = (_luaO_pushfstring($9,2184,$vararg_buffer)|0);
  $15 = $14;
  HEAP32[$vararg_buffer1>>2] = 2256;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $15;
  $16 = (_luaO_pushfstring($9,2224,$vararg_buffer1)|0);
  $17 = HEAP32[$6>>2]|0;
  _luaX_syntaxerror($17,$16);
  // unreachable;
 }
 $18 = ((($ls)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 do {
  switch ($19|0) {
  case 59:  {
   _luaX_next($ls);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 267:  {
   HEAP32[$escapelist$i>>2] = -1;
   _test_then_block($ls,$escapelist$i);
   while(1) {
    $20 = HEAP32[$18>>2]|0;
    if ((($20|0) == 260)) {
     label = 10;
     break;
    } else if (!((($20|0) == 261))) {
     $41 = $20;
     break;
    }
    _test_then_block($ls,$escapelist$i);
   }
   if ((label|0) == 10) {
    _luaX_next($ls);
    $21 = HEAP32[$ls$idx>>2]|0;
    $22 = ((($bl$i$i)) + 14|0);
    HEAP8[$22>>0] = 0;
    $23 = ((($21)) + 42|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ((($bl$i$i)) + 12|0);
    HEAP8[$25>>0] = $24;
    $26 = ((($21)) + 8|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ((($27)) + 68|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($29)) + 28|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ((($bl$i$i)) + 4|0);
    HEAP32[$32>>2] = $31;
    $33 = ((($29)) + 16|0);
    $34 = HEAP32[$33>>2]|0;
    $35 = ((($bl$i$i)) + 8|0);
    HEAP32[$35>>2] = $34;
    $36 = ((($bl$i$i)) + 13|0);
    HEAP8[$36>>0] = 0;
    $37 = ((($21)) + 12|0);
    $38 = HEAP32[$37>>2]|0;
    HEAP32[$bl$i$i>>2] = $38;
    HEAP32[$37>>2] = $bl$i$i;
    L17: while(1) {
     $ls$idx$val$i$i$i = HEAP32[$18>>2]|0;
     switch ($ls$idx$val$i$i$i|0) {
     case 277: case 289: case 262: case 261: case 260:  {
      break L17;
      break;
     }
     default: {
     }
     }
     $39 = ($ls$idx$val$i$i$i|0)==(274);
     _statement($ls);
     if ($39) {
      break;
     }
    }
    _leaveblock($21);
    $$pre113 = HEAP32[$18>>2]|0;
    $41 = $$pre113;
   }
   $40 = ($41|0)==(262);
   if ($40) {
    _luaX_next($ls);
    $48 = HEAP32[$escapelist$i>>2]|0;
    _luaK_patchtohere($ls$idx$val,$48);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $42 = HEAP32[$0>>2]|0;
   $43 = ($42|0)==($1|0);
   if ($43) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $44 = HEAP32[$ls$idx1>>2]|0;
    $45 = (_luaX_token2str($ls,262)|0);
    $46 = (_luaX_token2str($ls,267)|0);
    HEAP32[$vararg_buffer6>>2] = $45;
    $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
    HEAP32[$vararg_ptr9>>2] = $46;
    $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
    HEAP32[$vararg_ptr10>>2] = $1;
    $47 = (_luaO_pushfstring($44,2272,$vararg_buffer6)|0);
    _luaX_syntaxerror($ls,$47);
    // unreachable;
   }
   break;
  }
  case 273:  {
   $212 = (_luaK_getlabel($ls$idx$val)|0);
   $213 = ((($bl1$i)) + 14|0);
   HEAP8[$213>>0] = 1;
   $214 = ((($ls$idx$val)) + 42|0);
   $215 = HEAP8[$214>>0]|0;
   $216 = ((($bl1$i)) + 12|0);
   HEAP8[$216>>0] = $215;
   $217 = ((($ls$idx$val)) + 8|0);
   $218 = HEAP32[$217>>2]|0;
   $219 = ((($218)) + 68|0);
   $220 = HEAP32[$219>>2]|0;
   $221 = ((($220)) + 28|0);
   $222 = HEAP32[$221>>2]|0;
   $223 = ((($bl1$i)) + 4|0);
   HEAP32[$223>>2] = $222;
   $224 = ((($220)) + 16|0);
   $225 = HEAP32[$224>>2]|0;
   $226 = ((($bl1$i)) + 8|0);
   HEAP32[$226>>2] = $225;
   $227 = ((($bl1$i)) + 13|0);
   HEAP8[$227>>0] = 0;
   $228 = ((($ls$idx$val)) + 12|0);
   $229 = HEAP32[$228>>2]|0;
   HEAP32[$bl1$i>>2] = $229;
   $230 = ((($bl2$i)) + 14|0);
   HEAP8[$230>>0] = 0;
   $231 = ((($bl2$i)) + 12|0);
   HEAP8[$231>>0] = $215;
   $232 = ((($bl2$i)) + 4|0);
   HEAP32[$232>>2] = $222;
   $233 = ((($bl2$i)) + 8|0);
   HEAP32[$233>>2] = $225;
   $234 = ((($bl2$i)) + 13|0);
   HEAP8[$234>>0] = 0;
   $235 = $bl1$i;
   HEAP32[$bl2$i>>2] = $235;
   HEAP32[$228>>2] = $bl2$i;
   _luaX_next($ls);
   L30: while(1) {
    $ls$idx$val$i$i15 = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i15|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     $238 = $ls$idx$val$i$i15;
     break L30;
     break;
    }
    default: {
    }
    }
    $236 = ($ls$idx$val$i$i15|0)==(274);
    _statement($ls);
    if ($236) {
     label = 75;
     break;
    }
   }
   if ((label|0) == 75) {
    $$pre112 = HEAP32[$18>>2]|0;
    $238 = $$pre112;
   }
   $237 = ($238|0)==(277);
   if (!($237)) {
    $239 = HEAP32[$0>>2]|0;
    $240 = ($239|0)==($1|0);
    if ($240) {
     _error_expected($ls,277);
     // unreachable;
    } else {
     $241 = HEAP32[$ls$idx1>>2]|0;
     $242 = (_luaX_token2str($ls,277)|0);
     $243 = (_luaX_token2str($ls,273)|0);
     HEAP32[$vararg_buffer26>>2] = $242;
     $vararg_ptr29 = ((($vararg_buffer26)) + 4|0);
     HEAP32[$vararg_ptr29>>2] = $243;
     $vararg_ptr30 = ((($vararg_buffer26)) + 8|0);
     HEAP32[$vararg_ptr30>>2] = $1;
     $244 = (_luaO_pushfstring($241,2272,$vararg_buffer26)|0);
     _luaX_syntaxerror($ls,$244);
     // unreachable;
    }
   }
   _luaX_next($ls);
   (_subexpr($ls,$v$i$i13,0)|0);
   $245 = HEAP32[$v$i$i13>>2]|0;
   $246 = ($245|0)==(1);
   if ($246) {
    HEAP32[$v$i$i13>>2] = 3;
   }
   $247 = HEAP32[$ls$idx>>2]|0;
   _luaK_goiftrue($247,$v$i$i13);
   $248 = ((($v$i$i13)) + 20|0);
   $249 = HEAP32[$248>>2]|0;
   $250 = HEAP8[$234>>0]|0;
   $251 = ($250<<24>>24)==(0);
   if (!($251)) {
    $252 = HEAP8[$231>>0]|0;
    $253 = $252&255;
    _luaK_patchclose($ls$idx$val,$249,$253);
   }
   _leaveblock($ls$idx$val);
   _luaK_patchlist($ls$idx$val,$249,$212);
   _leaveblock($ls$idx$val);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 264:  {
   $129 = ((($bl$i9)) + 14|0);
   HEAP8[$129>>0] = 1;
   $130 = ((($ls$idx$val)) + 42|0);
   $131 = HEAP8[$130>>0]|0;
   $132 = ((($bl$i9)) + 12|0);
   HEAP8[$132>>0] = $131;
   $133 = ((($ls$idx$val)) + 8|0);
   $134 = HEAP32[$133>>2]|0;
   $135 = ((($134)) + 68|0);
   $136 = HEAP32[$135>>2]|0;
   $137 = ((($136)) + 28|0);
   $138 = HEAP32[$137>>2]|0;
   $139 = ((($bl$i9)) + 4|0);
   HEAP32[$139>>2] = $138;
   $140 = ((($136)) + 16|0);
   $141 = HEAP32[$140>>2]|0;
   $142 = ((($bl$i9)) + 8|0);
   HEAP32[$142>>2] = $141;
   $143 = ((($bl$i9)) + 13|0);
   HEAP8[$143>>0] = 0;
   $144 = ((($ls$idx$val)) + 12|0);
   $145 = HEAP32[$144>>2]|0;
   HEAP32[$bl$i9>>2] = $145;
   HEAP32[$144>>2] = $bl$i9;
   _luaX_next($ls);
   $146 = HEAP32[$18>>2]|0;
   $147 = ($146|0)==(292);
   if (!($147)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $148 = ((($ls)) + 24|0);
   $149 = HEAP32[$148>>2]|0;
   _luaX_next($ls);
   $150 = HEAP32[$18>>2]|0;
   if ((($150|0) == 61)) {
    $151 = HEAP32[$ls$idx>>2]|0;
    $152 = ((($151)) + 44|0);
    $153 = HEAP8[$152>>0]|0;
    $154 = $153&255;
    $155 = (_luaX_newstring($ls,2312,11)|0);
    _new_localvar($ls,$155);
    $156 = (_luaX_newstring($ls,2328,11)|0);
    _new_localvar($ls,$156);
    $157 = (_luaX_newstring($ls,2344,10)|0);
    _new_localvar($ls,$157);
    _new_localvar($ls,$149);
    $158 = HEAP32[$18>>2]|0;
    $159 = ($158|0)==(61);
    if (!($159)) {
     _error_expected($ls,61);
     // unreachable;
    }
    _luaX_next($ls);
    (_subexpr($ls,$e$i70,0)|0);
    $160 = HEAP32[$ls$idx>>2]|0;
    _luaK_exp2nextreg($160,$e$i70);
    $161 = HEAP32[$18>>2]|0;
    $162 = ($161|0)==(44);
    if (!($162)) {
     _error_expected($ls,44);
     // unreachable;
    }
    _luaX_next($ls);
    (_subexpr($ls,$e$i71,0)|0);
    $163 = HEAP32[$ls$idx>>2]|0;
    _luaK_exp2nextreg($163,$e$i71);
    $164 = HEAP32[$18>>2]|0;
    $165 = ($164|0)==(44);
    if ($165) {
     _luaX_next($ls);
     (_subexpr($ls,$e$i72,0)|0);
     $166 = HEAP32[$ls$idx>>2]|0;
     _luaK_exp2nextreg($166,$e$i72);
    } else {
     $167 = HEAP8[$152>>0]|0;
     $168 = $167&255;
     $169 = (_luaK_intK($151,1,0)|0);
     (_luaK_codek($151,$168,$169)|0);
     _luaK_reserveregs($151,1);
    }
    _forbody($ls,$154,$1,1,1);
   } else if ((($150|0) == 268) | (($150|0) == 44)) {
    $170 = HEAP32[$ls$idx>>2]|0;
    $171 = ((($170)) + 44|0);
    $172 = HEAP8[$171>>0]|0;
    $173 = $172&255;
    $174 = (_luaX_newstring($ls,2360,15)|0);
    _new_localvar($ls,$174);
    $175 = (_luaX_newstring($ls,2376,11)|0);
    _new_localvar($ls,$175);
    $176 = (_luaX_newstring($ls,2392,13)|0);
    _new_localvar($ls,$176);
    _new_localvar($ls,$149);
    $177 = HEAP32[$18>>2]|0;
    $178 = ($177|0)==(44);
    do {
     if ($178) {
      $nvars$0$i$i88 = 4;
      while(1) {
       _luaX_next($ls);
       $179 = HEAP32[$18>>2]|0;
       $180 = ($179|0)==(292);
       if (!($180)) {
        label = 52;
        break;
       }
       $181 = HEAP32[$148>>2]|0;
       _luaX_next($ls);
       _new_localvar($ls,$181);
       $182 = (($nvars$0$i$i88) + 1)|0;
       $183 = HEAP32[$18>>2]|0;
       $184 = ($183|0)==(44);
       if ($184) {
        $nvars$0$i$i88 = $182;
       } else {
        $$lcssa166 = $183;$nvars$0$i$i88$lcssa165 = $nvars$0$i$i88;
        label = 54;
        break;
       }
      }
      if ((label|0) == 52) {
       _error_expected($ls,292);
       // unreachable;
      }
      else if ((label|0) == 54) {
       $phitmp = (($nvars$0$i$i88$lcssa165) + -2)|0;
       $186 = $$lcssa166;$nvars$0$i$i$lcssa = $phitmp;
       break;
      }
     } else {
      $186 = $177;$nvars$0$i$i$lcssa = 1;
     }
    } while(0);
    $185 = ($186|0)==(268);
    if (!($185)) {
     _error_expected($ls,268);
     // unreachable;
    }
    _luaX_next($ls);
    $187 = HEAP32[$0>>2]|0;
    (_subexpr($ls,$e$i$i,0)|0);
    $188 = HEAP32[$18>>2]|0;
    $189 = ($188|0)==(44);
    if ($189) {
     $n$0$i87 = 1;
     while(1) {
      _luaX_next($ls);
      $190 = HEAP32[$ls$idx>>2]|0;
      _luaK_exp2nextreg($190,$e$i$i);
      (_subexpr($ls,$e$i$i,0)|0);
      $191 = (($n$0$i87) + 1)|0;
      $192 = HEAP32[$18>>2]|0;
      $193 = ($192|0)==(44);
      if ($193) {
       $n$0$i87 = $191;
      } else {
       $n$0$i$lcssa = $191;
       break;
      }
     }
    } else {
     $n$0$i$lcssa = 1;
    }
    $ls$idx$val$i$i12 = HEAP32[$ls$idx>>2]|0;
    $194 = (3 - ($n$0$i$lcssa))|0;
    $195 = HEAP32[$e$i$i>>2]|0;
    if ((($195|0) == 14) | (($195|0) == 13)) {
     $196 = (($194) + 1)|0;
     $197 = ($196|0)<(0);
     $$$i$i$i = $197 ? 0 : $196;
     _luaK_setreturns($ls$idx$val$i$i12,$e$i$i,$$$i$i$i);
     $198 = ($$$i$i$i|0)>(1);
     if ($198) {
      $199 = (($$$i$i$i) + -1)|0;
      _luaK_reserveregs($ls$idx$val$i$i12,$199);
     }
    } else if ((($195|0) == 0)) {
     label = 63;
    } else {
     _luaK_exp2nextreg($ls$idx$val$i$i12,$e$i$i);
     label = 63;
    }
    if ((label|0) == 63) {
     $200 = ($194|0)>(0);
     if ($200) {
      $201 = ((($ls$idx$val$i$i12)) + 44|0);
      $202 = HEAP8[$201>>0]|0;
      $203 = $202&255;
      _luaK_reserveregs($ls$idx$val$i$i12,$194);
      _luaK_nil($ls$idx$val$i$i12,$203,$194);
     }
    }
    _luaK_checkstack($170,3);
    _forbody($ls,$173,$187,$nvars$0$i$i$lcssa,0);
   } else {
    _luaX_syntaxerror($ls,2408);
    // unreachable;
   }
   $204 = HEAP32[$18>>2]|0;
   $205 = ($204|0)==(262);
   if ($205) {
    _luaX_next($ls);
    _leaveblock($ls$idx$val);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $206 = HEAP32[$0>>2]|0;
   $207 = ($206|0)==($1|0);
   if ($207) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $208 = HEAP32[$ls$idx1>>2]|0;
    $209 = (_luaX_token2str($ls,262)|0);
    $210 = (_luaX_token2str($ls,264)|0);
    HEAP32[$vararg_buffer21>>2] = $209;
    $vararg_ptr24 = ((($vararg_buffer21)) + 4|0);
    HEAP32[$vararg_ptr24>>2] = $210;
    $vararg_ptr25 = ((($vararg_buffer21)) + 8|0);
    HEAP32[$vararg_ptr25>>2] = $1;
    $211 = (_luaO_pushfstring($208,2272,$vararg_buffer21)|0);
    _luaX_syntaxerror($ls,$211);
    // unreachable;
   }
   break;
  }
  case 269:  {
   _luaX_next($ls);
   $270 = HEAP32[$18>>2]|0;
   $271 = ($270|0)==(265);
   if ($271) {
    _luaX_next($ls);
    $272 = HEAP32[$ls$idx>>2]|0;
    $273 = HEAP32[$18>>2]|0;
    $274 = ($273|0)==(292);
    if (!($274)) {
     _error_expected($ls,292);
     // unreachable;
    }
    $275 = ((($ls)) + 24|0);
    $276 = HEAP32[$275>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$276);
    $ls$idx$val$i = HEAP32[$ls$idx>>2]|0;
    $277 = ((($ls$idx$val$i)) + 42|0);
    $278 = HEAP8[$277>>0]|0;
    $279 = $278&255;
    $280 = (($279) + 1)|0;
    $281 = $280&255;
    HEAP8[$277>>0] = $281;
    $282 = ((($ls$idx$val$i)) + 16|0);
    $283 = HEAP32[$282>>2]|0;
    $284 = $280 & 255;
    $$idx$val$i$i = HEAP32[$ls$idx$val$i>>2]|0;
    $$idx1$i$i = ((($ls$idx$val$i)) + 8|0);
    $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
    $$idx2$i$i = ((($ls$idx$val$i)) + 36|0);
    $$idx2$val$i$i = HEAP32[$$idx2$i$i>>2]|0;
    $$idx$val$idx$i$i = ((($$idx$val$i$i)) + 60|0);
    $$idx$val$idx$val$i$i = HEAP32[$$idx$val$idx$i$i>>2]|0;
    $$idx1$val$idx$i$i = ((($$idx1$val$i$i)) + 68|0);
    $$idx1$val$idx$val$i$i = HEAP32[$$idx1$val$idx$i$i>>2]|0;
    $$idx1$val$idx$val$idx$val$i$i = HEAP32[$$idx1$val$idx$val$i$i>>2]|0;
    $285 = (($$idx2$val$i$i) + ($284))|0;
    $286 = (($285) + -1)|0;
    $287 = (($$idx1$val$idx$val$idx$val$i$i) + ($286<<1)|0);
    $288 = HEAP16[$287>>1]|0;
    $289 = $288 << 16 >> 16;
    $290 = (((($$idx$val$idx$val$i$i) + (($289*12)|0)|0)) + 4|0);
    HEAP32[$290>>2] = $283;
    $291 = HEAP32[$0>>2]|0;
    _body($ls,$b$i21,0,$291);
    $292 = ((($272)) + 16|0);
    $293 = HEAP32[$292>>2]|0;
    $294 = ((($b$i21)) + 8|0);
    $295 = HEAP32[$294>>2]|0;
    $$idx$val$i = HEAP32[$272>>2]|0;
    $$idx1$i = ((($272)) + 8|0);
    $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
    $$idx2$i = ((($272)) + 36|0);
    $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
    $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
    $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
    $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
    $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
    $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
    $296 = (($$idx2$val$i) + ($295))|0;
    $297 = (($$idx1$val$idx$val$idx$val$i) + ($296<<1)|0);
    $298 = HEAP16[$297>>1]|0;
    $299 = $298 << 16 >> 16;
    $300 = (((($$idx$val$idx$val$i) + (($299*12)|0)|0)) + 4|0);
    HEAP32[$300>>2] = $293;
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $301 = ($270|0)==(292);
   if (!($301)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $302 = ((($ls)) + 24|0);
   $nvars$0$i95 = 0;
   while(1) {
    $303 = HEAP32[$302>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$303);
    $304 = (($nvars$0$i95) + 1)|0;
    $305 = HEAP32[$18>>2]|0;
    if ((($305|0) == 61)) {
     $$lcssa170 = $304;
     label = 103;
     break;
    } else if (!((($305|0) == 44))) {
     $$lcssa169 = $304;
     label = 105;
     break;
    }
    _luaX_next($ls);
    $306 = HEAP32[$18>>2]|0;
    $307 = ($306|0)==(292);
    if ($307) {
     $nvars$0$i95 = $304;
    } else {
     label = 100;
     break;
    }
   }
   do {
    if ((label|0) == 100) {
     _error_expected($ls,292);
     // unreachable;
    }
    else if ((label|0) == 103) {
     _luaX_next($ls);
     (_subexpr($ls,$e$i,0)|0);
     $308 = HEAP32[$18>>2]|0;
     $309 = ($308|0)==(44);
     if ($309) {
      $n$0$i$i91 = 1;
      while(1) {
       _luaX_next($ls);
       $310 = HEAP32[$ls$idx>>2]|0;
       _luaK_exp2nextreg($310,$e$i);
       (_subexpr($ls,$e$i,0)|0);
       $311 = (($n$0$i$i91) + 1)|0;
       $312 = HEAP32[$18>>2]|0;
       $313 = ($312|0)==(44);
       if ($313) {
        $n$0$i$i91 = $311;
       } else {
        $n$0$i$i$lcssa = $311;
        break;
       }
      }
     } else {
      $n$0$i$i$lcssa = 1;
     }
     $$pre111 = HEAP32[$e$i>>2]|0;
     $ls$idx1$val$i = HEAP32[$ls$idx>>2]|0;
     $314 = (($$lcssa170) - ($n$0$i$i$lcssa))|0;
     if ((($$pre111|0) == 0)) {
      $320 = $314;$471 = $$lcssa170;$ls$idx1$val$i116 = $ls$idx1$val$i;
      label = 110;
      break;
     } else if (!((($$pre111|0) == 14) | (($$pre111|0) == 13))) {
      _luaK_exp2nextreg($ls$idx1$val$i,$e$i);
      $320 = $314;$471 = $$lcssa170;$ls$idx1$val$i116 = $ls$idx1$val$i;
      label = 110;
      break;
     }
     $315 = (($314) + 1)|0;
     $316 = ($315|0)<(0);
     $$$i$i = $316 ? 0 : $315;
     _luaK_setreturns($ls$idx1$val$i,$e$i,$$$i$i);
     $317 = ($$$i$i|0)>(1);
     if ($317) {
      $318 = (($$$i$i) + -1)|0;
      _luaK_reserveregs($ls$idx1$val$i,$318);
      $328 = $$lcssa170;
     } else {
      $328 = $$lcssa170;
     }
    }
    else if ((label|0) == 105) {
     HEAP32[$e$i>>2] = 0;
     $ls$idx1$val$i115 = HEAP32[$ls$idx>>2]|0;
     $320 = $$lcssa169;$471 = $$lcssa169;$ls$idx1$val$i116 = $ls$idx1$val$i115;
     label = 110;
    }
   } while(0);
   if ((label|0) == 110) {
    $319 = ($320|0)>(0);
    if ($319) {
     $321 = ((($ls$idx1$val$i116)) + 44|0);
     $322 = HEAP8[$321>>0]|0;
     $323 = $322&255;
     _luaK_reserveregs($ls$idx1$val$i116,$320);
     _luaK_nil($ls$idx1$val$i116,$323,$320);
     $328 = $471;
    } else {
     $328 = $471;
    }
   }
   $ls$idx$val$i29 = HEAP32[$ls$idx>>2]|0;
   $324 = ((($ls$idx$val$i29)) + 42|0);
   $325 = HEAP8[$324>>0]|0;
   $326 = $325&255;
   $327 = (($326) + ($328))|0;
   $329 = $327&255;
   HEAP8[$324>>0] = $329;
   $330 = ($328|0)==(0);
   if (!($330)) {
    $331 = ((($ls$idx$val$i29)) + 16|0);
    $332 = HEAP32[$331>>2]|0;
    $333 = $327 & 255;
    $$idx$val$i$i31 = HEAP32[$ls$idx$val$i29>>2]|0;
    $$idx1$i$i32 = ((($ls$idx$val$i29)) + 8|0);
    $$idx1$val$i$i33 = HEAP32[$$idx1$i$i32>>2]|0;
    $$idx2$i$i34 = ((($ls$idx$val$i29)) + 36|0);
    $$idx2$val$i$i35 = HEAP32[$$idx2$i$i34>>2]|0;
    $$idx$val$idx$i$i36 = ((($$idx$val$i$i31)) + 60|0);
    $$idx$val$idx$val$i$i37 = HEAP32[$$idx$val$idx$i$i36>>2]|0;
    $$idx1$val$idx$i$i38 = ((($$idx1$val$i$i33)) + 68|0);
    $$idx1$val$idx$val$i$i39 = HEAP32[$$idx1$val$idx$i$i38>>2]|0;
    $$idx1$val$idx$val$idx$val$i$i41 = HEAP32[$$idx1$val$idx$val$i$i39>>2]|0;
    $334 = (($$idx2$val$i$i35) + ($333))|0;
    $$01$i$i42 = $328;
    while(1) {
     $335 = (($334) - ($$01$i$i42))|0;
     $336 = (($$idx1$val$idx$val$idx$val$i$i41) + ($335<<1)|0);
     $337 = HEAP16[$336>>1]|0;
     $338 = $337 << 16 >> 16;
     $339 = (((($$idx$val$idx$val$i$i37) + (($338*12)|0)|0)) + 4|0);
     HEAP32[$339>>2] = $332;
     $340 = (($$01$i$i42) + -1)|0;
     $341 = ($340|0)==(0);
     if ($341) {
      break;
     } else {
      $$01$i$i42 = $340;
     }
    }
   }
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 278:  {
   _luaX_next($ls);
   $49 = (_luaK_getlabel($ls$idx$val)|0);
   (_subexpr($ls,$v$i$i,0)|0);
   $50 = HEAP32[$v$i$i>>2]|0;
   $51 = ($50|0)==(1);
   if ($51) {
    HEAP32[$v$i$i>>2] = 3;
   }
   $52 = HEAP32[$ls$idx>>2]|0;
   _luaK_goiftrue($52,$v$i$i);
   $53 = ((($v$i$i)) + 20|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = ((($bl$i)) + 14|0);
   HEAP8[$55>>0] = 1;
   $56 = ((($ls$idx$val)) + 42|0);
   $57 = HEAP8[$56>>0]|0;
   $58 = ((($bl$i)) + 12|0);
   HEAP8[$58>>0] = $57;
   $59 = ((($ls$idx$val)) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + 68|0);
   $62 = HEAP32[$61>>2]|0;
   $63 = ((($62)) + 28|0);
   $64 = HEAP32[$63>>2]|0;
   $65 = ((($bl$i)) + 4|0);
   HEAP32[$65>>2] = $64;
   $66 = ((($62)) + 16|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ((($bl$i)) + 8|0);
   HEAP32[$68>>2] = $67;
   $69 = ((($bl$i)) + 13|0);
   HEAP8[$69>>0] = 0;
   $70 = ((($ls$idx$val)) + 12|0);
   $71 = HEAP32[$70>>2]|0;
   HEAP32[$bl$i>>2] = $71;
   HEAP32[$70>>2] = $bl$i;
   $72 = HEAP32[$18>>2]|0;
   $73 = ($72|0)==(259);
   if (!($73)) {
    _error_expected($ls,259);
    // unreachable;
   }
   _luaX_next($ls);
   $74 = HEAP32[$ls$idx>>2]|0;
   $75 = ((($bl$i$i2)) + 14|0);
   HEAP8[$75>>0] = 0;
   $76 = ((($74)) + 42|0);
   $77 = HEAP8[$76>>0]|0;
   $78 = ((($bl$i$i2)) + 12|0);
   HEAP8[$78>>0] = $77;
   $79 = ((($74)) + 8|0);
   $80 = HEAP32[$79>>2]|0;
   $81 = ((($80)) + 68|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = ((($82)) + 28|0);
   $84 = HEAP32[$83>>2]|0;
   $85 = ((($bl$i$i2)) + 4|0);
   HEAP32[$85>>2] = $84;
   $86 = ((($82)) + 16|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = ((($bl$i$i2)) + 8|0);
   HEAP32[$88>>2] = $87;
   $89 = ((($bl$i$i2)) + 13|0);
   HEAP8[$89>>0] = 0;
   $90 = ((($74)) + 12|0);
   $91 = HEAP32[$90>>2]|0;
   HEAP32[$bl$i$i2>>2] = $91;
   HEAP32[$90>>2] = $bl$i$i2;
   L141: while(1) {
    $ls$idx$val$i$i$i4 = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i$i4|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     break L141;
     break;
    }
    default: {
    }
    }
    $92 = ($ls$idx$val$i$i$i4|0)==(274);
    _statement($ls);
    if ($92) {
     break;
    }
   }
   _leaveblock($74);
   $93 = (_luaK_jump($ls$idx$val)|0);
   _luaK_patchlist($ls$idx$val,$93,$49);
   $94 = HEAP32[$18>>2]|0;
   $95 = ($94|0)==(262);
   if ($95) {
    _luaX_next($ls);
    _leaveblock($ls$idx$val);
    _luaK_patchtohere($ls$idx$val,$54);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $96 = HEAP32[$0>>2]|0;
   $97 = ($96|0)==($1|0);
   if ($97) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $98 = HEAP32[$ls$idx1>>2]|0;
    $99 = (_luaX_token2str($ls,262)|0);
    $100 = (_luaX_token2str($ls,278)|0);
    HEAP32[$vararg_buffer11>>2] = $99;
    $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
    HEAP32[$vararg_ptr14>>2] = $100;
    $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
    HEAP32[$vararg_ptr15>>2] = $1;
    $101 = (_luaO_pushfstring($98,2272,$vararg_buffer11)|0);
    _luaX_syntaxerror($ls,$101);
    // unreachable;
   }
   break;
  }
  case 265:  {
   _luaX_next($ls);
   $254 = HEAP32[$18>>2]|0;
   $255 = ($254|0)==(292);
   if (!($255)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $256 = ((($ls)) + 24|0);
   $257 = HEAP32[$256>>2]|0;
   _luaX_next($ls);
   $258 = HEAP32[$ls$idx>>2]|0;
   $259 = (_singlevaraux($258,$257,$v$i,1)|0);
   $260 = ($259|0)==(0);
   if ($260) {
    $261 = ((($ls)) + 76|0);
    $262 = HEAP32[$261>>2]|0;
    (_singlevaraux($258,$262,$v$i,1)|0);
    $ls$idx$val$i$i$i20 = HEAP32[$ls$idx>>2]|0;
    $263 = (_luaK_stringK($ls$idx$val$i$i$i20,$257)|0);
    $264 = ((($key$i$i$i)) + 16|0);
    HEAP32[$264>>2] = -1;
    $265 = ((($key$i$i$i)) + 20|0);
    HEAP32[$265>>2] = -1;
    HEAP32[$key$i$i$i>>2] = 4;
    $266 = ((($key$i$i$i)) + 8|0);
    HEAP32[$266>>2] = $263;
    _luaK_indexed($258,$v$i,$key$i$i$i);
   }
   while(1) {
    $267 = HEAP32[$18>>2]|0;
    if ((($267|0) == 58)) {
     label = 92;
     break;
    } else if (!((($267|0) == 46))) {
     $ismethod$0$i$i = 0;
     break;
    }
    _fieldsel($ls,$v$i);
   }
   if ((label|0) == 92) {
    _fieldsel($ls,$v$i);
    $ismethod$0$i$i = 1;
   }
   _body($ls,$b$i,$ismethod$0$i$i,$1);
   $268 = HEAP32[$ls$idx>>2]|0;
   _luaK_storevar($268,$v$i,$b$i);
   $269 = HEAP32[$ls$idx>>2]|0;
   _luaK_fixline($269,$1);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 288:  {
   _luaX_next($ls);
   $342 = HEAP32[$18>>2]|0;
   $343 = ($342|0)==(292);
   if (!($343)) {
    _error_expected($ls,292);
    // unreachable;
   }
   $344 = ((($ls)) + 24|0);
   $345 = HEAP32[$344>>2]|0;
   _luaX_next($ls);
   $346 = HEAP32[$ls$idx>>2]|0;
   $347 = ((($ls)) + 68|0);
   $348 = HEAP32[$347>>2]|0;
   $349 = ((($348)) + 24|0);
   $350 = ((($346)) + 12|0);
   $351 = HEAP32[$350>>2]|0;
   $352 = ((($351)) + 4|0);
   $353 = HEAP32[$352>>2]|0;
   $354 = ((($348)) + 28|0);
   $355 = HEAP32[$354>>2]|0;
   $356 = ($353|0)<($355|0);
   L170: do {
    if ($356) {
     $357 = HEAP32[$349>>2]|0;
     $i$02$i$i = $353;
     while(1) {
      $358 = (($357) + ($i$02$i$i<<4)|0);
      $359 = HEAP32[$358>>2]|0;
      $360 = ($359|0)==($345|0);
      if ($360) {
       $i$02$i$i$lcssa = $i$02$i$i;
       break;
      }
      $370 = (($i$02$i$i) + 1)|0;
      $371 = ($370|0)<($355|0);
      if ($371) {
       $i$02$i$i = $370;
      } else {
       break L170;
      }
     }
     $361 = ((($346)) + 8|0);
     $362 = HEAP32[$361>>2]|0;
     $363 = ((($362)) + 52|0);
     $364 = HEAP32[$363>>2]|0;
     $365 = ((($345)) + 24|0);
     $366 = (((($357) + ($i$02$i$i$lcssa<<4)|0)) + 8|0);
     $367 = HEAP32[$366>>2]|0;
     HEAP32[$vararg_buffer31>>2] = $365;
     $vararg_ptr34 = ((($vararg_buffer31)) + 4|0);
     HEAP32[$vararg_ptr34>>2] = $367;
     $368 = (_luaO_pushfstring($364,2432,$vararg_buffer31)|0);
     $369 = HEAP32[$361>>2]|0;
     _semerror($369,$368);
     // unreachable;
    }
   } while(0);
   $372 = HEAP32[$18>>2]|0;
   $373 = ($372|0)==(288);
   if (!($373)) {
    _error_expected($ls,288);
    // unreachable;
   }
   _luaX_next($ls);
   $374 = ((($346)) + 16|0);
   $375 = HEAP32[$374>>2]|0;
   $376 = HEAP32[$354>>2]|0;
   $377 = (($376) + 1)|0;
   $378 = ((($348)) + 32|0);
   $379 = HEAP32[$378>>2]|0;
   $380 = ($376|0)<($379|0);
   if ($380) {
    $$pre$i$i = HEAP32[$349>>2]|0;
    $385 = $$pre$i$i;
   } else {
    $381 = HEAP32[$ls$idx1>>2]|0;
    $382 = HEAP32[$349>>2]|0;
    $383 = (_luaM_growaux_($381,$382,$378,16,32767,2008)|0);
    HEAP32[$349>>2] = $383;
    $385 = $383;
   }
   $384 = (($385) + ($376<<4)|0);
   HEAP32[$384>>2] = $345;
   $386 = (((($385) + ($376<<4)|0)) + 8|0);
   HEAP32[$386>>2] = $1;
   $387 = HEAP32[$ls$idx>>2]|0;
   $388 = ((($387)) + 42|0);
   $389 = HEAP8[$388>>0]|0;
   $390 = (((($385) + ($376<<4)|0)) + 12|0);
   HEAP8[$390>>0] = $389;
   $391 = (((($385) + ($376<<4)|0)) + 4|0);
   HEAP32[$391>>2] = $375;
   HEAP32[$354>>2] = $377;
   L184: while(1) {
    $392 = HEAP32[$18>>2]|0;
    switch ($392|0) {
    case 288: case 59:  {
     break;
    }
    case 289: case 262: case 261: case 260:  {
     label = 132;
     break L184;
     break;
    }
    default: {
     label = 131;
     break L184;
    }
    }
    _statement($ls);
   }
   if ((label|0) == 131) {
    $$pre = HEAP32[$349>>2]|0;
    $399 = $$pre;
   }
   else if ((label|0) == 132) {
    $393 = HEAP32[$350>>2]|0;
    $394 = ((($393)) + 12|0);
    $395 = HEAP8[$394>>0]|0;
    $396 = HEAP32[$349>>2]|0;
    $397 = (((($396) + ($376<<4)|0)) + 12|0);
    HEAP8[$397>>0] = $395;
    $399 = $396;
   }
   $398 = (($399) + ($376<<4)|0);
   $400 = HEAP32[$347>>2]|0;
   $401 = HEAP32[$ls$idx>>2]|0;
   $402 = ((($401)) + 12|0);
   $403 = HEAP32[$402>>2]|0;
   $404 = ((($403)) + 8|0);
   $405 = HEAP32[$404>>2]|0;
   $406 = ((($400)) + 16|0);
   $407 = HEAP32[$406>>2]|0;
   $408 = ($405|0)<($407|0);
   if (!($408)) {
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $409 = ((($400)) + 12|0);
   $472 = $407;$i$0$ph1$i$i = $405;
   L194: while(1) {
    $473 = $472;
    while(1) {
     $410 = HEAP32[$409>>2]|0;
     $411 = (($410) + ($i$0$ph1$i$i<<4)|0);
     $412 = HEAP32[$411>>2]|0;
     $413 = HEAP32[$398>>2]|0;
     $414 = ($412|0)==($413|0);
     if (!($414)) {
      $$lcssa172 = $473;
      break;
     }
     _closegoto($ls,$i$0$ph1$i$i,$398);
     $415 = HEAP32[$406>>2]|0;
     $416 = ($i$0$ph1$i$i|0)<($415|0);
     if ($416) {
      $473 = $415;
     } else {
      label = 159;
      break L194;
     }
    }
    $417 = (($i$0$ph1$i$i) + 1)|0;
    $418 = ($417|0)<($$lcssa172|0);
    if ($418) {
     $472 = $$lcssa172;$i$0$ph1$i$i = $417;
    } else {
     label = 159;
     break;
    }
   }
   if ((label|0) == 159) {
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   break;
  }
  case 274:  {
   _luaX_next($ls);
   $419 = HEAP32[$ls$idx>>2]|0;
   $ls$idx$val$i50 = HEAP32[$18>>2]|0;
   L204: do {
    switch ($ls$idx$val$i50|0) {
    case 59: case 277: case 289: case 262: case 261: case 260:  {
     $first$0$i = 0;$nret$0$i = 0;
     break;
    }
    default: {
     (_subexpr($ls,$e$i48,0)|0);
     $420 = HEAP32[$18>>2]|0;
     $421 = ($420|0)==(44);
     if ($421) {
      $n$0$i$i5397 = 1;
      while(1) {
       _luaX_next($ls);
       $422 = HEAP32[$ls$idx>>2]|0;
       _luaK_exp2nextreg($422,$e$i48);
       (_subexpr($ls,$e$i48,0)|0);
       $423 = (($n$0$i$i5397) + 1)|0;
       $424 = HEAP32[$18>>2]|0;
       $425 = ($424|0)==(44);
       if ($425) {
        $n$0$i$i5397 = $423;
       } else {
        $n$0$i$i53$lcssa = $423;
        break;
       }
      }
     } else {
      $n$0$i$i53$lcssa = 1;
     }
     $426 = HEAP32[$e$i48>>2]|0;
     $$off$i = (($426) + -13)|0;
     $switch$i = ($$off$i>>>0)<(2);
     if ($switch$i) {
      _luaK_setreturns($419,$e$i48,-1);
      $427 = HEAP32[$e$i48>>2]|0;
      $428 = ($427|0)==(13);
      $429 = ($n$0$i$i53$lcssa|0)==(1);
      $or$cond$i = $429 & $428;
      if ($or$cond$i) {
       $430 = ((($e$i48)) + 8|0);
       $431 = HEAP32[$430>>2]|0;
       $432 = HEAP32[$419>>2]|0;
       $433 = ((($432)) + 48|0);
       $434 = HEAP32[$433>>2]|0;
       $435 = (($434) + ($431<<2)|0);
       $436 = HEAP32[$435>>2]|0;
       $437 = $436 & -64;
       $438 = $437 | 37;
       HEAP32[$435>>2] = $438;
      }
      $439 = ((($419)) + 42|0);
      $440 = HEAP8[$439>>0]|0;
      $441 = $440&255;
      $first$0$i = $441;$nret$0$i = -1;
      break L204;
     } else {
      $442 = ($n$0$i$i53$lcssa|0)==(1);
      if ($442) {
       $443 = (_luaK_exp2anyreg($419,$e$i48)|0);
       $first$0$i = $443;$nret$0$i = 1;
       break L204;
      } else {
       _luaK_exp2nextreg($419,$e$i48);
       $444 = ((($419)) + 42|0);
       $445 = HEAP8[$444>>0]|0;
       $446 = $445&255;
       $first$0$i = $446;$nret$0$i = $n$0$i$i53$lcssa;
       break L204;
      }
     }
    }
    }
   } while(0);
   _luaK_ret($419,$first$0$i,$nret$0$i);
   $447 = HEAP32[$18>>2]|0;
   $448 = ($447|0)==(59);
   if ($448) {
    _luaX_next($ls);
   }
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  case 259:  {
   _luaX_next($ls);
   $102 = HEAP32[$ls$idx>>2]|0;
   $103 = ((($bl$i8)) + 14|0);
   HEAP8[$103>>0] = 0;
   $104 = ((($102)) + 42|0);
   $105 = HEAP8[$104>>0]|0;
   $106 = ((($bl$i8)) + 12|0);
   HEAP8[$106>>0] = $105;
   $107 = ((($102)) + 8|0);
   $108 = HEAP32[$107>>2]|0;
   $109 = ((($108)) + 68|0);
   $110 = HEAP32[$109>>2]|0;
   $111 = ((($110)) + 28|0);
   $112 = HEAP32[$111>>2]|0;
   $113 = ((($bl$i8)) + 4|0);
   HEAP32[$113>>2] = $112;
   $114 = ((($110)) + 16|0);
   $115 = HEAP32[$114>>2]|0;
   $116 = ((($bl$i8)) + 8|0);
   HEAP32[$116>>2] = $115;
   $117 = ((($bl$i8)) + 13|0);
   HEAP8[$117>>0] = 0;
   $118 = ((($102)) + 12|0);
   $119 = HEAP32[$118>>2]|0;
   HEAP32[$bl$i8>>2] = $119;
   HEAP32[$118>>2] = $bl$i8;
   L225: while(1) {
    $ls$idx$val$i$i = HEAP32[$18>>2]|0;
    switch ($ls$idx$val$i$i|0) {
    case 277: case 289: case 262: case 261: case 260:  {
     break L225;
     break;
    }
    default: {
    }
    }
    $120 = ($ls$idx$val$i$i|0)==(274);
    _statement($ls);
    if ($120) {
     break;
    }
   }
   _leaveblock($102);
   $121 = HEAP32[$18>>2]|0;
   $122 = ($121|0)==(262);
   if ($122) {
    _luaX_next($ls);
    $463 = HEAP32[$ls$idx>>2]|0;
    $464 = ((($463)) + 42|0);
    $465 = HEAP8[$464>>0]|0;
    $466 = ((($463)) + 44|0);
    HEAP8[$466>>0] = $465;
    $467 = HEAP32[$ls$idx1>>2]|0;
    $468 = ((($467)) + 106|0);
    $469 = HEAP16[$468>>1]|0;
    $470 = (($469) + -1)<<16>>16;
    HEAP16[$468>>1] = $470;
    STACKTOP = sp;return;
   }
   $123 = HEAP32[$0>>2]|0;
   $124 = ($123|0)==($1|0);
   if ($124) {
    _error_expected($ls,262);
    // unreachable;
   } else {
    $125 = HEAP32[$ls$idx1>>2]|0;
    $126 = (_luaX_token2str($ls,262)|0);
    $127 = (_luaX_token2str($ls,259)|0);
    HEAP32[$vararg_buffer16>>2] = $126;
    $vararg_ptr19 = ((($vararg_buffer16)) + 4|0);
    HEAP32[$vararg_ptr19>>2] = $127;
    $vararg_ptr20 = ((($vararg_buffer16)) + 8|0);
    HEAP32[$vararg_ptr20>>2] = $1;
    $128 = (_luaO_pushfstring($125,2272,$vararg_buffer16)|0);
    _luaX_syntaxerror($ls,$128);
    // unreachable;
   }
   break;
  }
  case 266: case 258:  {
   $449 = (_luaK_jump($ls$idx$val)|0);
   _gotostat($ls,$449);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
   break;
  }
  default: {
   $450 = ((($v$i59)) + 8|0);
   _suffixedexp($ls,$450);
   $451 = HEAP32[$18>>2]|0;
   do {
    if ((($451|0) == 44) | (($451|0) == 61)) {
     HEAP32[$v$i59>>2] = 0;
     _assignment($ls,$v$i59,1);
    } else {
     $452 = HEAP32[$450>>2]|0;
     $453 = ($452|0)==(13);
     if ($453) {
      $454 = ((($v$i59)) + 16|0);
      $455 = HEAP32[$454>>2]|0;
      $456 = HEAP32[$ls$idx$val>>2]|0;
      $457 = ((($456)) + 48|0);
      $458 = HEAP32[$457>>2]|0;
      $459 = (($458) + ($455<<2)|0);
      $460 = HEAP32[$459>>2]|0;
      $461 = $460 & -8372225;
      $462 = $461 | 16384;
      HEAP32[$459>>2] = $462;
      break;
     } else {
      _luaX_syntaxerror($ls,2472);
      // unreachable;
     }
    }
   } while(0);
   $463 = HEAP32[$ls$idx>>2]|0;
   $464 = ((($463)) + 42|0);
   $465 = HEAP8[$464>>0]|0;
   $466 = ((($463)) + 44|0);
   HEAP8[$466>>0] = $465;
   $467 = HEAP32[$ls$idx1>>2]|0;
   $468 = ((($467)) + 106|0);
   $469 = HEAP16[$468>>1]|0;
   $470 = (($469) + -1)<<16>>16;
   HEAP16[$468>>1] = $470;
   STACKTOP = sp;return;
  }
  }
 } while(0);
}
function _error_expected($ls,$token) {
 $ls = $ls|0;
 $token = $token|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaX_token2str($ls,$token)|0);
 HEAP32[$vararg_buffer>>2] = $2;
 $3 = (_luaO_pushfstring($1,2168,$vararg_buffer)|0);
 _luaX_syntaxerror($ls,$3);
 // unreachable;
}
function _close_func($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$3>>2]|0;
 _luaK_ret($3,0,0);
 _leaveblock($3);
 $5 = ((($3)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>(1073741823);
 if ($8) {
  _luaM_toobig($1);
  // unreachable;
 }
 $9 = ((($4)) + 48|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ((($4)) + 20|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = $12 << 2;
 $14 = $6 << 2;
 $15 = (_luaM_realloc_($1,$10,$13,$14)|0);
 HEAP32[$9>>2] = $15;
 $16 = HEAP32[$5>>2]|0;
 HEAP32[$11>>2] = $16;
 $17 = (($16) + 1)|0;
 $18 = ($17>>>0)>(1073741823);
 if ($18) {
  _luaM_toobig($1);
  // unreachable;
 }
 $19 = ((($4)) + 56|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = ((($4)) + 24|0);
 $22 = HEAP32[$21>>2]|0;
 $23 = $22 << 2;
 $24 = $16 << 2;
 $25 = (_luaM_realloc_($1,$20,$23,$24)|0);
 HEAP32[$19>>2] = $25;
 $26 = HEAP32[$5>>2]|0;
 HEAP32[$21>>2] = $26;
 $27 = ((($3)) + 28|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = (($28) + 1)|0;
 $30 = ($29>>>0)>(268435455);
 if ($30) {
  _luaM_toobig($1);
  // unreachable;
 }
 $31 = ((($4)) + 44|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = ((($4)) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = $34 << 4;
 $36 = $28 << 4;
 $37 = (_luaM_realloc_($1,$32,$35,$36)|0);
 HEAP32[$31>>2] = $37;
 $38 = HEAP32[$27>>2]|0;
 HEAP32[$33>>2] = $38;
 $39 = ((($3)) + 32|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + 1)|0;
 $42 = ($41>>>0)>(1073741823);
 if ($42) {
  _luaM_toobig($1);
  // unreachable;
 }
 $43 = ((($4)) + 52|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($4)) + 28|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = $46 << 2;
 $48 = $40 << 2;
 $49 = (_luaM_realloc_($1,$44,$47,$48)|0);
 HEAP32[$43>>2] = $49;
 $50 = HEAP32[$39>>2]|0;
 HEAP32[$45>>2] = $50;
 $51 = ((($4)) + 60|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($4)) + 32|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ($54*12)|0;
 $56 = ((($3)) + 40|0);
 $57 = HEAP16[$56>>1]|0;
 $58 = $57 << 16 >> 16;
 $59 = ($58*12)|0;
 $60 = (_luaM_realloc_($1,$52,$55,$59)|0);
 HEAP32[$51>>2] = $60;
 $61 = HEAP16[$56>>1]|0;
 $62 = $61 << 16 >> 16;
 HEAP32[$53>>2] = $62;
 $63 = ((($4)) + 64|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ((($4)) + 12|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $66 << 3;
 $68 = ((($3)) + 43|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = $70 << 3;
 $72 = (_luaM_realloc_($1,$64,$67,$71)|0);
 HEAP32[$63>>2] = $72;
 $73 = HEAP8[$68>>0]|0;
 $74 = $73&255;
 HEAP32[$65>>2] = $74;
 $75 = ((($3)) + 4|0);
 $76 = HEAP32[$75>>2]|0;
 HEAP32[$2>>2] = $76;
 $77 = ((($1)) + 12|0);
 $78 = HEAP32[$77>>2]|0;
 $79 = ((($78)) + 12|0);
 $80 = HEAP32[$79>>2]|0;
 $81 = ($80|0)>(0);
 if (!($81)) {
  return;
 }
 _luaC_step($1);
 return;
}
function _leaveblock($fs) {
 $fs = $fs|0;
 var $$0$i$i = 0, $$i$0$i = 0, $$lcssa = 0, $$lcssa33 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i2 = 0, $$pre4$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$val$idx$val$idx$val$i = 0, $fs$idx2$i = 0, $fs$idx2$val$i = 0, $i$0$ph1$i$i = 0, $i$03$i = 0, $i$04$i$i = 0, $i$04$i$i$lcssa = 0, $indvars$iv = 0, $indvars$iv$next = 0, $phitmp$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($fs)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $6 = ((($1)) + 13|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = ($7<<24>>24)==(0);
  if (!($8)) {
   $9 = (_luaK_jump($fs)|0);
   $10 = ((($1)) + 12|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = $11&255;
   _luaK_patchclose($fs,$9,$12);
   _luaK_patchtohere($fs,$9);
  }
 }
 $13 = ((($1)) + 14|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = ($14<<24>>24)==(0);
 L5: do {
  if (!($15)) {
   $16 = ((($3)) + 52|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = (_luaS_new($17,5712)|0);
   $19 = ((($3)) + 68|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ((($20)) + 24|0);
   $22 = ((($3)) + 48|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($23)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = ((($20)) + 28|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = (($27) + 1)|0;
   $29 = ((($20)) + 32|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($27|0)<($30|0);
   if ($31) {
    $$pre$i$i = HEAP32[$21>>2]|0;
    $36 = $$pre$i$i;$39 = $23;$44 = $20;
   } else {
    $32 = HEAP32[$16>>2]|0;
    $33 = HEAP32[$21>>2]|0;
    $34 = (_luaM_growaux_($32,$33,$29,16,32767,2008)|0);
    HEAP32[$21>>2] = $34;
    $$pre$i = HEAP32[$22>>2]|0;
    $$pre4$i = HEAP32[$19>>2]|0;
    $36 = $34;$39 = $$pre$i;$44 = $$pre4$i;
   }
   $35 = (($36) + ($27<<4)|0);
   HEAP32[$35>>2] = $18;
   $37 = (((($36) + ($27<<4)|0)) + 8|0);
   HEAP32[$37>>2] = 0;
   $38 = ((($39)) + 42|0);
   $40 = HEAP8[$38>>0]|0;
   $41 = (((($36) + ($27<<4)|0)) + 12|0);
   HEAP8[$41>>0] = $40;
   $42 = (((($36) + ($27<<4)|0)) + 4|0);
   HEAP32[$42>>2] = $25;
   HEAP32[$26>>2] = $28;
   $43 = ((($44)) + 24|0);
   $45 = HEAP32[$43>>2]|0;
   $46 = (($45) + ($27<<4)|0);
   $47 = ((($39)) + 12|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + 8|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($44)) + 16|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ($50|0)<($52|0);
   if ($53) {
    $54 = ((($44)) + 12|0);
    $169 = $52;$i$0$ph1$i$i = $50;
    while(1) {
     $170 = $169;
     while(1) {
      $55 = HEAP32[$54>>2]|0;
      $56 = (($55) + ($i$0$ph1$i$i<<4)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = HEAP32[$46>>2]|0;
      $59 = ($57|0)==($58|0);
      if (!($59)) {
       $$lcssa33 = $170;
       break;
      }
      _closegoto($3,$i$0$ph1$i$i,$46);
      $60 = HEAP32[$51>>2]|0;
      $61 = ($i$0$ph1$i$i|0)<($60|0);
      if ($61) {
       $170 = $60;
      } else {
       break L5;
      }
     }
     $62 = (($i$0$ph1$i$i) + 1)|0;
     $63 = ($62|0)<($$lcssa33|0);
     if ($63) {
      $169 = $$lcssa33;$i$0$ph1$i$i = $62;
     } else {
      break;
     }
    }
   }
  }
 } while(0);
 $64 = HEAP32[$1>>2]|0;
 HEAP32[$0>>2] = $64;
 $65 = ((($1)) + 12|0);
 $66 = HEAP8[$65>>0]|0;
 $67 = $66&255;
 $68 = ((($fs)) + 42|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = HEAP32[$2>>2]|0;
 $72 = ((($71)) + 68|0);
 $73 = HEAP32[$72>>2]|0;
 $74 = ((($73)) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 $76 = (($67) - ($70))|0;
 $77 = (($76) + ($75))|0;
 HEAP32[$74>>2] = $77;
 $78 = ($66&255)<($69&255);
 if ($78) {
  $79 = ((($fs)) + 16|0);
  $80 = HEAP32[$79>>2]|0;
  $fs$idx$val$i = HEAP32[$fs>>2]|0;
  $fs$idx2$i = ((($fs)) + 36|0);
  $fs$idx2$val$i = HEAP32[$fs$idx2$i>>2]|0;
  $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 60|0);
  $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
  $fs$idx1$val$idx$val$idx$val$i = HEAP32[$73>>2]|0;
  $indvars$iv = $70;
  while(1) {
   $81 = $indvars$iv&255;
   $82 = (($81) + -1)<<24>>24;
   $83 = $82&255;
   $84 = (($83) + ($fs$idx2$val$i))|0;
   $85 = (($fs$idx1$val$idx$val$idx$val$i) + ($84<<1)|0);
   $86 = HEAP16[$85>>1]|0;
   $87 = $86 << 16 >> 16;
   $88 = (((($fs$idx$val$idx$val$i) + (($87*12)|0)|0)) + 8|0);
   HEAP32[$88>>2] = $80;
   $89 = ($82&255)>($66&255);
   $indvars$iv$next = (($indvars$iv) + -1)|0;
   if ($89) {
    $indvars$iv = $indvars$iv$next;
   } else {
    break;
   }
  }
  HEAP8[$68>>0] = $66;
  $91 = $66;
 } else {
  $91 = $69;
 }
 $90 = ((($fs)) + 44|0);
 HEAP8[$90>>0] = $91;
 $92 = ((($1)) + 4|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($3)) + 68|0);
 $95 = HEAP32[$94>>2]|0;
 $96 = ((($95)) + 28|0);
 HEAP32[$96>>2] = $93;
 $97 = ($64|0)==(0);
 $98 = ((($1)) + 8|0);
 $99 = HEAP32[$98>>2]|0;
 if ($97) {
  $149 = ((($95)) + 16|0);
  $150 = HEAP32[$149>>2]|0;
  $151 = ($99|0)<($150|0);
  if (!($151)) {
   STACKTOP = sp;return;
  }
  $152 = ((($95)) + 12|0);
  $153 = HEAP32[$152>>2]|0;
  $154 = (($153) + ($99<<4)|0);
  $155 = HEAP32[$154>>2]|0;
  $156 = ((($155)) + 4|0);
  $157 = HEAP8[$156>>0]|0;
  $158 = ($157<<24>>24)==(4);
  if (!($158)) {
   $167 = 2064;
   $162 = ((($3)) + 52|0);
   $163 = HEAP32[$162>>2]|0;
   $164 = ((($155)) + 24|0);
   $165 = (((($153) + ($99<<4)|0)) + 8|0);
   $166 = HEAP32[$165>>2]|0;
   HEAP32[$vararg_buffer>>2] = $164;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $166;
   $168 = (_luaO_pushfstring($163,$167,$vararg_buffer)|0);
   _semerror($3,$168);
   // unreachable;
  }
  $159 = ((($155)) + 6|0);
  $160 = HEAP8[$159>>0]|0;
  $161 = ($160<<24>>24)!=(0);
  $phitmp$i = $161 ? 2024 : 2064;
  $167 = $phitmp$i;
  $162 = ((($3)) + 52|0);
  $163 = HEAP32[$162>>2]|0;
  $164 = ((($155)) + 24|0);
  $165 = (((($153) + ($99<<4)|0)) + 8|0);
  $166 = HEAP32[$165>>2]|0;
  HEAP32[$vararg_buffer>>2] = $164;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $166;
  $168 = (_luaO_pushfstring($163,$167,$vararg_buffer)|0);
  _semerror($3,$168);
  // unreachable;
 }
 $100 = ((($73)) + 16|0);
 $101 = HEAP32[$100>>2]|0;
 $102 = ($99|0)<($101|0);
 if (!($102)) {
  STACKTOP = sp;return;
 }
 $103 = ((($73)) + 12|0);
 $104 = ((($1)) + 13|0);
 $109 = $66;$i$03$i = $99;
 while(1) {
  $105 = HEAP32[$103>>2]|0;
  $106 = (((($105) + ($i$03$i<<4)|0)) + 12|0);
  $107 = HEAP8[$106>>0]|0;
  $108 = $109&255;
  $110 = ($107&255)>($109&255);
  if ($110) {
   $111 = HEAP8[$104>>0]|0;
   $112 = ($111<<24>>24)==(0);
   if ($112) {
    $115 = $109;
   } else {
    $113 = (((($105) + ($i$03$i<<4)|0)) + 4|0);
    $114 = HEAP32[$113>>2]|0;
    _luaK_patchclose($fs,$114,$108);
    $$pre$i2 = HEAP8[$65>>0]|0;
    $115 = $$pre$i2;
   }
   HEAP8[$106>>0] = $115;
  }
  $116 = HEAP32[$2>>2]|0;
  $117 = ((($116)) + 48|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = ((($118)) + 12|0);
  $120 = HEAP32[$119>>2]|0;
  $121 = ((($116)) + 68|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = ((($122)) + 12|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = ((($120)) + 4|0);
  $126 = HEAP32[$125>>2]|0;
  $127 = ((($122)) + 28|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = ($126|0)<($128|0);
  L46: do {
   if ($129) {
    $130 = ((($122)) + 24|0);
    $131 = HEAP32[$130>>2]|0;
    $132 = (($124) + ($i$03$i<<4)|0);
    $133 = HEAP32[$132>>2]|0;
    $i$04$i$i = $126;
    while(1) {
     $134 = (($131) + ($i$04$i$i<<4)|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($135|0)==($133|0);
     if ($136) {
      $$lcssa = $134;$i$04$i$i$lcssa = $i$04$i$i;
      break;
     }
     $145 = (($i$04$i$i) + 1)|0;
     $146 = ($145|0)<($128|0);
     if ($146) {
      $i$04$i$i = $145;
     } else {
      $$0$i$i = 1;
      break L46;
     }
    }
    $137 = (((($124) + ($i$03$i<<4)|0)) + 12|0);
    $138 = HEAP8[$137>>0]|0;
    $139 = (((($131) + ($i$04$i$i$lcssa<<4)|0)) + 12|0);
    $140 = HEAP8[$139>>0]|0;
    $141 = ($138&255)>($140&255);
    if ($141) {
     $142 = (((($124) + ($i$03$i<<4)|0)) + 4|0);
     $143 = HEAP32[$142>>2]|0;
     $144 = $140&255;
     _luaK_patchclose($118,$143,$144);
    }
    _closegoto($116,$i$03$i,$$lcssa);
    $$0$i$i = 0;
   } else {
    $$0$i$i = 1;
   }
  } while(0);
  $$i$0$i = (($$0$i$i) + ($i$03$i))|0;
  $147 = HEAP32[$100>>2]|0;
  $148 = ($$i$0$i|0)<($147|0);
  if (!($148)) {
   break;
  }
  $$pre = HEAP8[$65>>0]|0;
  $109 = $$pre;$i$03$i = $$i$0$i;
 }
 STACKTOP = sp;return;
}
function _closegoto($ls,$g,$label) {
 $ls = $ls|0;
 $g = $g|0;
 $label = $label|0;
 var $$idx$val = 0, $$idx$val$idx = 0, $$idx$val$idx$val = 0, $$idx1 = 0, $$idx1$val = 0, $$idx1$val$idx = 0, $$idx1$val$idx$val = 0, $$idx1$val$idx$val$idx$val = 0, $$idx2 = 0, $$idx2$val = 0, $$lcssa3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (((($5) + ($g<<4)|0)) + 12|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ((($label)) + 12|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($7&255)<($9&255);
 if ($10) {
  $11 = (($5) + ($g<<4)|0);
  $12 = $7&255;
  $$idx$val = HEAP32[$1>>2]|0;
  $$idx1 = ((($1)) + 8|0);
  $$idx1$val = HEAP32[$$idx1>>2]|0;
  $$idx2 = ((($1)) + 36|0);
  $$idx2$val = HEAP32[$$idx2>>2]|0;
  $$idx$val$idx = ((($$idx$val)) + 60|0);
  $$idx$val$idx$val = HEAP32[$$idx$val$idx>>2]|0;
  $$idx1$val$idx = ((($$idx1$val)) + 68|0);
  $$idx1$val$idx$val = HEAP32[$$idx1$val$idx>>2]|0;
  $$idx1$val$idx$val$idx$val = HEAP32[$$idx1$val$idx$val>>2]|0;
  $13 = (($$idx2$val) + ($12))|0;
  $14 = (($$idx1$val$idx$val$idx$val) + ($13<<1)|0);
  $15 = HEAP16[$14>>1]|0;
  $16 = $15 << 16 >> 16;
  $17 = (($$idx$val$idx$val) + (($16*12)|0)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ((($ls)) + 52|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = HEAP32[$11>>2]|0;
  $22 = ((($21)) + 24|0);
  $23 = (((($5) + ($g<<4)|0)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ((($18)) + 24|0);
  HEAP32[$vararg_buffer>>2] = $22;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $24;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $25;
  $26 = (_luaO_pushfstring($20,2112,$vararg_buffer)|0);
  _semerror($ls,$26);
  // unreachable;
 }
 $27 = (((($5) + ($g<<4)|0)) + 4|0);
 $28 = HEAP32[$27>>2]|0;
 $29 = ((($label)) + 4|0);
 $30 = HEAP32[$29>>2]|0;
 _luaK_patchlist($1,$28,$30);
 $31 = ((($3)) + 16|0);
 $32 = HEAP32[$31>>2]|0;
 $33 = (($32) + -1)|0;
 $34 = ($33|0)>($g|0);
 if ($34) {
  $i$04 = $g;
 } else {
  $$lcssa3 = $33;
  HEAP32[$31>>2] = $$lcssa3;
  STACKTOP = sp;return;
 }
 while(1) {
  $35 = HEAP32[$4>>2]|0;
  $36 = (($35) + ($i$04<<4)|0);
  $37 = (($i$04) + 1)|0;
  $38 = (($35) + ($37<<4)|0);
  ;HEAP32[$36>>2]=HEAP32[$38>>2]|0;HEAP32[$36+4>>2]=HEAP32[$38+4>>2]|0;HEAP32[$36+8>>2]=HEAP32[$38+8>>2]|0;HEAP32[$36+12>>2]=HEAP32[$38+12>>2]|0;
  $39 = HEAP32[$31>>2]|0;
  $40 = (($39) + -1)|0;
  $41 = ($37|0)<($40|0);
  if ($41) {
   $i$04 = $37;
  } else {
   $$lcssa3 = $40;
   break;
  }
 }
 HEAP32[$31>>2] = $$lcssa3;
 STACKTOP = sp;return;
}
function _semerror($ls,$msg) {
 $ls = $ls|0;
 $msg = $msg|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 HEAP32[$0>>2] = 0;
 _luaX_syntaxerror($ls,$msg);
 // unreachable;
}
function _test_then_block($ls,$escapelist) {
 $ls = $ls|0;
 $escapelist = $escapelist|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $bl = 0, $jf$0 = 0, $ls$idx$val$i = 0, $switch = 0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl = sp + 24|0;
 $v = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 _luaX_next($ls);
 (_subexpr($ls,$v,0)|0);
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(275);
 if (!($4)) {
  _error_expected($ls,275);
  // unreachable;
 }
 _luaX_next($ls);
 $5 = HEAP32[$2>>2]|0;
 do {
  if ((($5|0) == 258) | (($5|0) == 266)) {
   $6 = HEAP32[$0>>2]|0;
   _luaK_goiffalse($6,$v);
   $7 = ((($bl)) + 14|0);
   HEAP8[$7>>0] = 0;
   $8 = ((($1)) + 42|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = ((($bl)) + 12|0);
   HEAP8[$10>>0] = $9;
   $11 = ((($1)) + 8|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ((($12)) + 68|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = ((($14)) + 28|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ((($bl)) + 4|0);
   HEAP32[$17>>2] = $16;
   $18 = ((($14)) + 16|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = ((($bl)) + 8|0);
   HEAP32[$20>>2] = $19;
   $21 = ((($bl)) + 13|0);
   HEAP8[$21>>0] = 0;
   $22 = ((($1)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   HEAP32[$bl>>2] = $23;
   HEAP32[$22>>2] = $bl;
   $24 = ((($v)) + 16|0);
   $25 = HEAP32[$24>>2]|0;
   _gotostat($ls,$25);
   L7: while(1) {
    $26 = HEAP32[$2>>2]|0;
    switch ($26|0) {
    case 288: case 59:  {
     break;
    }
    case 289: case 262: case 261: case 260:  {
     break L7;
     break;
    }
    default: {
     label = 8;
     break L7;
    }
    }
    _statement($ls);
   }
   if ((label|0) == 8) {
    $27 = (_luaK_jump($1)|0);
    $jf$0 = $27;
    break;
   }
   _leaveblock($1);
   STACKTOP = sp;return;
  } else {
   $28 = HEAP32[$0>>2]|0;
   _luaK_goiftrue($28,$v);
   $29 = ((($bl)) + 14|0);
   HEAP8[$29>>0] = 0;
   $30 = ((($1)) + 42|0);
   $31 = HEAP8[$30>>0]|0;
   $32 = ((($bl)) + 12|0);
   HEAP8[$32>>0] = $31;
   $33 = ((($1)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ((($34)) + 68|0);
   $36 = HEAP32[$35>>2]|0;
   $37 = ((($36)) + 28|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ((($bl)) + 4|0);
   HEAP32[$39>>2] = $38;
   $40 = ((($36)) + 16|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ((($bl)) + 8|0);
   HEAP32[$42>>2] = $41;
   $43 = ((($bl)) + 13|0);
   HEAP8[$43>>0] = 0;
   $44 = ((($1)) + 12|0);
   $45 = HEAP32[$44>>2]|0;
   HEAP32[$bl>>2] = $45;
   HEAP32[$44>>2] = $bl;
   $46 = ((($v)) + 20|0);
   $47 = HEAP32[$46>>2]|0;
   $jf$0 = $47;
  }
 } while(0);
 L15: while(1) {
  $ls$idx$val$i = HEAP32[$2>>2]|0;
  switch ($ls$idx$val$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   break L15;
   break;
  }
  default: {
  }
  }
  $48 = ($ls$idx$val$i|0)==(274);
  _statement($ls);
  if ($48) {
   break;
  }
 }
 _leaveblock($1);
 $49 = HEAP32[$2>>2]|0;
 $50 = $49 & -2;
 $switch = ($50|0)==(260);
 if ($switch) {
  $51 = (_luaK_jump($1)|0);
  _luaK_concat($1,$escapelist,$51);
 }
 _luaK_patchtohere($1,$jf$0);
 STACKTOP = sp;return;
}
function _subexpr($ls,$v,$limit) {
 $ls = $ls|0;
 $v = $v|0;
 $limit = $limit|0;
 var $$0$i2$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0.0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $ls$idx = 0, $ls$idx$val = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $op$0$lcssa = 0, $op$0$ph$ph = 0, $op$04 = 0, $v2 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 32|0;
 $vararg_buffer = sp + 24|0;
 $v2 = sp;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $0 = ((($ls$idx1$val)) + 106|0);
 $1 = HEAP16[$0>>1]|0;
 $2 = (($1) + 1)<<16>>16;
 HEAP16[$0>>1] = $2;
 $3 = ($2&65535)>(200);
 if ($3) {
  $4 = ((($ls$idx$val)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($5)) + 52|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = HEAP32[$ls$idx$val>>2]|0;
  $9 = ((($8)) + 36|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   $13 = 2208;
   HEAP32[$vararg_buffer1>>2] = 2256;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $13;
   $14 = (_luaO_pushfstring($7,2224,$vararg_buffer1)|0);
   $15 = HEAP32[$4>>2]|0;
   _luaX_syntaxerror($15,$14);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $10;
  $12 = (_luaO_pushfstring($7,2184,$vararg_buffer)|0);
  $13 = $12;
  HEAP32[$vararg_buffer1>>2] = 2256;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $13;
  $14 = (_luaO_pushfstring($7,2224,$vararg_buffer1)|0);
  $15 = HEAP32[$4>>2]|0;
  _luaX_syntaxerror($15,$14);
  // unreachable;
 }
 $16 = ((($ls)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 L8: do {
  switch ($17|0) {
  case 290:  {
   $21 = ((($v)) + 16|0);
   HEAP32[$21>>2] = -1;
   $22 = ((($v)) + 20|0);
   HEAP32[$22>>2] = -1;
   HEAP32[$v>>2] = 5;
   $23 = ((($v)) + 8|0);
   HEAP32[$23>>2] = 0;
   $24 = ((($ls)) + 24|0);
   $25 = +HEAPF64[$24>>3];
   $26 = ((($v)) + 8|0);
   HEAPF64[$26>>3] = $25;
   label = 22;
   break;
  }
  case 271:  {
   $$0$i2$ph = 2;
   label = 9;
   break;
  }
  case 35:  {
   $$0$i2$ph = 3;
   label = 9;
   break;
  }
  case 126:  {
   $$0$i2$ph = 1;
   label = 9;
   break;
  }
  case 291:  {
   $27 = ((($v)) + 16|0);
   HEAP32[$27>>2] = -1;
   $28 = ((($v)) + 20|0);
   HEAP32[$28>>2] = -1;
   HEAP32[$v>>2] = 6;
   $29 = ((($v)) + 8|0);
   HEAP32[$29>>2] = 0;
   $30 = ((($ls)) + 24|0);
   $31 = $30;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $29;
   $38 = $37;
   HEAP32[$38>>2] = $33;
   $39 = (($37) + 4)|0;
   $40 = $39;
   HEAP32[$40>>2] = $36;
   label = 22;
   break;
  }
  case 265:  {
   _luaX_next($ls);
   $64 = ((($ls)) + 4|0);
   $65 = HEAP32[$64>>2]|0;
   _body($ls,$v,0,$65);
   break;
  }
  case 263:  {
   $53 = ((($v)) + 16|0);
   HEAP32[$53>>2] = -1;
   $54 = ((($v)) + 20|0);
   HEAP32[$54>>2] = -1;
   HEAP32[$v>>2] = 3;
   $55 = ((($v)) + 8|0);
   HEAP32[$55>>2] = 0;
   label = 22;
   break;
  }
  case 270:  {
   $47 = ((($v)) + 16|0);
   HEAP32[$47>>2] = -1;
   $48 = ((($v)) + 20|0);
   HEAP32[$48>>2] = -1;
   HEAP32[$v>>2] = 1;
   $49 = ((($v)) + 8|0);
   HEAP32[$49>>2] = 0;
   label = 22;
   break;
  }
  case 281:  {
   $56 = HEAP32[$ls$idx$val>>2]|0;
   $57 = ((($56)) + 7|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = ($58<<24>>24)==(0);
   if ($59) {
    _luaX_syntaxerror($ls,2616);
    // unreachable;
   } else {
    $60 = (_luaK_codeABC($ls$idx$val,45,0,1,0)|0);
    $61 = ((($v)) + 16|0);
    HEAP32[$61>>2] = -1;
    $62 = ((($v)) + 20|0);
    HEAP32[$62>>2] = -1;
    HEAP32[$v>>2] = 14;
    $63 = ((($v)) + 8|0);
    HEAP32[$63>>2] = $60;
    label = 22;
    break L8;
   }
   break;
  }
  case 123:  {
   _constructor($ls,$v);
   break;
  }
  case 293:  {
   $41 = ((($ls)) + 24|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = (_luaK_stringK($ls$idx$val,$42)|0);
   $44 = ((($v)) + 16|0);
   HEAP32[$44>>2] = -1;
   $45 = ((($v)) + 20|0);
   HEAP32[$45>>2] = -1;
   HEAP32[$v>>2] = 4;
   $46 = ((($v)) + 8|0);
   HEAP32[$46>>2] = $43;
   label = 22;
   break;
  }
  case 276:  {
   $50 = ((($v)) + 16|0);
   HEAP32[$50>>2] = -1;
   $51 = ((($v)) + 20|0);
   HEAP32[$51>>2] = -1;
   HEAP32[$v>>2] = 2;
   $52 = ((($v)) + 8|0);
   HEAP32[$52>>2] = 0;
   label = 22;
   break;
  }
  case 45:  {
   $$0$i2$ph = 0;
   label = 9;
   break;
  }
  default: {
   _suffixedexp($ls,$v);
  }
  }
 } while(0);
 if ((label|0) == 9) {
  $18 = ((($ls)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  _luaX_next($ls);
  (_subexpr($ls,$v,12)|0);
  $20 = HEAP32[$ls$idx>>2]|0;
  _luaK_prefix($20,$$0$i2$ph,$v,$19);
 }
 else if ((label|0) == 22) {
  _luaX_next($ls);
 }
 $66 = HEAP32[$16>>2]|0;
 do {
  switch ($66|0) {
  case 284:  {
   $op$0$ph$ph = 15;
   break;
  }
  case 62:  {
   $op$0$ph$ph = 17;
   break;
  }
  case 283:  {
   $op$0$ph$ph = 18;
   break;
  }
  case 43:  {
   $op$0$ph$ph = 0;
   break;
  }
  case 126:  {
   $op$0$ph$ph = 9;
   break;
  }
  case 286:  {
   $op$0$ph$ph = 10;
   break;
  }
  case 285:  {
   $op$0$ph$ph = 16;
   break;
  }
  case 282:  {
   $op$0$ph$ph = 13;
   break;
  }
  case 60:  {
   $op$0$ph$ph = 14;
   break;
  }
  case 287:  {
   $op$0$ph$ph = 11;
   break;
  }
  case 280:  {
   $op$0$ph$ph = 12;
   break;
  }
  case 45:  {
   $op$0$ph$ph = 1;
   break;
  }
  case 42:  {
   $op$0$ph$ph = 2;
   break;
  }
  case 47:  {
   $op$0$ph$ph = 5;
   break;
  }
  case 279:  {
   $op$0$ph$ph = 6;
   break;
  }
  case 37:  {
   $op$0$ph$ph = 3;
   break;
  }
  case 94:  {
   $op$0$ph$ph = 4;
   break;
  }
  case 257:  {
   $op$0$ph$ph = 19;
   break;
  }
  case 272:  {
   $op$0$ph$ph = 20;
   break;
  }
  case 38:  {
   $op$0$ph$ph = 7;
   break;
  }
  case 124:  {
   $op$0$ph$ph = 8;
   break;
  }
  default: {
   $op$0$lcssa = 21;
   $80 = HEAP32[$ls$idx1>>2]|0;
   $81 = ((($80)) + 106|0);
   $82 = HEAP16[$81>>1]|0;
   $83 = (($82) + -1)<<16>>16;
   HEAP16[$81>>1] = $83;
   STACKTOP = sp;return ($op$0$lcssa|0);
  }
  }
 } while(0);
 $67 = ((($ls)) + 4|0);
 $op$04 = $op$0$ph$ph;
 while(1) {
  $68 = (2664 + ($op$04<<1)|0);
  $69 = HEAP8[$68>>0]|0;
  $70 = $69&255;
  $71 = ($70|0)>($limit|0);
  if (!($71)) {
   $op$0$lcssa = $op$04;
   label = 47;
   break;
  }
  $72 = HEAP32[$67>>2]|0;
  _luaX_next($ls);
  $73 = HEAP32[$ls$idx>>2]|0;
  _luaK_infix($73,$op$04,$v);
  $74 = (((2664 + ($op$04<<1)|0)) + 1|0);
  $75 = HEAP8[$74>>0]|0;
  $76 = $75&255;
  $77 = (_subexpr($ls,$v2,$76)|0);
  $78 = HEAP32[$ls$idx>>2]|0;
  _luaK_posfix($78,$op$04,$v,$v2,$72);
  $79 = ($77|0)==(21);
  if ($79) {
   $op$0$lcssa = 21;
   label = 47;
   break;
  } else {
   $op$04 = $77;
  }
 }
 if ((label|0) == 47) {
  $80 = HEAP32[$ls$idx1>>2]|0;
  $81 = ((($80)) + 106|0);
  $82 = HEAP16[$81>>1]|0;
  $83 = (($82) + -1)<<16>>16;
  HEAP16[$81>>1] = $83;
  STACKTOP = sp;return ($op$0$lcssa|0);
 }
 return (0)|0;
}
function _new_localvar($ls,$name) {
 $ls = $ls|0;
 $name = $name|0;
 var $$phi$trans$insert = 0, $$pre = 0, $$pre$i = 0, $$pre1 = 0, $$pre3 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $oldsize$01$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 68|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$1>>2]|0;
 $5 = ((($4)) + 32|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($1)) + 40|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = $8 << 16 >> 16;
 $10 = ($9|0)<($6|0);
 if ($10) {
  $$phi$trans$insert = ((($4)) + 60|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $17 = $6;$20 = $$pre;
 } else {
  $11 = ((($ls)) + 52|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ((($4)) + 60|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_luaM_growaux_($12,$14,$5,12,32767,2600)|0);
  HEAP32[$13>>2] = $15;
  $$pre$i = HEAP32[$5>>2]|0;
  $17 = $$pre$i;$20 = $15;
 }
 $16 = ($6|0)<($17|0);
 if ($16) {
  $oldsize$01$i = $6;
  while(1) {
   $18 = (($oldsize$01$i) + 1)|0;
   $19 = (($20) + (($oldsize$01$i*12)|0)|0);
   HEAP32[$19>>2] = 0;
   $exitcond = ($18|0)==($17|0);
   if ($exitcond) {
    break;
   } else {
    $oldsize$01$i = $18;
   }
  }
 }
 $21 = HEAP16[$7>>1]|0;
 $22 = $21 << 16 >> 16;
 $23 = (($20) + (($22*12)|0)|0);
 HEAP32[$23>>2] = $name;
 $24 = ((($4)) + 5|0);
 $25 = HEAP8[$24>>0]|0;
 $26 = $25 & 4;
 $27 = ($26<<24>>24)==(0);
 if ($27) {
  $35 = $21;
 } else {
  $28 = ((($name)) + 5|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29 & 3;
  $31 = ($30<<24>>24)==(0);
  if ($31) {
   $35 = $21;
  } else {
   $32 = ((($ls)) + 52|0);
   $33 = HEAP32[$32>>2]|0;
   _luaC_barrier_($33,$4,$name);
   $$pre3$i = HEAP16[$7>>1]|0;
   $35 = $$pre3$i;
  }
 }
 $34 = (($35) + 1)<<16>>16;
 HEAP16[$7>>1] = $34;
 $36 = ((($3)) + 4|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = (($37) + 1)|0;
 $39 = ((($1)) + 36|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($38) - ($40))|0;
 $42 = ($41|0)>(200);
 if ($42) {
  $43 = ((($1)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ((($44)) + 52|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = HEAP32[$1>>2]|0;
  $48 = ((($47)) + 36|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==(0);
  if ($50) {
   $52 = 2208;
   HEAP32[$vararg_buffer1>>2] = 2600;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $52;
   $53 = (_luaO_pushfstring($46,2224,$vararg_buffer1)|0);
   $54 = HEAP32[$43>>2]|0;
   _luaX_syntaxerror($54,$53);
   // unreachable;
  }
  HEAP32[$vararg_buffer>>2] = $49;
  $51 = (_luaO_pushfstring($46,2184,$vararg_buffer)|0);
  $52 = $51;
  HEAP32[$vararg_buffer1>>2] = 2600;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = 200;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $52;
  $53 = (_luaO_pushfstring($46,2224,$vararg_buffer1)|0);
  $54 = HEAP32[$43>>2]|0;
  _luaX_syntaxerror($54,$53);
  // unreachable;
 }
 $55 = (($37) + 2)|0;
 $56 = ((($3)) + 8|0);
 $57 = HEAP32[$56>>2]|0;
 $58 = ($55|0)>($57|0);
 if ($58) {
  $59 = ((($ls)) + 52|0);
  $60 = HEAP32[$59>>2]|0;
  $61 = HEAP32[$3>>2]|0;
  $62 = (_luaM_growaux_($60,$61,$56,2,2147483647,2600)|0);
  HEAP32[$3>>2] = $62;
  $$pre1 = HEAP32[$36>>2]|0;
  $64 = $$pre1;$66 = $62;
  $63 = (($64) + 1)|0;
  HEAP32[$36>>2] = $63;
  $65 = (($66) + ($64<<1)|0);
  HEAP16[$65>>1] = $35;
  STACKTOP = sp;return;
 } else {
  $$pre3 = HEAP32[$3>>2]|0;
  $64 = $37;$66 = $$pre3;
  $63 = (($64) + 1)|0;
  HEAP32[$36>>2] = $63;
  $65 = (($66) + ($64<<1)|0);
  HEAP16[$65>>1] = $35;
  STACKTOP = sp;return;
 }
}
function _forbody($ls,$base,$line,$nvars,$isnum) {
 $ls = $ls|0;
 $base = $base|0;
 $line = $line|0;
 $nvars = $nvars|0;
 $isnum = $isnum|0;
 var $$01$i14 = 0, $$idx$val$i = 0, $$idx$val$i3 = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i8 = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i9 = 0, $$idx1$i = 0, $$idx1$i4 = 0, $$idx1$val$i = 0, $$idx1$val$i5 = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i10 = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i11 = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i13 = 0, $$idx2$i = 0, $$idx2$i6 = 0, $$idx2$val$i = 0;
 var $$idx2$val$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $bl = 0, $bl$i = 0, $endfor$0 = 0, $ls$idx$val = 0, $ls$idx$val$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $bl$i = sp + 16|0;
 $bl = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 42|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = (($4) + 3)|0;
 $6 = $5&255;
 HEAP8[$2>>0] = $6;
 $7 = ((($1)) + 16|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $5 & 255;
 $$idx$val$i = HEAP32[$1>>2]|0;
 $$idx1$i = ((($1)) + 8|0);
 $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
 $$idx2$i = ((($1)) + 36|0);
 $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
 $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
 $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
 $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
 $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
 $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
 $10 = (($$idx2$val$i) + ($9))|0;
 $11 = (($10) + -3)|0;
 $12 = (($$idx1$val$idx$val$idx$val$i) + ($11<<1)|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 << 16 >> 16;
 $15 = (((($$idx$val$idx$val$i) + (($14*12)|0)|0)) + 4|0);
 HEAP32[$15>>2] = $8;
 $16 = (($10) + -2)|0;
 $17 = (($$idx1$val$idx$val$idx$val$i) + ($16<<1)|0);
 $18 = HEAP16[$17>>1]|0;
 $19 = $18 << 16 >> 16;
 $20 = (((($$idx$val$idx$val$i) + (($19*12)|0)|0)) + 4|0);
 HEAP32[$20>>2] = $8;
 $21 = (($10) + -1)|0;
 $22 = (($$idx1$val$idx$val$idx$val$i) + ($21<<1)|0);
 $23 = HEAP16[$22>>1]|0;
 $24 = $23 << 16 >> 16;
 $25 = (((($$idx$val$idx$val$i) + (($24*12)|0)|0)) + 4|0);
 HEAP32[$25>>2] = $8;
 $26 = ((($ls)) + 16|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($27|0)==(259);
 if (!($28)) {
  _error_expected($ls,259);
  // unreachable;
 }
 _luaX_next($ls);
 $29 = ($isnum|0)!=(0);
 if ($29) {
  $30 = (_luaK_codeABx($1,40,$base,131070)|0);
  $83 = $30;
 } else {
  $31 = (_luaK_jump($1)|0);
  $83 = $31;
 }
 $32 = ((($bl)) + 14|0);
 HEAP8[$32>>0] = 0;
 $33 = HEAP8[$2>>0]|0;
 $34 = ((($bl)) + 12|0);
 HEAP8[$34>>0] = $33;
 $35 = HEAP32[$$idx1$i>>2]|0;
 $36 = ((($35)) + 68|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ((($37)) + 28|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($bl)) + 4|0);
 HEAP32[$40>>2] = $39;
 $41 = ((($37)) + 16|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($bl)) + 8|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($bl)) + 13|0);
 HEAP8[$44>>0] = 0;
 $45 = ((($1)) + 12|0);
 $46 = HEAP32[$45>>2]|0;
 HEAP32[$bl>>2] = $46;
 HEAP32[$45>>2] = $bl;
 $ls$idx$val = HEAP32[$0>>2]|0;
 $47 = ((($ls$idx$val)) + 42|0);
 $48 = HEAP8[$47>>0]|0;
 $49 = $48&255;
 $50 = (($49) + ($nvars))|0;
 $51 = $50&255;
 HEAP8[$47>>0] = $51;
 $52 = ($nvars|0)==(0);
 if (!($52)) {
  $53 = ((($ls$idx$val)) + 16|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = $50 & 255;
  $$idx$val$i3 = HEAP32[$ls$idx$val>>2]|0;
  $$idx1$i4 = ((($ls$idx$val)) + 8|0);
  $$idx1$val$i5 = HEAP32[$$idx1$i4>>2]|0;
  $$idx2$i6 = ((($ls$idx$val)) + 36|0);
  $$idx2$val$i7 = HEAP32[$$idx2$i6>>2]|0;
  $$idx$val$idx$i8 = ((($$idx$val$i3)) + 60|0);
  $$idx$val$idx$val$i9 = HEAP32[$$idx$val$idx$i8>>2]|0;
  $$idx1$val$idx$i10 = ((($$idx1$val$i5)) + 68|0);
  $$idx1$val$idx$val$i11 = HEAP32[$$idx1$val$idx$i10>>2]|0;
  $$idx1$val$idx$val$idx$val$i13 = HEAP32[$$idx1$val$idx$val$i11>>2]|0;
  $56 = (($$idx2$val$i7) + ($55))|0;
  $$01$i14 = $nvars;
  while(1) {
   $57 = (($56) - ($$01$i14))|0;
   $58 = (($$idx1$val$idx$val$idx$val$i13) + ($57<<1)|0);
   $59 = HEAP16[$58>>1]|0;
   $60 = $59 << 16 >> 16;
   $61 = (((($$idx$val$idx$val$i9) + (($60*12)|0)|0)) + 4|0);
   HEAP32[$61>>2] = $54;
   $62 = (($$01$i14) + -1)|0;
   $63 = ($62|0)==(0);
   if ($63) {
    break;
   } else {
    $$01$i14 = $62;
   }
  }
 }
 _luaK_reserveregs($1,$nvars);
 $64 = HEAP32[$0>>2]|0;
 $65 = ((($bl$i)) + 14|0);
 HEAP8[$65>>0] = 0;
 $66 = ((($64)) + 42|0);
 $67 = HEAP8[$66>>0]|0;
 $68 = ((($bl$i)) + 12|0);
 HEAP8[$68>>0] = $67;
 $69 = ((($64)) + 8|0);
 $70 = HEAP32[$69>>2]|0;
 $71 = ((($70)) + 68|0);
 $72 = HEAP32[$71>>2]|0;
 $73 = ((($72)) + 28|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($bl$i)) + 4|0);
 HEAP32[$75>>2] = $74;
 $76 = ((($72)) + 16|0);
 $77 = HEAP32[$76>>2]|0;
 $78 = ((($bl$i)) + 8|0);
 HEAP32[$78>>2] = $77;
 $79 = ((($bl$i)) + 13|0);
 HEAP8[$79>>0] = 0;
 $80 = ((($64)) + 12|0);
 $81 = HEAP32[$80>>2]|0;
 HEAP32[$bl$i>>2] = $81;
 HEAP32[$80>>2] = $bl$i;
 L13: while(1) {
  $ls$idx$val$i$i = HEAP32[$26>>2]|0;
  switch ($ls$idx$val$i$i|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   break L13;
   break;
  }
  default: {
  }
  }
  $82 = ($ls$idx$val$i$i|0)==(274);
  _statement($ls);
  if ($82) {
   break;
  }
 }
 _leaveblock($64);
 _leaveblock($1);
 _luaK_patchtohere($1,$83);
 if ($29) {
  $84 = (_luaK_codeABx($1,39,$base,131070)|0);
  $endfor$0 = $84;
  $87 = (($83) + 1)|0;
  _luaK_patchlist($1,$endfor$0,$87);
  _luaK_fixline($1,$line);
  STACKTOP = sp;return;
 } else {
  (_luaK_codeABC($1,41,$base,0,$nvars)|0);
  _luaK_fixline($1,$line);
  $85 = (($base) + 2)|0;
  $86 = (_luaK_codeABx($1,42,$85,131070)|0);
  $endfor$0 = $86;
  $87 = (($83) + 1)|0;
  _luaK_patchlist($1,$endfor$0,$87);
  _luaK_fixline($1,$line);
  STACKTOP = sp;return;
 }
}
function _singlevaraux($fs,$n,$var,$base) {
 $fs = $fs|0;
 $n = $n|0;
 $var = $var|0;
 $base = $base|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $bl$0$i = 0, $bl$0$i$lcssa = 0, $bl$0$in$i = 0, $fs$idx$val$i = 0, $fs$idx$val$i$lcssa = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$i = 0, $fs$idx1$val$i = 0, $fs$idx1$val$idx$i = 0, $fs$idx1$val$idx$val$i = 0, $fs$idx1$val$idx$val$idx$val$i = 0, $fs$idx2$i = 0, $fs$idx2$val$i = 0, $i$0$i = 0, $i$0$i$lcssa18 = 0, $i$0$in$i = 0;
 var $i$01$i = 0, $i$01$i$lcssa = 0, $idx$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($fs|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = ((($fs)) + 42|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = $2&255;
 $fs$idx1$i = ((($fs)) + 8|0);
 $fs$idx2$i = ((($fs)) + 36|0);
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 60|0);
 $i$0$in$i = $3;
 while(1) {
  $i$0$i = (($i$0$in$i) + -1)|0;
  $4 = ($i$0$in$i|0)>(0);
  if (!($4)) {
   $fs$idx$val$i$lcssa = $fs$idx$val$i;
   break;
  }
  $fs$idx1$val$i = HEAP32[$fs$idx1$i>>2]|0;
  $fs$idx2$val$i = HEAP32[$fs$idx2$i>>2]|0;
  $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
  $fs$idx1$val$idx$i = ((($fs$idx1$val$i)) + 68|0);
  $fs$idx1$val$idx$val$i = HEAP32[$fs$idx1$val$idx$i>>2]|0;
  $fs$idx1$val$idx$val$idx$val$i = HEAP32[$fs$idx1$val$idx$val$i>>2]|0;
  $5 = (($fs$idx2$val$i) + ($i$0$i))|0;
  $6 = (($fs$idx1$val$idx$val$idx$val$i) + ($5<<1)|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7 << 16 >> 16;
  $9 = (($fs$idx$val$idx$val$i) + (($8*12)|0)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==($n|0);
  if ($11) {
   $i$0$i$lcssa18 = $i$0$i;
   label = 5;
   break;
  } else {
   $i$0$in$i = $i$0$i;
  }
 }
 if ((label|0) == 5) {
  $12 = ((($var)) + 16|0);
  HEAP32[$12>>2] = -1;
  $13 = ((($var)) + 20|0);
  HEAP32[$13>>2] = -1;
  HEAP32[$var>>2] = 8;
  $14 = ((($var)) + 8|0);
  HEAP32[$14>>2] = $i$0$i$lcssa18;
  $15 = ($base|0)==(0);
  if (!($15)) {
   $$0 = 8;
   return ($$0|0);
  }
  $16 = ((($fs)) + 12|0);
  $bl$0$in$i = $16;
  while(1) {
   $bl$0$i = HEAP32[$bl$0$in$i>>2]|0;
   $17 = ((($bl$0$i)) + 12|0);
   $18 = HEAP8[$17>>0]|0;
   $19 = $18&255;
   $20 = ($19|0)>($i$0$i$lcssa18|0);
   if ($20) {
    $bl$0$in$i = $bl$0$i;
   } else {
    $bl$0$i$lcssa = $bl$0$i;
    break;
   }
  }
  $21 = ((($bl$0$i$lcssa)) + 13|0);
  HEAP8[$21>>0] = 1;
  $$0 = 8;
  return ($$0|0);
 }
 $$phi$trans$insert = ((($fs$idx$val$i$lcssa)) + 64|0);
 $$pre8 = HEAP32[$$phi$trans$insert>>2]|0;
 $22 = ((($fs)) + 43|0);
 $23 = HEAP8[$22>>0]|0;
 $24 = ($23<<24>>24)==(0);
 L17: do {
  if ($24) {
   label = 14;
  } else {
   $25 = $23&255;
   $i$01$i = 0;
   while(1) {
    $26 = (($$pre8) + ($i$01$i<<3)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==($n|0);
    if ($28) {
     $i$01$i$lcssa = $i$01$i;
     break;
    }
    $29 = (($i$01$i) + 1)|0;
    $30 = ($29|0)<($25|0);
    if ($30) {
     $i$01$i = $29;
    } else {
     label = 14;
     break L17;
    }
   }
   $31 = ($i$01$i$lcssa|0)<(0);
   if ($31) {
    label = 14;
   } else {
    $idx$0 = $i$01$i$lcssa;
   }
  }
 } while(0);
 do {
  if ((label|0) == 14) {
   $32 = ((($fs)) + 4|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = (_singlevaraux($33,$n,$var,0)|0);
   $35 = ($34|0)==(0);
   if ($35) {
    $$0 = 0;
    return ($$0|0);
   } else {
    $36 = (_newupvalue($fs,$n,$var)|0);
    $idx$0 = $36;
    break;
   }
  }
 } while(0);
 $37 = ((($var)) + 16|0);
 HEAP32[$37>>2] = -1;
 $38 = ((($var)) + 20|0);
 HEAP32[$38>>2] = -1;
 HEAP32[$var>>2] = 9;
 $39 = ((($var)) + 8|0);
 HEAP32[$39>>2] = $idx$0;
 $$0 = 9;
 return ($$0|0);
}
function _fieldsel($ls,$v) {
 $ls = $ls|0;
 $v = $v|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $key = 0, $ls$idx$val$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $key = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 _luaK_exp2anyregup($1,$v);
 _luaX_next($ls);
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(292);
 if ($4) {
  $5 = ((($ls)) + 24|0);
  $6 = HEAP32[$5>>2]|0;
  _luaX_next($ls);
  $ls$idx$val$i = HEAP32[$0>>2]|0;
  $7 = (_luaK_stringK($ls$idx$val$i,$6)|0);
  $8 = ((($key)) + 16|0);
  HEAP32[$8>>2] = -1;
  $9 = ((($key)) + 20|0);
  HEAP32[$9>>2] = -1;
  HEAP32[$key>>2] = 4;
  $10 = ((($key)) + 8|0);
  HEAP32[$10>>2] = $7;
  _luaK_indexed($1,$v,$key);
  STACKTOP = sp;return;
 } else {
  _error_expected($ls,292);
  // unreachable;
 }
}
function _body($ls,$e,$ismethod,$line) {
 $ls = $ls|0;
 $e = $e|0;
 $ismethod = $ismethod|0;
 $line = $line|0;
 var $$01$i$i = 0, $$idx$val$i = 0, $$idx$val$i$i = 0, $$idx$val$idx$i = 0, $$idx$val$idx$i$i = 0, $$idx$val$idx$val$i = 0, $$idx$val$idx$val$i$i = 0, $$idx1$i = 0, $$idx1$i$i = 0, $$idx1$val$i = 0, $$idx1$val$i$i = 0, $$idx1$val$idx$i = 0, $$idx1$val$idx$i$i = 0, $$idx1$val$idx$val$i = 0, $$idx1$val$idx$val$i$i = 0, $$idx1$val$idx$val$idx$val$i = 0, $$idx1$val$idx$val$idx$val$i$i = 0, $$idx2$i = 0, $$idx2$i$i = 0, $$idx2$val$i = 0;
 var $$idx2$val$i$i = 0, $$pr$i = 0, $$pr1$i = 0, $$pre = 0, $$pre$i = 0, $$pre14 = 0, $$pre15 = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $bl = 0;
 var $exitcond = 0, $ls$idx = 0, $ls$idx$val = 0, $ls$idx$val$i = 0, $ls$idx$val$i7 = 0, $ls$idx1 = 0, $ls$idx1$val = 0, $ls$idx2$val = 0, $ls$idx3$val = 0, $ls$idx3$val$idx = 0, $ls$idx3$val$idx$val = 0, $new_fs = 0, $nparams$0$i = 0, $nparams$0$i$lcssa26 = 0, $nparams$2$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $new_fs = sp + 32|0;
 $bl = sp + 16|0;
 $ls$idx = ((($ls)) + 48|0);
 $ls$idx$val = HEAP32[$ls$idx>>2]|0;
 $ls$idx1 = ((($ls)) + 52|0);
 $ls$idx1$val = HEAP32[$ls$idx1>>2]|0;
 $0 = HEAP32[$ls$idx$val>>2]|0;
 $1 = ((($ls$idx$val)) + 32|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($0)) + 28|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)<($4|0);
 $$pre3$i = ((($0)) + 52|0);
 if (!($5)) {
  $6 = HEAP32[$$pre3$i>>2]|0;
  $7 = (_luaM_growaux_($ls$idx1$val,$6,$3,4,262143,2544)|0);
  HEAP32[$$pre3$i>>2] = $7;
  $8 = HEAP32[$3>>2]|0;
  $9 = ($4|0)<($8|0);
  if ($9) {
   $10 = (($4) + 1)|0;
   $11 = (($7) + ($4<<2)|0);
   HEAP32[$11>>2] = 0;
   $12 = ($10|0)<($8|0);
   if ($12) {
    $14 = $10;
    while(1) {
     $$pre$i = HEAP32[$$pre3$i>>2]|0;
     $13 = (($14) + 1)|0;
     $15 = (($$pre$i) + ($14<<2)|0);
     HEAP32[$15>>2] = 0;
     $exitcond = ($13|0)==($8|0);
     if ($exitcond) {
      break;
     } else {
      $14 = $13;
     }
    }
   }
  }
 }
 $16 = (_luaF_newproto($ls$idx1$val)|0);
 $17 = HEAP32[$1>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$1>>2] = $18;
 $19 = HEAP32[$$pre3$i>>2]|0;
 $20 = (($19) + ($17<<2)|0);
 HEAP32[$20>>2] = $16;
 $21 = ((($0)) + 5|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = $22 & 4;
 $24 = ($23<<24>>24)==(0);
 if (!($24)) {
  $25 = ((($16)) + 5|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = $26 & 3;
  $28 = ($27<<24>>24)==(0);
  if (!($28)) {
   _luaC_barrier_($ls$idx1$val,$0,$16);
  }
 }
 HEAP32[$new_fs>>2] = $16;
 $29 = ((($16)) + 36|0);
 HEAP32[$29>>2] = $line;
 $30 = HEAP32[$ls$idx>>2]|0;
 $31 = ((($new_fs)) + 4|0);
 HEAP32[$31>>2] = $30;
 $32 = ((($new_fs)) + 8|0);
 HEAP32[$32>>2] = $ls;
 HEAP32[$ls$idx>>2] = $new_fs;
 $33 = ((($new_fs)) + 16|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($new_fs)) + 20|0);
 HEAP32[$34>>2] = 0;
 $35 = ((($new_fs)) + 24|0);
 HEAP32[$35>>2] = -1;
 $36 = ((($new_fs)) + 28|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($new_fs)) + 32|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($new_fs)) + 40|0);
 $39 = ((($ls)) + 68|0);
 ;HEAP32[$38>>2]=0|0;HEAP8[$38+4>>0]=0|0;
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($40)) + 4|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($new_fs)) + 36|0);
 HEAP32[$43>>2] = $42;
 $44 = ((($new_fs)) + 12|0);
 $45 = ((($ls)) + 72|0);
 $46 = HEAP32[$45>>2]|0;
 $47 = ((($16)) + 72|0);
 HEAP32[$47>>2] = $46;
 $48 = ((($16)) + 8|0);
 HEAP8[$48>>0] = 2;
 $49 = ((($bl)) + 14|0);
 HEAP8[$49>>0] = 0;
 $50 = ((($bl)) + 12|0);
 HEAP8[$50>>0] = 0;
 $51 = ((($40)) + 28|0);
 $52 = HEAP32[$51>>2]|0;
 $53 = ((($bl)) + 4|0);
 HEAP32[$53>>2] = $52;
 $54 = ((($40)) + 16|0);
 $55 = HEAP32[$54>>2]|0;
 $56 = ((($bl)) + 8|0);
 HEAP32[$56>>2] = $55;
 $57 = ((($bl)) + 13|0);
 HEAP8[$57>>0] = 0;
 HEAP32[$bl>>2] = 0;
 HEAP32[$44>>2] = $bl;
 $58 = ((($ls)) + 16|0);
 $59 = HEAP32[$58>>2]|0;
 $60 = ($59|0)==(40);
 if (!($60)) {
  _error_expected($ls,40);
  // unreachable;
 }
 _luaX_next($ls);
 $61 = ($ismethod|0)==(0);
 if ($61) {
  $$pre = HEAP32[$ls$idx>>2]|0;
  $$pre14 = HEAP32[$$pre>>2]|0;
  $105 = $$pre;$78 = $$pre14;
 } else {
  $62 = (_luaX_newstring($ls,2560,4)|0);
  _new_localvar($ls,$62);
  $ls$idx2$val = HEAP32[$ls$idx>>2]|0;
  $63 = ((($ls$idx2$val)) + 42|0);
  $64 = HEAP8[$63>>0]|0;
  $65 = $64&255;
  $66 = (($65) + 1)|0;
  $67 = $66&255;
  HEAP8[$63>>0] = $67;
  $68 = ((($ls$idx2$val)) + 16|0);
  $69 = HEAP32[$68>>2]|0;
  $70 = $66 & 255;
  $$idx$val$i = HEAP32[$ls$idx2$val>>2]|0;
  $$idx1$i = ((($ls$idx2$val)) + 8|0);
  $$idx1$val$i = HEAP32[$$idx1$i>>2]|0;
  $$idx2$i = ((($ls$idx2$val)) + 36|0);
  $$idx2$val$i = HEAP32[$$idx2$i>>2]|0;
  $$idx$val$idx$i = ((($$idx$val$i)) + 60|0);
  $$idx$val$idx$val$i = HEAP32[$$idx$val$idx$i>>2]|0;
  $$idx1$val$idx$i = ((($$idx1$val$i)) + 68|0);
  $$idx1$val$idx$val$i = HEAP32[$$idx1$val$idx$i>>2]|0;
  $$idx1$val$idx$val$idx$val$i = HEAP32[$$idx1$val$idx$val$i>>2]|0;
  $71 = (($$idx2$val$i) + ($70))|0;
  $72 = (($71) + -1)|0;
  $73 = (($$idx1$val$idx$val$idx$val$i) + ($72<<1)|0);
  $74 = HEAP16[$73>>1]|0;
  $75 = $74 << 16 >> 16;
  $76 = (((($$idx$val$idx$val$i) + (($75*12)|0)|0)) + 4|0);
  HEAP32[$76>>2] = $69;
  $105 = $ls$idx2$val;$78 = $$idx$val$i;
 }
 $77 = ((($78)) + 7|0);
 HEAP8[$77>>0] = 0;
 $79 = HEAP32[$58>>2]|0;
 $80 = ($79|0)==(41);
 L18: do {
  if ($80) {
   $nparams$2$i = 0;
  } else {
   $81 = ((($ls)) + 24|0);
   $130 = $79;$nparams$0$i = 0;
   while(1) {
    if ((($130|0) == 281)) {
     $nparams$0$i$lcssa26 = $nparams$0$i;
     label = 17;
     break;
    } else if (!((($130|0) == 292))) {
     label = 18;
     break;
    }
    $82 = HEAP32[$81>>2]|0;
    _luaX_next($ls);
    _new_localvar($ls,$82);
    $83 = (($nparams$0$i) + 1)|0;
    $$pr1$i = HEAP8[$77>>0]|0;
    $84 = ($$pr1$i<<24>>24)==(0);
    if (!($84)) {
     $nparams$2$i = $83;
     break L18;
    }
    $85 = HEAP32[$58>>2]|0;
    $86 = ($85|0)==(44);
    if (!($86)) {
     $nparams$2$i = $83;
     break L18;
    }
    _luaX_next($ls);
    $$pr$i = HEAP32[$58>>2]|0;
    $130 = $$pr$i;$nparams$0$i = $83;
   }
   if ((label|0) == 17) {
    _luaX_next($ls);
    HEAP8[$77>>0] = 1;
    $nparams$2$i = $nparams$0$i$lcssa26;
    break;
   }
   else if ((label|0) == 18) {
    _luaX_syntaxerror($ls,2568);
    // unreachable;
   }
  }
 } while(0);
 $ls$idx$val$i = HEAP32[$ls$idx>>2]|0;
 $87 = ((($ls$idx$val$i)) + 42|0);
 $88 = HEAP8[$87>>0]|0;
 $89 = $88&255;
 $90 = (($89) + ($nparams$2$i))|0;
 $91 = $90&255;
 HEAP8[$87>>0] = $91;
 $92 = ($nparams$2$i|0)==(0);
 if (!($92)) {
  $93 = ((($ls$idx$val$i)) + 16|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = $90 & 255;
  $$idx$val$i$i = HEAP32[$ls$idx$val$i>>2]|0;
  $$idx1$i$i = ((($ls$idx$val$i)) + 8|0);
  $$idx1$val$i$i = HEAP32[$$idx1$i$i>>2]|0;
  $$idx2$i$i = ((($ls$idx$val$i)) + 36|0);
  $$idx2$val$i$i = HEAP32[$$idx2$i$i>>2]|0;
  $$idx$val$idx$i$i = ((($$idx$val$i$i)) + 60|0);
  $$idx$val$idx$val$i$i = HEAP32[$$idx$val$idx$i$i>>2]|0;
  $$idx1$val$idx$i$i = ((($$idx1$val$i$i)) + 68|0);
  $$idx1$val$idx$val$i$i = HEAP32[$$idx1$val$idx$i$i>>2]|0;
  $$idx1$val$idx$val$idx$val$i$i = HEAP32[$$idx1$val$idx$val$i$i>>2]|0;
  $96 = (($$idx2$val$i$i) + ($95))|0;
  $$01$i$i = $nparams$2$i;
  while(1) {
   $97 = (($96) - ($$01$i$i))|0;
   $98 = (($$idx1$val$idx$val$idx$val$i$i) + ($97<<1)|0);
   $99 = HEAP16[$98>>1]|0;
   $100 = $99 << 16 >> 16;
   $101 = (((($$idx$val$idx$val$i$i) + (($100*12)|0)|0)) + 4|0);
   HEAP32[$101>>2] = $94;
   $102 = (($$01$i$i) + -1)|0;
   $103 = ($102|0)==(0);
   if ($103) {
    break;
   } else {
    $$01$i$i = $102;
   }
  }
 }
 $104 = ((($105)) + 42|0);
 $106 = HEAP8[$104>>0]|0;
 $107 = ((($78)) + 6|0);
 HEAP8[$107>>0] = $106;
 $108 = $106&255;
 _luaK_reserveregs($105,$108);
 $109 = HEAP32[$58>>2]|0;
 $110 = ($109|0)==(41);
 if (!($110)) {
  _error_expected($ls,41);
  // unreachable;
 }
 _luaX_next($ls);
 L37: while(1) {
  $ls$idx$val$i7 = HEAP32[$58>>2]|0;
  switch ($ls$idx$val$i7|0) {
  case 277: case 289: case 262: case 261: case 260:  {
   $117 = $ls$idx$val$i7;
   break L37;
   break;
  }
  default: {
  }
  }
  $111 = ($ls$idx$val$i7|0)==(274);
  _statement($ls);
  if ($111) {
   label = 29;
   break;
  }
 }
 if ((label|0) == 29) {
  $$pre15 = HEAP32[$58>>2]|0;
  $117 = $$pre15;
 }
 $112 = ((($ls)) + 4|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = HEAP32[$new_fs>>2]|0;
 $115 = ((($114)) + 40|0);
 HEAP32[$115>>2] = $113;
 $116 = ($117|0)==(262);
 if ($116) {
  _luaX_next($ls);
  $ls$idx3$val = HEAP32[$ls$idx>>2]|0;
  $ls$idx3$val$idx = ((($ls$idx3$val)) + 4|0);
  $ls$idx3$val$idx$val = HEAP32[$ls$idx3$val$idx>>2]|0;
  $123 = ((($ls$idx3$val$idx$val)) + 32|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (($124) + -1)|0;
  $126 = (_luaK_codeABx($ls$idx3$val$idx$val,44,0,$125)|0);
  $127 = ((($e)) + 16|0);
  HEAP32[$127>>2] = -1;
  $128 = ((($e)) + 20|0);
  HEAP32[$128>>2] = -1;
  HEAP32[$e>>2] = 12;
  $129 = ((($e)) + 8|0);
  HEAP32[$129>>2] = $126;
  _luaK_exp2nextreg($ls$idx3$val$idx$val,$e);
  _close_func($ls);
  STACKTOP = sp;return;
 }
 $118 = ($113|0)==($line|0);
 if ($118) {
  _error_expected($ls,262);
  // unreachable;
 } else {
  $119 = HEAP32[$ls$idx1>>2]|0;
  $120 = (_luaX_token2str($ls,262)|0);
  $121 = (_luaX_token2str($ls,265)|0);
  HEAP32[$vararg_buffer>>2] = $120;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $121;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = $line;
  $122 = (_luaO_pushfstring($119,2272,$vararg_buffer)|0);
  _luaX_syntaxerror($ls,$122);
  // unreachable;
 }
}
function _gotostat($ls,$pc) {
 $ls = $ls|0;
 $pc = $pc|0;
 var $$lcssa = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04$i = 0, $i$04$i$lcssa = 0, $label$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(266);
 _luaX_next($ls);
 do {
  if ($4) {
   $5 = HEAP32[$2>>2]|0;
   $6 = ($5|0)==(292);
   if ($6) {
    $7 = ((($ls)) + 24|0);
    $8 = HEAP32[$7>>2]|0;
    _luaX_next($ls);
    $label$0 = $8;
    break;
   } else {
    _error_expected($ls,292);
    // unreachable;
   }
  } else {
   $9 = ((($ls)) + 52|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (_luaS_new($10,5712)|0);
   $label$0 = $11;
  }
 } while(0);
 $12 = ((($ls)) + 68|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ((($13)) + 12|0);
 $15 = ((($13)) + 16|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + 1)|0;
 $18 = ((($13)) + 20|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($16|0)<($19|0);
 if ($20) {
  $$pre$i = HEAP32[$14>>2]|0;
  $26 = $$pre$i;$37 = $13;
 } else {
  $21 = ((($ls)) + 52|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = HEAP32[$14>>2]|0;
  $24 = (_luaM_growaux_($22,$23,$18,16,32767,2008)|0);
  HEAP32[$14>>2] = $24;
  $$pre = HEAP32[$12>>2]|0;
  $26 = $24;$37 = $$pre;
 }
 $25 = (($26) + ($16<<4)|0);
 HEAP32[$25>>2] = $label$0;
 $27 = (((($26) + ($16<<4)|0)) + 8|0);
 HEAP32[$27>>2] = $1;
 $28 = ((($ls)) + 48|0);
 $29 = HEAP32[$28>>2]|0;
 $30 = ((($29)) + 42|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = (((($26) + ($16<<4)|0)) + 12|0);
 HEAP8[$32>>0] = $31;
 $33 = (((($26) + ($16<<4)|0)) + 4|0);
 HEAP32[$33>>2] = $pc;
 HEAP32[$15>>2] = $17;
 $34 = ((($29)) + 12|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ((($37)) + 12|0);
 $38 = HEAP32[$36>>2]|0;
 $39 = ((($35)) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($37)) + 28|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ($40|0)<($42|0);
 if (!($43)) {
  return;
 }
 $44 = ((($37)) + 24|0);
 $45 = HEAP32[$44>>2]|0;
 $46 = (($38) + ($16<<4)|0);
 $47 = HEAP32[$46>>2]|0;
 $i$04$i = $40;
 while(1) {
  $48 = (($45) + ($i$04$i<<4)|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($49|0)==($47|0);
  if ($50) {
   $$lcssa = $48;$i$04$i$lcssa = $i$04$i;
   break;
  }
  $59 = (($i$04$i) + 1)|0;
  $60 = ($59|0)<($42|0);
  if ($60) {
   $i$04$i = $59;
  } else {
   label = 16;
   break;
  }
 }
 if ((label|0) == 16) {
  return;
 }
 $51 = (((($38) + ($16<<4)|0)) + 12|0);
 $52 = HEAP8[$51>>0]|0;
 $53 = (((($45) + ($i$04$i$lcssa<<4)|0)) + 12|0);
 $54 = HEAP8[$53>>0]|0;
 $55 = ($52&255)>($54&255);
 if ($55) {
  $56 = (((($38) + ($16<<4)|0)) + 4|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = $54&255;
  _luaK_patchclose($29,$57,$58);
 }
 _closegoto($ls,$16,$$lcssa);
 return;
}
function _suffixedexp($ls,$v) {
 $ls = $ls|0;
 $v = $v|0;
 var $$pre = 0, $$pre$phi2Z2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $key = 0, $key$i$i = 0, $key1 = 0, $ls$idx$val$i = 0, $ls$idx$val$i$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 72|0;
 $key$i$i = sp + 48|0;
 $key = sp + 24|0;
 $key1 = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($ls)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 do {
  if ((($5|0) == 40)) {
   _luaX_next($ls);
   (_subexpr($ls,$v,0)|0);
   $6 = HEAP32[$4>>2]|0;
   $7 = ($6|0)==(41);
   if ($7) {
    _luaX_next($ls);
    $15 = HEAP32[$0>>2]|0;
    _luaK_dischargevars($15,$v);
    $$pre = ((($ls)) + 24|0);
    $$pre$phi2Z2D = $$pre;
    break;
   }
   $8 = HEAP32[$2>>2]|0;
   $9 = ($8|0)==($3|0);
   if ($9) {
    _error_expected($ls,41);
    // unreachable;
   } else {
    $10 = ((($ls)) + 52|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = (_luaX_token2str($ls,41)|0);
    $13 = (_luaX_token2str($ls,40)|0);
    HEAP32[$vararg_buffer>>2] = $12;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $13;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $3;
    $14 = (_luaO_pushfstring($11,2272,$vararg_buffer)|0);
    _luaX_syntaxerror($ls,$14);
    // unreachable;
   }
  } else if ((($5|0) == 292)) {
   $16 = ((($ls)) + 24|0);
   $17 = HEAP32[$16>>2]|0;
   _luaX_next($ls);
   $18 = HEAP32[$0>>2]|0;
   $19 = (_singlevaraux($18,$17,$v,1)|0);
   $20 = ($19|0)==(0);
   if ($20) {
    $21 = ((($ls)) + 76|0);
    $22 = HEAP32[$21>>2]|0;
    (_singlevaraux($18,$22,$v,1)|0);
    $ls$idx$val$i$i = HEAP32[$0>>2]|0;
    $23 = (_luaK_stringK($ls$idx$val$i$i,$17)|0);
    $24 = ((($key$i$i)) + 16|0);
    HEAP32[$24>>2] = -1;
    $25 = ((($key$i$i)) + 20|0);
    HEAP32[$25>>2] = -1;
    HEAP32[$key$i$i>>2] = 4;
    $26 = ((($key$i$i)) + 8|0);
    HEAP32[$26>>2] = $23;
    _luaK_indexed($18,$v,$key$i$i);
   }
   $$pre$phi2Z2D = $16;
  } else {
   _luaX_syntaxerror($ls,2488);
   // unreachable;
  }
 } while(0);
 $27 = ((($key1)) + 16|0);
 $28 = ((($key1)) + 20|0);
 $29 = ((($key1)) + 8|0);
 L15: while(1) {
  $30 = HEAP32[$4>>2]|0;
  switch ($30|0) {
  case 91:  {
   _luaK_exp2anyregup($1,$v);
   _luaX_next($ls);
   (_subexpr($ls,$key,0)|0);
   $31 = HEAP32[$0>>2]|0;
   _luaK_exp2val($31,$key);
   $32 = HEAP32[$4>>2]|0;
   $33 = ($32|0)==(93);
   if (!($33)) {
    label = 15;
    break L15;
   }
   _luaX_next($ls);
   _luaK_indexed($1,$v,$key);
   continue L15;
   break;
  }
  case 123: case 293: case 40:  {
   _luaK_exp2nextreg($1,$v);
   _funcargs($ls,$v,$3);
   continue L15;
   break;
  }
  case 58:  {
   _luaX_next($ls);
   $34 = HEAP32[$4>>2]|0;
   $35 = ($34|0)==(292);
   if (!($35)) {
    label = 18;
    break L15;
   }
   $36 = HEAP32[$$pre$phi2Z2D>>2]|0;
   _luaX_next($ls);
   $ls$idx$val$i = HEAP32[$0>>2]|0;
   $37 = (_luaK_stringK($ls$idx$val$i,$36)|0);
   HEAP32[$27>>2] = -1;
   HEAP32[$28>>2] = -1;
   HEAP32[$key1>>2] = 4;
   HEAP32[$29>>2] = $37;
   _luaK_self($1,$v,$key1);
   _funcargs($ls,$v,$3);
   continue L15;
   break;
  }
  case 46:  {
   _fieldsel($ls,$v);
   continue L15;
   break;
  }
  default: {
   label = 21;
   break L15;
  }
  }
 }
 if ((label|0) == 15) {
  _error_expected($ls,93);
  // unreachable;
 }
 else if ((label|0) == 18) {
  _error_expected($ls,292);
  // unreachable;
 }
 else if ((label|0) == 21) {
  STACKTOP = sp;return;
 }
}
function _assignment($ls,$lh,$nvars) {
 $ls = $ls|0;
 $lh = $lh|0;
 $nvars = $nvars|0;
 var $$$i = 0, $$02$i = 0, $$02$i$us = 0, $$off = 0, $$pre$phi4Z2D = 0, $$pre$phiZ2D = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $conflict$01$i = 0, $conflict$01$i$us = 0, $conflict$1$i$us = 0, $conflict$2$i = 0, $conflict$2$i$lcssa = 0, $conflict$2$i$us = 0, $e = 0, $ls$idx1$val = 0, $n$0$i$lcssa = 0, $n$0$i2 = 0;
 var $nv = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 64|0;
 $vararg_buffer = sp + 56|0;
 $e = sp + 32|0;
 $nv = sp;
 $0 = ((($lh)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $$off = (($1) + -8)|0;
 $2 = ($$off>>>0)<(3);
 if (!($2)) {
  _luaX_syntaxerror($ls,2472);
  // unreachable;
 }
 $3 = ((($ls)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 do {
  if ((($4|0) == 44)) {
   _luaX_next($ls);
   HEAP32[$nv>>2] = $lh;
   $5 = ((($nv)) + 8|0);
   _suffixedexp($ls,$5);
   $6 = HEAP32[$5>>2]|0;
   $7 = ($6|0)==(10);
   $$pre5 = ((($ls)) + 48|0);
   if (!($7)) {
    $ls$idx1$val = HEAP32[$$pre5>>2]|0;
    $8 = ((($ls$idx1$val)) + 44|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = $9&255;
    $11 = ((($nv)) + 16|0);
    $12 = $9&255;
    $13 = HEAP32[$11>>2]|0;
    $14 = ($6|0)==(8);
    if ($14) {
     $$02$i$us = $lh;$conflict$01$i$us = 0;
     while(1) {
      $15 = ((($$02$i$us)) + 8|0);
      $16 = HEAP32[$15>>2]|0;
      $17 = ($16|0)==(10);
      if ($17) {
       $18 = ((($$02$i$us)) + 16|0);
       $19 = ((($18)) + 3|0);
       $20 = HEAP8[$19>>0]|0;
       $21 = ($20<<24>>24)==(8);
       if ($21) {
        $22 = ((($18)) + 2|0);
        $23 = HEAP8[$22>>0]|0;
        $24 = $23&255;
        $25 = ($24|0)==($13|0);
        if ($25) {
         HEAP8[$19>>0] = 8;
         HEAP8[$22>>0] = $9;
         $conflict$1$i$us = 1;
        } else {
         $conflict$1$i$us = $conflict$01$i$us;
        }
       } else {
        $conflict$1$i$us = $conflict$01$i$us;
       }
       $26 = HEAP16[$18>>1]|0;
       $27 = $26 << 16 >> 16;
       $28 = ($27|0)==($13|0);
       if ($28) {
        HEAP16[$18>>1] = $12;
        $conflict$2$i$us = 1;
       } else {
        $conflict$2$i$us = $conflict$1$i$us;
       }
      } else {
       $conflict$2$i$us = $conflict$01$i$us;
      }
      $29 = HEAP32[$$02$i$us>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $conflict$2$i$lcssa = $conflict$2$i$us;
       break;
      } else {
       $$02$i$us = $29;$conflict$01$i$us = $conflict$2$i$us;
      }
     }
    } else {
     $$02$i = $lh;$conflict$01$i = 0;
     while(1) {
      $31 = ((($$02$i)) + 8|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = ($32|0)==(10);
      if ($33) {
       $34 = ((($$02$i)) + 16|0);
       $35 = ((($34)) + 3|0);
       $36 = HEAP8[$35>>0]|0;
       $37 = $36&255;
       $38 = ($37|0)==($6|0);
       if ($38) {
        $39 = ((($34)) + 2|0);
        $40 = HEAP8[$39>>0]|0;
        $41 = $40&255;
        $42 = ($41|0)==($13|0);
        if ($42) {
         HEAP8[$35>>0] = 8;
         HEAP8[$39>>0] = $9;
         $conflict$2$i = 1;
        } else {
         $conflict$2$i = $conflict$01$i;
        }
       } else {
        $conflict$2$i = $conflict$01$i;
       }
      } else {
       $conflict$2$i = $conflict$01$i;
      }
      $43 = HEAP32[$$02$i>>2]|0;
      $44 = ($43|0)==(0|0);
      if ($44) {
       $conflict$2$i$lcssa = $conflict$2$i;
       break;
      } else {
       $$02$i = $43;$conflict$01$i = $conflict$2$i;
      }
     }
    }
    $45 = ($conflict$2$i$lcssa|0)==(0);
    if (!($45)) {
     $46 = $14 ? 0 : 5;
     (_luaK_codeABC($ls$idx1$val,$46,$10,$13,0)|0);
     _luaK_reserveregs($ls$idx1$val,1);
    }
   }
   $47 = HEAP32[$$pre5>>2]|0;
   $48 = ((($ls)) + 52|0);
   $49 = HEAP32[$48>>2]|0;
   $50 = ((($49)) + 106|0);
   $51 = HEAP16[$50>>1]|0;
   $52 = $51&65535;
   $53 = (($52) + ($nvars))|0;
   $54 = ($53|0)>(200);
   if (!($54)) {
    $67 = (($nvars) + 1)|0;
    _assignment($ls,$nv,$67);
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $$pre5;
    break;
   }
   $55 = ((($47)) + 8|0);
   $56 = HEAP32[$55>>2]|0;
   $57 = ((($56)) + 52|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = HEAP32[$47>>2]|0;
   $60 = ((($59)) + 36|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0);
   if ($62) {
    $64 = 2208;
    HEAP32[$vararg_buffer1>>2] = 2256;
    $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
    HEAP32[$vararg_ptr4>>2] = 200;
    $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
    HEAP32[$vararg_ptr5>>2] = $64;
    $65 = (_luaO_pushfstring($58,2224,$vararg_buffer1)|0);
    $66 = HEAP32[$55>>2]|0;
    _luaX_syntaxerror($66,$65);
    // unreachable;
   }
   HEAP32[$vararg_buffer>>2] = $61;
   $63 = (_luaO_pushfstring($58,2184,$vararg_buffer)|0);
   $64 = $63;
   HEAP32[$vararg_buffer1>>2] = 2256;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = 200;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $64;
   $65 = (_luaO_pushfstring($58,2224,$vararg_buffer1)|0);
   $66 = HEAP32[$55>>2]|0;
   _luaX_syntaxerror($66,$65);
   // unreachable;
  } else if ((($4|0) == 61)) {
   _luaX_next($ls);
   (_subexpr($ls,$e,0)|0);
   $68 = HEAP32[$3>>2]|0;
   $69 = ($68|0)==(44);
   $70 = ((($ls)) + 48|0);
   if ($69) {
    $n$0$i2 = 1;
    while(1) {
     _luaX_next($ls);
     $71 = HEAP32[$70>>2]|0;
     _luaK_exp2nextreg($71,$e);
     (_subexpr($ls,$e,0)|0);
     $72 = (($n$0$i2) + 1)|0;
     $73 = HEAP32[$3>>2]|0;
     $74 = ($73|0)==(44);
     if ($74) {
      $n$0$i2 = $72;
     } else {
      $n$0$i$lcssa = $72;
      break;
     }
    }
   } else {
    $n$0$i$lcssa = 1;
   }
   $75 = ($n$0$i$lcssa|0)==($nvars|0);
   $76 = HEAP32[$70>>2]|0;
   if ($75) {
    _luaK_setoneret($76,$e);
    $94 = HEAP32[$70>>2]|0;
    _luaK_storevar($94,$0,$e);
    STACKTOP = sp;return;
   }
   $77 = (($nvars) - ($n$0$i$lcssa))|0;
   $78 = HEAP32[$e>>2]|0;
   if ((($78|0) == 0)) {
    label = 33;
   } else if ((($78|0) == 14) | (($78|0) == 13)) {
    $79 = (($77) + 1)|0;
    $80 = ($79|0)<(0);
    $$$i = $80 ? 0 : $79;
    _luaK_setreturns($76,$e,$$$i);
    $81 = ($$$i|0)>(1);
    if ($81) {
     $82 = (($$$i) + -1)|0;
     _luaK_reserveregs($76,$82);
    }
   } else {
    _luaK_exp2nextreg($76,$e);
    label = 33;
   }
   if ((label|0) == 33) {
    $83 = ($77|0)>(0);
    if ($83) {
     $84 = ((($76)) + 44|0);
     $85 = HEAP8[$84>>0]|0;
     $86 = $85&255;
     _luaK_reserveregs($76,$77);
     _luaK_nil($76,$86,$77);
    }
   }
   $87 = ($n$0$i$lcssa|0)>($nvars|0);
   if ($87) {
    $88 = HEAP32[$70>>2]|0;
    $89 = ((($88)) + 44|0);
    $90 = HEAP8[$89>>0]|0;
    $91 = $90&255;
    $92 = (($77) + ($91))|0;
    $93 = $92&255;
    HEAP8[$89>>0] = $93;
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $70;
   } else {
    $$pre$phi4Z2D = $e;$$pre$phiZ2D = $70;
   }
  } else {
   _error_expected($ls,61);
   // unreachable;
  }
 } while(0);
 $95 = HEAP32[$$pre$phiZ2D>>2]|0;
 $96 = ((($95)) + 44|0);
 $97 = HEAP8[$96>>0]|0;
 $98 = $97&255;
 $99 = (($98) + -1)|0;
 $100 = ((($e)) + 16|0);
 HEAP32[$100>>2] = -1;
 $101 = ((($e)) + 20|0);
 HEAP32[$101>>2] = -1;
 HEAP32[$$pre$phi4Z2D>>2] = 7;
 $102 = ((($e)) + 8|0);
 HEAP32[$102>>2] = $99;
 _luaK_storevar($95,$0,$e);
 STACKTOP = sp;return;
}
function _funcargs($ls,$f,$line) {
 $ls = $ls|0;
 $f = $f|0;
 $line = $line|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, $nparams$0 = 0;
 var $phitmp = 0, $phitmp2 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 24|0;
 $args = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 if ((($3|0) == 293)) {
  $19 = ((($ls)) + 24|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (_luaK_stringK($1,$20)|0);
  $22 = ((($args)) + 16|0);
  HEAP32[$22>>2] = -1;
  $23 = ((($args)) + 20|0);
  HEAP32[$23>>2] = -1;
  HEAP32[$args>>2] = 4;
  $24 = ((($args)) + 8|0);
  HEAP32[$24>>2] = $21;
  _luaX_next($ls);
 } else if ((($3|0) == 123)) {
  _constructor($ls,$args);
 } else if ((($3|0) == 40)) {
  _luaX_next($ls);
  $4 = HEAP32[$2>>2]|0;
  $5 = ($4|0)==(41);
  if ($5) {
   HEAP32[$args>>2] = 0;
  } else {
   (_subexpr($ls,$args,0)|0);
   $6 = HEAP32[$2>>2]|0;
   $7 = ($6|0)==(44);
   if ($7) {
    while(1) {
     _luaX_next($ls);
     $8 = HEAP32[$0>>2]|0;
     _luaK_exp2nextreg($8,$args);
     (_subexpr($ls,$args,0)|0);
     $9 = HEAP32[$2>>2]|0;
     $10 = ($9|0)==(44);
     if (!($10)) {
      break;
     }
    }
   }
   _luaK_setreturns($1,$args,-1);
   $$pre = HEAP32[$2>>2]|0;
   $phitmp2 = ($$pre|0)==(41);
   if (!($phitmp2)) {
    $11 = ((($ls)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($line|0);
    if ($13) {
     _error_expected($ls,41);
     // unreachable;
    } else {
     $14 = ((($ls)) + 52|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = (_luaX_token2str($ls,41)|0);
     $17 = (_luaX_token2str($ls,40)|0);
     HEAP32[$vararg_buffer>>2] = $16;
     $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
     HEAP32[$vararg_ptr1>>2] = $17;
     $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
     HEAP32[$vararg_ptr2>>2] = $line;
     $18 = (_luaO_pushfstring($15,2272,$vararg_buffer)|0);
     _luaX_syntaxerror($ls,$18);
     // unreachable;
    }
   }
  }
  _luaX_next($ls);
 } else {
  _luaX_syntaxerror($ls,2512);
  // unreachable;
 }
 $25 = ((($f)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = HEAP32[$args>>2]|0;
 if ((($27|0) == 14) | (($27|0) == 13)) {
  $nparams$0 = 0;
  $31 = (_luaK_codeABC($1,36,$26,$nparams$0,2)|0);
  $32 = ((($f)) + 16|0);
  HEAP32[$32>>2] = -1;
  $33 = ((($f)) + 20|0);
  HEAP32[$33>>2] = -1;
  HEAP32[$f>>2] = 13;
  HEAP32[$25>>2] = $31;
  _luaK_fixline($1,$line);
  $34 = (($26) + 1)|0;
  $35 = $34&255;
  $36 = ((($1)) + 44|0);
  HEAP8[$36>>0] = $35;
  STACKTOP = sp;return;
 } else if (!((($27|0) == 0))) {
  _luaK_exp2nextreg($1,$args);
 }
 $28 = ((($1)) + 44|0);
 $29 = HEAP8[$28>>0]|0;
 $30 = $29&255;
 $phitmp = (($30) - ($26))|0;
 $nparams$0 = $phitmp;
 $31 = (_luaK_codeABC($1,36,$26,$nparams$0,2)|0);
 $32 = ((($f)) + 16|0);
 HEAP32[$32>>2] = -1;
 $33 = ((($f)) + 20|0);
 HEAP32[$33>>2] = -1;
 HEAP32[$f>>2] = 13;
 HEAP32[$25>>2] = $31;
 _luaK_fixline($1,$line);
 $34 = (($26) + 1)|0;
 $35 = $34&255;
 $36 = ((($1)) + 44|0);
 HEAP8[$36>>0] = $35;
 STACKTOP = sp;return;
}
function _constructor($ls,$t) {
 $ls = $ls|0;
 $t = $t|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $cc = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 40|0;
 $cc = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_luaK_codeABC($1,11,0,0,0)|0);
 $5 = ((($cc)) + 36|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($cc)) + 28|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($cc)) + 32|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($cc)) + 24|0);
 HEAP32[$8>>2] = $t;
 $9 = ((($t)) + 16|0);
 HEAP32[$9>>2] = -1;
 $10 = ((($t)) + 20|0);
 HEAP32[$10>>2] = -1;
 HEAP32[$t>>2] = 12;
 $11 = ((($t)) + 8|0);
 HEAP32[$11>>2] = $4;
 $12 = ((($cc)) + 16|0);
 HEAP32[$12>>2] = -1;
 $13 = ((($cc)) + 20|0);
 HEAP32[$13>>2] = -1;
 HEAP32[$cc>>2] = 0;
 $14 = ((($cc)) + 8|0);
 HEAP32[$14>>2] = 0;
 $15 = HEAP32[$0>>2]|0;
 _luaK_exp2nextreg($15,$t);
 $16 = ((($ls)) + 16|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(123);
 if (!($18)) {
  _error_expected($ls,123);
  // unreachable;
 }
 _luaX_next($ls);
 $19 = HEAP32[$16>>2]|0;
 $20 = ($19|0)==(125);
 L4: do {
  if (!($20)) {
   $22 = 0;
   while(1) {
    $21 = ($22|0)==(0);
    if (!($21)) {
     _luaK_exp2nextreg($1,$cc);
     HEAP32[$cc>>2] = 0;
     $23 = HEAP32[$5>>2]|0;
     $24 = ($23|0)==(50);
     if ($24) {
      $25 = HEAP32[$8>>2]|0;
      $26 = ((($25)) + 8|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = HEAP32[$7>>2]|0;
      _luaK_setlist($1,$27,$28,50);
      HEAP32[$5>>2] = 0;
     }
    }
    $29 = HEAP32[$16>>2]|0;
    do {
     if ((($29|0) == 91)) {
      _recfield($ls,$cc);
     } else if ((($29|0) == 292)) {
      $30 = (_luaX_lookahead($ls)|0);
      $31 = ($30|0)==(61);
      if ($31) {
       _recfield($ls,$cc);
       break;
      } else {
       (_subexpr($ls,$cc,0)|0);
       $32 = HEAP32[$7>>2]|0;
       $33 = (($32) + 1)|0;
       HEAP32[$7>>2] = $33;
       $34 = HEAP32[$5>>2]|0;
       $35 = (($34) + 1)|0;
       HEAP32[$5>>2] = $35;
       break;
      }
     } else {
      (_subexpr($ls,$cc,0)|0);
      $36 = HEAP32[$7>>2]|0;
      $37 = (($36) + 1)|0;
      HEAP32[$7>>2] = $37;
      $38 = HEAP32[$5>>2]|0;
      $39 = (($38) + 1)|0;
      HEAP32[$5>>2] = $39;
     }
    } while(0);
    $40 = HEAP32[$16>>2]|0;
    if ((($40|0) == 125)) {
     break L4;
    } else if ((($40|0) == 44)) {
     _luaX_next($ls);
    } else if ((($40|0) == 59)) {
     _luaX_next($ls);
    } else {
     break;
    }
    $41 = HEAP32[$16>>2]|0;
    $42 = ($41|0)==(125);
    if ($42) {
     break L4;
    }
    $$pre = HEAP32[$cc>>2]|0;
    $22 = $$pre;
   }
   $43 = HEAP32[$2>>2]|0;
   $44 = ($43|0)==($3|0);
   if ($44) {
    _error_expected($ls,125);
    // unreachable;
   } else {
    $45 = ((($ls)) + 52|0);
    $46 = HEAP32[$45>>2]|0;
    $47 = (_luaX_token2str($ls,125)|0);
    $48 = (_luaX_token2str($ls,123)|0);
    HEAP32[$vararg_buffer>>2] = $47;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $48;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $3;
    $49 = (_luaO_pushfstring($46,2272,$vararg_buffer)|0);
    _luaX_syntaxerror($ls,$49);
    // unreachable;
   }
  }
 } while(0);
 _luaX_next($ls);
 $50 = HEAP32[$5>>2]|0;
 $51 = ($50|0)==(0);
 do {
  if (!($51)) {
   $52 = HEAP32[$cc>>2]|0;
   if ((($52|0) == 14) | (($52|0) == 13)) {
    _luaK_setreturns($1,$cc,-1);
    $53 = HEAP32[$8>>2]|0;
    $54 = ((($53)) + 8|0);
    $55 = HEAP32[$54>>2]|0;
    $56 = HEAP32[$7>>2]|0;
    _luaK_setlist($1,$55,$56,-1);
    $57 = HEAP32[$7>>2]|0;
    $58 = (($57) + -1)|0;
    HEAP32[$7>>2] = $58;
    break;
   } else if ((($52|0) == 0)) {
    $63 = $50;
   } else {
    _luaK_exp2nextreg($1,$cc);
    $$pre$i = HEAP32[$5>>2]|0;
    $63 = $$pre$i;
   }
   $59 = HEAP32[$8>>2]|0;
   $60 = ((($59)) + 8|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = HEAP32[$7>>2]|0;
   _luaK_setlist($1,$61,$62,$63);
  }
 } while(0);
 $64 = HEAP32[$1>>2]|0;
 $65 = ((($64)) + 48|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = (($66) + ($4<<2)|0);
 $68 = HEAP32[$67>>2]|0;
 $69 = $68 & 8388607;
 $70 = HEAP32[$7>>2]|0;
 $71 = (_luaO_int2fb($70)|0);
 $72 = $71 << 23;
 $73 = $72 | $69;
 $74 = HEAP32[$1>>2]|0;
 $75 = ((($74)) + 48|0);
 $76 = HEAP32[$75>>2]|0;
 $77 = (($76) + ($4<<2)|0);
 HEAP32[$77>>2] = $73;
 $78 = $73 & -8372225;
 $79 = HEAP32[$6>>2]|0;
 $80 = (_luaO_int2fb($79)|0);
 $81 = $80 << 14;
 $82 = $81 & 8372224;
 $83 = $82 | $78;
 $84 = HEAP32[$1>>2]|0;
 $85 = ((($84)) + 48|0);
 $86 = HEAP32[$85>>2]|0;
 $87 = (($86) + ($4<<2)|0);
 HEAP32[$87>>2] = $83;
 STACKTOP = sp;return;
}
function _recfield($ls,$cc) {
 $ls = $ls|0;
 $cc = $cc|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $key = 0, $ls$idx$val$i = 0, $val = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $key = sp + 24|0;
 $val = sp;
 $0 = ((($ls)) + 48|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 44|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ((($ls)) + 16|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(292);
 do {
  if ($6) {
   $7 = ((($ls)) + 24|0);
   $8 = HEAP32[$7>>2]|0;
   _luaX_next($ls);
   $ls$idx$val$i = HEAP32[$0>>2]|0;
   $9 = (_luaK_stringK($ls$idx$val$i,$8)|0);
   $10 = ((($key)) + 16|0);
   HEAP32[$10>>2] = -1;
   $11 = ((($key)) + 20|0);
   HEAP32[$11>>2] = -1;
   HEAP32[$key>>2] = 4;
   $12 = ((($key)) + 8|0);
   HEAP32[$12>>2] = $9;
  } else {
   _luaX_next($ls);
   (_subexpr($ls,$key,0)|0);
   $13 = HEAP32[$0>>2]|0;
   _luaK_exp2val($13,$key);
   $14 = HEAP32[$4>>2]|0;
   $15 = ($14|0)==(93);
   if ($15) {
    _luaX_next($ls);
    break;
   } else {
    _error_expected($ls,93);
    // unreachable;
   }
  }
 } while(0);
 $16 = ((($cc)) + 28|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 HEAP32[$16>>2] = $18;
 $19 = HEAP32[$4>>2]|0;
 $20 = ($19|0)==(61);
 if ($20) {
  _luaX_next($ls);
  $21 = (_luaK_exp2RK($1,$key)|0);
  (_subexpr($ls,$val,0)|0);
  $22 = ((($cc)) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($23)) + 8|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = (_luaK_exp2RK($1,$val)|0);
  (_luaK_codeABC($1,10,$25,$21,$26)|0);
  HEAP8[$2>>0] = $3;
  STACKTOP = sp;return;
 } else {
  _error_expected($ls,61);
  // unreachable;
 }
}
function _luaE_setdebt($g,$debt) {
 $g = $g|0;
 $debt = $debt|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($g)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($g)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($1) - ($debt))|0;
 $5 = (($4) + ($3))|0;
 HEAP32[$2>>2] = $5;
 HEAP32[$0>>2] = $debt;
 return;
}
function _luaE_extendCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaM_realloc_($L,0,0,36)|0);
 $1 = ((($L)) + 16|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 12|0);
 HEAP32[$3>>2] = $0;
 $4 = $2;
 $5 = ((($0)) + 8|0);
 HEAP32[$5>>2] = $4;
 $6 = ((($0)) + 12|0);
 HEAP32[$6>>2] = 0;
 return ($0|0);
}
function _luaE_freeCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $next$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 HEAP32[$2>>2] = 0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 } else {
  $next$01 = $3;
 }
 while(1) {
  $5 = ((($next$01)) + 12|0);
  $6 = HEAP32[$5>>2]|0;
  (_luaM_realloc_($L,$next$01,36,0)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   break;
  } else {
   $next$01 = $6;
  }
 }
 return;
}
function _luaE_shrinkCI($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ci$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  return;
 } else {
  $6 = $3;$9 = $2;$ci$01 = $1;
 }
 while(1) {
  $5 = ((($6)) + 12|0);
  $7 = HEAP32[$5>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 4;
   break;
  }
  (_luaM_realloc_($L,$6,36,0)|0);
  HEAP32[$9>>2] = $7;
  $10 = ((($7)) + 8|0);
  HEAP32[$10>>2] = $ci$01;
  $11 = ((($7)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 4;
   break;
  } else {
   $6 = $12;$9 = $11;$ci$01 = $7;
  }
 }
 if ((label|0) == 4) {
  return;
 }
}
function _lua_newthread($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 12|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)>(0);
 if ($4) {
  _luaC_step($L);
 }
 $5 = (_luaM_realloc_($L,0,8,116)|0);
 $6 = ((($5)) + 4|0);
 $7 = ((($1)) + 60|0);
 $8 = HEAP8[$7>>0]|0;
 $9 = $8&255;
 $10 = $9 & 3;
 $11 = $10&255;
 $12 = ((($5)) + 9|0);
 HEAP8[$12>>0] = $11;
 $13 = ((($5)) + 8|0);
 HEAP8[$13>>0] = 8;
 $14 = ((($1)) + 64|0);
 $15 = HEAP32[$14>>2]|0;
 HEAP32[$6>>2] = $15;
 HEAP32[$14>>2] = $6;
 $16 = ((($L)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 HEAP32[$17>>2] = $6;
 $18 = ((($17)) + 8|0);
 HEAP32[$18>>2] = 72;
 $19 = HEAP32[$16>>2]|0;
 $20 = ((($19)) + 16|0);
 HEAP32[$16>>2] = $20;
 $21 = ((($5)) + 16|0);
 HEAP32[$21>>2] = $1;
 $22 = ((($5)) + 32|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($5)) + 20|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($5)) + 96|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($5)) + 44|0);
 HEAP32[$25>>2] = $6;
 $26 = ((($5)) + 48|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($5)) + 110|0);
 HEAP16[$27>>1] = 0;
 $28 = ((($5)) + 88|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($5)) + 112|0);
 HEAP8[$29>>0] = 0;
 $30 = ((($5)) + 100|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($5)) + 113|0);
 HEAP8[$31>>0] = 1;
 $32 = ((($5)) + 104|0);
 $33 = ((($5)) + 36|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($5)) + 108|0);
 HEAP16[$34>>1] = 1;
 $35 = ((($5)) + 10|0);
 HEAP8[$35>>0] = 0;
 $36 = ((($5)) + 92|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($L)) + 108|0);
 $38 = HEAP8[$37>>0]|0;
 HEAP8[$29>>0] = $38;
 $39 = ((($L)) + 96|0);
 $40 = HEAP32[$39>>2]|0;
 HEAP32[$30>>2] = $40;
 $41 = ((($L)) + 84|0);
 $42 = HEAP32[$41>>2]|0;
 HEAP32[$28>>2] = $42;
 HEAP32[$32>>2] = $40;
 $43 = ((($1)) + 136|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = ((($44)) + -4|0);
 $46 = HEAPU8[$45>>0]|(HEAPU8[$45+1>>0]<<8)|(HEAPU8[$45+2>>0]<<16)|(HEAPU8[$45+3>>0]<<24);
 HEAP8[$5>>0]=$46&255;HEAP8[$5+1>>0]=($46>>8)&255;HEAP8[$5+2>>0]=($46>>16)&255;HEAP8[$5+3>>0]=$46>>24;
 $47 = (_luaM_realloc_($L,0,0,640)|0);
 HEAP32[$22>>2] = $47;
 HEAP32[$24>>2] = 40;
 $48 = ((($47)) + 8|0);
 HEAP32[$48>>2] = 0;
 $49 = ((($47)) + 24|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($47)) + 40|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($47)) + 56|0);
 HEAP32[$51>>2] = 0;
 $52 = ((($47)) + 72|0);
 HEAP32[$52>>2] = 0;
 $53 = ((($47)) + 88|0);
 HEAP32[$53>>2] = 0;
 $54 = ((($47)) + 104|0);
 HEAP32[$54>>2] = 0;
 $55 = ((($47)) + 120|0);
 HEAP32[$55>>2] = 0;
 $56 = ((($47)) + 136|0);
 HEAP32[$56>>2] = 0;
 $57 = ((($47)) + 152|0);
 HEAP32[$57>>2] = 0;
 $58 = ((($47)) + 168|0);
 HEAP32[$58>>2] = 0;
 $59 = ((($47)) + 184|0);
 HEAP32[$59>>2] = 0;
 $60 = ((($47)) + 200|0);
 HEAP32[$60>>2] = 0;
 $61 = ((($47)) + 216|0);
 HEAP32[$61>>2] = 0;
 $62 = ((($47)) + 232|0);
 HEAP32[$62>>2] = 0;
 $63 = ((($47)) + 248|0);
 HEAP32[$63>>2] = 0;
 $64 = ((($47)) + 264|0);
 HEAP32[$64>>2] = 0;
 $65 = ((($47)) + 280|0);
 HEAP32[$65>>2] = 0;
 $66 = ((($47)) + 296|0);
 HEAP32[$66>>2] = 0;
 $67 = ((($47)) + 312|0);
 HEAP32[$67>>2] = 0;
 $68 = ((($47)) + 328|0);
 HEAP32[$68>>2] = 0;
 $69 = ((($47)) + 344|0);
 HEAP32[$69>>2] = 0;
 $70 = ((($47)) + 360|0);
 HEAP32[$70>>2] = 0;
 $71 = ((($47)) + 376|0);
 HEAP32[$71>>2] = 0;
 $72 = ((($47)) + 392|0);
 HEAP32[$72>>2] = 0;
 $73 = ((($47)) + 408|0);
 HEAP32[$73>>2] = 0;
 $74 = ((($47)) + 424|0);
 HEAP32[$74>>2] = 0;
 $75 = ((($47)) + 440|0);
 HEAP32[$75>>2] = 0;
 $76 = ((($47)) + 456|0);
 HEAP32[$76>>2] = 0;
 $77 = ((($47)) + 472|0);
 HEAP32[$77>>2] = 0;
 $78 = ((($47)) + 488|0);
 HEAP32[$78>>2] = 0;
 $79 = ((($47)) + 504|0);
 HEAP32[$79>>2] = 0;
 $80 = ((($47)) + 520|0);
 HEAP32[$80>>2] = 0;
 $81 = ((($47)) + 536|0);
 HEAP32[$81>>2] = 0;
 $82 = ((($47)) + 552|0);
 HEAP32[$82>>2] = 0;
 $83 = ((($47)) + 568|0);
 HEAP32[$83>>2] = 0;
 $84 = ((($47)) + 584|0);
 HEAP32[$84>>2] = 0;
 $85 = ((($47)) + 600|0);
 HEAP32[$85>>2] = 0;
 $86 = ((($47)) + 616|0);
 HEAP32[$86>>2] = 0;
 $87 = ((($47)) + 632|0);
 HEAP32[$87>>2] = 0;
 $88 = ((($5)) + 12|0);
 $89 = ((($47)) + 560|0);
 $90 = ((($5)) + 28|0);
 HEAP32[$90>>2] = $89;
 $91 = ((($5)) + 52|0);
 $92 = ((($5)) + 60|0);
 HEAP32[$92>>2] = 0;
 $93 = ((($5)) + 64|0);
 HEAP32[$93>>2] = 0;
 $94 = ((($5)) + 86|0);
 HEAP8[$94>>0] = 0;
 $95 = $47;
 HEAP32[$91>>2] = $95;
 $96 = ((($47)) + 16|0);
 HEAP32[$88>>2] = $96;
 HEAP32[$48>>2] = 0;
 $97 = ((($47)) + 336|0);
 $98 = ((($5)) + 56|0);
 HEAP32[$98>>2] = $97;
 HEAP32[$23>>2] = $91;
 return ($6|0);
}
function _luaE_freethread($L,$L1) {
 $L = $L|0;
 $L1 = $L1|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $next$01$i$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($L1)) + -4|0);
 $1 = ((($L1)) + 28|0);
 $2 = HEAP32[$1>>2]|0;
 _luaF_close($L1,$2);
 $3 = HEAP32[$1>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_luaM_realloc_($L,$0,116,0)|0);
  return;
 }
 $5 = ((($L1)) + 48|0);
 $6 = ((($L1)) + 16|0);
 HEAP32[$6>>2] = $5;
 $7 = ((($L1)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$7>>2] = 0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  $16 = $3;
 } else {
  $next$01$i$i = $8;
  while(1) {
   $10 = ((($next$01$i$i)) + 12|0);
   $11 = HEAP32[$10>>2]|0;
   (_luaM_realloc_($L1,$next$01$i$i,36,0)|0);
   $12 = ($11|0)==(0|0);
   if ($12) {
    break;
   } else {
    $next$01$i$i = $11;
   }
  }
  $$pre$i = HEAP32[$1>>2]|0;
  $16 = $$pre$i;
 }
 $13 = ((($L1)) + 92|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = $14 << 4;
 (_luaM_realloc_($L1,$16,$15,0)|0);
 (_luaM_realloc_($L,$0,116,0)|0);
 return;
}
function _lua_newstate($f,$ud) {
 $f = $f|0;
 $ud = $ud|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buff$i = 0, $h$i = 0, $scevgep = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buff$i = sp + 8|0;
 $h$i = sp;
 $0 = (FUNCTION_TABLE_iiiii[$f & 511]($ud,0,8,400)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($0)) + 4|0);
 $3 = ((($0)) + 120|0);
 HEAP32[$2>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP8[$4>>0] = 8;
 $5 = ((($0)) + 180|0);
 HEAP8[$5>>0] = 1;
 $6 = ((($0)) + 9|0);
 HEAP8[$6>>0] = 1;
 $7 = ((($0)) + 16|0);
 HEAP32[$7>>2] = $3;
 $8 = ((($0)) + 32|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($0)) + 20|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($0)) + 96|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 44|0);
 HEAP32[$11>>2] = $2;
 $12 = ((($0)) + 48|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($0)) + 110|0);
 HEAP16[$13>>1] = 0;
 $14 = ((($0)) + 88|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($0)) + 112|0);
 HEAP8[$15>>0] = 0;
 $16 = ((($0)) + 100|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($0)) + 113|0);
 HEAP8[$17>>0] = 1;
 $18 = ((($0)) + 104|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($0)) + 36|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($0)) + 108|0);
 HEAP16[$20>>1] = 1;
 $21 = ((($0)) + 10|0);
 HEAP8[$21>>0] = 0;
 $22 = ((($0)) + 92|0);
 HEAP32[$22>>2] = 0;
 HEAP32[$3>>2] = $f;
 $23 = ((($0)) + 124|0);
 HEAP32[$23>>2] = $ud;
 $24 = ((($0)) + 256|0);
 HEAP32[$24>>2] = $2;
 $25 = (_time((0|0))|0);
 HEAP32[$h$i>>2] = $25;
 $26 = $2;
 HEAP32[$buff$i>>2] = $26;
 $27 = $h$i;
 $28 = ((($buff$i)) + 4|0);
 HEAP32[$28>>2] = $27;
 $29 = ((($buff$i)) + 8|0);
 HEAP32[$29>>2] = (1568);
 $30 = ((($buff$i)) + 12|0);
 HEAP32[$30>>2] = (314);
 $31 = (_luaS_hash($buff$i,16,$25)|0);
 $32 = ((($0)) + 176|0);
 HEAP32[$32>>2] = $31;
 $33 = ((($0)) + 183|0);
 HEAP8[$33>>0] = 0;
 $34 = ((($0)) + 140|0);
 $35 = ((($0)) + 168|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($0)) + 228|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($0)) + 236|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($0)) + 252|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($0)) + 260|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($0)) + 181|0);
 ;HEAP32[$34>>2]=0|0;HEAP32[$34+4>>2]=0|0;HEAP32[$34+8>>2]=0|0;HEAP32[$34+12>>2]=0|0;
 HEAP8[$40>>0] = 7;
 $41 = ((($0)) + 182|0);
 HEAP8[$41>>0] = 0;
 $42 = ((($0)) + 184|0);
 $43 = ((($0)) + 128|0);
 dest=$42; stop=dest+44|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$43>>2] = 400;
 $44 = ((($0)) + 132|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($0)) + 240|0);
 HEAP32[$45>>2] = 0;
 $46 = ((($0)) + 244|0);
 HEAP32[$46>>2] = 200;
 $47 = ((($0)) + 248|0);
 HEAP32[$47>>2] = 200;
 $scevgep = ((($0)) + 364|0);
 dest=$scevgep; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $48 = (_luaD_rawrunprotected($2,315,0)|0);
 $49 = ($48|0)==(0);
 if ($49) {
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 _close_state($2);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _lua_close($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 136|0);
 $3 = HEAP32[$2>>2]|0;
 _close_state($3);
 return;
}
function _f_luaopen($L,$ud) {
 $L = $L|0;
 $ud = $ud|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $temp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp$i = sp;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaM_realloc_($L,0,0,640)|0);
 $3 = ((($L)) + 28|0);
 HEAP32[$3>>2] = $2;
 $4 = ((($L)) + 92|0);
 HEAP32[$4>>2] = 40;
 $5 = ((($2)) + 8|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($2)) + 24|0);
 HEAP32[$6>>2] = 0;
 $7 = ((($2)) + 40|0);
 HEAP32[$7>>2] = 0;
 $8 = ((($2)) + 56|0);
 HEAP32[$8>>2] = 0;
 $9 = ((($2)) + 72|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($2)) + 88|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($2)) + 104|0);
 HEAP32[$11>>2] = 0;
 $12 = ((($2)) + 120|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($2)) + 136|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($2)) + 152|0);
 HEAP32[$14>>2] = 0;
 $15 = ((($2)) + 168|0);
 HEAP32[$15>>2] = 0;
 $16 = ((($2)) + 184|0);
 HEAP32[$16>>2] = 0;
 $17 = ((($2)) + 200|0);
 HEAP32[$17>>2] = 0;
 $18 = ((($2)) + 216|0);
 HEAP32[$18>>2] = 0;
 $19 = ((($2)) + 232|0);
 HEAP32[$19>>2] = 0;
 $20 = ((($2)) + 248|0);
 HEAP32[$20>>2] = 0;
 $21 = ((($2)) + 264|0);
 HEAP32[$21>>2] = 0;
 $22 = ((($2)) + 280|0);
 HEAP32[$22>>2] = 0;
 $23 = ((($2)) + 296|0);
 HEAP32[$23>>2] = 0;
 $24 = ((($2)) + 312|0);
 HEAP32[$24>>2] = 0;
 $25 = ((($2)) + 328|0);
 HEAP32[$25>>2] = 0;
 $26 = ((($2)) + 344|0);
 HEAP32[$26>>2] = 0;
 $27 = ((($2)) + 360|0);
 HEAP32[$27>>2] = 0;
 $28 = ((($2)) + 376|0);
 HEAP32[$28>>2] = 0;
 $29 = ((($2)) + 392|0);
 HEAP32[$29>>2] = 0;
 $30 = ((($2)) + 408|0);
 HEAP32[$30>>2] = 0;
 $31 = ((($2)) + 424|0);
 HEAP32[$31>>2] = 0;
 $32 = ((($2)) + 440|0);
 HEAP32[$32>>2] = 0;
 $33 = ((($2)) + 456|0);
 HEAP32[$33>>2] = 0;
 $34 = ((($2)) + 472|0);
 HEAP32[$34>>2] = 0;
 $35 = ((($2)) + 488|0);
 HEAP32[$35>>2] = 0;
 $36 = ((($2)) + 504|0);
 HEAP32[$36>>2] = 0;
 $37 = ((($2)) + 520|0);
 HEAP32[$37>>2] = 0;
 $38 = ((($2)) + 536|0);
 HEAP32[$38>>2] = 0;
 $39 = ((($2)) + 552|0);
 HEAP32[$39>>2] = 0;
 $40 = ((($2)) + 568|0);
 HEAP32[$40>>2] = 0;
 $41 = ((($2)) + 584|0);
 HEAP32[$41>>2] = 0;
 $42 = ((($2)) + 600|0);
 HEAP32[$42>>2] = 0;
 $43 = ((($2)) + 616|0);
 HEAP32[$43>>2] = 0;
 $44 = ((($2)) + 632|0);
 HEAP32[$44>>2] = 0;
 $45 = ((($L)) + 8|0);
 $46 = ((($2)) + 560|0);
 $47 = ((($L)) + 24|0);
 HEAP32[$47>>2] = $46;
 $48 = ((($L)) + 48|0);
 $49 = ((($L)) + 56|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($L)) + 60|0);
 HEAP32[$50>>2] = 0;
 $51 = ((($L)) + 82|0);
 HEAP8[$51>>0] = 0;
 $52 = $2;
 HEAP32[$48>>2] = $52;
 $53 = ((($2)) + 16|0);
 HEAP32[$45>>2] = $53;
 HEAP32[$5>>2] = 0;
 $54 = ((($2)) + 336|0);
 $55 = ((($L)) + 52|0);
 HEAP32[$55>>2] = $54;
 $56 = ((($L)) + 16|0);
 HEAP32[$56>>2] = $48;
 $57 = (_luaH_new($L)|0);
 $58 = ((($1)) + 40|0);
 HEAP32[$58>>2] = $57;
 $59 = ((($1)) + 48|0);
 HEAP32[$59>>2] = 69;
 _luaH_resize($L,$57,2,0);
 HEAP32[$temp$i>>2] = $L;
 $60 = ((($temp$i)) + 8|0);
 HEAP32[$60>>2] = 72;
 _luaH_setint($L,$57,1,0,$temp$i);
 $61 = (_luaH_new($L)|0);
 HEAP32[$temp$i>>2] = $61;
 HEAP32[$60>>2] = 69;
 _luaH_setint($L,$57,2,0,$temp$i);
 _luaS_resize($L,64);
 _luaT_init($L);
 _luaX_init($L);
 $62 = (_luaS_newlstr($L,2728,17)|0);
 $63 = ((($1)) + 144|0);
 HEAP32[$63>>2] = $62;
 _luaC_fix($L,$62);
 $64 = ((($1)) + 63|0);
 HEAP8[$64>>0] = 1;
 $65 = (_lua_version(0)|0);
 $66 = ((($1)) + 140|0);
 HEAP32[$66>>2] = $65;
 STACKTOP = sp;return;
}
function _close_state($L) {
 $L = $L|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $next$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 28|0);
 $3 = HEAP32[$2>>2]|0;
 _luaF_close($L,$3);
 _luaC_freeallobjects($L);
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 24|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ((($4)) + 32|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 << 2;
 (_luaM_realloc_($L,$6,$9,0)|0);
 $10 = ((($1)) + 108|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ((($1)) + 116|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_luaM_realloc_($L,$11,$13,0)|0);
 HEAP32[$10>>2] = $14;
 HEAP32[$12>>2] = 0;
 $15 = HEAP32[$2>>2]|0;
 $16 = ($15|0)==(0|0);
 if ($16) {
  $29 = HEAP32[$1>>2]|0;
  $30 = ((($1)) + 4|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($L)) + -4|0);
  (FUNCTION_TABLE_iiiii[$29 & 511]($31,$32,400,0)|0);
  return;
 }
 $17 = ((($L)) + 48|0);
 $18 = ((($L)) + 16|0);
 HEAP32[$18>>2] = $17;
 $19 = ((($L)) + 60|0);
 $20 = HEAP32[$19>>2]|0;
 HEAP32[$19>>2] = 0;
 $21 = ($20|0)==(0|0);
 if ($21) {
  $28 = $15;
 } else {
  $next$01$i$i = $20;
  while(1) {
   $22 = ((($next$01$i$i)) + 12|0);
   $23 = HEAP32[$22>>2]|0;
   (_luaM_realloc_($L,$next$01$i$i,36,0)|0);
   $24 = ($23|0)==(0|0);
   if ($24) {
    break;
   } else {
    $next$01$i$i = $23;
   }
  }
  $$pre$i = HEAP32[$2>>2]|0;
  $28 = $$pre$i;
 }
 $25 = ((($L)) + 92|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = $26 << 4;
 (_luaM_realloc_($L,$28,$27,0)|0);
 $29 = HEAP32[$1>>2]|0;
 $30 = ((($1)) + 4|0);
 $31 = HEAP32[$30>>2]|0;
 $32 = ((($L)) + -4|0);
 (FUNCTION_TABLE_iiiii[$29 & 511]($31,$32,400,0)|0);
 return;
}
function _luaS_eqlngstr($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($a)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($a|0)==($b|0);
 if ($2) {
  $11 = 1;
 } else {
  $3 = ((($b)) + 12|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($1|0)==($4|0);
  if ($5) {
   $6 = ((($a)) + 24|0);
   $7 = ((($b)) + 24|0);
   $8 = (_memcmp($6,$7,$1)|0);
   $9 = ($8|0)==(0);
   $11 = $9;
  } else {
   $11 = 0;
  }
 }
 $10 = $11&1;
 return ($10|0);
}
function _luaS_hash($str,$l,$seed) {
 $str = $str|0;
 $l = $l|0;
 $seed = $seed|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $h$0$lcssa = 0, $h$02 = 0, $l1$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $seed ^ $l;
 $1 = $l >>> 5;
 $2 = (($1) + 1)|0;
 $3 = ($2>>>0)>($l>>>0);
 if ($3) {
  $h$0$lcssa = $0;
  return ($h$0$lcssa|0);
 } else {
  $h$02 = $0;$l1$01 = $l;
 }
 while(1) {
  $4 = $h$02 << 5;
  $5 = $h$02 >>> 2;
  $6 = (($4) + ($5))|0;
  $7 = (($l1$01) + -1)|0;
  $8 = (($str) + ($7)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9&255;
  $11 = (($6) + ($10))|0;
  $12 = $11 ^ $h$02;
  $13 = (($l1$01) - ($2))|0;
  $14 = ($13>>>0)<($2>>>0);
  if ($14) {
   $h$0$lcssa = $12;
   break;
  } else {
   $h$02 = $12;$l1$01 = $13;
  }
 }
 return ($h$0$lcssa|0);
}
function _luaS_resize($L,$newsize) {
 $L = $L|0;
 $newsize = $newsize|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond9 = 0, $i$12 = 0, $p$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 24|0);
 $3 = ((($1)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)<($newsize|0);
 if ($5) {
  $9 = (($newsize) + 1)|0;
  $10 = ($9>>>0)>(1073741823);
  if ($10) {
   _luaM_toobig($L);
   // unreachable;
  }
  $11 = HEAP32[$2>>2]|0;
  $12 = $4 << 2;
  $13 = $newsize << 2;
  $14 = (_luaM_realloc_($L,$11,$12,$13)|0);
  HEAP32[$2>>2] = $14;
  $15 = HEAP32[$3>>2]|0;
  $16 = ($15|0)<($newsize|0);
  if ($16) {
   $17 = (($14) + ($15<<2)|0);
   HEAP32[$17>>2] = 0;
   $18 = (($15) + 1)|0;
   $exitcond9 = ($18|0)==($newsize|0);
   if ($exitcond9) {
    $7 = $15;
   } else {
    $20 = $18;
    while(1) {
     $$pre = HEAP32[$2>>2]|0;
     $19 = (($$pre) + ($20<<2)|0);
     HEAP32[$19>>2] = 0;
     $21 = (($20) + 1)|0;
     $exitcond = ($21|0)==($newsize|0);
     if ($exitcond) {
      $7 = $15;
      break;
     } else {
      $20 = $21;
     }
    }
   }
  } else {
   $7 = $15;
  }
 } else {
  $7 = $4;
 }
 $6 = ($7|0)>(0);
 if ($6) {
  $8 = (($newsize) + -1)|0;
  $i$12 = 0;
  while(1) {
   $22 = HEAP32[$2>>2]|0;
   $23 = (($22) + ($i$12<<2)|0);
   $24 = HEAP32[$23>>2]|0;
   HEAP32[$23>>2] = 0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $p$01 = $24;
    while(1) {
     $26 = ((($p$01)) + 16|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ((($p$01)) + 8|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = $29 & $8;
     $31 = HEAP32[$2>>2]|0;
     $32 = (($31) + ($30<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     HEAP32[$26>>2] = $33;
     HEAP32[$32>>2] = $p$01;
     $34 = ($27|0)==(0|0);
     if ($34) {
      break;
     } else {
      $p$01 = $27;
     }
    }
   }
   $35 = (($i$12) + 1)|0;
   $36 = ($35|0)<($7|0);
   if ($36) {
    $i$12 = $35;
   } else {
    break;
   }
  }
 }
 $37 = ($7|0)>($newsize|0);
 if (!($37)) {
  HEAP32[$3>>2] = $newsize;
  return;
 }
 $38 = (($newsize) + 1)|0;
 $39 = ($38>>>0)>(1073741823);
 if ($39) {
  _luaM_toobig($L);
  // unreachable;
 }
 $40 = HEAP32[$2>>2]|0;
 $41 = $7 << 2;
 $42 = $newsize << 2;
 $43 = (_luaM_realloc_($L,$40,$41,$42)|0);
 HEAP32[$2>>2] = $43;
 HEAP32[$3>>2] = $newsize;
 return;
}
function _luaS_remove($L,$ts) {
 $L = $L|0;
 $ts = $ts|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $p$0 = 0;
 var $p$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ts)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 32|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + -1)|0;
 $7 = $6 & $3;
 $8 = ((($1)) + 24|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<2)|0);
 $p$0 = $10;
 while(1) {
  $11 = HEAP32[$p$0>>2]|0;
  $12 = ($11|0)==($ts|0);
  $13 = ((($11)) + 16|0);
  if ($12) {
   $$lcssa = $13;$p$0$lcssa = $p$0;
   break;
  } else {
   $p$0 = $13;
  }
 }
 $14 = HEAP32[$$lcssa>>2]|0;
 HEAP32[$p$0$lcssa>>2] = $14;
 $15 = ((($1)) + 28|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (($16) + -1)|0;
 HEAP32[$15>>2] = $17;
 return;
}
function _luaS_newlstr($L,$str,$l) {
 $L = $L|0;
 $str = $str|0;
 $l = $l|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $9 = 0, $h$0$lcssa$i$i = 0, $h$02$i$i = 0, $l1$01$i$i = 0, $list$0$i = 0, $or$cond$i = 0, $ts$0$i = 0, $ts$02$i = 0, $ts$03$i = 0, $ts$03$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l>>>0)<(41);
 if (!($0)) {
  $68 = (($l) + 1)|0;
  $69 = ($68>>>0)>(4294967275);
  if ($69) {
   _luaM_toobig($L);
   // unreachable;
  }
  $70 = ((($L)) + 12|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = ((($71)) + 56|0);
  $73 = HEAP32[$72>>2]|0;
  $74 = (($l) + 25)|0;
  $75 = (_luaC_newobj($L,20,$74)|0);
  $76 = ((($75)) + 12|0);
  HEAP32[$76>>2] = $l;
  $77 = ((($75)) + 8|0);
  HEAP32[$77>>2] = $73;
  $78 = ((($75)) + 6|0);
  HEAP8[$78>>0] = 0;
  $79 = ((($75)) + 24|0);
  _memcpy(($79|0),($str|0),($l|0))|0;
  $80 = (($79) + ($l)|0);
  HEAP8[$80>>0] = 0;
  $$0 = $75;
  return ($$0|0);
 }
 $1 = ((($L)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 56|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 ^ $l;
 $6 = $l >>> 5;
 $7 = (($6) + 1)|0;
 $8 = ($7>>>0)>($l>>>0);
 if ($8) {
  $h$0$lcssa$i$i = $5;
 } else {
  $h$02$i$i = $5;$l1$01$i$i = $l;
  while(1) {
   $9 = $h$02$i$i << 5;
   $10 = $h$02$i$i >>> 2;
   $11 = (($9) + ($10))|0;
   $12 = (($l1$01$i$i) + -1)|0;
   $13 = (($str) + ($12)|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14&255;
   $16 = (($11) + ($15))|0;
   $17 = $16 ^ $h$02$i$i;
   $18 = (($l1$01$i$i) - ($7))|0;
   $19 = ($18>>>0)<($7>>>0);
   if ($19) {
    $h$0$lcssa$i$i = $17;
    break;
   } else {
    $h$02$i$i = $17;$l1$01$i$i = $18;
   }
  }
 }
 $20 = ((($2)) + 32|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + -1)|0;
 $23 = $22 & $h$0$lcssa$i$i;
 $24 = ((($2)) + 24|0);
 $25 = HEAP32[$24>>2]|0;
 $26 = (($25) + ($23<<2)|0);
 $ts$02$i = HEAP32[$26>>2]|0;
 $27 = ($ts$02$i|0)==(0|0);
 L12: do {
  if (!($27)) {
   $ts$03$i = $ts$02$i;
   while(1) {
    $28 = ((($ts$03$i)) + 12|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==($l|0);
    if ($30) {
     $31 = ((($ts$03$i)) + 24|0);
     $32 = (_memcmp($str,$31,$l)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $ts$03$i$lcssa = $ts$03$i;
      break;
     }
    }
    $45 = ((($ts$03$i)) + 16|0);
    $ts$0$i = HEAP32[$45>>2]|0;
    $46 = ($ts$0$i|0)==(0|0);
    if ($46) {
     break L12;
    } else {
     $ts$03$i = $ts$0$i;
    }
   }
   $34 = ((($ts$03$i$lcssa)) + 5|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = $35&255;
   $37 = $36 ^ 3;
   $38 = ((($2)) + 60|0);
   $39 = HEAP8[$38>>0]|0;
   $40 = $39&255;
   $41 = $40 ^ 3;
   $42 = $41 & $37;
   $43 = ($42|0)==(0);
   if (!($43)) {
    $$0 = $ts$03$i$lcssa;
    return ($$0|0);
   }
   $44 = $37&255;
   HEAP8[$34>>0] = $44;
   $$0 = $ts$03$i$lcssa;
   return ($$0|0);
  }
 } while(0);
 $47 = ((($2)) + 28|0);
 $48 = HEAP32[$47>>2]|0;
 $49 = ($48|0)>=($21|0);
 $50 = ($21|0)<(1073741824);
 $or$cond$i = $50 & $49;
 if ($or$cond$i) {
  $51 = $21 << 1;
  _luaS_resize($L,$51);
  $52 = HEAP32[$20>>2]|0;
  $53 = (($52) + -1)|0;
  $54 = $53 & $h$0$lcssa$i$i;
  $55 = HEAP32[$24>>2]|0;
  $56 = (($55) + ($54<<2)|0);
  $list$0$i = $56;
 } else {
  $list$0$i = $26;
 }
 $57 = (($l) + 25)|0;
 $58 = (_luaC_newobj($L,4,$57)|0);
 $59 = ((($58)) + 12|0);
 HEAP32[$59>>2] = $l;
 $60 = ((($58)) + 8|0);
 HEAP32[$60>>2] = $h$0$lcssa$i$i;
 $61 = ((($58)) + 6|0);
 HEAP8[$61>>0] = 0;
 $62 = ((($58)) + 24|0);
 _memcpy(($62|0),($str|0),($l|0))|0;
 $63 = (($62) + ($l)|0);
 HEAP8[$63>>0] = 0;
 $64 = HEAP32[$list$0$i>>2]|0;
 $65 = ((($58)) + 16|0);
 HEAP32[$65>>2] = $64;
 HEAP32[$list$0$i>>2] = $58;
 $66 = HEAP32[$47>>2]|0;
 $67 = (($66) + 1)|0;
 HEAP32[$47>>2] = $67;
 $$0 = $58;
 return ($$0|0);
}
function _luaS_new($L,$str) {
 $L = $L|0;
 $str = $str|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($str|0))|0);
 $1 = (_luaS_newlstr($L,$str,$0)|0);
 return ($1|0);
}
function _luaS_newudata($L,$s) {
 $L = $L|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($s>>>0)>(4294967271);
 if ($0) {
  _luaM_toobig($L);
  // unreachable;
 } else {
  $1 = (($s) + 24)|0;
  $2 = (_luaC_newobj($L,7,$1)|0);
  $3 = ((($2)) + 12|0);
  HEAP32[$3>>2] = $s;
  $4 = ((($2)) + 8|0);
  HEAP32[$4>>2] = 0;
  $5 = ((($2)) + 16|0);
  $6 = 1568;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (($6) + 4)|0;
  $10 = $9;
  $11 = HEAP32[$10>>2]|0;
  $12 = $5;
  $13 = $12;
  HEAP32[$13>>2] = $8;
  $14 = (($12) + 4)|0;
  $15 = $14;
  HEAP32[$15>>2] = $11;
  $16 = HEAP32[(1576)>>2]|0;
  $17 = $16&255;
  $18 = ((($2)) + 6|0);
  HEAP8[$18>>0] = $17;
  return ($2|0);
 }
 return (0)|0;
}
function _luaH_next($L,$t,$key) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa22 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$0 = 0, $i$0$lcssa = 0, $i$0$lcssa21 = 0, $i$0$ph = 0, $i$18 = 0, $i$18$lcssa = 0, $n$0$lcssa$i = 0, $n$02$i = 0, $or$cond$i = 0, $or$cond$i$not$i = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 19)) {
  $2 = $key;
  $3 = $2;
  $4 = HEAP32[$3>>2]|0;
  $5 = (($2) + 4)|0;
  $6 = $5;
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)<(0);
  $9 = ($4>>>0)<(1);
  $10 = ($7|0)==(0);
  $11 = $10 & $9;
  $12 = $8 | $11;
  $13 = ($7>>>0)>(0);
  $14 = ($4>>>0)>(2147483648);
  $15 = ($7|0)==(0);
  $16 = $15 & $14;
  $17 = $13 | $16;
  $or$cond$i$not$i = $17 | $12;
  $18 = ($4|0)==(0);
  $or$cond$i = $or$cond$i$not$i | $18;
  if ($or$cond$i) {
   label = 5;
  } else {
   $19 = ((($t)) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   $21 = ($4>>>0)>($20>>>0);
   if ($21) {
    label = 5;
   } else {
    $55 = $20;$i$0$ph = $4;
   }
  }
 } else if ((($1|0) == 0)) {
  $$phi$trans$insert = ((($t)) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $55 = $$pre;$i$0$ph = 0;
 } else {
  label = 5;
 }
 if ((label|0) == 5) {
  $22 = (_mainposition($t,$key)|0);
  $23 = ((($22)) + 16|0);
  $24 = (_luaV_equalobj(0,$23,$key)|0);
  $25 = ($24|0)==(0);
  L7: do {
   if ($25) {
    $33 = $23;$n$02$i = $22;
    while(1) {
     $26 = ((($n$02$i)) + 24|0);
     $27 = HEAP32[$26>>2]|0;
     $28 = ($27|0)==(10);
     if ($28) {
      $29 = HEAP32[$0>>2]|0;
      $30 = $29 & 64;
      $31 = ($30|0)==(0);
      if (!($31)) {
       $32 = HEAP32[$33>>2]|0;
       $34 = HEAP32[$key>>2]|0;
       $35 = ($32|0)==($34|0);
       if ($35) {
        $n$0$lcssa$i = $n$02$i;
        break L7;
       }
      }
     }
     $47 = ((($n$02$i)) + 28|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==(0);
     if ($49) {
      break;
     }
     $50 = (($n$02$i) + ($48<<5)|0);
     $51 = (((($n$02$i) + ($48<<5)|0)) + 16|0);
     $52 = (_luaV_equalobj(0,$51,$key)|0);
     $53 = ($52|0)==(0);
     if ($53) {
      $33 = $51;$n$02$i = $50;
     } else {
      $n$0$lcssa$i = $50;
      break L7;
     }
    }
    _luaG_runerror($L,2752,$vararg_buffer);
    // unreachable;
   } else {
    $n$0$lcssa$i = $22;
   }
  } while(0);
  $36 = ((($t)) + 16|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = $n$0$lcssa$i;
  $39 = $37;
  $40 = (($38) - ($39))|0;
  $41 = $40 >> 5;
  $42 = ((($t)) + 8|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (($43) + 1)|0;
  $45 = (($44) + ($41))|0;
  $55 = $43;$i$0$ph = $45;
 }
 $46 = ((($t)) + 12|0);
 $i$0 = $i$0$ph;
 while(1) {
  $54 = ($i$0>>>0)<($55>>>0);
  if (!($54)) {
   $i$0$lcssa = $i$0;
   break;
  }
  $56 = HEAP32[$46>>2]|0;
  $57 = (((($56) + ($i$0<<4)|0)) + 8|0);
  $58 = HEAP32[$57>>2]|0;
  $59 = ($58|0)==(0);
  $60 = (($i$0) + 1)|0;
  if ($59) {
   $i$0 = $60;
  } else {
   $$lcssa = $56;$$lcssa22 = $60;$i$0$lcssa21 = $i$0;
   label = 17;
   break;
  }
 }
 if ((label|0) == 17) {
  $61 = $key;
  $62 = $61;
  HEAP32[$62>>2] = $$lcssa22;
  $63 = (($61) + 4)|0;
  $64 = $63;
  HEAP32[$64>>2] = 0;
  HEAP32[$0>>2] = 19;
  $65 = ((($key)) + 16|0);
  $66 = (($$lcssa) + ($i$0$lcssa21<<4)|0);
  ;HEAP32[$65>>2]=HEAP32[$66>>2]|0;HEAP32[$65+4>>2]=HEAP32[$66+4>>2]|0;HEAP32[$65+8>>2]=HEAP32[$66+8>>2]|0;HEAP32[$65+12>>2]=HEAP32[$66+12>>2]|0;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (($i$0$lcssa) - ($55))|0;
 $68 = ((($t)) + 7|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = $69&255;
 $71 = 1 << $70;
 $72 = ($67|0)<($71|0);
 if (!($72)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $73 = ((($t)) + 16|0);
 $74 = HEAP32[$73>>2]|0;
 $i$18 = $67;
 while(1) {
  $75 = (((($74) + ($i$18<<5)|0)) + 8|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = ($76|0)==(0);
  if (!($77)) {
   $i$18$lcssa = $i$18;
   break;
  }
  $82 = (($i$18) + 1)|0;
  $83 = ($82|0)<($71|0);
  if ($83) {
   $i$18 = $82;
  } else {
   $$0 = 0;
   label = 23;
   break;
  }
 }
 if ((label|0) == 23) {
  STACKTOP = sp;return ($$0|0);
 }
 $78 = (((($74) + ($i$18$lcssa<<5)|0)) + 16|0);
 ;HEAP32[$key>>2]=HEAP32[$78>>2]|0;HEAP32[$key+4>>2]=HEAP32[$78+4>>2]|0;HEAP32[$key+8>>2]=HEAP32[$78+8>>2]|0;HEAP32[$key+12>>2]=HEAP32[$78+12>>2]|0;
 $79 = ((($key)) + 16|0);
 $80 = HEAP32[$73>>2]|0;
 $81 = (($80) + ($i$18$lcssa<<5)|0);
 ;HEAP32[$79>>2]=HEAP32[$81>>2]|0;HEAP32[$79+4>>2]=HEAP32[$81+4>>2]|0;HEAP32[$79+8>>2]=HEAP32[$81+8>>2]|0;HEAP32[$79+12>>2]=HEAP32[$81+12>>2]|0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _luaH_resize($L,$t,$nasize,$nhsize) {
 $L = $L|0;
 $t = $t|0;
 $nasize = $nasize|0;
 $nhsize = $nhsize|0;
 var $$0$i = 0, $$0$i$i = 0, $$0$i3 = 0, $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cell$0$i = 0, $exitcond = 0, $exitcond$i = 0, $i$01$i = 0, $i$01$i1 = 0, $i$07 = 0, $j$06 = 0, $j$06$in = 0, $k$i = 0, $lsize$0$i = 0, $n$0$i$i = 0, $n$0$i$i$lcssa = 0;
 var $phitmp$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 16|0;
 $k$i = sp;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 7|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = ((($t)) + 16|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($1>>>0)<($nasize>>>0);
 if ($7) {
  $8 = (($nasize) + 1)|0;
  $9 = ($8>>>0)>(268435455);
  if ($9) {
   _luaM_toobig($L);
   // unreachable;
  }
  $10 = ((($t)) + 12|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $1 << 4;
  $13 = $nasize << 4;
  $14 = (_luaM_realloc_($L,$11,$12,$13)|0);
  HEAP32[$10>>2] = $14;
  $15 = HEAP32[$0>>2]|0;
  $16 = ($15>>>0)<($nasize>>>0);
  if ($16) {
   $i$01$i1 = $15;
   while(1) {
    $17 = (((($14) + ($i$01$i1<<4)|0)) + 8|0);
    HEAP32[$17>>2] = 0;
    $18 = (($i$01$i1) + 1)|0;
    $exitcond$i = ($18|0)==($nasize|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i1 = $18;
    }
   }
  }
  HEAP32[$0>>2] = $nasize;
 }
 $19 = ($nhsize|0)==(0);
 if ($19) {
  HEAP32[$5>>2] = 2776;
  $$0$i = 0;$33 = 2776;$lsize$0$i = 0;
 } else {
  $20 = (_luaO_ceillog2($nhsize)|0);
  $21 = ($20|0)>(30);
  if ($21) {
   _luaG_runerror($L,2808,$vararg_buffer);
   // unreachable;
  }
  $22 = 1 << $20;
  $23 = (($22) + 1)|0;
  $24 = ($23>>>0)>(134217727);
  if ($24) {
   _luaM_toobig($L);
   // unreachable;
  }
  $25 = $22 << 5;
  $26 = (_luaM_realloc_($L,0,0,$25)|0);
  HEAP32[$5>>2] = $26;
  $i$01$i = 0;
  while(1) {
   $27 = (((($26) + ($i$01$i<<5)|0)) + 28|0);
   HEAP32[$27>>2] = 0;
   $28 = (((($26) + ($i$01$i<<5)|0)) + 24|0);
   HEAP32[$28>>2] = 0;
   $29 = (((($26) + ($i$01$i<<5)|0)) + 8|0);
   HEAP32[$29>>2] = 0;
   $30 = (($i$01$i) + 1)|0;
   $31 = ($30|0)<($22|0);
   if ($31) {
    $i$01$i = $30;
   } else {
    break;
   }
  }
  $phitmp$i = $20&255;
  $$0$i = $22;$33 = $26;$lsize$0$i = $phitmp$i;
 }
 HEAP8[$2>>0] = $lsize$0$i;
 $32 = (($33) + ($$0$i<<5)|0);
 $34 = ((($t)) + 20|0);
 HEAP32[$34>>2] = $32;
 $35 = ($1>>>0)>($nasize>>>0);
 do {
  if ($35) {
   HEAP32[$0>>2] = $nasize;
   $36 = ((($t)) + 12|0);
   $37 = ((($k$i)) + 8|0);
   $i$07 = $nasize;
   while(1) {
    $38 = HEAP32[$36>>2]|0;
    $39 = (((($38) + ($i$07<<4)|0)) + 8|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ($40|0)==(0);
    if ($41) {
     $$pre = (($i$07) + 1)|0;
     $$pre$phiZ2D = $$pre;
    } else {
     $42 = (($38) + ($i$07<<4)|0);
     $43 = (($i$07) + 1)|0;
     $44 = (_i64Add(($43|0),0,-1,-1)|0);
     $45 = tempRet0;
     $46 = HEAP32[$0>>2]|0;
     $47 = ($45>>>0)<(0);
     $48 = ($44>>>0)<($46>>>0);
     $49 = ($45|0)==(0);
     $50 = $49 & $48;
     $51 = $47 | $50;
     L30: do {
      if ($51) {
       $52 = (($38) + ($44<<4)|0);
       $$0$i$i = $52;
       label = 28;
      } else {
       $53 = HEAP8[$2>>0]|0;
       $54 = $53&255;
       $55 = 1 << $54;
       $56 = (($55) + -1)|0;
       $57 = $56 & $43;
       $58 = HEAP32[$5>>2]|0;
       $59 = (($58) + ($57<<5)|0);
       $n$0$i$i = $59;
       while(1) {
        $60 = ((($n$0$i$i)) + 24|0);
        $61 = HEAP32[$60>>2]|0;
        $62 = ($61|0)==(19);
        if ($62) {
         $63 = ((($n$0$i$i)) + 16|0);
         $64 = $63;
         $65 = $64;
         $66 = HEAP32[$65>>2]|0;
         $67 = (($64) + 4)|0;
         $68 = $67;
         $69 = HEAP32[$68>>2]|0;
         $70 = ($66|0)==($43|0);
         $71 = ($69|0)==(0);
         $72 = $70 & $71;
         if ($72) {
          $n$0$i$i$lcssa = $n$0$i$i;
          break;
         }
        }
        $73 = ((($n$0$i$i)) + 28|0);
        $74 = HEAP32[$73>>2]|0;
        $75 = ($74|0)==(0);
        if ($75) {
         label = 29;
         break L30;
        }
        $76 = (($n$0$i$i) + ($74<<5)|0);
        $n$0$i$i = $76;
       }
       $$0$i$i = $n$0$i$i$lcssa;
       label = 28;
      }
     } while(0);
     if ((label|0) == 28) {
      label = 0;
      $77 = ($$0$i$i|0)==(1568|0);
      if ($77) {
       label = 29;
      } else {
       $cell$0$i = $$0$i$i;
      }
     }
     if ((label|0) == 29) {
      label = 0;
      $78 = $k$i;
      $79 = $78;
      HEAP32[$79>>2] = $43;
      $80 = (($78) + 4)|0;
      $81 = $80;
      HEAP32[$81>>2] = 0;
      HEAP32[$37>>2] = 19;
      $82 = (_luaH_newkey($L,$t,$k$i)|0);
      $cell$0$i = $82;
     }
     ;HEAP32[$cell$0$i>>2]=HEAP32[$42>>2]|0;HEAP32[$cell$0$i+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$cell$0$i+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$cell$0$i+12>>2]=HEAP32[$42+12>>2]|0;
     $$pre$phiZ2D = $43;
    }
    $exitcond = ($$pre$phiZ2D|0)==($1|0);
    if ($exitcond) {
     break;
    } else {
     $i$07 = $$pre$phiZ2D;
    }
   }
   $83 = (($nasize) + 1)|0;
   $84 = ($83>>>0)>(268435455);
   if ($84) {
    _luaM_toobig($L);
    // unreachable;
   } else {
    $85 = ((($t)) + 12|0);
    $86 = HEAP32[$85>>2]|0;
    $87 = $1 << 4;
    $88 = $nasize << 4;
    $89 = (_luaM_realloc_($L,$86,$87,$88)|0);
    HEAP32[$85>>2] = $89;
    break;
   }
  }
 } while(0);
 $90 = 1 << $4;
 $91 = ($3<<24>>24)==(31);
 if (!($91)) {
  $j$06$in = $90;
  while(1) {
   $j$06 = (($j$06$in) + -1)|0;
   $92 = (((($6) + ($j$06<<5)|0)) + 8|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(0);
   if (!($94)) {
    $96 = (($6) + ($j$06<<5)|0);
    $97 = (((($6) + ($j$06<<5)|0)) + 16|0);
    $98 = (_luaH_get($t,$97)|0);
    $99 = ($98|0)==(1568|0);
    if ($99) {
     $100 = (_luaH_newkey($L,$t,$97)|0);
     $$0$i3 = $100;
    } else {
     $$0$i3 = $98;
    }
    ;HEAP32[$$0$i3>>2]=HEAP32[$96>>2]|0;HEAP32[$$0$i3+4>>2]=HEAP32[$96+4>>2]|0;HEAP32[$$0$i3+8>>2]=HEAP32[$96+8>>2]|0;HEAP32[$$0$i3+12>>2]=HEAP32[$96+12>>2]|0;
   }
   $95 = ($j$06$in|0)>(1);
   if ($95) {
    $j$06$in = $j$06;
   } else {
    break;
   }
  }
 }
 $101 = ($6|0)==(2776|0);
 if ($101) {
  STACKTOP = sp;return;
 }
 $102 = $90 << 5;
 (_luaM_realloc_($L,$6,$102,0)|0);
 STACKTOP = sp;return;
}
function _luaH_setint($L,$t,$0,$1,$value) {
 $L = $L|0;
 $t = $t|0;
 $0 = $0|0;
 $1 = $1|0;
 $value = $value|0;
 var $$0$i = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cell$0 = 0, $k = 0, $n$0$i = 0, $n$0$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp;
 $2 = (_i64Add(($0|0),($1|0),-1,-1)|0);
 $3 = tempRet0;
 $4 = ((($t)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<(0);
 $7 = ($2>>>0)<($5>>>0);
 $8 = ($3|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 L1: do {
  if ($10) {
   $11 = ((($t)) + 12|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = (($12) + ($2<<4)|0);
   $$0$i = $13;
   label = 9;
  } else {
   $14 = ((($t)) + 7|0);
   $15 = HEAP8[$14>>0]|0;
   $16 = $15&255;
   $17 = 1 << $16;
   $18 = (($17) + -1)|0;
   $19 = $18 & $0;
   $20 = ((($t)) + 16|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (($21) + ($19<<5)|0);
   $n$0$i = $22;
   while(1) {
    $23 = ((($n$0$i)) + 24|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = ($24|0)==(19);
    if ($25) {
     $26 = ((($n$0$i)) + 16|0);
     $27 = $26;
     $28 = $27;
     $29 = HEAP32[$28>>2]|0;
     $30 = (($27) + 4)|0;
     $31 = $30;
     $32 = HEAP32[$31>>2]|0;
     $33 = ($29|0)==($0|0);
     $34 = ($32|0)==($1|0);
     $35 = $33 & $34;
     if ($35) {
      $n$0$i$lcssa = $n$0$i;
      break;
     }
    }
    $36 = ((($n$0$i)) + 28|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ($37|0)==(0);
    if ($38) {
     break L1;
    }
    $39 = (($n$0$i) + ($37<<5)|0);
    $n$0$i = $39;
   }
   $$0$i = $n$0$i$lcssa;
   label = 9;
  }
 } while(0);
 if ((label|0) == 9) {
  $40 = ($$0$i|0)==(1568|0);
  if (!($40)) {
   $cell$0 = $$0$i;
   ;HEAP32[$cell$0>>2]=HEAP32[$value>>2]|0;HEAP32[$cell$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$cell$0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$cell$0+12>>2]=HEAP32[$value+12>>2]|0;
   STACKTOP = sp;return;
  }
 }
 $41 = $k;
 $42 = $41;
 HEAP32[$42>>2] = $0;
 $43 = (($41) + 4)|0;
 $44 = $43;
 HEAP32[$44>>2] = $1;
 $45 = ((($k)) + 8|0);
 HEAP32[$45>>2] = 19;
 $46 = (_luaH_newkey($L,$t,$k)|0);
 $cell$0 = $46;
 ;HEAP32[$cell$0>>2]=HEAP32[$value>>2]|0;HEAP32[$cell$0+4>>2]=HEAP32[$value+4>>2]|0;HEAP32[$cell$0+8>>2]=HEAP32[$value+8>>2]|0;HEAP32[$cell$0+12>>2]=HEAP32[$value+12>>2]|0;
 STACKTOP = sp;return;
}
function _luaH_set($L,$t,$key) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaH_get($t,$key)|0);
 $1 = ($0|0)==(1568|0);
 if (!($1)) {
  $$0 = $0;
  return ($$0|0);
 }
 $2 = (_luaH_newkey($L,$t,$key)|0);
 $$0 = $2;
 return ($$0|0);
}
function _luaH_resizearray($L,$t,$nasize) {
 $L = $L|0;
 $t = $t|0;
 $nasize = $nasize|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2776|0);
 if ($2) {
  $7 = 0;
 } else {
  $3 = ((($t)) + 7|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = 1 << $5;
  $7 = $6;
 }
 _luaH_resize($L,$t,$nasize,$7);
 return;
}
function _luaH_new($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaC_newobj($L,5,32)|0);
 $1 = ((($0)) + 24|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 6|0);
 HEAP8[$2>>0] = -1;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 8|0);
 HEAP32[$4>>2] = 0;
 $5 = ((($0)) + 16|0);
 HEAP32[$5>>2] = 2776;
 $6 = ((($0)) + 7|0);
 HEAP8[$6>>0] = 0;
 $7 = ((($0)) + 20|0);
 HEAP32[$7>>2] = 2776;
 return ($0|0);
}
function _luaH_free($L,$t) {
 $L = $L|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(2776|0);
 if (!($2)) {
  $3 = ((($t)) + 7|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4&255;
  $6 = 32 << $5;
  (_luaM_realloc_($L,$1,$6,0)|0);
 }
 $7 = ((($t)) + 12|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = ((($t)) + 8|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 << 4;
 (_luaM_realloc_($L,$8,$11,0)|0);
 (_luaM_realloc_($L,$t,32,0)|0);
 return;
}
function _luaH_newkey($L,$t,$key) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$02 = 0, $$lcssa = 0, $$lcssa44 = 0, $$lcssa45 = 0, $$lcssa48 = 0, $$lcssa49 = 0, $$na$0$i$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0.0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $a$03$i$i = 0, $a$1$i$i = 0, $ause$0$lcssa$i$i = 0, $ause$0$ph$i$i = 0, $ause$0$ph$i$i$lcssa = 0, $ause$06$i$i = 0, $aux = 0, $i$0$i$i = 0, $i$0$ph$i$i = 0, $i$01$i$i = 0, $i$07$i$i = 0, $i$1$lcssa$i$i = 0, $i$11$i$i = 0, $lc$0$$i$i = 0, $lc$0$lcssa$i$i = 0, $lc$02$i$i = 0, $lg$04$i$i = 0, $lim$0$ph$i$i = 0, $mp$0 = 0, $n$05$i$i = 0;
 var $n$1$i$i = 0, $n$2$i$i = 0, $na$04$i$i = 0, $na$1$i$i = 0, $na$2$i$i = 0, $not$$i$i = 0, $nums$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i$i = 0, $or$cond$i$not$i$i = 0, $or$cond$i$not$i$i$i = 0, $othern$0 = 0, $othern$0$lcssa = 0, $totaluse$0$ph$i$i = 0, $totaluse$0$ph$i$i$lcssa = 0, $ttlg$05$i$i = 0, $twotoi$0$n$0$i$i = 0, $twotoi$02$i$i = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 24|0;
 $vararg_buffer = sp + 16|0;
 $nums$i = sp + 32|0;
 $aux = sp;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 if ((($1|0) == 3)) {
  label = 3;
 } else if ((($1|0) == 0)) {
  _luaG_runerror($L,2824,$vararg_buffer);
  // unreachable;
 } else {
  $$02 = $key;
 }
 if ((label|0) == 3) {
  $2 = +HEAPF64[$key>>3];
  $3 = ($2 == $2) & (0.0 == 0.0);
  if (!($3)) {
   _luaG_runerror($L,2848,$vararg_buffer1);
   // unreachable;
  }
  $4 = (+Math_floor((+$2)));
  $5 = $4 == $2;
  if ($5) {
   $6 = $2 >= -9.2233720368547758E+18;
   $7 = $2 < 9.2233720368547758E+18;
   $or$cond$i = $6 & $7;
   if ($or$cond$i) {
    $8 = (~~$2)>>>0;
    $9 = +Math_abs($2) >= 1.0 ? $2 > 0.0 ? (~~+Math_min(+Math_floor($2 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($2 - +(~~$2 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $10 = $aux;
    $11 = $10;
    HEAP32[$11>>2] = $8;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP32[$13>>2] = $9;
    $14 = ((($aux)) + 8|0);
    HEAP32[$14>>2] = 19;
    $$02 = $aux;
   } else {
    $$02 = $key;
   }
  } else {
   $$02 = $key;
  }
 }
 $15 = (_mainposition($t,$$02)|0);
 $16 = ((($15)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)!=(0);
 $19 = ($15|0)==(2776|0);
 $or$cond = $19 | $18;
 do {
  if ($or$cond) {
   $20 = ((($t)) + 20|0);
   $21 = ((($t)) + 16|0);
   $22 = HEAP32[$21>>2]|0;
   $$pre$i = HEAP32[$20>>2]|0;
   $24 = $$pre$i;
   while(1) {
    $23 = ($24>>>0)>($22>>>0);
    if (!($23)) {
     break;
    }
    $25 = ((($24)) + -32|0);
    HEAP32[$20>>2] = $25;
    $26 = ((($24)) + -8|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = ($27|0)==(0);
    if ($28) {
     $$lcssa48 = $24;$$lcssa49 = $25;
     label = 37;
     break;
    } else {
     $24 = $25;
    }
   }
   if ((label|0) == 37) {
    $130 = ((($15)) + 16|0);
    $131 = (_mainposition($t,$130)|0);
    $132 = ($131|0)==($15|0);
    if ($132) {
     $150 = ((($15)) + 28|0);
     $151 = HEAP32[$150>>2]|0;
     $152 = ($151|0)==(0);
     if ($152) {
      $$pre = $$lcssa49;
      $$pre$phiZ2D = $$pre;
     } else {
      $153 = (($15) + ($151<<5)|0);
      $154 = $153;
      $155 = $$lcssa49;
      $156 = (($154) - ($155))|0;
      $157 = $156 >> 5;
      $158 = ((($$lcssa48)) + -4|0);
      HEAP32[$158>>2] = $157;
      $$pre$phiZ2D = $155;
     }
     $159 = $15;
     $160 = (($$pre$phiZ2D) - ($159))|0;
     $161 = $160 >> 5;
     HEAP32[$150>>2] = $161;
     $mp$0 = $$lcssa49;
     break;
    } else {
     $othern$0 = $131;
     while(1) {
      $133 = ((($othern$0)) + 28|0);
      $134 = HEAP32[$133>>2]|0;
      $135 = (($othern$0) + ($134<<5)|0);
      $136 = ($135|0)==($15|0);
      if ($136) {
       $$lcssa = $133;$othern$0$lcssa = $othern$0;
       break;
      } else {
       $othern$0 = $135;
      }
     }
     $137 = $$lcssa49;
     $138 = $othern$0$lcssa;
     $139 = (($137) - ($138))|0;
     $140 = $139 >> 5;
     HEAP32[$$lcssa>>2] = $140;
     ;HEAP32[$$lcssa49>>2]=HEAP32[$15>>2]|0;HEAP32[$$lcssa49+4>>2]=HEAP32[$15+4>>2]|0;HEAP32[$$lcssa49+8>>2]=HEAP32[$15+8>>2]|0;HEAP32[$$lcssa49+12>>2]=HEAP32[$15+12>>2]|0;HEAP32[$$lcssa49+16>>2]=HEAP32[$15+16>>2]|0;HEAP32[$$lcssa49+20>>2]=HEAP32[$15+20>>2]|0;HEAP32[$$lcssa49+24>>2]=HEAP32[$15+24>>2]|0;HEAP32[$$lcssa49+28>>2]=HEAP32[$15+28>>2]|0;
     $141 = ((($15)) + 28|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ($142|0)==(0);
     if (!($143)) {
      $144 = $15;
      $145 = (($144) - ($137))|0;
      $146 = $145 >> 5;
      $147 = ((($$lcssa48)) + -4|0);
      $148 = HEAP32[$147>>2]|0;
      $149 = (($148) + ($146))|0;
      HEAP32[$147>>2] = $149;
      HEAP32[$141>>2] = 0;
     }
     HEAP32[$16>>2] = 0;
     $mp$0 = $15;
     break;
    }
   }
   dest=$nums$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
   $29 = ((($t)) + 8|0);
   $30 = ((($t)) + 12|0);
   $31 = HEAP32[$29>>2]|0;
   $ause$06$i$i = 0;$i$07$i$i = 1;$lg$04$i$i = 0;$ttlg$05$i$i = 1;
   while(1) {
    $32 = ($ttlg$05$i$i>>>0)>($31>>>0);
    if ($32) {
     $33 = ($i$07$i$i>>>0)>($31>>>0);
     if ($33) {
      $ause$0$lcssa$i$i = $ause$06$i$i;
      break;
     } else {
      $lim$0$ph$i$i = $31;
     }
    } else {
     $lim$0$ph$i$i = $ttlg$05$i$i;
    }
    $34 = ($i$07$i$i>>>0)>($lim$0$ph$i$i>>>0);
    if ($34) {
     $i$1$lcssa$i$i = $i$07$i$i;$lc$0$lcssa$i$i = 0;
    } else {
     $35 = HEAP32[$30>>2]|0;
     $i$11$i$i = $i$07$i$i;$lc$02$i$i = 0;
     while(1) {
      $36 = (($i$11$i$i) + -1)|0;
      $37 = (((($35) + ($36<<4)|0)) + 8|0);
      $38 = HEAP32[$37>>2]|0;
      $not$$i$i = ($38|0)!=(0);
      $39 = $not$$i$i&1;
      $lc$0$$i$i = (($39) + ($lc$02$i$i))|0;
      $40 = (($i$11$i$i) + 1)|0;
      $41 = ($40>>>0)>($lim$0$ph$i$i>>>0);
      if ($41) {
       $i$1$lcssa$i$i = $40;$lc$0$lcssa$i$i = $lc$0$$i$i;
       break;
      } else {
       $i$11$i$i = $40;$lc$02$i$i = $lc$0$$i$i;
      }
     }
    }
    $42 = (($nums$i) + ($lg$04$i$i<<2)|0);
    $43 = HEAP32[$42>>2]|0;
    $44 = (($43) + ($lc$0$lcssa$i$i))|0;
    HEAP32[$42>>2] = $44;
    $45 = (($lc$0$lcssa$i$i) + ($ause$06$i$i))|0;
    $46 = (($lg$04$i$i) + 1)|0;
    $47 = $ttlg$05$i$i << 1;
    $48 = ($46|0)<(32);
    if ($48) {
     $ause$06$i$i = $45;$i$07$i$i = $i$1$lcssa$i$i;$lg$04$i$i = $46;$ttlg$05$i$i = $47;
    } else {
     $ause$0$lcssa$i$i = $45;
     break;
    }
   }
   $49 = ((($t)) + 7|0);
   $50 = HEAP8[$49>>0]|0;
   $51 = $50&255;
   $52 = 1 << $51;
   $ause$0$ph$i$i = 0;$i$0$ph$i$i = $52;$totaluse$0$ph$i$i = 0;
   L42: while(1) {
    $i$0$i$i = $i$0$ph$i$i;
    while(1) {
     $53 = (($i$0$i$i) + -1)|0;
     $54 = ($i$0$i$i|0)==(0);
     if ($54) {
      $ause$0$ph$i$i$lcssa = $ause$0$ph$i$i;$totaluse$0$ph$i$i$lcssa = $totaluse$0$ph$i$i;
      break L42;
     }
     $55 = HEAP32[$21>>2]|0;
     $56 = (((($55) + ($53<<5)|0)) + 8|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = ($57|0)==(0);
     if ($58) {
      $i$0$i$i = $53;
     } else {
      $$lcssa44 = $53;$$lcssa45 = $55;
      break;
     }
    }
    $59 = (((($$lcssa45) + ($$lcssa44<<5)|0)) + 24|0);
    $60 = HEAP32[$59>>2]|0;
    $61 = ($60|0)==(19);
    if ($61) {
     $62 = (((($$lcssa45) + ($$lcssa44<<5)|0)) + 16|0);
     $63 = $62;
     $64 = $63;
     $65 = HEAP32[$64>>2]|0;
     $66 = (($63) + 4)|0;
     $67 = $66;
     $68 = HEAP32[$67>>2]|0;
     $69 = ($68|0)<(0);
     $70 = ($65>>>0)<(1);
     $71 = ($68|0)==(0);
     $72 = $71 & $70;
     $73 = $69 | $72;
     $74 = ($68>>>0)>(0);
     $75 = ($65>>>0)>(2147483648);
     $76 = ($68|0)==(0);
     $77 = $76 & $75;
     $78 = $74 | $77;
     $or$cond$i$not$i$i$i = $78 | $73;
     $79 = ($65|0)==(0);
     $or$cond$i$i$i = $or$cond$i$not$i$i$i | $79;
     if ($or$cond$i$i$i) {
      $$0$i$i$i = 0;
     } else {
      $80 = (_luaO_ceillog2($65)|0);
      $81 = (($nums$i) + ($80<<2)|0);
      $82 = HEAP32[$81>>2]|0;
      $83 = (($82) + 1)|0;
      HEAP32[$81>>2] = $83;
      $$0$i$i$i = 1;
     }
    } else {
     $$0$i$i$i = 0;
    }
    $84 = (($$0$i$i$i) + ($ause$0$ph$i$i))|0;
    $85 = (($totaluse$0$ph$i$i) + 1)|0;
    $ause$0$ph$i$i = $84;$i$0$ph$i$i = $$lcssa44;$totaluse$0$ph$i$i = $85;
   }
   $86 = (($ause$0$ph$i$i$lcssa) + ($ause$0$lcssa$i$i))|0;
   $87 = ((($$02)) + 8|0);
   $88 = HEAP32[$87>>2]|0;
   $89 = ($88|0)==(19);
   if ($89) {
    $90 = $$02;
    $91 = $90;
    $92 = HEAP32[$91>>2]|0;
    $93 = (($90) + 4)|0;
    $94 = $93;
    $95 = HEAP32[$94>>2]|0;
    $96 = ($95|0)<(0);
    $97 = ($92>>>0)<(1);
    $98 = ($95|0)==(0);
    $99 = $98 & $97;
    $100 = $96 | $99;
    $101 = ($95>>>0)>(0);
    $102 = ($92>>>0)>(2147483648);
    $103 = ($95|0)==(0);
    $104 = $103 & $102;
    $105 = $101 | $104;
    $or$cond$i$not$i$i = $105 | $100;
    $106 = ($92|0)==(0);
    $or$cond$i$i = $or$cond$i$not$i$i | $106;
    if ($or$cond$i$i) {
     $$0$i$i = 0;
    } else {
     $107 = (_luaO_ceillog2($92)|0);
     $108 = (($nums$i) + ($107<<2)|0);
     $109 = HEAP32[$108>>2]|0;
     $110 = (($109) + 1)|0;
     HEAP32[$108>>2] = $110;
     $$0$i$i = 1;
    }
   } else {
    $$0$i$i = 0;
   }
   $111 = (($86) + ($$0$i$i))|0;
   $112 = ($111|0)==(0);
   L57: do {
    if ($112) {
     $n$2$i$i = 0;$na$2$i$i = 0;
    } else {
     $118 = 0;$a$03$i$i = 0;$i$01$i$i = 0;$n$05$i$i = 0;$na$04$i$i = 0;$twotoi$02$i$i = 1;
     while(1) {
      $113 = (($nums$i) + ($i$01$i$i<<2)|0);
      $114 = HEAP32[$113>>2]|0;
      $115 = ($114|0)==(0);
      if ($115) {
       $a$1$i$i = $a$03$i$i;$n$1$i$i = $n$05$i$i;$na$1$i$i = $na$04$i$i;
      } else {
       $116 = (($114) + ($a$03$i$i))|0;
       $117 = ($116>>>0)>($118>>>0);
       $$na$0$i$i = $117 ? $116 : $na$04$i$i;
       $twotoi$0$n$0$i$i = $117 ? $twotoi$02$i$i : $n$05$i$i;
       $a$1$i$i = $116;$n$1$i$i = $twotoi$0$n$0$i$i;$na$1$i$i = $$na$0$i$i;
      }
      $119 = ($a$1$i$i|0)==($111|0);
      if ($119) {
       $n$2$i$i = $n$1$i$i;$na$2$i$i = $na$1$i$i;
       break L57;
      }
      $120 = (($i$01$i$i) + 1)|0;
      $121 = $twotoi$02$i$i << 1;
      $122 = $twotoi$02$i$i & 2147483647;
      $123 = ($122>>>0)<($111>>>0);
      if ($123) {
       $118 = $122;$a$03$i$i = $a$1$i$i;$i$01$i$i = $120;$n$05$i$i = $n$1$i$i;$na$04$i$i = $na$1$i$i;$twotoi$02$i$i = $121;
      } else {
       $n$2$i$i = $n$1$i$i;$na$2$i$i = $na$1$i$i;
       break;
      }
     }
    }
   } while(0);
   $124 = (($ause$0$lcssa$i$i) + 1)|0;
   $125 = (($124) + ($totaluse$0$ph$i$i$lcssa))|0;
   $126 = (($125) - ($na$2$i$i))|0;
   _luaH_resize($L,$t,$n$2$i$i,$126);
   $127 = (_luaH_get($t,$$02)|0);
   $128 = ($127|0)==(1568|0);
   if (!($128)) {
    $$0 = $127;
    STACKTOP = sp;return ($$0|0);
   }
   $129 = (_luaH_newkey($L,$t,$$02)|0);
   $$0 = $129;
   STACKTOP = sp;return ($$0|0);
  } else {
   $mp$0 = $15;
  }
 } while(0);
 $162 = ((($mp$0)) + 16|0);
 $163 = $$02;
 $164 = $163;
 $165 = HEAP32[$164>>2]|0;
 $166 = (($163) + 4)|0;
 $167 = $166;
 $168 = HEAP32[$167>>2]|0;
 $169 = $162;
 $170 = $169;
 HEAP32[$170>>2] = $165;
 $171 = (($169) + 4)|0;
 $172 = $171;
 HEAP32[$172>>2] = $168;
 $173 = ((($$02)) + 8|0);
 $174 = HEAP32[$173>>2]|0;
 $175 = ((($mp$0)) + 24|0);
 HEAP32[$175>>2] = $174;
 $176 = $174 & 64;
 $177 = ($176|0)==(0);
 if (!($177)) {
  $178 = ((($t)) + 5|0);
  $179 = HEAP8[$178>>0]|0;
  $180 = $179 & 4;
  $181 = ($180<<24>>24)==(0);
  if (!($181)) {
   $182 = HEAP32[$$02>>2]|0;
   $183 = ((($182)) + 5|0);
   $184 = HEAP8[$183>>0]|0;
   $185 = $184 & 3;
   $186 = ($185<<24>>24)==(0);
   if (!($186)) {
    _luaC_barrierback_($L,$t);
   }
  }
 }
 $$0 = $mp$0;
 STACKTOP = sp;return ($$0|0);
}
function _luaH_getint($t,$0,$1) {
 $t = $t|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$0 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $n$0 = 0;
 var $n$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $2 = (_i64Add(($0|0),($1|0),-1,-1)|0);
 $3 = tempRet0;
 $4 = ((($t)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3>>>0)<(0);
 $7 = ($2>>>0)<($5>>>0);
 $8 = ($3|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if ($10) {
  $11 = ((($t)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (($12) + ($2<<4)|0);
  $$0 = $13;
  return ($$0|0);
 }
 $14 = ((($t)) + 7|0);
 $15 = HEAP8[$14>>0]|0;
 $16 = $15&255;
 $17 = 1 << $16;
 $18 = (($17) + -1)|0;
 $19 = $18 & $0;
 $20 = ((($t)) + 16|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = (($21) + ($19<<5)|0);
 $n$0 = $22;
 while(1) {
  $23 = ((($n$0)) + 24|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(19);
  if ($25) {
   $26 = ((($n$0)) + 16|0);
   $27 = $26;
   $28 = $27;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($27) + 4)|0;
   $31 = $30;
   $32 = HEAP32[$31>>2]|0;
   $33 = ($29|0)==($0|0);
   $34 = ($32|0)==($1|0);
   $35 = $33 & $34;
   if ($35) {
    $n$0$lcssa = $n$0;
    break;
   }
  }
  $36 = ((($n$0)) + 28|0);
  $37 = HEAP32[$36>>2]|0;
  $38 = ($37|0)==(0);
  if ($38) {
   $$0 = 1568;
   label = 9;
   break;
  }
  $39 = (($n$0) + ($37<<5)|0);
  $n$0 = $39;
 }
 if ((label|0) == 9) {
  return ($$0|0);
 }
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_getstr($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $n$0 = 0, $n$0$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($t)) + 7|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3&255;
 $5 = 1 << $4;
 $6 = (($5) + -1)|0;
 $7 = $6 & $1;
 $8 = ((($t)) + 16|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($7<<5)|0);
 $n$0 = $10;
 while(1) {
  $11 = ((($n$0)) + 24|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = ($12|0)==(68);
  if ($13) {
   $14 = ((($n$0)) + 16|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==($key|0);
   if ($16) {
    $n$0$lcssa = $n$0;
    break;
   }
  }
  $17 = ((($n$0)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   $$0 = 1568;
   label = 7;
   break;
  }
  $20 = (($n$0) + ($18<<5)|0);
  $n$0 = $20;
 }
 if ((label|0) == 7) {
  return ($$0|0);
 }
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_get($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $n$0$i = 0, $n$0$i$lcssa = 0, $n$0$i1 = 0, $n$0$i1$lcssa = 0, $n$0$i3 = 0, $n$0$i3$lcssa = 0, $n$0$lcssa = 0, $n$014 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 if ((($2|0) == 19)) {
  $25 = $key;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = (_i64Add(($27|0),($30|0),-1,-1)|0);
  $32 = tempRet0;
  $33 = ((($t)) + 8|0);
  $34 = HEAP32[$33>>2]|0;
  $35 = ($32>>>0)<(0);
  $36 = ($31>>>0)<($34>>>0);
  $37 = ($32|0)==(0);
  $38 = $37 & $36;
  $39 = $35 | $38;
  if ($39) {
   $40 = ((($t)) + 12|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = (($41) + ($31<<4)|0);
   $$0 = $42;
   return ($$0|0);
  }
  $43 = ((($t)) + 7|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = 1 << $45;
  $47 = (($46) + -1)|0;
  $48 = $47 & $27;
  $49 = ((($t)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($48<<5)|0);
  $n$0$i1 = $51;
  while(1) {
   $52 = ((($n$0$i1)) + 24|0);
   $53 = HEAP32[$52>>2]|0;
   $54 = ($53|0)==(19);
   if ($54) {
    $55 = ((($n$0$i1)) + 16|0);
    $56 = $55;
    $57 = $56;
    $58 = HEAP32[$57>>2]|0;
    $59 = (($56) + 4)|0;
    $60 = $59;
    $61 = HEAP32[$60>>2]|0;
    $62 = ($58|0)==($27|0);
    $63 = ($61|0)==($30|0);
    $64 = $62 & $63;
    if ($64) {
     $n$0$i1$lcssa = $n$0$i1;
     break;
    }
   }
   $65 = ((($n$0$i1)) + 28|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0);
   if ($67) {
    $$0 = 1568;
    label = 30;
    break;
   }
   $68 = (($n$0$i1) + ($66<<5)|0);
   $n$0$i1 = $68;
  }
  if ((label|0) == 30) {
   return ($$0|0);
  }
  $$0 = $n$0$i1$lcssa;
  return ($$0|0);
 } else if ((($2|0) == 3)) {
  $69 = +HEAPF64[$key>>3];
  $70 = (+Math_floor((+$69)));
  $71 = $70 == $69;
  if ($71) {
   $72 = $69 >= -9.2233720368547758E+18;
   $73 = $69 < 9.2233720368547758E+18;
   $or$cond$i = $72 & $73;
   if ($or$cond$i) {
    $74 = (~~$69)>>>0;
    $75 = +Math_abs($69) >= 1.0 ? $69 > 0.0 ? (~~+Math_min(+Math_floor($69 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($69 - +(~~$69 >>> 0)) / 4294967296.0) >>> 0 : 0;
    $76 = (_i64Add(($74|0),($75|0),-1,-1)|0);
    $77 = tempRet0;
    $78 = ((($t)) + 8|0);
    $79 = HEAP32[$78>>2]|0;
    $80 = ($77>>>0)<(0);
    $81 = ($76>>>0)<($79>>>0);
    $82 = ($77|0)==(0);
    $83 = $82 & $81;
    $84 = $80 | $83;
    if ($84) {
     $85 = ((($t)) + 12|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = (($86) + ($76<<4)|0);
     $$0 = $87;
     return ($$0|0);
    }
    $88 = ((($t)) + 7|0);
    $89 = HEAP8[$88>>0]|0;
    $90 = $89&255;
    $91 = 1 << $90;
    $92 = (($91) + -1)|0;
    $93 = $92 & $74;
    $94 = ((($t)) + 16|0);
    $95 = HEAP32[$94>>2]|0;
    $96 = (($95) + ($93<<5)|0);
    $n$0$i3 = $96;
    while(1) {
     $97 = ((($n$0$i3)) + 24|0);
     $98 = HEAP32[$97>>2]|0;
     $99 = ($98|0)==(19);
     if ($99) {
      $100 = ((($n$0$i3)) + 16|0);
      $101 = $100;
      $102 = $101;
      $103 = HEAP32[$102>>2]|0;
      $104 = (($101) + 4)|0;
      $105 = $104;
      $106 = HEAP32[$105>>2]|0;
      $107 = ($103|0)==($74|0);
      $108 = ($106|0)==($75|0);
      $109 = $107 & $108;
      if ($109) {
       $n$0$i3$lcssa = $n$0$i3;
       break;
      }
     }
     $110 = ((($n$0$i3)) + 28|0);
     $111 = HEAP32[$110>>2]|0;
     $112 = ($111|0)==(0);
     if ($112) {
      $$0 = 1568;
      label = 30;
      break;
     }
     $113 = (($n$0$i3) + ($111<<5)|0);
     $n$0$i3 = $113;
    }
    if ((label|0) == 30) {
     return ($$0|0);
    }
    $$0 = $n$0$i3$lcssa;
    return ($$0|0);
   }
  }
 } else if ((($2|0) == 0)) {
  $$0 = 1568;
  return ($$0|0);
 } else if ((($2|0) == 4)) {
  $3 = HEAP32[$key>>2]|0;
  $4 = ((($3)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($t)) + 7|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = 1 << $8;
  $10 = (($9) + -1)|0;
  $11 = $10 & $5;
  $12 = ((($t)) + 16|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (($13) + ($11<<5)|0);
  $n$0$i = $14;
  while(1) {
   $15 = ((($n$0$i)) + 24|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($16|0)==(68);
   if ($17) {
    $18 = ((($n$0$i)) + 16|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = ($19|0)==($3|0);
    if ($20) {
     $n$0$i$lcssa = $n$0$i;
     break;
    }
   }
   $21 = ((($n$0$i)) + 28|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $$0 = 1568;
    label = 30;
    break;
   }
   $24 = (($n$0$i) + ($22<<5)|0);
   $n$0$i = $24;
  }
  if ((label|0) == 30) {
   return ($$0|0);
  }
  $$0 = $n$0$i$lcssa;
  return ($$0|0);
 }
 $114 = (_mainposition($t,$key)|0);
 $115 = ((($114)) + 16|0);
 $116 = (_luaV_equalobj(0,$115,$key)|0);
 $117 = ($116|0)==(0);
 L47: do {
  if ($117) {
   $n$014 = $114;
   while(1) {
    $118 = ((($n$014)) + 28|0);
    $119 = HEAP32[$118>>2]|0;
    $120 = ($119|0)==(0);
    if ($120) {
     $$0 = 1568;
     break;
    }
    $121 = (($n$014) + ($119<<5)|0);
    $122 = (((($n$014) + ($119<<5)|0)) + 16|0);
    $123 = (_luaV_equalobj(0,$122,$key)|0);
    $124 = ($123|0)==(0);
    if ($124) {
     $n$014 = $121;
    } else {
     $n$0$lcssa = $121;
     break L47;
    }
   }
   return ($$0|0);
  } else {
   $n$0$lcssa = $114;
  }
 } while(0);
 $$0 = $n$0$lcssa;
 return ($$0|0);
}
function _luaH_getn($t) {
 $t = $t|0;
 var $$$1$i = 0, $$0 = 0, $$0$i$i = 0, $$0$i3$i = 0, $$0$i6$i = 0, $$01$i = 0, $$01$i$lcssa = 0, $$115$i = 0, $$j$0 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$0$ = 0, $i$0$i = 0, $i$0$i$lcssa = 0, $i$0$i$phi = 0, $i$08 = 0, $i$1$i = 0, $i$1$i$lcssa = 0, $i$2$$i = 0, $i$216$i = 0, $j$07 = 0, $n$0$i$i = 0, $n$0$i$i$lcssa = 0;
 var $n$0$i2$i = 0, $n$0$i2$i$lcssa = 0, $n$0$i5$i = 0, $n$0$i5$i$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($1) + -1)|0;
  $4 = ((($t)) + 12|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (((($5) + ($3<<4)|0)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = ($1>>>0)>(1);
   if ($9) {
    $i$08 = 0;$j$07 = $1;
   } else {
    $$0 = 0;
    return ($$0|0);
   }
   while(1) {
    $10 = (($i$08) + ($j$07))|0;
    $11 = $10 >>> 1;
    $12 = (($11) + -1)|0;
    $13 = (((($5) + ($12<<4)|0)) + 8|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(0);
    $$j$0 = $15 ? $11 : $j$07;
    $i$0$ = $15 ? $i$08 : $11;
    $16 = (($$j$0) - ($i$0$))|0;
    $17 = ($16>>>0)>(1);
    if ($17) {
     $i$08 = $i$0$;$j$07 = $$j$0;
    } else {
     $$0 = $i$0$;
     break;
    }
   }
   return ($$0|0);
  }
 }
 $18 = ((($t)) + 16|0);
 $19 = HEAP32[$18>>2]|0;
 $20 = ($19|0)==(2776|0);
 if ($20) {
  $$0 = $1;
  return ($$0|0);
 }
 $21 = (($1) + 1)|0;
 $22 = ((($t)) + 12|0);
 $23 = ((($t)) + 7|0);
 $$01$i = $21;$i$0$i = $1;
 while(1) {
  $24 = (_i64Add(($$01$i|0),0,-1,-1)|0);
  $25 = tempRet0;
  $26 = ($25>>>0)<(0);
  $27 = ($24>>>0)<($1>>>0);
  $28 = ($25|0)==(0);
  $29 = $28 & $27;
  $30 = $26 | $29;
  L15: do {
   if ($30) {
    $31 = HEAP32[$22>>2]|0;
    $32 = (($31) + ($24<<4)|0);
    $$0$i$i = $32;
   } else {
    $33 = HEAP8[$23>>0]|0;
    $34 = $33&255;
    $35 = 1 << $34;
    $36 = (($35) + -1)|0;
    $37 = $36 & $$01$i;
    $38 = (($19) + ($37<<5)|0);
    $n$0$i$i = $38;
    while(1) {
     $39 = ((($n$0$i$i)) + 24|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==(19);
     if ($41) {
      $42 = ((($n$0$i$i)) + 16|0);
      $43 = $42;
      $44 = $43;
      $45 = HEAP32[$44>>2]|0;
      $46 = (($43) + 4)|0;
      $47 = $46;
      $48 = HEAP32[$47>>2]|0;
      $49 = ($45|0)==($$01$i|0);
      $50 = ($48|0)==(0);
      $51 = $49 & $50;
      if ($51) {
       $n$0$i$i$lcssa = $n$0$i$i;
       break;
      }
     }
     $52 = ((($n$0$i$i)) + 28|0);
     $53 = HEAP32[$52>>2]|0;
     $54 = ($53|0)==(0);
     if ($54) {
      $$0$i$i = 1568;
      break L15;
     }
     $55 = (($n$0$i$i) + ($53<<5)|0);
     $n$0$i$i = $55;
    }
    $$0$i$i = $n$0$i$i$lcssa;
   }
  } while(0);
  $56 = ((($$0$i$i)) + 8|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ($57|0)==(0);
  if ($58) {
   $$01$i$lcssa = $$01$i;$i$0$i$lcssa = $i$0$i;
   break;
  }
  $61 = ($$01$i>>>0)>(1073741823);
  if ($61) {
   $i$1$i = 1;
   label = 18;
   break;
  }
  $99 = $$01$i << 1;
  $i$0$i$phi = $$01$i;$$01$i = $99;$i$0$i = $i$0$i$phi;
 }
 if ((label|0) == 18) {
  while(1) {
   label = 0;
   $62 = (_i64Add(($i$1$i|0),0,-1,-1)|0);
   $63 = tempRet0;
   $64 = ($63>>>0)<(0);
   $65 = ($62>>>0)<($1>>>0);
   $66 = ($63|0)==(0);
   $67 = $66 & $65;
   $68 = $64 | $67;
   L31: do {
    if ($68) {
     $69 = HEAP32[$22>>2]|0;
     $70 = (($69) + ($62<<4)|0);
     $$0$i6$i = $70;
    } else {
     $71 = HEAP8[$23>>0]|0;
     $72 = $71&255;
     $73 = 1 << $72;
     $74 = (($73) + -1)|0;
     $75 = $74 & $i$1$i;
     $76 = (($19) + ($75<<5)|0);
     $n$0$i5$i = $76;
     while(1) {
      $77 = ((($n$0$i5$i)) + 24|0);
      $78 = HEAP32[$77>>2]|0;
      $79 = ($78|0)==(19);
      if ($79) {
       $80 = ((($n$0$i5$i)) + 16|0);
       $81 = $80;
       $82 = $81;
       $83 = HEAP32[$82>>2]|0;
       $84 = (($81) + 4)|0;
       $85 = $84;
       $86 = HEAP32[$85>>2]|0;
       $87 = ($83|0)==($i$1$i|0);
       $88 = ($86|0)==(0);
       $89 = $87 & $88;
       if ($89) {
        $n$0$i5$i$lcssa = $n$0$i5$i;
        break;
       }
      }
      $90 = ((($n$0$i5$i)) + 28|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = ($91|0)==(0);
      if ($92) {
       $$0$i6$i = 1568;
       break L31;
      }
      $93 = (($n$0$i5$i) + ($91<<5)|0);
      $n$0$i5$i = $93;
     }
     $$0$i6$i = $n$0$i5$i$lcssa;
    }
   } while(0);
   $94 = ((($$0$i6$i)) + 8|0);
   $95 = HEAP32[$94>>2]|0;
   $96 = ($95|0)==(0);
   $97 = (($i$1$i) + 1)|0;
   if ($96) {
    $i$1$i$lcssa = $i$1$i;
    break;
   } else {
    $i$1$i = $97;
    label = 18;
   }
  }
  $98 = (($i$1$i$lcssa) + -1)|0;
  $$0 = $98;
  return ($$0|0);
 }
 $59 = (($$01$i$lcssa) - ($i$0$i$lcssa))|0;
 $60 = ($59>>>0)>(1);
 if ($60) {
  $$115$i = $$01$i$lcssa;$i$216$i = $i$0$i$lcssa;
 } else {
  $$0 = $i$0$i$lcssa;
  return ($$0|0);
 }
 while(1) {
  $100 = (($$115$i) + ($i$216$i))|0;
  $101 = $100 >>> 1;
  $102 = (_i64Add(($101|0),0,-1,-1)|0);
  $103 = tempRet0;
  $104 = ($103>>>0)<(0);
  $105 = ($102>>>0)<($1>>>0);
  $106 = ($103|0)==(0);
  $107 = $106 & $105;
  $108 = $104 | $107;
  L49: do {
   if ($108) {
    $109 = HEAP32[$22>>2]|0;
    $110 = (($109) + ($102<<4)|0);
    $$0$i3$i = $110;
   } else {
    $111 = HEAP8[$23>>0]|0;
    $112 = $111&255;
    $113 = 1 << $112;
    $114 = (($113) + 2147483647)|0;
    $115 = $114 & $101;
    $116 = (($19) + ($115<<5)|0);
    $n$0$i2$i = $116;
    while(1) {
     $117 = ((($n$0$i2$i)) + 24|0);
     $118 = HEAP32[$117>>2]|0;
     $119 = ($118|0)==(19);
     if ($119) {
      $120 = ((($n$0$i2$i)) + 16|0);
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $127 = ($123|0)==($101|0);
      $128 = ($126|0)==(0);
      $129 = $127 & $128;
      if ($129) {
       $n$0$i2$i$lcssa = $n$0$i2$i;
       break;
      }
     }
     $130 = ((($n$0$i2$i)) + 28|0);
     $131 = HEAP32[$130>>2]|0;
     $132 = ($131|0)==(0);
     if ($132) {
      $$0$i3$i = 1568;
      break L49;
     }
     $133 = (($n$0$i2$i) + ($131<<5)|0);
     $n$0$i2$i = $133;
    }
    $$0$i3$i = $n$0$i2$i$lcssa;
   }
  } while(0);
  $134 = ((($$0$i3$i)) + 8|0);
  $135 = HEAP32[$134>>2]|0;
  $136 = ($135|0)==(0);
  $$$1$i = $136 ? $101 : $$115$i;
  $i$2$$i = $136 ? $i$216$i : $101;
  $137 = (($$$1$i) - ($i$2$$i))|0;
  $138 = ($137>>>0)>(1);
  if ($138) {
   $$115$i = $$$1$i;$i$216$i = $i$2$$i;
  } else {
   $$0 = $i$2$$i;
   break;
  }
 }
 return ($$0|0);
}
function _mainposition($t,$key) {
 $t = $t|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i$i = sp;
 $0 = ((($key)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 switch ($2|0) {
 case 4:  {
  $40 = HEAP32[$key>>2]|0;
  $41 = ((($40)) + 8|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($t)) + 7|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  $46 = 1 << $45;
  $47 = (($46) + -1)|0;
  $48 = $47 & $42;
  $49 = ((($t)) + 16|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = (($50) + ($48<<5)|0);
  $$0 = $51;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 3:  {
  $18 = +HEAPF64[$key>>3];
  $19 = (+_frexp($18,$i$i));
  $20 = $19 * 2147482623.0;
  $21 = (~~(($20)));
  $22 = HEAP32[$i$i>>2]|0;
  $23 = (($21) + ($22))|0;
  HEAP32[$i$i>>2] = $23;
  $24 = ($23|0)<(0);
  if ($24) {
   $25 = (0 - ($23))|0;
   $26 = ($23|0)==($25|0);
   if ($26) {
    HEAP32[$i$i>>2] = 0;
    $28 = 0;
   } else {
    $28 = $23;
   }
   $27 = (0 - ($28))|0;
   HEAP32[$i$i>>2] = $27;
   $36 = $27;
  } else {
   $36 = $23;
  }
  $29 = ((($t)) + 7|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = 1 << $31;
  $33 = (($32) + -1)|0;
  $34 = $33 | 1;
  $35 = (($36|0) % ($34|0))&-1;
  $37 = ((($t)) + 16|0);
  $38 = HEAP32[$37>>2]|0;
  $39 = (($38) + ($35<<5)|0);
  $$0 = $39;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 22:  {
  $96 = HEAP32[$key>>2]|0;
  $97 = $96;
  $98 = ((($t)) + 7|0);
  $99 = HEAP8[$98>>0]|0;
  $100 = $99&255;
  $101 = 1 << $100;
  $102 = (($101) + -1)|0;
  $103 = $102 | 1;
  $104 = (($97>>>0) % ($103>>>0))&-1;
  $105 = ((($t)) + 16|0);
  $106 = HEAP32[$105>>2]|0;
  $107 = (($106) + ($104<<5)|0);
  $$0 = $107;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 2:  {
  $84 = HEAP32[$key>>2]|0;
  $85 = $84;
  $86 = ((($t)) + 7|0);
  $87 = HEAP8[$86>>0]|0;
  $88 = $87&255;
  $89 = 1 << $88;
  $90 = (($89) + -1)|0;
  $91 = $90 | 1;
  $92 = (($85>>>0) % ($91>>>0))&-1;
  $93 = ((($t)) + 16|0);
  $94 = HEAP32[$93>>2]|0;
  $95 = (($94) + ($92<<5)|0);
  $$0 = $95;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 20:  {
  $52 = HEAP32[$key>>2]|0;
  $53 = ((($52)) + 6|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $56 = ((($52)) + 24|0);
   $57 = ((($52)) + 12|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ((($52)) + 8|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = (_luaS_hash($56,$58,$60)|0);
   HEAP32[$59>>2] = $61;
   HEAP8[$53>>0] = 1;
   $$pre = HEAP32[$key>>2]|0;
   $63 = $$pre;
  } else {
   $63 = $52;
  }
  $62 = ((($63)) + 8|0);
  $64 = HEAP32[$62>>2]|0;
  $65 = ((($t)) + 7|0);
  $66 = HEAP8[$65>>0]|0;
  $67 = $66&255;
  $68 = 1 << $67;
  $69 = (($68) + -1)|0;
  $70 = $69 & $64;
  $71 = ((($t)) + 16|0);
  $72 = HEAP32[$71>>2]|0;
  $73 = (($72) + ($70<<5)|0);
  $$0 = $73;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 1:  {
  $74 = HEAP32[$key>>2]|0;
  $75 = ((($t)) + 7|0);
  $76 = HEAP8[$75>>0]|0;
  $77 = $76&255;
  $78 = 1 << $77;
  $79 = (($78) + -1)|0;
  $80 = $79 & $74;
  $81 = ((($t)) + 16|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($82) + ($80<<5)|0);
  $$0 = $83;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 case 19:  {
  $3 = $key;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = ((($t)) + 7|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = 1 << $11;
  $13 = (($12) + -1)|0;
  $14 = $13 & $5;
  $15 = ((($t)) + 16|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = (($16) + ($14<<5)|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
  break;
 }
 default: {
  $108 = HEAP32[$key>>2]|0;
  $109 = $108;
  $110 = ((($t)) + 7|0);
  $111 = HEAP8[$110>>0]|0;
  $112 = $111&255;
  $113 = 1 << $112;
  $114 = (($113) + -1)|0;
  $115 = $114 | 1;
  $116 = (($109>>>0) % ($115>>>0))&-1;
  $117 = ((($t)) + 16|0);
  $118 = HEAP32[$117>>2]|0;
  $119 = (($118) + ($116<<5)|0);
  $$0 = $119;
  STACKTOP = sp;return ($$0|0);
 }
 }
 return (0)|0;
}
function _luaT_init($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 12|0);
 $i$01 = 0;
 while(1) {
  $1 = (2920 + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (_luaS_new($L,$2)|0);
  $4 = HEAP32[$0>>2]|0;
  $5 = (((($4)) + 148|0) + ($i$01<<2)|0);
  HEAP32[$5>>2] = $3;
  $6 = HEAP32[$0>>2]|0;
  $7 = (((($6)) + 148|0) + ($i$01<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  _luaC_fix($L,$8);
  $9 = (($i$01) + 1)|0;
  $exitcond = ($9|0)==(24);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $9;
  }
 }
 return;
}
function _luaT_gettm($events,$event,$ename) {
 $events = $events|0;
 $event = $event|0;
 $ename = $ename|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaH_getstr($events,$ename)|0);
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = $0;
  return ($$0|0);
 }
 $4 = 1 << $event;
 $5 = ((($events)) + 6|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = $7 | $4;
 $9 = $8&255;
 HEAP8[$5>>0] = $9;
 $$0 = 0;
 return ($$0|0);
}
function _luaT_gettmbyobj($L,$o,$event) {
 $L = $L|0;
 $o = $o|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0 = 0, $mt$0$in = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ((($o)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 if ((($2|0) == 7)) {
  $5 = HEAP32[$o>>2]|0;
  $6 = ((($5)) + 8|0);
  $mt$0$in = $6;
 } else if ((($2|0) == 5)) {
  $3 = HEAP32[$o>>2]|0;
  $4 = ((($3)) + 24|0);
  $mt$0$in = $4;
 } else {
  $7 = ((($L)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (((($8)) + 244|0) + ($2<<2)|0);
  $mt$0$in = $9;
 }
 $mt$0 = HEAP32[$mt$0$in>>2]|0;
 $10 = ($mt$0|0)==(0|0);
 if ($10) {
  $16 = 1568;
  return ($16|0);
 }
 $11 = ((($L)) + 12|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = (((($12)) + 148|0) + ($event<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (_luaH_getstr($mt$0,$14)|0);
 $16 = $15;
 return ($16|0);
}
function _luaT_callTM($L,$f,$p1,$p2,$p3,$hasres) {
 $L = $L|0;
 $f = $f|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $p3 = $p3|0;
 $hasres = $hasres|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 28|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 16|0);
 HEAP32[$2>>2] = $4;
 ;HEAP32[$3>>2]=HEAP32[$f>>2]|0;HEAP32[$3+4>>2]=HEAP32[$f+4>>2]|0;HEAP32[$3+8>>2]=HEAP32[$f+8>>2]|0;HEAP32[$3+12>>2]=HEAP32[$f+12>>2]|0;
 $5 = HEAP32[$2>>2]|0;
 $6 = ((($5)) + 16|0);
 HEAP32[$2>>2] = $6;
 ;HEAP32[$5>>2]=HEAP32[$p1>>2]|0;HEAP32[$5+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$5+8>>2]=HEAP32[$p1+8>>2]|0;HEAP32[$5+12>>2]=HEAP32[$p1+12>>2]|0;
 $7 = HEAP32[$2>>2]|0;
 $8 = ((($7)) + 16|0);
 HEAP32[$2>>2] = $8;
 ;HEAP32[$7>>2]=HEAP32[$p2>>2]|0;HEAP32[$7+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$7+8>>2]=HEAP32[$p2+8>>2]|0;HEAP32[$7+12>>2]=HEAP32[$p2+12>>2]|0;
 $9 = ($hasres|0)==(0);
 if ($9) {
  $10 = HEAP32[$2>>2]|0;
  $11 = ((($10)) + 16|0);
  HEAP32[$2>>2] = $11;
  ;HEAP32[$10>>2]=HEAP32[$p3>>2]|0;HEAP32[$10+4>>2]=HEAP32[$p3+4>>2]|0;HEAP32[$10+8>>2]=HEAP32[$p3+8>>2]|0;HEAP32[$10+12>>2]=HEAP32[$p3+12>>2]|0;
  $12 = HEAP32[$2>>2]|0;
  $13 = ((($12)) + -64|0);
  $14 = ((($L)) + 16|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = ((($15)) + 34|0);
  $17 = HEAP8[$16>>0]|0;
  $18 = $17&255;
  $19 = $18 & 2;
  _luaD_call($L,$13,0,$19);
  return;
 } else {
  $20 = $p3;
  $21 = $1;
  $22 = (($20) - ($21))|0;
  $23 = HEAP32[$2>>2]|0;
  $24 = (($hasres) + -4)|0;
  $25 = (($23) + ($24<<4)|0);
  $26 = ((($L)) + 16|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + 34|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 & 2;
  _luaD_call($L,$25,$hasres,$31);
  $32 = HEAP32[$0>>2]|0;
  $33 = (($32) + ($22)|0);
  $34 = HEAP32[$2>>2]|0;
  $35 = ((($34)) + -16|0);
  HEAP32[$2>>2] = $35;
  ;HEAP32[$33>>2]=HEAP32[$35>>2]|0;HEAP32[$33+4>>2]=HEAP32[$35+4>>2]|0;HEAP32[$33+8>>2]=HEAP32[$35+8>>2]|0;HEAP32[$33+12>>2]=HEAP32[$35+12>>2]|0;
  return;
 }
}
function _luaT_callbinTM($L,$p1,$p2,$res,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $7 = 0, $8 = 0, $9 = 0, $mt$0$i = 0, $mt$0$i2 = 0, $mt$0$in$i = 0, $mt$0$in$i1 = 0, $tm$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 if ((($2|0) == 5)) {
  $3 = HEAP32[$p1>>2]|0;
  $4 = ((($3)) + 24|0);
  $mt$0$in$i = $4;
 } else if ((($2|0) == 7)) {
  $5 = HEAP32[$p1>>2]|0;
  $6 = ((($5)) + 8|0);
  $mt$0$in$i = $6;
 } else {
  $7 = ((($L)) + 12|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = (((($8)) + 244|0) + ($2<<2)|0);
  $mt$0$in$i = $9;
 }
 $mt$0$i = HEAP32[$mt$0$in$i>>2]|0;
 $10 = ($mt$0$i|0)==(0|0);
 if ($10) {
  $17 = 1568;
 } else {
  $11 = ((($L)) + 12|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = (((($12)) + 148|0) + ($event<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (_luaH_getstr($mt$0$i,$14)|0);
  $17 = $15;
 }
 $16 = ((($17)) + 8|0);
 $18 = HEAP32[$16>>2]|0;
 $19 = ($18|0)==(0);
 if ($19) {
  $20 = ((($p2)) + 8|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = $21 & 15;
  if ((($22|0) == 5)) {
   $23 = HEAP32[$p2>>2]|0;
   $24 = ((($23)) + 24|0);
   $mt$0$in$i1 = $24;
  } else if ((($22|0) == 7)) {
   $25 = HEAP32[$p2>>2]|0;
   $26 = ((($25)) + 8|0);
   $mt$0$in$i1 = $26;
  } else {
   $27 = ((($L)) + 12|0);
   $28 = HEAP32[$27>>2]|0;
   $29 = (((($28)) + 244|0) + ($22<<2)|0);
   $mt$0$in$i1 = $29;
  }
  $mt$0$i2 = HEAP32[$mt$0$in$i1>>2]|0;
  $30 = ($mt$0$i2|0)==(0|0);
  if ($30) {
   $tm$0 = 1568;
  } else {
   $31 = ((($L)) + 12|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = (((($32)) + 148|0) + ($event<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = (_luaH_getstr($mt$0$i2,$34)|0);
   $tm$0 = $35;
  }
 } else {
  $tm$0 = $17;
 }
 $36 = ((($tm$0)) + 8|0);
 $37 = HEAP32[$36>>2]|0;
 $38 = ($37|0)==(0);
 if ($38) {
  $$0 = 0;
  return ($$0|0);
 }
 $39 = ((($L)) + 28|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ((($L)) + 8|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = ((($42)) + 16|0);
 HEAP32[$41>>2] = $43;
 ;HEAP32[$42>>2]=HEAP32[$tm$0>>2]|0;HEAP32[$42+4>>2]=HEAP32[$tm$0+4>>2]|0;HEAP32[$42+8>>2]=HEAP32[$tm$0+8>>2]|0;HEAP32[$42+12>>2]=HEAP32[$tm$0+12>>2]|0;
 $44 = HEAP32[$41>>2]|0;
 $45 = ((($44)) + 16|0);
 HEAP32[$41>>2] = $45;
 ;HEAP32[$44>>2]=HEAP32[$p1>>2]|0;HEAP32[$44+4>>2]=HEAP32[$p1+4>>2]|0;HEAP32[$44+8>>2]=HEAP32[$p1+8>>2]|0;HEAP32[$44+12>>2]=HEAP32[$p1+12>>2]|0;
 $46 = HEAP32[$41>>2]|0;
 $47 = ((($46)) + 16|0);
 HEAP32[$41>>2] = $47;
 ;HEAP32[$46>>2]=HEAP32[$p2>>2]|0;HEAP32[$46+4>>2]=HEAP32[$p2+4>>2]|0;HEAP32[$46+8>>2]=HEAP32[$p2+8>>2]|0;HEAP32[$46+12>>2]=HEAP32[$p2+12>>2]|0;
 $48 = $res;
 $49 = $40;
 $50 = (($48) - ($49))|0;
 $51 = HEAP32[$41>>2]|0;
 $52 = ((($51)) + -48|0);
 $53 = ((($L)) + 16|0);
 $54 = HEAP32[$53>>2]|0;
 $55 = ((($54)) + 34|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = $56&255;
 $58 = $57 & 2;
 _luaD_call($L,$52,1,$58);
 $59 = HEAP32[$39>>2]|0;
 $60 = (($59) + ($50)|0);
 $61 = HEAP32[$41>>2]|0;
 $62 = ((($61)) + -16|0);
 HEAP32[$41>>2] = $62;
 ;HEAP32[$60>>2]=HEAP32[$62>>2]|0;HEAP32[$60+4>>2]=HEAP32[$62+4>>2]|0;HEAP32[$60+8>>2]=HEAP32[$62+8>>2]|0;HEAP32[$60+12>>2]=HEAP32[$62+12>>2]|0;
 $$0 = 1;
 return ($$0|0);
}
function _luaT_trybinTM($L,$p1,$p2,$res,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $res = $res|0;
 $event = $event|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0.0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $dummy = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $dummy = sp;
 $0 = (_luaT_callbinTM($L,$p1,$p2,$res,$event)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 switch ($event|0) {
 case 22:  {
  _luaG_concaterror($L,$p1,$p2);
  // unreachable;
  break;
 }
 case 19: case 17: case 16: case 15: case 14: case 13:  {
  $2 = ((($p1)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(3);
  if ($4) {
   $5 = +HEAPF64[$p1>>3];
   HEAPF64[$dummy>>3] = $5;
  } else {
   $6 = (_luaV_tonumber_($p1,$dummy)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    _luaG_opinterror($L,$p1,$p2,3016);
    // unreachable;
   }
  }
  $8 = ((($p2)) + 8|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(3);
  if ($10) {
   $11 = +HEAPF64[$p2>>3];
   HEAPF64[$dummy>>3] = $11;
   _luaG_tointerror($L,$p1,$p2);
   // unreachable;
  }
  $12 = (_luaV_tonumber_($p2,$dummy)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   _luaG_opinterror($L,$p1,$p2,3016);
   // unreachable;
  } else {
   _luaG_tointerror($L,$p1,$p2);
   // unreachable;
  }
  break;
 }
 default: {
  _luaG_opinterror($L,$p1,$p2,3048);
  // unreachable;
 }
 }
}
function _luaT_callorderTM($L,$p1,$p2,$event) {
 $L = $L|0;
 $p1 = $p1|0;
 $p2 = $p2|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaT_callbinTM($L,$p1,$p2,$1,$event)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = -1;
  return ($$0|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $11 = 0;
 } else {
  $8 = ($6|0)==(1);
  if ($8) {
   $9 = HEAP32[$4>>2]|0;
   $phitmp = ($9|0)!=(0);
   $11 = $phitmp;
  } else {
   $11 = 1;
  }
 }
 $10 = $11&1;
 $$0 = $10;
 return ($$0|0);
}
function _luaU_undump($L,$Z,$buff,$name) {
 $L = $L|0;
 $Z = $Z|0;
 $buff = $buff|0;
 $name = $name|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0.0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $S = 0, $buff$i$i = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, $x$i = 0, $x$i$i = 0, $x$i$i$i = 0, $x$i$i11$i = 0, $x$i$i14$i = 0, $x$i$i17$i = 0, $x$i$i8$i = 0, $x$i2$i = 0, $x$i20$i = 0, $x$i22$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer10 = sp + 48|0;
 $vararg_buffer7 = sp + 40|0;
 $vararg_buffer4 = sp + 32|0;
 $vararg_buffer1 = sp + 24|0;
 $vararg_buffer = sp + 16|0;
 $x$i = sp + 91|0;
 $x$i22$i = sp + 8|0;
 $x$i20$i = sp;
 $x$i$i17$i = sp + 90|0;
 $x$i$i14$i = sp + 89|0;
 $x$i$i11$i = sp + 88|0;
 $x$i$i8$i = sp + 87|0;
 $x$i$i$i = sp + 86|0;
 $x$i2$i = sp + 85|0;
 $x$i$i = sp + 84|0;
 $buff$i$i = sp + 72|0;
 $S = sp + 56|0;
 $0 = HEAP8[$name>>0]|0;
 if ((($0<<24>>24) == 27)) {
  $3 = ((($S)) + 12|0);
  HEAP32[$3>>2] = 3288;
 } else if ((($0<<24>>24) == 61) | (($0<<24>>24) == 64)) {
  $1 = ((($name)) + 1|0);
  $2 = ((($S)) + 12|0);
  HEAP32[$2>>2] = $1;
 } else {
  $4 = ((($S)) + 12|0);
  HEAP32[$4>>2] = $name;
 }
 HEAP32[$S>>2] = $L;
 $5 = ((($S)) + 4|0);
 HEAP32[$5>>2] = $Z;
 $6 = ((($S)) + 8|0);
 HEAP32[$6>>2] = $buff;
 $7 = (_luaZ_read($Z,$buff$i$i,3)|0);
 $8 = ($7|0)==(0);
 if (!($8)) {
  _error($S,3304);
  // unreachable;
 }
 $9 = (_memcmp((3321),$buff$i$i,3)|0);
 $10 = ($9|0)==(0);
 if (!($10)) {
  _error($S,3328);
  // unreachable;
 }
 $11 = HEAP32[$5>>2]|0;
 $12 = (_luaZ_read($11,$x$i$i,1)|0);
 $13 = ($12|0)==(0);
 if (!($13)) {
  _error($S,3304);
  // unreachable;
 }
 $14 = HEAP8[$x$i$i>>0]|0;
 $15 = ($14<<24>>24)==(83);
 if (!($15)) {
  _error($S,3336);
  // unreachable;
 }
 $16 = HEAP32[$5>>2]|0;
 $17 = (_luaZ_read($16,$x$i2$i,1)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  _error($S,3304);
  // unreachable;
 }
 $19 = HEAP8[$x$i2$i>>0]|0;
 $20 = ($19<<24>>24)==(0);
 if (!($20)) {
  _error($S,3360);
  // unreachable;
 }
 $21 = HEAP32[$5>>2]|0;
 $22 = (_luaZ_read($21,$buff$i$i,6)|0);
 $23 = ($22|0)==(0);
 if (!($23)) {
  _error($S,3304);
  // unreachable;
 }
 $24 = (_memcmp(3384,$buff$i$i,6)|0);
 $25 = ($24|0)==(0);
 if (!($25)) {
  _error($S,3392);
  // unreachable;
 }
 $26 = HEAP32[$5>>2]|0;
 $27 = (_luaZ_read($26,$x$i$i$i,1)|0);
 $28 = ($27|0)==(0);
 if (!($28)) {
  _error($S,3304);
  // unreachable;
 }
 $29 = HEAP8[$x$i$i$i>>0]|0;
 $30 = ($29<<24>>24)==(4);
 if (!($30)) {
  $31 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer>>2] = 3432;
  $32 = (_luaO_pushfstring($31,3408,$vararg_buffer)|0);
  _error($S,$32);
  // unreachable;
 }
 $33 = HEAP32[$5>>2]|0;
 $34 = (_luaZ_read($33,$x$i$i8$i,1)|0);
 $35 = ($34|0)==(0);
 if (!($35)) {
  _error($S,3304);
  // unreachable;
 }
 $36 = HEAP8[$x$i$i8$i>>0]|0;
 $37 = ($36<<24>>24)==(4);
 if (!($37)) {
  $38 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer1>>2] = 3440;
  $39 = (_luaO_pushfstring($38,3408,$vararg_buffer1)|0);
  _error($S,$39);
  // unreachable;
 }
 $40 = HEAP32[$5>>2]|0;
 $41 = (_luaZ_read($40,$x$i$i11$i,1)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  _error($S,3304);
  // unreachable;
 }
 $43 = HEAP8[$x$i$i11$i>>0]|0;
 $44 = ($43<<24>>24)==(4);
 if (!($44)) {
  $45 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer4>>2] = 3448;
  $46 = (_luaO_pushfstring($45,3408,$vararg_buffer4)|0);
  _error($S,$46);
  // unreachable;
 }
 $47 = HEAP32[$5>>2]|0;
 $48 = (_luaZ_read($47,$x$i$i14$i,1)|0);
 $49 = ($48|0)==(0);
 if (!($49)) {
  _error($S,3304);
  // unreachable;
 }
 $50 = HEAP8[$x$i$i14$i>>0]|0;
 $51 = ($50<<24>>24)==(8);
 if (!($51)) {
  $52 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer7>>2] = 3464;
  $53 = (_luaO_pushfstring($52,3408,$vararg_buffer7)|0);
  _error($S,$53);
  // unreachable;
 }
 $54 = HEAP32[$5>>2]|0;
 $55 = (_luaZ_read($54,$x$i$i17$i,1)|0);
 $56 = ($55|0)==(0);
 if (!($56)) {
  _error($S,3304);
  // unreachable;
 }
 $57 = HEAP8[$x$i$i17$i>>0]|0;
 $58 = ($57<<24>>24)==(8);
 if (!($58)) {
  $59 = HEAP32[$S>>2]|0;
  HEAP32[$vararg_buffer10>>2] = 3480;
  $60 = (_luaO_pushfstring($59,3408,$vararg_buffer10)|0);
  _error($S,$60);
  // unreachable;
 }
 $61 = HEAP32[$5>>2]|0;
 $62 = (_luaZ_read($61,$x$i20$i,8)|0);
 $63 = ($62|0)==(0);
 if (!($63)) {
  _error($S,3304);
  // unreachable;
 }
 $64 = $x$i20$i;
 $65 = $64;
 $66 = HEAP32[$65>>2]|0;
 $67 = (($64) + 4)|0;
 $68 = $67;
 $69 = HEAP32[$68>>2]|0;
 $70 = ($66|0)==(22136);
 $71 = ($69|0)==(0);
 $72 = $70 & $71;
 if (!($72)) {
  _error($S,3496);
  // unreachable;
 }
 $73 = HEAP32[$5>>2]|0;
 $74 = (_luaZ_read($73,$x$i22$i,8)|0);
 $75 = ($74|0)==(0);
 if (!($75)) {
  _error($S,3304);
  // unreachable;
 }
 $76 = +HEAPF64[$x$i22$i>>3];
 $77 = $76 != 370.5;
 if ($77) {
  _error($S,3520);
  // unreachable;
 }
 $78 = HEAP32[$5>>2]|0;
 $79 = (_luaZ_read($78,$x$i,1)|0);
 $80 = ($79|0)==(0);
 if (!($80)) {
  _error($S,3304);
  // unreachable;
 }
 $81 = HEAP8[$x$i>>0]|0;
 $82 = $81&255;
 $83 = (_luaF_newLclosure($L,$82)|0);
 $84 = ((($L)) + 8|0);
 $85 = HEAP32[$84>>2]|0;
 HEAP32[$85>>2] = $83;
 $86 = ((($85)) + 8|0);
 HEAP32[$86>>2] = 70;
 $87 = HEAP32[$84>>2]|0;
 $88 = ((($87)) + 16|0);
 HEAP32[$84>>2] = $88;
 $89 = ((($L)) + 24|0);
 $90 = HEAP32[$89>>2]|0;
 $91 = $90;
 $92 = $88;
 $93 = (($91) - ($92))|0;
 $94 = ($93|0)<(16);
 if (!($94)) {
  $95 = (_luaF_newproto($L)|0);
  $96 = ((($83)) + 12|0);
  HEAP32[$96>>2] = $95;
  _LoadFunction($S,$95,0);
  STACKTOP = sp;return ($83|0);
 }
 _luaD_growstack($L,0);
 $95 = (_luaF_newproto($L)|0);
 $96 = ((($83)) + 12|0);
 HEAP32[$96>>2] = $95;
 _LoadFunction($S,$95,0);
 STACKTOP = sp;return ($83|0);
}
function _error($S,$why) {
 $S = $S|0;
 $why = $why|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[$S>>2]|0;
 $1 = ((($S)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 HEAP32[$vararg_buffer>>2] = $2;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $why;
 (_luaO_pushfstring($0,3552,$vararg_buffer)|0);
 $3 = HEAP32[$S>>2]|0;
 _luaD_throw($3,3);
 // unreachable;
}
function _LoadFunction($S,$f,$psource) {
 $S = $S|0;
 $f = $f|0;
 $psource = $psource|0;
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0;
 var $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0;
 var $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0;
 var $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0;
 var $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0;
 var $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0;
 var $204 = 0, $205 = 0, $206 = 0, $207 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0.0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i22 = 0, $exitcond$i28 = 0, $exitcond16$i = 0, $exitcond38 = 0, $exitcond3840 = 0, $i$013$i = 0, $i$05$i = 0, $i$08$i = 0;
 var $i$1$i34 = 0, $i$110$i = 0, $i$14$i = 0, $i$16$i37 = 0, $i$29$i = 0, $psource$ = 0, $x$i = 0, $x$i$i = 0, $x$i$i13 = 0, $x$i$i18 = 0, $x$i$i25 = 0, $x$i$i32 = 0, $x$i1$i = 0, $x$i1$i17 = 0, $x$i1$i24 = 0, $x$i10 = 0, $x$i2 = 0, $x$i2$i = 0, $x$i2$i23 = 0, $x$i3$i = 0;
 var $x$i4$i = 0, $x$i5 = 0, $x$i5$i = 0, $x$i5$i16 = 0, $x$i7 = 0, $x$i7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i$i32 = sp + 56|0;
 $x$i2$i23 = sp + 66|0;
 $x$i1$i24 = sp + 65|0;
 $x$i$i25 = sp + 52|0;
 $x$i5$i16 = sp + 8|0;
 $x$i4$i = sp;
 $x$i2$i = sp + 64|0;
 $x$i1$i17 = sp + 63|0;
 $x$i$i18 = sp + 48|0;
 $x$i$i13 = sp + 44|0;
 $x$i10 = sp + 62|0;
 $x$i7 = sp + 61|0;
 $x$i5 = sp + 60|0;
 $x$i2 = sp + 40|0;
 $x$i = sp + 36|0;
 $x$i7$i = sp + 32|0;
 $x$i5$i = sp + 28|0;
 $x$i3$i = sp + 24|0;
 $x$i1$i = sp + 20|0;
 $x$i$i = sp + 16|0;
 $0 = (_LoadString($S)|0);
 $1 = ((($f)) + 72|0);
 $2 = ($0|0)==(0|0);
 $psource$ = $2 ? $psource : $0;
 HEAP32[$1>>2] = $psource$;
 $3 = ((($S)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_luaZ_read($4,$x$i,4)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  _error($S,3304);
  // unreachable;
 }
 $7 = HEAP32[$x$i>>2]|0;
 $8 = ((($f)) + 36|0);
 HEAP32[$8>>2] = $7;
 $9 = HEAP32[$3>>2]|0;
 $10 = (_luaZ_read($9,$x$i2,4)|0);
 $11 = ($10|0)==(0);
 if (!($11)) {
  _error($S,3304);
  // unreachable;
 }
 $12 = HEAP32[$x$i2>>2]|0;
 $13 = ((($f)) + 40|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[$3>>2]|0;
 $15 = (_luaZ_read($14,$x$i5,1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  _error($S,3304);
  // unreachable;
 }
 $17 = HEAP8[$x$i5>>0]|0;
 $18 = ((($f)) + 6|0);
 HEAP8[$18>>0] = $17;
 $19 = HEAP32[$3>>2]|0;
 $20 = (_luaZ_read($19,$x$i7,1)|0);
 $21 = ($20|0)==(0);
 if (!($21)) {
  _error($S,3304);
  // unreachable;
 }
 $22 = HEAP8[$x$i7>>0]|0;
 $23 = ((($f)) + 7|0);
 HEAP8[$23>>0] = $22;
 $24 = HEAP32[$3>>2]|0;
 $25 = (_luaZ_read($24,$x$i10,1)|0);
 $26 = ($25|0)==(0);
 if (!($26)) {
  _error($S,3304);
  // unreachable;
 }
 $27 = HEAP8[$x$i10>>0]|0;
 $28 = ((($f)) + 8|0);
 HEAP8[$28>>0] = $27;
 $29 = HEAP32[$3>>2]|0;
 $30 = (_luaZ_read($29,$x$i$i13,4)|0);
 $31 = ($30|0)==(0);
 if (!($31)) {
  _error($S,3304);
  // unreachable;
 }
 $32 = HEAP32[$x$i$i13>>2]|0;
 $33 = (($32) + 1)|0;
 $34 = ($33>>>0)>(1073741823);
 $35 = HEAP32[$S>>2]|0;
 if ($34) {
  _luaM_toobig($35);
  // unreachable;
 }
 $36 = $32 << 2;
 $37 = (_luaM_realloc_($35,0,0,$36)|0);
 $38 = ((($f)) + 48|0);
 HEAP32[$38>>2] = $37;
 $39 = ((($f)) + 20|0);
 HEAP32[$39>>2] = $32;
 $40 = HEAP32[$3>>2]|0;
 $41 = (_luaZ_read($40,$37,$36)|0);
 $42 = ($41|0)==(0);
 if (!($42)) {
  _error($S,3304);
  // unreachable;
 }
 $43 = HEAP32[$3>>2]|0;
 $44 = (_luaZ_read($43,$x$i$i18,4)|0);
 $45 = ($44|0)==(0);
 if (!($45)) {
  _error($S,3304);
  // unreachable;
 }
 $46 = HEAP32[$x$i$i18>>2]|0;
 $47 = (($46) + 1)|0;
 $48 = ($47>>>0)>(268435455);
 $49 = HEAP32[$S>>2]|0;
 if ($48) {
  _luaM_toobig($49);
  // unreachable;
 }
 $50 = $46 << 4;
 $51 = (_luaM_realloc_($49,0,0,$50)|0);
 $52 = ((($f)) + 44|0);
 HEAP32[$52>>2] = $51;
 $53 = ((($f)) + 16|0);
 HEAP32[$53>>2] = $46;
 $54 = ($46|0)>(0);
 L31: do {
  if ($54) {
   $i$08$i = 0;
   while(1) {
    $58 = (((($51) + ($i$08$i<<4)|0)) + 8|0);
    HEAP32[$58>>2] = 0;
    $59 = (($i$08$i) + 1)|0;
    $exitcond$i22 = ($59|0)==($46|0);
    if ($exitcond$i22) {
     break;
    } else {
     $i$08$i = $59;
    }
   }
   $55 = HEAP32[$3>>2]|0;
   $56 = (_luaZ_read($55,$x$i1$i17,1)|0);
   $57 = ($56|0)==(0);
   if ($57) {
    $63 = $51;$69 = $51;$i$16$i37 = 0;
   } else {
    _error($S,3304);
    // unreachable;
   }
   L37: while(1) {
    $60 = HEAP8[$x$i1$i17>>0]|0;
    $61 = $60&255;
    switch ($61|0) {
    case 1:  {
     $64 = HEAP32[$3>>2]|0;
     $65 = (_luaZ_read($64,$x$i2$i,1)|0);
     $66 = ($65|0)==(0);
     if (!($66)) {
      label = 28;
      break L37;
     }
     $67 = HEAP8[$x$i2$i>>0]|0;
     $68 = $67&255;
     HEAP32[$69>>2] = $68;
     $70 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$70>>2] = 1;
     break;
    }
    case 3:  {
     $71 = HEAP32[$3>>2]|0;
     $72 = (_luaZ_read($71,$x$i4$i,8)|0);
     $73 = ($72|0)==(0);
     if (!($73)) {
      label = 31;
      break L37;
     }
     $74 = +HEAPF64[$x$i4$i>>3];
     HEAPF64[$69>>3] = $74;
     $75 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$75>>2] = 3;
     break;
    }
    case 20: case 4:  {
     $90 = (_LoadString($S)|0);
     HEAP32[$69>>2] = $90;
     $91 = ((($90)) + 4|0);
     $92 = HEAP8[$91>>0]|0;
     $93 = $92&255;
     $94 = $93 | 64;
     $95 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$95>>2] = $94;
     break;
    }
    case 0:  {
     $62 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$62>>2] = 0;
     break;
    }
    case 19:  {
     $76 = HEAP32[$3>>2]|0;
     $77 = (_luaZ_read($76,$x$i5$i16,8)|0);
     $78 = ($77|0)==(0);
     if (!($78)) {
      label = 34;
      break L37;
     }
     $79 = $x$i5$i16;
     $80 = $79;
     $81 = HEAP32[$80>>2]|0;
     $82 = (($79) + 4)|0;
     $83 = $82;
     $84 = HEAP32[$83>>2]|0;
     $85 = $69;
     $86 = $85;
     HEAP32[$86>>2] = $81;
     $87 = (($85) + 4)|0;
     $88 = $87;
     HEAP32[$88>>2] = $84;
     $89 = (((($63) + ($i$16$i37<<4)|0)) + 8|0);
     HEAP32[$89>>2] = 19;
     break;
    }
    default: {
    }
    }
    $96 = (($i$16$i37) + 1)|0;
    $97 = ($96|0)<($46|0);
    if (!($97)) {
     break L31;
    }
    $$pre$i = HEAP32[$52>>2]|0;
    $98 = (($$pre$i) + ($96<<4)|0);
    $99 = HEAP32[$3>>2]|0;
    $100 = (_luaZ_read($99,$x$i1$i17,1)|0);
    $101 = ($100|0)==(0);
    if ($101) {
     $63 = $$pre$i;$69 = $98;$i$16$i37 = $96;
    } else {
     label = 24;
     break;
    }
   }
   if ((label|0) == 24) {
    _error($S,3304);
    // unreachable;
   }
   else if ((label|0) == 28) {
    _error($S,3304);
    // unreachable;
   }
   else if ((label|0) == 31) {
    _error($S,3304);
    // unreachable;
   }
   else if ((label|0) == 34) {
    _error($S,3304);
    // unreachable;
   }
  }
 } while(0);
 $102 = HEAP32[$3>>2]|0;
 $103 = (_luaZ_read($102,$x$i$i25,4)|0);
 $104 = ($103|0)==(0);
 if (!($104)) {
  _error($S,3304);
  // unreachable;
 }
 $105 = HEAP32[$x$i$i25>>2]|0;
 $106 = (($105) + 1)|0;
 $107 = ($106>>>0)>(536870911);
 $108 = HEAP32[$S>>2]|0;
 if ($107) {
  _luaM_toobig($108);
  // unreachable;
 }
 $109 = $105 << 3;
 $110 = (_luaM_realloc_($108,0,0,$109)|0);
 $111 = ((($f)) + 64|0);
 HEAP32[$111>>2] = $110;
 $112 = ((($f)) + 12|0);
 HEAP32[$112>>2] = $105;
 $113 = ($105|0)>(0);
 L62: do {
  if ($113) {
   $i$05$i = 0;
   while(1) {
    $114 = (($110) + ($i$05$i<<3)|0);
    HEAP32[$114>>2] = 0;
    $115 = (($i$05$i) + 1)|0;
    $exitcond$i28 = ($115|0)==($105|0);
    if ($exitcond$i28) {
     $i$14$i = 0;
     break;
    } else {
     $i$05$i = $115;
    }
   }
   while(1) {
    $116 = HEAP32[$3>>2]|0;
    $117 = (_luaZ_read($116,$x$i1$i24,1)|0);
    $118 = ($117|0)==(0);
    if (!($118)) {
     label = 46;
     break;
    }
    $119 = HEAP8[$x$i1$i24>>0]|0;
    $120 = HEAP32[$111>>2]|0;
    $121 = (((($120) + ($i$14$i<<3)|0)) + 4|0);
    HEAP8[$121>>0] = $119;
    $122 = HEAP32[$3>>2]|0;
    $123 = (_luaZ_read($122,$x$i2$i23,1)|0);
    $124 = ($123|0)==(0);
    if (!($124)) {
     label = 48;
     break;
    }
    $125 = HEAP8[$x$i2$i23>>0]|0;
    $126 = HEAP32[$111>>2]|0;
    $127 = (((($126) + ($i$14$i<<3)|0)) + 5|0);
    HEAP8[$127>>0] = $125;
    $128 = (($i$14$i) + 1)|0;
    $129 = ($128|0)<($105|0);
    if ($129) {
     $i$14$i = $128;
    } else {
     break L62;
    }
   }
   if ((label|0) == 46) {
    _error($S,3304);
    // unreachable;
   }
   else if ((label|0) == 48) {
    _error($S,3304);
    // unreachable;
   }
  }
 } while(0);
 $130 = HEAP32[$3>>2]|0;
 $131 = (_luaZ_read($130,$x$i$i32,4)|0);
 $132 = ($131|0)==(0);
 if (!($132)) {
  _error($S,3304);
  // unreachable;
 }
 $133 = HEAP32[$x$i$i32>>2]|0;
 $134 = (($133) + 1)|0;
 $135 = ($134>>>0)>(1073741823);
 $136 = HEAP32[$S>>2]|0;
 if ($135) {
  _luaM_toobig($136);
  // unreachable;
 }
 $137 = $133 << 2;
 $138 = (_luaM_realloc_($136,0,0,$137)|0);
 $139 = ((($f)) + 52|0);
 HEAP32[$139>>2] = $138;
 $140 = ((($f)) + 28|0);
 HEAP32[$140>>2] = $133;
 $141 = ($133|0)>(0);
 if ($141) {
  HEAP32[$138>>2] = 0;
  $exitcond3840 = ($133|0)==(1);
  if (!($exitcond3840)) {
   $143 = 1;
   while(1) {
    $$pre = HEAP32[$139>>2]|0;
    $142 = (($$pre) + ($143<<2)|0);
    HEAP32[$142>>2] = 0;
    $144 = (($143) + 1)|0;
    $exitcond38 = ($144|0)==($133|0);
    if ($exitcond38) {
     break;
    } else {
     $143 = $144;
    }
   }
  }
  if ($141) {
   $i$1$i34 = 0;
   while(1) {
    $145 = HEAP32[$S>>2]|0;
    $146 = (_luaF_newproto($145)|0);
    $147 = HEAP32[$139>>2]|0;
    $148 = (($147) + ($i$1$i34<<2)|0);
    HEAP32[$148>>2] = $146;
    $149 = HEAP32[$139>>2]|0;
    $150 = (($149) + ($i$1$i34<<2)|0);
    $151 = HEAP32[$150>>2]|0;
    $152 = HEAP32[$1>>2]|0;
    _LoadFunction($S,$151,$152);
    $153 = (($i$1$i34) + 1)|0;
    $exitcond = ($153|0)==($133|0);
    if ($exitcond) {
     break;
    } else {
     $i$1$i34 = $153;
    }
   }
  }
 }
 $154 = HEAP32[$3>>2]|0;
 $155 = (_luaZ_read($154,$x$i$i,4)|0);
 $156 = ($155|0)==(0);
 if (!($156)) {
  _error($S,3304);
  // unreachable;
 }
 $157 = HEAP32[$x$i$i>>2]|0;
 $158 = (($157) + 1)|0;
 $159 = ($158>>>0)>(1073741823);
 $160 = HEAP32[$S>>2]|0;
 if ($159) {
  _luaM_toobig($160);
  // unreachable;
 }
 $161 = $157 << 2;
 $162 = (_luaM_realloc_($160,0,0,$161)|0);
 $163 = ((($f)) + 56|0);
 HEAP32[$163>>2] = $162;
 $164 = ((($f)) + 24|0);
 HEAP32[$164>>2] = $157;
 $165 = HEAP32[$3>>2]|0;
 $166 = (_luaZ_read($165,$162,$161)|0);
 $167 = ($166|0)==(0);
 if (!($167)) {
  _error($S,3304);
  // unreachable;
 }
 $168 = HEAP32[$3>>2]|0;
 $169 = (_luaZ_read($168,$x$i1$i,4)|0);
 $170 = ($169|0)==(0);
 if (!($170)) {
  _error($S,3304);
  // unreachable;
 }
 $171 = HEAP32[$x$i1$i>>2]|0;
 $172 = (($171) + 1)|0;
 $173 = ($172>>>0)>(357913941);
 $174 = HEAP32[$S>>2]|0;
 if ($173) {
  _luaM_toobig($174);
  // unreachable;
 }
 $175 = ($171*12)|0;
 $176 = (_luaM_realloc_($174,0,0,$175)|0);
 $177 = ((($f)) + 60|0);
 HEAP32[$177>>2] = $176;
 $178 = ((($f)) + 32|0);
 HEAP32[$178>>2] = $171;
 $179 = ($171|0)>(0);
 L103: do {
  if ($179) {
   $i$013$i = 0;
   while(1) {
    $180 = (($176) + (($i$013$i*12)|0)|0);
    HEAP32[$180>>2] = 0;
    $181 = (($i$013$i) + 1)|0;
    $exitcond16$i = ($181|0)==($171|0);
    if ($exitcond16$i) {
     break;
    } else {
     $i$013$i = $181;
    }
   }
   $i$110$i = 0;
   while(1) {
    $182 = (_LoadString($S)|0);
    $183 = HEAP32[$177>>2]|0;
    $184 = (($183) + (($i$110$i*12)|0)|0);
    HEAP32[$184>>2] = $182;
    $185 = HEAP32[$3>>2]|0;
    $186 = (_luaZ_read($185,$x$i3$i,4)|0);
    $187 = ($186|0)==(0);
    if (!($187)) {
     label = 73;
     break;
    }
    $188 = HEAP32[$x$i3$i>>2]|0;
    $189 = HEAP32[$177>>2]|0;
    $190 = (((($189) + (($i$110$i*12)|0)|0)) + 4|0);
    HEAP32[$190>>2] = $188;
    $191 = HEAP32[$3>>2]|0;
    $192 = (_luaZ_read($191,$x$i5$i,4)|0);
    $193 = ($192|0)==(0);
    if (!($193)) {
     label = 75;
     break;
    }
    $194 = HEAP32[$x$i5$i>>2]|0;
    $195 = HEAP32[$177>>2]|0;
    $196 = (((($195) + (($i$110$i*12)|0)|0)) + 8|0);
    HEAP32[$196>>2] = $194;
    $197 = (($i$110$i) + 1)|0;
    $198 = ($197|0)<($171|0);
    if ($198) {
     $i$110$i = $197;
    } else {
     break L103;
    }
   }
   if ((label|0) == 73) {
    _error($S,3304);
    // unreachable;
   }
   else if ((label|0) == 75) {
    _error($S,3304);
    // unreachable;
   }
  }
 } while(0);
 $199 = HEAP32[$3>>2]|0;
 $200 = (_luaZ_read($199,$x$i7$i,4)|0);
 $201 = ($200|0)==(0);
 if (!($201)) {
  _error($S,3304);
  // unreachable;
 }
 $202 = HEAP32[$x$i7$i>>2]|0;
 $203 = ($202|0)>(0);
 if ($203) {
  $i$29$i = 0;
 } else {
  STACKTOP = sp;return;
 }
 while(1) {
  $204 = (_LoadString($S)|0);
  $205 = HEAP32[$111>>2]|0;
  $206 = (($205) + ($i$29$i<<3)|0);
  HEAP32[$206>>2] = $204;
  $207 = (($i$29$i) + 1)|0;
  $exitcond$i = ($207|0)==($202|0);
  if ($exitcond$i) {
   break;
  } else {
   $i$29$i = $207;
  }
 }
 STACKTOP = sp;return;
}
function _LoadString($S) {
 $S = $S|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $size = 0, $x$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp + 4|0;
 $size = sp;
 $0 = ((($S)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaZ_read($1,$x$i,1)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  _error($S,3304);
  // unreachable;
 }
 $4 = HEAP8[$x$i>>0]|0;
 $5 = $4&255;
 HEAP32[$size>>2] = $5;
 $6 = ($4<<24>>24)==(-1);
 do {
  if ($6) {
   $7 = HEAP32[$0>>2]|0;
   $8 = (_luaZ_read($7,$size,4)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $$pr = HEAP32[$size>>2]|0;
    $11 = $$pr;
    break;
   } else {
    _error($S,3304);
    // unreachable;
   }
  } else {
   $11 = $5;
  }
 } while(0);
 $10 = ($11|0)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$S>>2]|0;
 $13 = ((($S)) + 8|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (($11) + -1)|0;
 HEAP32[$size>>2] = $15;
 $16 = (_luaZ_openspace($12,$14,$15)|0);
 $17 = HEAP32[$size>>2]|0;
 $18 = HEAP32[$0>>2]|0;
 $19 = (_luaZ_read($18,$16,$17)|0);
 $20 = ($19|0)==(0);
 if (!($20)) {
  _error($S,3304);
  // unreachable;
 }
 $21 = HEAP32[$S>>2]|0;
 $22 = HEAP32[$size>>2]|0;
 $23 = (_luaS_newlstr($21,$16,$22)|0);
 $$0 = $23;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_tonumber_($obj,$n) {
 $obj = $obj|0;
 $n = $n|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, $v = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $v = sp;
 $0 = ((($obj)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 if ($2) {
  $3 = $obj;
  $4 = $3;
  $5 = HEAP32[$4>>2]|0;
  $6 = (($3) + 4)|0;
  $7 = $6;
  $8 = HEAP32[$7>>2]|0;
  $9 = (+($5>>>0)) + (4294967296.0*(+($8|0)));
  HEAPF64[$n>>3] = $9;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = $1 & 15;
 $11 = ($10|0)==(4);
 if (!($11)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = HEAP32[$obj>>2]|0;
 $13 = ((($12)) + 24|0);
 $14 = (_luaO_str2num($13,$v)|0);
 $15 = HEAP32[$obj>>2]|0;
 $16 = ((($15)) + 12|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = (($17) + 1)|0;
 $19 = ($14|0)==($18|0);
 if (!($19)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $20 = ((($v)) + 8|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = ($21|0)==(19);
 $23 = $v;
 $24 = $23;
 $25 = HEAP32[$24>>2]|0;
 $26 = (($23) + 4)|0;
 $27 = $26;
 $28 = HEAP32[$27>>2]|0;
 $29 = (+($25>>>0)) + (4294967296.0*(+($28|0)));
 HEAP32[tempDoublePtr>>2] = $25;HEAP32[tempDoublePtr+4>>2] = $28;$30 = +HEAPF64[tempDoublePtr>>3];
 $31 = $22 ? $29 : $30;
 HEAPF64[$n>>3] = $31;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_tointeger_($obj,$p) {
 $obj = $obj|0;
 $p = $p|0;
 var $$0$i = 0, $$02$i = 0, $$02$i$lcssa = 0, $$02$i$lcssa11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0.0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $v$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $v$i = sp;
 $$02$i = $obj;
 while(1) {
  $0 = ((($$02$i)) + 8|0);
  $1 = HEAP32[$0>>2]|0;
  if ((($1|0) == 3)) {
   $$02$i$lcssa = $$02$i;
   label = 3;
   break;
  } else if ((($1|0) == 19)) {
   $$02$i$lcssa11 = $$02$i;
   label = 6;
   break;
  }
  $23 = $1 & 15;
  $24 = ($23|0)==(4);
  if (!($24)) {
   $$0$i = 0;
   label = 9;
   break;
  }
  $25 = HEAP32[$$02$i>>2]|0;
  $26 = ((($25)) + 24|0);
  $27 = (_luaO_str2num($26,$v$i)|0);
  $28 = HEAP32[$$02$i>>2]|0;
  $29 = ((($28)) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + 1)|0;
  $32 = ($27|0)==($31|0);
  if ($32) {
   $$02$i = $v$i;
  } else {
   $$0$i = 0;
   label = 9;
   break;
  }
 }
 if ((label|0) == 3) {
  $2 = +HEAPF64[$$02$i$lcssa>>3];
  $3 = (+Math_floor((+$2)));
  $4 = $2 != $3;
  if ($4) {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  $5 = $3 >= -9.2233720368547758E+18;
  $6 = $3 < 9.2233720368547758E+18;
  $or$cond$i = $5 & $6;
  if (!($or$cond$i)) {
   $$0$i = 0;
   STACKTOP = sp;return ($$0$i|0);
  }
  $7 = (~~$3)>>>0;
  $8 = +Math_abs($3) >= 1.0 ? $3 > 0.0 ? (~~+Math_min(+Math_floor($3 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($3 - +(~~$3 >>> 0)) / 4294967296.0) >>> 0 : 0;
  $9 = $p;
  $10 = $9;
  HEAP32[$10>>2] = $7;
  $11 = (($9) + 4)|0;
  $12 = $11;
  HEAP32[$12>>2] = $8;
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 6) {
  $13 = $$02$i$lcssa11;
  $14 = $13;
  $15 = HEAP32[$14>>2]|0;
  $16 = (($13) + 4)|0;
  $17 = $16;
  $18 = HEAP32[$17>>2]|0;
  $19 = $p;
  $20 = $19;
  HEAP32[$20>>2] = $15;
  $21 = (($19) + 4)|0;
  $22 = $21;
  HEAP32[$22>>2] = $18;
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 else if ((label|0) == 9) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return (0)|0;
}
function _luaV_gettable($L,$t,$key,$val) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 $val = $val|0;
 var $$05 = 0, $$05$lcssa = 0, $$05$lcssa25 = 0, $$lcssa = 0, $$phi$trans$insert = 0, $$phi$trans$insert10 = 0, $$pre = 0, $$pre11 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $loop$04 = 0, $tm$0 = 0, $tm$0$lcssa = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 12|0);
 $$phi$trans$insert = ((($t)) + 8|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $$05 = $t;$4 = $$pre;$loop$04 = 0;
 while(1) {
  $3 = ($4|0)==(69);
  if ($3) {
   $5 = HEAP32[$$05>>2]|0;
   $6 = (_luaH_get($5,$key)|0);
   $7 = ((($6)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $10 = ((($5)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $13 = ((($11)) + 6|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 1;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 148|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (_luaT_gettm($11,0,$19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$lcssa = $6;
    label = 9;
    break;
   }
   $$phi$trans$insert10 = ((($20)) + 8|0);
   $$pre11 = HEAP32[$$phi$trans$insert10>>2]|0;
   $27 = $$pre11;$tm$0 = $20;
  } else {
   $22 = (_luaT_gettmbyobj($L,$$05,0)|0);
   $23 = ((($22)) + 8|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    $$05$lcssa = $$05;
    label = 11;
    break;
   } else {
    $27 = $24;$tm$0 = $22;
   }
  }
  $26 = $27 & 15;
  $28 = ($26|0)==(6);
  $2 = (($loop$04) + 1)|0;
  if ($28) {
   $$05$lcssa25 = $$05;$tm$0$lcssa = $tm$0;
   label = 13;
   break;
  }
  $1 = ($2|0)<(2000);
  if ($1) {
   $$05 = $tm$0;$4 = $27;$loop$04 = $2;
  } else {
   label = 14;
   break;
  }
 }
 if ((label|0) == 9) {
  ;HEAP32[$val>>2]=HEAP32[$$lcssa>>2]|0;HEAP32[$val+4>>2]=HEAP32[$$lcssa+4>>2]|0;HEAP32[$val+8>>2]=HEAP32[$$lcssa+8>>2]|0;HEAP32[$val+12>>2]=HEAP32[$$lcssa+12>>2]|0;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 11) {
  _luaG_typeerror($L,$$05$lcssa,3584);
  // unreachable;
 }
 else if ((label|0) == 13) {
  _luaT_callTM($L,$tm$0$lcssa,$$05$lcssa25,$key,$val,1);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 14) {
  _luaG_runerror($L,3592,$vararg_buffer);
  // unreachable;
 }
}
function _luaV_settable($L,$t,$key,$val) {
 $L = $L|0;
 $t = $t|0;
 $key = $key|0;
 $val = $val|0;
 var $$09 = 0, $$09$lcssa = 0, $$09$lcssa46 = 0, $$lcssa48 = 0, $$lcssa50 = 0, $$phi$trans$insert = 0, $$phi$trans$insert18 = 0, $$pre = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $loop$08 = 0, $oldval$0 = 0, $tm$0 = 0, $tm$0$lcssa = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 12|0);
 $$phi$trans$insert = ((($t)) + 8|0);
 $$pre = HEAP32[$$phi$trans$insert>>2]|0;
 $$09 = $t;$4 = $$pre;$loop$08 = 0;
 while(1) {
  $3 = ($4|0)==(69);
  if ($3) {
   $5 = HEAP32[$$09>>2]|0;
   $6 = (_luaH_get($5,$key)|0);
   $7 = ((($6)) + 8|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $25 = $5;$oldval$0 = $6;
    break;
   }
   $10 = ((($5)) + 24|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ($11|0)==(0|0);
   if ($12) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $13 = ((($11)) + 6|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = $14 & 2;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $17 = HEAP32[$0>>2]|0;
   $18 = ((($17)) + 152|0);
   $19 = HEAP32[$18>>2]|0;
   $20 = (_luaT_gettm($11,1,$19)|0);
   $21 = ($20|0)==(0|0);
   if ($21) {
    $$lcssa48 = $5;$$lcssa50 = $6;
    label = 9;
    break;
   }
   $$phi$trans$insert18 = ((($20)) + 8|0);
   $$pre19 = HEAP32[$$phi$trans$insert18>>2]|0;
   $44 = $$pre19;$tm$0 = $20;
  } else {
   $39 = (_luaT_gettmbyobj($L,$$09,1)|0);
   $40 = ((($39)) + 8|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(0);
   if ($42) {
    $$09$lcssa = $$09;
    label = 16;
    break;
   } else {
    $44 = $41;$tm$0 = $39;
   }
  }
  $43 = $44 & 15;
  $45 = ($43|0)==(6);
  $2 = (($loop$08) + 1)|0;
  if ($45) {
   $$09$lcssa46 = $$09;$tm$0$lcssa = $tm$0;
   label = 18;
   break;
  }
  $1 = ($2|0)<(2000);
  if ($1) {
   $$09 = $tm$0;$4 = $44;$loop$08 = $2;
  } else {
   label = 19;
   break;
  }
 }
 if ((label|0) == 9) {
  $22 = ($$lcssa50|0)==(1568|0);
  if ($22) {
   $23 = (_luaH_newkey($L,$$lcssa48,$key)|0);
   $25 = $$lcssa48;$oldval$0 = $23;
  } else {
   $25 = $$lcssa48;$oldval$0 = $$lcssa50;
  }
 }
 else if ((label|0) == 16) {
  _luaG_typeerror($L,$$09$lcssa,3584);
  // unreachable;
 }
 else if ((label|0) == 18) {
  _luaT_callTM($L,$tm$0$lcssa,$$09$lcssa46,$key,$val,0);
  STACKTOP = sp;return;
 }
 else if ((label|0) == 19) {
  _luaG_runerror($L,3632,$vararg_buffer);
  // unreachable;
 }
 ;HEAP32[$oldval$0>>2]=HEAP32[$val>>2]|0;HEAP32[$oldval$0+4>>2]=HEAP32[$val+4>>2]|0;HEAP32[$oldval$0+8>>2]=HEAP32[$val+8>>2]|0;HEAP32[$oldval$0+12>>2]=HEAP32[$val+12>>2]|0;
 $24 = ((($25)) + 6|0);
 HEAP8[$24>>0] = 0;
 $26 = ((($val)) + 8|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = $27 & 64;
 $29 = ($28|0)==(0);
 if ($29) {
  STACKTOP = sp;return;
 }
 $30 = ((($25)) + 5|0);
 $31 = HEAP8[$30>>0]|0;
 $32 = $31 & 4;
 $33 = ($32<<24>>24)==(0);
 if ($33) {
  STACKTOP = sp;return;
 }
 $34 = HEAP32[$val>>2]|0;
 $35 = ((($34)) + 5|0);
 $36 = HEAP8[$35>>0]|0;
 $37 = $36 & 3;
 $38 = ($37<<24>>24)==(0);
 if ($38) {
  STACKTOP = sp;return;
 }
 _luaC_barrierback_($L,$25);
 STACKTOP = sp;return;
}
function _luaV_lessthan($L,$l,$r) {
 $L = $L|0;
 $l = $l|0;
 $r = $r|0;
 var $$0 = 0, $$0$i1 = 0, $$lcssa = 0, $$lobit = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $8 = 0, $9 = 0, $cond = 0, $l$01$i = 0, $ll$02$i = 0, $lr$04$i = 0, $r$03$i = 0, $storemerge1$i$ph = 0.0, $storemerge1$i3$ph = 0.0, $x$i = 0, $x$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i2 = sp + 8|0;
 $x$i = sp;
 $0 = ((($l)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 do {
  if ($2) {
   $3 = ((($r)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(19);
   if (!($5)) {
    $6 = $l;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = (($6) + 4)|0;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (+($8>>>0)) + (4294967296.0*(+($11|0)));
    HEAPF64[$x$i>>3] = $12;
    $13 = +HEAPF64[$x$i>>3];
    $77 = $x$i;$storemerge1$i$ph = $13;
    label = 8;
    break;
   }
   $14 = $l;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $r;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($19|0)<($25|0);
   $27 = ($16>>>0)<($22>>>0);
   $28 = ($19|0)==($25|0);
   $29 = $28 & $27;
   $30 = $26 | $29;
   $31 = $30&1;
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  } else {
   $cond = ($1|0)==(3);
   if ($cond) {
    $32 = +HEAPF64[$l>>3];
    $77 = $x$i;$storemerge1$i$ph = $32;
    label = 8;
    break;
   } else {
    $47 = $1;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $33 = ((($r)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   if ((($34|0) == 3)) {
    $35 = +HEAPF64[$r>>3];
    $storemerge1$i3$ph = $35;
   } else if ((($34|0) == 19)) {
    $36 = $r;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = (+($38>>>0)) + (4294967296.0*(+($41|0)));
    HEAPF64[$x$i2>>3] = $42;
    $43 = +HEAPF64[$x$i2>>3];
    $storemerge1$i3$ph = $43;
   } else {
    $$pre = HEAP32[$0>>2]|0;
    $47 = $$pre;
    break;
   }
   $44 = $storemerge1$i$ph < $storemerge1$i3$ph;
   $45 = $44&1;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $46 = $47 & 15;
 $48 = ($46|0)==(4);
 if ($48) {
  $49 = ((($r)) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 15;
  $52 = ($51|0)==(4);
  if ($52) {
   $53 = HEAP32[$l>>2]|0;
   $54 = HEAP32[$r>>2]|0;
   $55 = ((($53)) + 24|0);
   $56 = ((($54)) + 24|0);
   $57 = (_strcoll($55,$56)|0);
   $58 = ($57|0)==(0);
   L23: do {
    if ($58) {
     $59 = ((($54)) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($53)) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $l$01$i = $55;$ll$02$i = $62;$lr$04$i = $60;$r$03$i = $56;
     while(1) {
      $63 = (_strlen(($l$01$i|0))|0);
      $64 = ($63|0)==($lr$04$i|0);
      $65 = ($63|0)==($ll$02$i|0);
      if ($64) {
       $$lcssa = $65;
       break;
      }
      if ($65) {
       $$0$i1 = -1;
       break L23;
      }
      $68 = (($63) + 1)|0;
      $69 = (($l$01$i) + ($68)|0);
      $70 = (($ll$02$i) - ($68))|0;
      $71 = (($r$03$i) + ($68)|0);
      $72 = (($lr$04$i) - ($68))|0;
      $73 = (_strcoll($69,$71)|0);
      $74 = ($73|0)==(0);
      if ($74) {
       $l$01$i = $69;$ll$02$i = $70;$lr$04$i = $72;$r$03$i = $71;
      } else {
       $$0$i1 = $73;
       break L23;
      }
     }
     $66 = $$lcssa&1;
     $67 = $66 ^ 1;
     $$0$i1 = $67;
    } else {
     $$0$i1 = $57;
    }
   } while(0);
   $$lobit = $$0$i1 >>> 31;
   $$0 = $$lobit;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $75 = (_luaT_callorderTM($L,$l,$r,20)|0);
 $76 = ($75|0)<(0);
 if ($76) {
  _luaG_ordererror($L,$l,$r);
  // unreachable;
 } else {
  $$0 = $75;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaV_lessequal($L,$l,$r) {
 $L = $L|0;
 $l = $l|0;
 $r = $r|0;
 var $$0 = 0, $$0$i1 = 0, $$lcssa = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0.0, $43 = 0.0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $cond = 0, $l$01$i = 0, $ll$02$i = 0, $lr$04$i = 0, $r$03$i = 0, $storemerge1$i$ph = 0.0, $storemerge1$i3$ph = 0.0, $x$i = 0, $x$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i2 = sp + 8|0;
 $x$i = sp;
 $0 = ((($l)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(19);
 do {
  if ($2) {
   $3 = ((($r)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(19);
   if (!($5)) {
    $6 = $l;
    $7 = $6;
    $8 = HEAP32[$7>>2]|0;
    $9 = (($6) + 4)|0;
    $10 = $9;
    $11 = HEAP32[$10>>2]|0;
    $12 = (+($8>>>0)) + (4294967296.0*(+($11|0)));
    HEAPF64[$x$i>>3] = $12;
    $13 = +HEAPF64[$x$i>>3];
    $83 = $x$i;$storemerge1$i$ph = $13;
    label = 8;
    break;
   }
   $14 = $l;
   $15 = $14;
   $16 = HEAP32[$15>>2]|0;
   $17 = (($14) + 4)|0;
   $18 = $17;
   $19 = HEAP32[$18>>2]|0;
   $20 = $r;
   $21 = $20;
   $22 = HEAP32[$21>>2]|0;
   $23 = (($20) + 4)|0;
   $24 = $23;
   $25 = HEAP32[$24>>2]|0;
   $26 = ($19|0)<($25|0);
   $27 = ($16>>>0)<=($22>>>0);
   $28 = ($19|0)==($25|0);
   $29 = $28 & $27;
   $30 = $26 | $29;
   $31 = $30&1;
   $$0 = $31;
   STACKTOP = sp;return ($$0|0);
  } else {
   $cond = ($1|0)==(3);
   if ($cond) {
    $32 = +HEAPF64[$l>>3];
    $83 = $x$i;$storemerge1$i$ph = $32;
    label = 8;
    break;
   } else {
    $47 = $1;
    break;
   }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $33 = ((($r)) + 8|0);
   $34 = HEAP32[$33>>2]|0;
   if ((($34|0) == 3)) {
    $35 = +HEAPF64[$r>>3];
    $storemerge1$i3$ph = $35;
   } else if ((($34|0) == 19)) {
    $36 = $r;
    $37 = $36;
    $38 = HEAP32[$37>>2]|0;
    $39 = (($36) + 4)|0;
    $40 = $39;
    $41 = HEAP32[$40>>2]|0;
    $42 = (+($38>>>0)) + (4294967296.0*(+($41|0)));
    HEAPF64[$x$i2>>3] = $42;
    $43 = +HEAPF64[$x$i2>>3];
    $storemerge1$i3$ph = $43;
   } else {
    $$pre = HEAP32[$0>>2]|0;
    $47 = $$pre;
    break;
   }
   $44 = $storemerge1$i$ph <= $storemerge1$i3$ph;
   $45 = $44&1;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $46 = $47 & 15;
 $48 = ($46|0)==(4);
 if ($48) {
  $49 = ((($r)) + 8|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 15;
  $52 = ($51|0)==(4);
  if ($52) {
   $53 = HEAP32[$l>>2]|0;
   $54 = HEAP32[$r>>2]|0;
   $55 = ((($53)) + 24|0);
   $56 = ((($54)) + 24|0);
   $57 = (_strcoll($55,$56)|0);
   $58 = ($57|0)==(0);
   L23: do {
    if ($58) {
     $59 = ((($54)) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = ((($53)) + 12|0);
     $62 = HEAP32[$61>>2]|0;
     $l$01$i = $55;$ll$02$i = $62;$lr$04$i = $60;$r$03$i = $56;
     while(1) {
      $63 = (_strlen(($l$01$i|0))|0);
      $64 = ($63|0)==($lr$04$i|0);
      $65 = ($63|0)==($ll$02$i|0);
      if ($64) {
       $$lcssa = $65;
       break;
      }
      if ($65) {
       $$0$i1 = -1;
       break L23;
      }
      $68 = (($63) + 1)|0;
      $69 = (($l$01$i) + ($68)|0);
      $70 = (($ll$02$i) - ($68))|0;
      $71 = (($r$03$i) + ($68)|0);
      $72 = (($lr$04$i) - ($68))|0;
      $73 = (_strcoll($69,$71)|0);
      $74 = ($73|0)==(0);
      if ($74) {
       $l$01$i = $69;$ll$02$i = $70;$lr$04$i = $72;$r$03$i = $71;
      } else {
       $$0$i1 = $73;
       break L23;
      }
     }
     $66 = $$lcssa&1;
     $67 = $66 ^ 1;
     $$0$i1 = $67;
    } else {
     $$0$i1 = $57;
    }
   } while(0);
   $75 = ($$0$i1|0)<(1);
   $76 = $75&1;
   $$0 = $76;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $77 = (_luaT_callorderTM($L,$l,$r,21)|0);
 $78 = ($77|0)>(-1);
 if ($78) {
  $$0 = $77;
  STACKTOP = sp;return ($$0|0);
 }
 $79 = (_luaT_callorderTM($L,$r,$l,20)|0);
 $80 = ($79|0)<(0);
 if ($80) {
  _luaG_ordererror($L,$l,$r);
  // unreachable;
 }
 $81 = ($79|0)==(0);
 $82 = $81&1;
 $$0 = $82;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_equalobj($L,$t1,$t2) {
 $L = $L|0;
 $t1 = $t1|0;
 $t2 = $t2|0;
 var $$0 = 0, $$pre = 0, $$pre12 = 0, $$pre13 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0.0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0.0, $28 = 0.0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0.0, $48 = 0.0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $or$cond = 0, $phitmp = 0, $storemerge1$i = 0.0, $storemerge1$i2 = 0.0, $tm$0 = 0, $tm$011 = 0, $x$i = 0, $x$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i1 = sp + 8|0;
 $x$i = sp;
 $0 = ((($t1)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 63;
 $3 = ((($t2)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $4 & 63;
 $6 = ($2|0)==($5|0);
 if (!($6)) {
  $7 = $1 & 15;
  $8 = $4 & 15;
  $9 = ($7|0)==($8|0);
  $10 = ($7|0)==(3);
  $or$cond = $10 & $9;
  if (!($or$cond)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  if ((($1|0) == 3)) {
   $11 = +HEAPF64[$t1>>3];
   $145 = $4;$storemerge1$i = $11;
  } else if ((($1|0) == 19)) {
   $12 = $t1;
   $13 = $12;
   $14 = HEAP32[$13>>2]|0;
   $15 = (($12) + 4)|0;
   $16 = $15;
   $17 = HEAP32[$16>>2]|0;
   $18 = (+($14>>>0)) + (4294967296.0*(+($17|0)));
   HEAPF64[$x$i>>3] = $18;
   $19 = +HEAPF64[$x$i>>3];
   $$pre = HEAP32[$3>>2]|0;
   $145 = $$pre;$storemerge1$i = $19;
  } else {
   $145 = $4;$storemerge1$i = 0.0;
  }
  if ((($145|0) == 3)) {
   $20 = +HEAPF64[$t2>>3];
   $storemerge1$i2 = $20;
  } else if ((($145|0) == 19)) {
   $21 = $t2;
   $22 = $21;
   $23 = HEAP32[$22>>2]|0;
   $24 = (($21) + 4)|0;
   $25 = $24;
   $26 = HEAP32[$25>>2]|0;
   $27 = (+($23>>>0)) + (4294967296.0*(+($26|0)));
   HEAPF64[$x$i1>>3] = $27;
   $28 = +HEAPF64[$x$i1>>3];
   $storemerge1$i2 = $28;
  } else {
   $storemerge1$i2 = 0.0;
  }
  $29 = $storemerge1$i == $storemerge1$i2;
  $30 = $29&1;
  $$0 = $30;
  STACKTOP = sp;return ($$0|0);
 }
 L16: do {
  switch ($2|0) {
  case 7:  {
   $70 = HEAP32[$t1>>2]|0;
   $71 = HEAP32[$t2>>2]|0;
   $72 = ($70|0)==($71|0);
   if ($72) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $73 = ($L|0)==(0|0);
   if ($73) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $74 = ((($70)) + 8|0);
   $75 = HEAP32[$74>>2]|0;
   $76 = ($75|0)==(0|0);
   if ($76) {
    $88 = $71;
   } else {
    $77 = ((($75)) + 6|0);
    $78 = HEAP8[$77>>0]|0;
    $79 = $78 & 32;
    $80 = ($79<<24>>24)==(0);
    if ($80) {
     $81 = ((($L)) + 12|0);
     $82 = HEAP32[$81>>2]|0;
     $83 = ((($82)) + 168|0);
     $84 = HEAP32[$83>>2]|0;
     $85 = (_luaT_gettm($75,5,$84)|0);
     $86 = ($85|0)==(0|0);
     if (!($86)) {
      $tm$011 = $85;
      break L16;
     }
     $$pre13 = HEAP32[$t2>>2]|0;
     $88 = $$pre13;
    } else {
     $88 = $71;
    }
   }
   $87 = ((($88)) + 8|0);
   $89 = HEAP32[$87>>2]|0;
   $90 = ($89|0)==(0|0);
   if ($90) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $91 = ((($89)) + 6|0);
   $92 = HEAP8[$91>>0]|0;
   $93 = $92 & 32;
   $94 = ($93<<24>>24)==(0);
   if ($94) {
    $95 = ((($L)) + 12|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = ((($96)) + 168|0);
    $98 = HEAP32[$97>>2]|0;
    $99 = (_luaT_gettm($89,5,$98)|0);
    $tm$0 = $99;
    label = 37;
    break L16;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 22:  {
   $59 = HEAP32[$t1>>2]|0;
   $60 = HEAP32[$t2>>2]|0;
   $61 = ($59|0)==($60|0);
   $62 = $61&1;
   $$0 = $62;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 4:  {
   $63 = HEAP32[$t1>>2]|0;
   $64 = HEAP32[$t2>>2]|0;
   $65 = ($63|0)==($64|0);
   $66 = $65&1;
   $$0 = $66;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 3:  {
   $47 = +HEAPF64[$t1>>3];
   $48 = +HEAPF64[$t2>>3];
   $49 = $47 == $48;
   $50 = $49&1;
   $$0 = $50;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 19:  {
   $31 = $t1;
   $32 = $31;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($31) + 4)|0;
   $35 = $34;
   $36 = HEAP32[$35>>2]|0;
   $37 = $t2;
   $38 = $37;
   $39 = HEAP32[$38>>2]|0;
   $40 = (($37) + 4)|0;
   $41 = $40;
   $42 = HEAP32[$41>>2]|0;
   $43 = ($33|0)==($39|0);
   $44 = ($36|0)==($42|0);
   $45 = $43 & $44;
   $46 = $45&1;
   $$0 = $46;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 1:  {
   $51 = HEAP32[$t1>>2]|0;
   $52 = HEAP32[$t2>>2]|0;
   $53 = ($51|0)==($52|0);
   $54 = $53&1;
   $$0 = $54;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 20:  {
   $67 = HEAP32[$t1>>2]|0;
   $68 = HEAP32[$t2>>2]|0;
   $69 = (_luaS_eqlngstr($67,$68)|0);
   $$0 = $69;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 0:  {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 5:  {
   $100 = HEAP32[$t1>>2]|0;
   $101 = HEAP32[$t2>>2]|0;
   $102 = ($100|0)==($101|0);
   if ($102) {
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   }
   $103 = ($L|0)==(0|0);
   if ($103) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $104 = ((($100)) + 24|0);
   $105 = HEAP32[$104>>2]|0;
   $106 = ($105|0)==(0|0);
   if ($106) {
    $118 = $101;
   } else {
    $107 = ((($105)) + 6|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = $108 & 32;
    $110 = ($109<<24>>24)==(0);
    if ($110) {
     $111 = ((($L)) + 12|0);
     $112 = HEAP32[$111>>2]|0;
     $113 = ((($112)) + 168|0);
     $114 = HEAP32[$113>>2]|0;
     $115 = (_luaT_gettm($105,5,$114)|0);
     $116 = ($115|0)==(0|0);
     if (!($116)) {
      $tm$011 = $115;
      break L16;
     }
     $$pre12 = HEAP32[$t2>>2]|0;
     $118 = $$pre12;
    } else {
     $118 = $101;
    }
   }
   $117 = ((($118)) + 24|0);
   $119 = HEAP32[$117>>2]|0;
   $120 = ($119|0)==(0|0);
   if ($120) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   $121 = ((($119)) + 6|0);
   $122 = HEAP8[$121>>0]|0;
   $123 = $122 & 32;
   $124 = ($123<<24>>24)==(0);
   if ($124) {
    $125 = ((($L)) + 12|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ((($126)) + 168|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = (_luaT_gettm($119,5,$128)|0);
    $tm$0 = $129;
    label = 37;
    break L16;
   } else {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 2:  {
   $55 = HEAP32[$t1>>2]|0;
   $56 = HEAP32[$t2>>2]|0;
   $57 = ($55|0)==($56|0);
   $58 = $57&1;
   $$0 = $58;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $130 = HEAP32[$t1>>2]|0;
   $131 = HEAP32[$t2>>2]|0;
   $132 = ($130|0)==($131|0);
   $133 = $132&1;
   $$0 = $133;
   STACKTOP = sp;return ($$0|0);
  }
  }
 } while(0);
 if ((label|0) == 37) {
  $134 = ($tm$0|0)==(0|0);
  if ($134) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $tm$011 = $tm$0;
  }
 }
 $135 = ((($L)) + 8|0);
 $136 = HEAP32[$135>>2]|0;
 _luaT_callTM($L,$tm$011,$t1,$t2,$136,1);
 $137 = HEAP32[$135>>2]|0;
 $138 = ((($137)) + 8|0);
 $139 = HEAP32[$138>>2]|0;
 $140 = ($139|0)==(0);
 if ($140) {
  $144 = 0;
 } else {
  $141 = ($139|0)==(1);
  if ($141) {
   $142 = HEAP32[$137>>2]|0;
   $phitmp = ($142|0)!=(0);
   $144 = $phitmp;
  } else {
   $144 = 1;
  }
 }
 $143 = $144&1;
 $$0 = $143;
 STACKTOP = sp;return ($$0|0);
}
function _luaV_concat($L,$total) {
 $L = $L|0;
 $total = $total|0;
 var $$0 = 0, $$lcssa = 0, $$neg = 0, $$not = 0, $$off = 0, $$pre = 0, $$pre17 = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$lcssa = 0, $i$05 = 0, $i$1 = 0, $n$0 = 0, $or$cond = 0, $switch = 0, $tl$0$lcssa = 0, $tl$06 = 0, $tl$1 = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($L)) + 8|0);
 $1 = ((($L)) + 12|0);
 $$pre = HEAP32[$0>>2]|0;
 $$0 = $total;$3 = $$pre;
 L1: while(1) {
  $2 = ((($3)) + -32|0);
  $4 = ((($3)) + -24|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 15;
  $$off = (($6) + -3)|0;
  $switch = ($$off>>>0)<(2);
  $7 = ((($3)) + -16|0);
  do {
   if ($switch) {
    $8 = ((($3)) + -8|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 15;
    if ((($10|0) == 3)) {
     _luaO_tostring($L,$7);
     $$pre17 = HEAP32[$4>>2]|0;
     $16 = $$pre17;
    } else if ((($10|0) == 4)) {
     $16 = $5;
    } else {
     label = 5;
     break;
    }
    $11 = HEAP32[$7>>2]|0;
    $12 = ((($11)) + 12|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0);
    $15 = $16 & 15;
    $17 = ($15|0)==(4);
    if ($14) {
     $$not = $17 ^ 1;
     $18 = ($15|0)==(3);
     $or$cond = $18 & $$not;
     if (!($or$cond)) {
      $n$0 = 2;
      break;
     }
     _luaO_tostring($L,$2);
     $n$0 = 2;
     break;
    }
    if ($17) {
     $19 = HEAP32[$2>>2]|0;
     $20 = ((($19)) + 12|0);
     $21 = HEAP32[$20>>2]|0;
     $22 = ($21|0)==(0);
     if ($22) {
      ;HEAP32[$2>>2]=HEAP32[$7>>2]|0;HEAP32[$2+4>>2]=HEAP32[$7+4>>2]|0;HEAP32[$2+8>>2]=HEAP32[$7+8>>2]|0;HEAP32[$2+12>>2]=HEAP32[$7+12>>2]|0;
      $n$0 = 2;
      break;
     }
    }
    $23 = ($$0|0)>(1);
    L16: do {
     if ($23) {
      $i$05 = 1;$tl$06 = $13;
      while(1) {
       $$sum = $i$05 ^ -1;
       $24 = (($3) + ($$sum<<4)|0);
       $25 = (((($3) + ($$sum<<4)|0)) + 8|0);
       $26 = HEAP32[$25>>2]|0;
       $27 = $26 & 15;
       if ((($27|0) == 3)) {
        _luaO_tostring($L,$24);
       } else if (!((($27|0) == 4))) {
        $i$0$lcssa = $i$05;$tl$0$lcssa = $tl$06;
        break L16;
       }
       $28 = HEAP32[$24>>2]|0;
       $29 = ((($28)) + 12|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = $tl$06 ^ -1;
       $32 = ($30>>>0)<($31>>>0);
       if (!($32)) {
        label = 16;
        break L1;
       }
       $33 = (($30) + ($tl$06))|0;
       $34 = (($i$05) + 1)|0;
       $35 = ($34|0)<($$0|0);
       if ($35) {
        $i$05 = $34;$tl$06 = $33;
       } else {
        $i$0$lcssa = $34;$tl$0$lcssa = $33;
        break;
       }
      }
     } else {
      $i$0$lcssa = 1;$tl$0$lcssa = $13;
     }
    } while(0);
    $36 = HEAP32[$1>>2]|0;
    $37 = ((($36)) + 108|0);
    $38 = (_luaZ_openspace($L,$37,$tl$0$lcssa)|0);
    $i$1 = $i$0$lcssa;$tl$1 = 0;
    while(1) {
     $39 = (0 - ($i$1))|0;
     $40 = (($3) + ($39<<4)|0);
     $41 = HEAP32[$40>>2]|0;
     $42 = ((($41)) + 12|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = (($38) + ($tl$1)|0);
     $45 = ((($41)) + 24|0);
     _memcpy(($44|0),($45|0),($43|0))|0;
     $46 = (($43) + ($tl$1))|0;
     $47 = (($i$1) + -1)|0;
     $48 = ($i$1|0)>(1);
     if ($48) {
      $i$1 = $47;$tl$1 = $46;
     } else {
      $$lcssa = $46;
      break;
     }
    }
    $49 = (0 - ($i$0$lcssa))|0;
    $50 = (($3) + ($49<<4)|0);
    $51 = (_luaS_newlstr($L,$38,$$lcssa)|0);
    HEAP32[$50>>2] = $51;
    $52 = ((($51)) + 4|0);
    $53 = HEAP8[$52>>0]|0;
    $54 = $53&255;
    $55 = $54 | 64;
    $56 = (((($3) + ($49<<4)|0)) + 8|0);
    HEAP32[$56>>2] = $55;
    $n$0 = $i$0$lcssa;
   } else {
    label = 5;
   }
  } while(0);
  if ((label|0) == 5) {
   label = 0;
   _luaT_trybinTM($L,$2,$7,$2,22);
   $n$0 = 2;
  }
  $$neg = (($$0) + 1)|0;
  $57 = (($$neg) - ($n$0))|0;
  $58 = HEAP32[$0>>2]|0;
  $59 = (1 - ($n$0))|0;
  $60 = (($58) + ($59<<4)|0);
  HEAP32[$0>>2] = $60;
  $61 = ($57|0)>(1);
  if ($61) {
   $$0 = $57;$3 = $60;
  } else {
   label = 22;
   break;
  }
 }
 if ((label|0) == 16) {
  _luaG_runerror($L,3672,$vararg_buffer);
  // unreachable;
 }
 else if ((label|0) == 22) {
  STACKTOP = sp;return;
 }
}
function _luaV_objlen($L,$ra,$rb) {
 $L = $L|0;
 $ra = $ra|0;
 $rb = $rb|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $tm$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($rb)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & 15;
 do {
  if ((($2|0) == 4)) {
   $25 = HEAP32[$rb>>2]|0;
   $26 = ((($25)) + 12|0);
   $27 = HEAP32[$26>>2]|0;
   $28 = $ra;
   $29 = $28;
   HEAP32[$29>>2] = $27;
   $30 = (($28) + 4)|0;
   $31 = $30;
   HEAP32[$31>>2] = 0;
   $32 = ((($ra)) + 8|0);
   HEAP32[$32>>2] = 19;
   return;
  } else if ((($2|0) == 5)) {
   $3 = HEAP32[$rb>>2]|0;
   $4 = ((($3)) + 24|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    $7 = ((($5)) + 6|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8 & 16;
    $10 = ($9<<24>>24)==(0);
    if ($10) {
     $11 = ((($L)) + 12|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = ((($12)) + 164|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = (_luaT_gettm($5,4,$14)|0);
     $16 = ($15|0)==(0|0);
     if (!($16)) {
      $tm$0 = $15;
      break;
     }
    }
   }
   $17 = (_luaH_getn($3)|0);
   $18 = ($17|0)<(0);
   $19 = $18 << 31 >> 31;
   $20 = $ra;
   $21 = $20;
   HEAP32[$21>>2] = $17;
   $22 = (($20) + 4)|0;
   $23 = $22;
   HEAP32[$23>>2] = $19;
   $24 = ((($ra)) + 8|0);
   HEAP32[$24>>2] = 19;
   return;
  } else {
   $33 = (_luaT_gettmbyobj($L,$rb,4)|0);
   $34 = ((($33)) + 8|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = ($35|0)==(0);
   if ($36) {
    _luaG_typeerror($L,$rb,3696);
    // unreachable;
   } else {
    $tm$0 = $33;
   }
  }
 } while(0);
 _luaT_callTM($L,$tm$0,$rb,$rb,$ra,1);
 return;
}
function _luaV_div($L,$0,$1,$2,$3) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $4 = (_i64Add(($2|0),($3|0),1,0)|0);
 $5 = tempRet0;
 $6 = ($5>>>0)<(0);
 $7 = ($4>>>0)<(2);
 $8 = ($5|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if (!($10)) {
  $16 = (___divdi3(($0|0),($1|0),($2|0),($3|0))|0);
  $17 = tempRet0;
  $2 ^ $0;
  $18 = $3 ^ $1;
  $19 = ($18|0)<(0);
  if ($19) {
   $20 = (___remdi3(($0|0),($1|0),($2|0),($3|0))|0);
   $21 = tempRet0;
   $22 = ($20|0)!=(0);
   $23 = ($21|0)!=(0);
   $24 = $22 | $23;
   $25 = $24 << 31 >> 31;
   $26 = ($25|0)<(0);
   $27 = $26 << 31 >> 31;
   $28 = (_i64Add(($25|0),($27|0),($16|0),($17|0))|0);
   $29 = tempRet0;
   tempRet0 = ($29);
   STACKTOP = sp;return ($28|0);
  } else {
   $30 = $17;$31 = $16;
   tempRet0 = ($30);
   STACKTOP = sp;return ($31|0);
  }
 }
 $11 = ($2|0)==(0);
 $12 = ($3|0)==(0);
 $13 = $11 & $12;
 if ($13) {
  _luaG_runerror($L,3712,$vararg_buffer);
  // unreachable;
 }
 $14 = (_i64Subtract(0,0,($0|0),($1|0))|0);
 $15 = tempRet0;
 $30 = $15;$31 = $14;
 tempRet0 = ($30);
 STACKTOP = sp;return ($31|0);
}
function _luaV_mod($L,$0,$1,$2,$3) {
 $L = $L|0;
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $4 = (_i64Add(($2|0),($3|0),1,0)|0);
 $5 = tempRet0;
 $6 = ($5>>>0)<(0);
 $7 = ($4>>>0)<(2);
 $8 = ($5|0)==(0);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if (!($10)) {
  $14 = (___remdi3(($0|0),($1|0),($2|0),($3|0))|0);
  $15 = tempRet0;
  $16 = ($14|0)!=(0);
  $17 = ($15|0)!=(0);
  $18 = $16 | $17;
  $2 ^ $0;
  $19 = $3 ^ $1;
  $20 = ($19|0)<(0);
  $or$cond = $20 & $18;
  $21 = $or$cond ? $2 : 0;
  $22 = $or$cond ? $3 : 0;
  $23 = (_i64Add(($21|0),($22|0),($14|0),($15|0))|0);
  $24 = tempRet0;
  $25 = $24;$26 = $23;
  tempRet0 = ($25);
  STACKTOP = sp;return ($26|0);
 }
 $11 = ($2|0)==(0);
 $12 = ($3|0)==(0);
 $13 = $11 & $12;
 if ($13) {
  _luaG_runerror($L,3744,$vararg_buffer);
  // unreachable;
 } else {
  $25 = 0;$26 = 0;
  tempRet0 = ($25);
  STACKTOP = sp;return ($26|0);
 }
 return (0)|0;
}
function _luaV_shiftl($0,$1,$2,$3) {
 $0 = $0|0;
 $1 = $1|0;
 $2 = $2|0;
 $3 = $3|0;
 var $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $4 = ($3|0)<(0);
 if ($4) {
  $5 = ($3|0)<(-1);
  $6 = ($2>>>0)<(4294967233);
  $7 = ($3|0)==(-1);
  $8 = $7 & $6;
  $9 = $5 | $8;
  $10 = (_i64Subtract(0,0,($2|0),($3|0))|0);
  $11 = tempRet0;
  $12 = (_bitshift64Lshr(($0|0),($1|0),($10|0))|0);
  $13 = tempRet0;
  $14 = $9 ? 0 : $12;
  $15 = $9 ? 0 : $13;
  tempRet0 = ($15);
  return ($14|0);
 } else {
  $16 = ($3|0)>(0);
  $17 = ($2>>>0)>(63);
  $18 = ($3|0)==(0);
  $19 = $18 & $17;
  $20 = $16 | $19;
  $21 = (_bitshift64Shl(($0|0),($1|0),($2|0))|0);
  $22 = tempRet0;
  $23 = $20 ? 0 : $21;
  $24 = $20 ? 0 : $22;
  tempRet0 = ($24);
  return ($23|0);
 }
 return (0)|0;
}
function _luaV_finishOp($L) {
 $L = $L|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($1)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ((($5)) + -4|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = $7 & 63;
 switch ($8|0) {
 case 41:  {
  $60 = ((($1)) + 4|0);
  $61 = HEAP32[$60>>2]|0;
  $62 = ((($L)) + 8|0);
  HEAP32[$62>>2] = $61;
  return;
  break;
 }
 case 29:  {
  $40 = ((($L)) + 8|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = ((($41)) + -16|0);
  $43 = $7 >>> 23;
  $44 = ((($41)) + -32|0);
  $45 = (($3) + ($43<<4)|0);
  $46 = $44;
  $47 = $45;
  $48 = (($46) - ($47))|0;
  $49 = ((($41)) + -48|0);
  ;HEAP32[$49>>2]=HEAP32[$42>>2]|0;HEAP32[$49+4>>2]=HEAP32[$42+4>>2]|0;HEAP32[$49+8>>2]=HEAP32[$42+8>>2]|0;HEAP32[$49+12>>2]=HEAP32[$42+12>>2]|0;
  $50 = ($48|0)>(16);
  if ($50) {
   $51 = $48 >> 4;
   HEAP32[$40>>2] = $44;
   _luaV_concat($L,$51);
  }
  $52 = HEAP32[$2>>2]|0;
  $53 = $7 >>> 6;
  $54 = $53 & 255;
  $55 = (($52) + ($54<<4)|0);
  $56 = HEAP32[$40>>2]|0;
  $57 = ((($56)) + -16|0);
  ;HEAP32[$55>>2]=HEAP32[$57>>2]|0;HEAP32[$55+4>>2]=HEAP32[$57+4>>2]|0;HEAP32[$55+8>>2]=HEAP32[$57+8>>2]|0;HEAP32[$55+12>>2]=HEAP32[$57+12>>2]|0;
  $58 = ((($1)) + 4|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$40>>2] = $59;
  return;
  break;
 }
 case 36:  {
  $63 = $7 & 8372224;
  $64 = ($63|0)==(0);
  if ($64) {
   return;
  }
  $65 = ((($1)) + 4|0);
  $66 = HEAP32[$65>>2]|0;
  $67 = ((($L)) + 8|0);
  HEAP32[$67>>2] = $66;
  return;
  break;
 }
 case 12: case 7: case 6: case 28: case 26: case 25: case 17: case 16: case 24: case 23: case 22: case 21: case 20: case 19: case 18: case 15: case 14: case 13:  {
  $9 = $7 >>> 6;
  $10 = $9 & 255;
  $11 = (($3) + ($10<<4)|0);
  $12 = ((($L)) + 8|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($13)) + -16|0);
  HEAP32[$12>>2] = $14;
  ;HEAP32[$11>>2]=HEAP32[$14>>2]|0;HEAP32[$11+4>>2]=HEAP32[$14+4>>2]|0;HEAP32[$11+8>>2]=HEAP32[$14+8>>2]|0;HEAP32[$11+12>>2]=HEAP32[$14+12>>2]|0;
  return;
  break;
 }
 case 31: case 32: case 33:  {
  $15 = ((($L)) + 8|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($16)) + -8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($18|0)==(0);
  if ($19) {
   $25 = 1;
  } else {
   $20 = ($18|0)==(1);
   if ($20) {
    $21 = ((($16)) + -16|0);
    $22 = HEAP32[$21>>2]|0;
    $23 = ($22|0)==(0);
    $25 = $23;
   } else {
    $25 = 0;
   }
  }
  $24 = $25&1;
  $26 = $24 ^ 1;
  $27 = ((($16)) + -16|0);
  HEAP32[$15>>2] = $27;
  $28 = ($8|0)==(33);
  if ($28) {
   $29 = $7 >>> 23;
   $30 = (($3) + ($29<<4)|0);
   $31 = (_luaT_gettmbyobj($L,$30,21)|0);
   $32 = ((($31)) + 8|0);
   $33 = HEAP32[$32>>2]|0;
   $34 = ($33|0)==(0);
   $$ = $34 ? $24 : $26;
   $res$0 = $$;
  } else {
   $res$0 = $26;
  }
  $35 = $7 >>> 6;
  $36 = $35 & 255;
  $37 = ($res$0|0)==($36|0);
  if ($37) {
   return;
  }
  $38 = HEAP32[$4>>2]|0;
  $39 = ((($38)) + 4|0);
  HEAP32[$4>>2] = $39;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _luaV_execute($L) {
 $L = $L|0;
 var $$02$i$i = 0, $$02$i$i$lcssa = 0, $$02$i$i$lcssa959 = 0, $$02$i$i102 = 0, $$02$i$i102$lcssa = 0, $$02$i$i102$lcssa943 = 0, $$02$i$i107 = 0, $$02$i$i107$lcssa = 0, $$02$i$i107$lcssa945 = 0, $$02$i$i146 = 0, $$02$i$i146$lcssa = 0, $$02$i$i146$lcssa941 = 0, $$02$i$i151 = 0, $$02$i$i151$lcssa = 0, $$02$i$i151$lcssa939 = 0, $$02$i$i66 = 0, $$02$i$i66$lcssa = 0, $$02$i$i66$lcssa961 = 0, $$02$i$i71 = 0, $$02$i$i71$lcssa = 0;
 var $$02$i$i71$lcssa955 = 0, $$02$i$i76 = 0, $$02$i$i76$lcssa = 0, $$02$i$i76$lcssa957 = 0, $$02$i$i81 = 0, $$02$i$i81$lcssa = 0, $$02$i$i81$lcssa951 = 0, $$02$i$i86 = 0, $$02$i$i86$lcssa = 0, $$02$i$i86$lcssa953 = 0, $$02$i$i91 = 0, $$02$i$i91$lcssa = 0, $$02$i$i91$lcssa947 = 0, $$02$i$i96 = 0, $$02$i$i96$lcssa = 0, $$02$i$i96$lcssa949 = 0, $$lcssa = 0, $$lcssa977 = 0, $$lcssa985 = 0, $$ph = 0.0;
 var $$ph$i = 0.0, $$ph173 = 0.0, $$ph178 = 0.0, $$ph181 = 0.0, $$ph186 = 0.0, $$ph189 = 0.0, $$ph192 = 0.0, $$ph195 = 0.0, $$ph230 = 0.0, $$ph233 = 0.0, $$ph238 = 0.0, $$ph241 = 0.0, $$ph244 = 0.0, $$ph247 = 0.0, $$ph263 = 0.0, $$ph266 = 0.0, $$ph269 = 0.0, $$phi$trans$insert = 0, $$phi$trans$insert723 = 0, $$phi$trans$insert733 = 0;
 var $$phi$trans$insert736 = 0, $$phi$trans$insert739 = 0, $$phi$trans$insert742 = 0, $$phi$trans$insert745 = 0, $$phi$trans$insert748 = 0, $$phi$trans$insert751 = 0, $$phi$trans$insert754 = 0, $$phi$trans$insert757 = 0, $$phi$trans$insert760 = 0, $$pre = 0, $$pre$phi765Z2D = 0, $$pre$phi767Z2D = 0, $$pre$phi769Z2D = 0, $$pre$phiZ2D = 0, $$pre724 = 0, $$pre725 = 0, $$pre726 = 0, $$pre727 = 0, $$pre728 = 0, $$pre729 = 0;
 var $$pre731 = 0, $$pre734 = 0, $$pre737 = 0, $$pre740 = 0, $$pre743 = 0, $$pre746 = 0, $$pre749 = 0, $$pre752 = 0, $$pre755 = 0, $$pre758 = 0, $$pre761 = 0, $$pre762$pre$phiZZ2D = 0, $$pre763 = 0, $$sum = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0;
 var $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum26 = 0, $$sum28 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum32 = 0, $$sum33 = 0, $$sum34 = 0, $$sum35 = 0, $$sum4 = 0;
 var $$sum5 = 0, $$sum6 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0.0;
 var $1029 = 0.0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0;
 var $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0;
 var $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0;
 var $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0;
 var $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0.0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0;
 var $1155 = 0, $1156 = 0.0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0, $1162 = 0, $1163 = 0, $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $117 = 0, $1170 = 0, $1171 = 0, $1172 = 0;
 var $1173 = 0, $1174 = 0, $1175 = 0.0, $1176 = 0.0, $1177 = 0.0, $1178 = 0, $1179 = 0, $118 = 0, $1180 = 0, $1181 = 0.0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $1188 = 0, $1189 = 0.0, $119 = 0, $1190 = 0;
 var $1191 = 0, $1192 = 0, $1193 = 0, $1194 = 0, $1195 = 0, $1196 = 0, $1197 = 0, $1198 = 0, $1199 = 0, $12 = 0, $120 = 0, $1200 = 0, $1201 = 0, $1202 = 0, $1203 = 0, $1204 = 0, $1205 = 0, $1206 = 0, $1207 = 0, $1208 = 0.0;
 var $1209 = 0.0, $121 = 0, $1210 = 0.0, $1211 = 0.0, $1212 = 0.0, $1213 = 0.0, $1214 = 0.0, $1215 = 0, $1216 = 0.0, $1217 = 0, $1218 = 0, $1219 = 0, $122 = 0, $1220 = 0, $1221 = 0, $1222 = 0, $1223 = 0, $1224 = 0, $1225 = 0, $1226 = 0;
 var $1227 = 0, $1228 = 0, $1229 = 0, $123 = 0, $1230 = 0, $1231 = 0, $1232 = 0, $1233 = 0, $1234 = 0, $1235 = 0, $1236 = 0, $1237 = 0, $1238 = 0, $1239 = 0, $124 = 0, $1240 = 0, $1241 = 0, $1242 = 0, $1243 = 0, $1244 = 0;
 var $1245 = 0, $1246 = 0, $1247 = 0, $1248 = 0, $1249 = 0, $125 = 0, $1250 = 0, $1251 = 0, $1252 = 0, $1253 = 0, $1254 = 0, $1255 = 0, $1256 = 0, $1257 = 0, $1258 = 0, $1259 = 0, $126 = 0, $1260 = 0, $1261 = 0, $1262 = 0;
 var $1263 = 0, $1264 = 0, $1265 = 0, $1266 = 0, $1267 = 0, $1268 = 0, $1269 = 0, $127 = 0, $1270 = 0, $1271 = 0, $1272 = 0, $1273 = 0, $1274 = 0, $1275 = 0, $1276 = 0, $1277 = 0, $1278 = 0, $1279 = 0, $128 = 0, $1280 = 0;
 var $1281 = 0, $1282 = 0, $1283 = 0, $1284 = 0.0, $1285 = 0, $1286 = 0, $1287 = 0, $1288 = 0, $1289 = 0, $129 = 0, $1290 = 0, $1291 = 0.0, $1292 = 0, $1293 = 0, $1294 = 0, $1295 = 0, $1296 = 0, $1297 = 0, $1298 = 0, $1299 = 0;
 var $13 = 0, $130 = 0, $1300 = 0, $1301 = 0, $1302 = 0, $1303 = 0, $1304 = 0, $1305 = 0, $1306 = 0, $1307 = 0, $1308 = 0, $1309 = 0, $131 = 0, $1310 = 0.0, $1311 = 0.0, $1312 = 0.0, $1313 = 0, $1314 = 0, $1315 = 0, $1316 = 0.0;
 var $1317 = 0, $1318 = 0, $1319 = 0, $132 = 0, $1320 = 0, $1321 = 0, $1322 = 0, $1323 = 0, $1324 = 0.0, $1325 = 0, $1326 = 0, $1327 = 0, $1328 = 0, $1329 = 0, $133 = 0, $1330 = 0, $1331 = 0, $1332 = 0, $1333 = 0, $1334 = 0;
 var $1335 = 0, $1336 = 0, $1337 = 0, $1338 = 0, $1339 = 0, $134 = 0, $1340 = 0, $1341 = 0, $1342 = 0, $1343 = 0.0, $1344 = 0.0, $1345 = 0.0, $1346 = 0.0, $1347 = 0.0, $1348 = 0.0, $1349 = 0.0, $135 = 0, $1350 = 0, $1351 = 0, $1352 = 0;
 var $1353 = 0, $1354 = 0, $1355 = 0, $1356 = 0, $1357 = 0, $1358 = 0, $1359 = 0, $136 = 0, $1360 = 0, $1361 = 0, $1362 = 0, $1363 = 0, $1364 = 0, $1365 = 0, $1366 = 0, $1367 = 0, $1368 = 0, $1369 = 0, $137 = 0, $1370 = 0.0;
 var $1371 = 0, $1372 = 0, $1373 = 0, $1374 = 0, $1375 = 0, $1376 = 0, $1377 = 0, $1378 = 0.0, $1379 = 0, $138 = 0, $1380 = 0, $1381 = 0, $1382 = 0, $1383 = 0, $1384 = 0, $1385 = 0, $1386 = 0, $1387 = 0, $1388 = 0, $1389 = 0;
 var $139 = 0, $1390 = 0, $1391 = 0, $1392 = 0, $1393 = 0, $1394 = 0, $1395 = 0, $1396 = 0, $1397 = 0.0, $1398 = 0.0, $1399 = 0.0, $14 = 0, $140 = 0, $1400 = 0, $1401 = 0, $1402 = 0, $1403 = 0.0, $1404 = 0, $1405 = 0, $1406 = 0;
 var $1407 = 0, $1408 = 0, $1409 = 0, $141 = 0, $1410 = 0, $1411 = 0.0, $1412 = 0, $1413 = 0, $1414 = 0, $1415 = 0, $1416 = 0, $1417 = 0, $1418 = 0, $1419 = 0, $142 = 0, $1420 = 0, $1421 = 0, $1422 = 0, $1423 = 0, $1424 = 0;
 var $1425 = 0, $1426 = 0, $1427 = 0, $1428 = 0, $1429 = 0, $143 = 0, $1430 = 0.0, $1431 = 0.0, $1432 = 0.0, $1433 = 0.0, $1434 = 0.0, $1435 = 0.0, $1436 = 0, $1437 = 0, $1438 = 0, $1439 = 0, $144 = 0, $1440 = 0, $1441 = 0, $1442 = 0;
 var $1443 = 0, $1444 = 0, $1445 = 0, $1446 = 0, $1447 = 0, $1448 = 0, $1449 = 0, $145 = 0, $1450 = 0, $1451 = 0, $1452 = 0, $1453 = 0, $1454 = 0, $1455 = 0.0, $1456 = 0, $1457 = 0, $1458 = 0, $1459 = 0, $146 = 0, $1460 = 0;
 var $1461 = 0, $1462 = 0, $1463 = 0, $1464 = 0, $1465 = 0, $1466 = 0, $1467 = 0, $1468 = 0, $1469 = 0, $147 = 0, $1470 = 0, $1471 = 0, $1472 = 0, $1473 = 0, $1474 = 0.0, $1475 = 0.0, $1476 = 0.0, $1477 = 0.0, $1478 = 0.0, $1479 = 0;
 var $148 = 0, $1480 = 0, $1481 = 0, $1482 = 0, $1483 = 0, $1484 = 0, $1485 = 0, $1486 = 0, $1487 = 0, $1488 = 0, $1489 = 0, $149 = 0, $1490 = 0, $1491 = 0, $1492 = 0, $1493 = 0, $1494 = 0.0, $1495 = 0.0, $1496 = 0, $1497 = 0;
 var $1498 = 0, $1499 = 0, $15 = 0, $150 = 0, $1500 = 0, $1501 = 0, $1502 = 0, $1503 = 0, $1504 = 0, $1505 = 0, $1506 = 0, $1507 = 0, $1508 = 0, $1509 = 0, $151 = 0, $1510 = 0, $1511 = 0, $1512 = 0, $1513 = 0, $1514 = 0;
 var $1515 = 0, $1516 = 0, $1517 = 0, $1518 = 0, $1519 = 0, $152 = 0, $1520 = 0, $1521 = 0, $1522 = 0, $1523 = 0, $1524 = 0, $1525 = 0, $1526 = 0, $1527 = 0, $1528 = 0, $1529 = 0, $153 = 0, $1530 = 0, $1531 = 0, $1532 = 0;
 var $1533 = 0, $1534 = 0, $1535 = 0, $1536 = 0, $1537 = 0, $1538 = 0, $1539 = 0, $154 = 0, $1540 = 0, $1541 = 0, $1542 = 0, $1543 = 0, $1544 = 0, $1545 = 0, $1546 = 0, $1547 = 0, $1548 = 0, $1549 = 0, $155 = 0, $1550 = 0;
 var $1551 = 0, $1552 = 0, $1553 = 0, $1554 = 0, $1555 = 0, $1556 = 0, $1557 = 0, $1558 = 0, $1559 = 0, $156 = 0, $1560 = 0, $1561 = 0, $1562 = 0, $1563 = 0, $1564 = 0, $1565 = 0, $1566 = 0, $1567 = 0, $1568 = 0, $1569 = 0;
 var $157 = 0, $1570 = 0, $1571 = 0, $1572 = 0, $1573 = 0, $1574 = 0, $1575 = 0, $1576 = 0, $1577 = 0, $1578 = 0, $1579 = 0, $158 = 0, $1580 = 0, $1581 = 0, $1582 = 0, $1583 = 0, $1584 = 0, $1585 = 0, $1586 = 0, $1587 = 0;
 var $1588 = 0, $1589 = 0, $159 = 0, $1590 = 0, $1591 = 0, $1592 = 0, $1593 = 0, $1594 = 0, $1595 = 0, $1596 = 0, $1597 = 0, $1598 = 0, $1599 = 0, $16 = 0, $160 = 0, $1600 = 0, $1601 = 0, $1602 = 0, $1603 = 0, $1604 = 0;
 var $1605 = 0, $1606 = 0, $1607 = 0, $1608 = 0, $1609 = 0, $161 = 0, $1610 = 0, $1611 = 0, $1612 = 0, $1613 = 0, $1614 = 0, $1615 = 0, $1616 = 0, $1617 = 0, $1618 = 0, $1619 = 0, $162 = 0, $1620 = 0, $1621 = 0, $1622 = 0;
 var $1623 = 0, $1624 = 0, $1625 = 0, $1626 = 0, $1627 = 0, $1628 = 0, $1629 = 0, $163 = 0, $1630 = 0, $1631 = 0, $1632 = 0, $1633 = 0, $1634 = 0, $1635 = 0, $1636 = 0, $1637 = 0, $1638 = 0, $1639 = 0, $164 = 0, $1640 = 0;
 var $1641 = 0, $1642 = 0, $1643 = 0, $1644 = 0, $1645 = 0, $1646 = 0, $1647 = 0, $1648 = 0, $1649 = 0, $165 = 0, $1650 = 0, $1651 = 0, $1652 = 0, $1653 = 0, $1654 = 0, $1655 = 0, $1656 = 0, $1657 = 0, $1658 = 0, $1659 = 0;
 var $166 = 0, $1660 = 0, $1661 = 0, $1662 = 0, $1663 = 0, $1664 = 0, $1665 = 0, $1666 = 0, $1667 = 0, $1668 = 0, $1669 = 0, $167 = 0, $1670 = 0, $1671 = 0, $1672 = 0, $1673 = 0, $1674 = 0, $1675 = 0, $1676 = 0, $1677 = 0;
 var $1678 = 0, $1679 = 0, $168 = 0, $1680 = 0, $1681 = 0, $1682 = 0, $1683 = 0, $1684 = 0, $1685 = 0, $1686 = 0, $1687 = 0, $1688 = 0, $1689 = 0, $169 = 0, $1690 = 0, $1691 = 0, $1692 = 0, $1693 = 0, $1694 = 0, $1695 = 0;
 var $1696 = 0, $1697 = 0, $1698 = 0, $1699 = 0, $17 = 0, $170 = 0, $1700 = 0, $1701 = 0, $1702 = 0, $1703 = 0, $1704 = 0, $1705 = 0, $1706 = 0, $1707 = 0, $1708 = 0, $1709 = 0, $171 = 0, $1710 = 0, $1711 = 0, $1712 = 0;
 var $1713 = 0, $1714 = 0, $1715 = 0, $1716 = 0, $1717 = 0, $1718 = 0, $1719 = 0, $172 = 0, $1720 = 0, $1721 = 0, $1722 = 0, $1723 = 0, $1724 = 0, $1725 = 0, $1726 = 0, $1727 = 0, $1728 = 0, $1729 = 0, $173 = 0, $1730 = 0;
 var $1731 = 0, $1732 = 0, $1733 = 0, $1734 = 0, $1735 = 0, $1736 = 0, $1737 = 0, $1738 = 0, $1739 = 0, $174 = 0, $1740 = 0, $1741 = 0, $1742 = 0, $1743 = 0, $1744 = 0, $1745 = 0, $1746 = 0, $1747 = 0, $1748 = 0, $1749 = 0;
 var $175 = 0, $1750 = 0, $1751 = 0, $1752 = 0, $1753 = 0, $1754 = 0, $1755 = 0, $1756 = 0, $1757 = 0, $1758 = 0, $1759 = 0, $176 = 0, $1760 = 0, $1761 = 0, $1762 = 0, $1763 = 0, $1764 = 0, $1765 = 0, $1766 = 0, $1767 = 0;
 var $1768 = 0, $1769 = 0, $177 = 0, $1770 = 0, $1771 = 0, $1772 = 0, $1773 = 0, $1774 = 0, $1775 = 0, $1776 = 0, $1777 = 0, $1778 = 0, $1779 = 0, $178 = 0, $1780 = 0, $1781 = 0, $1782 = 0, $1783 = 0, $1784 = 0, $1785 = 0;
 var $1786 = 0, $1787 = 0, $1788 = 0, $1789 = 0, $179 = 0, $1790 = 0, $1791 = 0, $1792 = 0, $1793 = 0, $1794 = 0, $1795 = 0, $1796 = 0, $1797 = 0, $1798 = 0, $1799 = 0, $18 = 0, $180 = 0, $1800 = 0, $1801 = 0, $1802 = 0;
 var $1803 = 0, $1804 = 0, $1805 = 0, $1806 = 0, $1807 = 0, $1808 = 0, $1809 = 0, $181 = 0, $1810 = 0, $1811 = 0, $1812 = 0, $1813 = 0, $1814 = 0, $1815 = 0, $1816 = 0, $1817 = 0, $1818 = 0, $1819 = 0, $182 = 0, $1820 = 0;
 var $1821 = 0, $1822 = 0, $1823 = 0, $1824 = 0, $1825 = 0, $1826 = 0, $1827 = 0, $1828 = 0, $1829 = 0, $183 = 0, $1830 = 0, $1831 = 0, $1832 = 0, $1833 = 0, $1834 = 0, $1835 = 0, $1836 = 0, $1837 = 0, $1838 = 0, $1839 = 0;
 var $184 = 0, $1840 = 0, $1841 = 0, $1842 = 0, $1843 = 0, $1844 = 0, $1845 = 0, $1846 = 0, $1847 = 0.0, $1848 = 0.0, $1849 = 0.0, $185 = 0, $1850 = 0, $1851 = 0.0, $1852 = 0, $1853 = 0, $1854 = 0, $1855 = 0, $1856 = 0, $1857 = 0;
 var $1858 = 0, $1859 = 0, $186 = 0, $1860 = 0, $1861 = 0, $1862 = 0, $1863 = 0, $1864 = 0, $1865 = 0, $1866 = 0, $1867 = 0, $1868 = 0, $1869 = 0, $187 = 0, $1870 = 0, $1871 = 0, $1872 = 0, $1873 = 0, $1874 = 0, $1875 = 0;
 var $1876 = 0, $1877 = 0, $1878 = 0.0, $1879 = 0.0, $188 = 0, $1880 = 0, $1881 = 0.0, $1882 = 0, $1883 = 0, $1884 = 0, $1885 = 0, $1886 = 0, $1887 = 0, $1888 = 0, $1889 = 0, $189 = 0, $1890 = 0, $1891 = 0, $1892 = 0, $1893 = 0;
 var $1894 = 0, $1895 = 0, $1896 = 0, $1897 = 0, $1898 = 0, $1899 = 0, $19 = 0, $190 = 0, $1900 = 0, $1901 = 0, $1902 = 0, $1903 = 0, $1904 = 0, $1905 = 0, $1906 = 0.0, $1907 = 0, $1908 = 0, $1909 = 0, $191 = 0, $1910 = 0;
 var $1911 = 0, $1912 = 0, $1913 = 0, $1914 = 0.0, $1915 = 0, $1916 = 0, $1917 = 0, $1918 = 0, $1919 = 0, $192 = 0, $1920 = 0, $1921 = 0, $1922 = 0, $1923 = 0, $1924 = 0, $1925 = 0, $1926 = 0, $1927 = 0, $1928 = 0, $1929 = 0;
 var $193 = 0, $1930 = 0, $1931 = 0, $1932 = 0, $1933 = 0.0, $1934 = 0.0, $1935 = 0.0, $1936 = 0, $1937 = 0.0, $1938 = 0, $1939 = 0, $194 = 0, $1940 = 0, $1941 = 0, $1942 = 0, $1943 = 0, $1944 = 0, $1945 = 0, $1946 = 0, $1947 = 0;
 var $1948 = 0, $1949 = 0, $195 = 0, $1950 = 0, $1951 = 0, $1952 = 0, $1953 = 0, $1954 = 0, $1955 = 0, $1956 = 0, $1957 = 0, $1958 = 0, $1959 = 0, $196 = 0, $1960 = 0, $1961 = 0, $1962 = 0, $1963 = 0, $1964 = 0, $1965 = 0;
 var $1966 = 0, $1967 = 0, $1968 = 0, $1969 = 0, $197 = 0, $1970 = 0, $1971 = 0, $1972 = 0.0, $1973 = 0, $1974 = 0, $1975 = 0, $1976 = 0, $1977 = 0, $1978 = 0, $1979 = 0, $198 = 0, $1980 = 0.0, $1981 = 0, $1982 = 0, $1983 = 0;
 var $1984 = 0, $1985 = 0, $1986 = 0, $1987 = 0, $1988 = 0, $1989 = 0, $199 = 0, $1990 = 0, $1991 = 0, $1992 = 0, $1993 = 0, $1994 = 0, $1995 = 0, $1996 = 0, $1997 = 0, $1998 = 0, $1999 = 0.0, $2 = 0, $20 = 0, $200 = 0;
 var $2000 = 0.0, $2001 = 0.0, $2002 = 0.0, $2003 = 0, $2004 = 0, $2005 = 0, $2006 = 0.0, $2007 = 0, $2008 = 0, $2009 = 0, $201 = 0, $2010 = 0, $2011 = 0, $2012 = 0, $2013 = 0, $2014 = 0.0, $2015 = 0, $2016 = 0, $2017 = 0, $2018 = 0;
 var $2019 = 0, $202 = 0, $2020 = 0, $2021 = 0, $2022 = 0, $2023 = 0, $2024 = 0, $2025 = 0, $2026 = 0, $2027 = 0, $2028 = 0, $2029 = 0, $203 = 0, $2030 = 0, $2031 = 0, $2032 = 0, $2033 = 0.0, $2034 = 0.0, $2035 = 0.0, $2036 = 0.0;
 var $2037 = 0, $2038 = 0, $2039 = 0.0, $204 = 0, $2040 = 0, $2041 = 0, $2042 = 0, $2043 = 0, $2044 = 0, $2045 = 0, $2046 = 0, $2047 = 0.0, $2048 = 0, $2049 = 0, $205 = 0, $2050 = 0, $2051 = 0, $2052 = 0, $2053 = 0, $2054 = 0;
 var $2055 = 0, $2056 = 0, $2057 = 0, $2058 = 0, $2059 = 0, $206 = 0, $2060 = 0, $2061 = 0, $2062 = 0, $2063 = 0, $2064 = 0, $2065 = 0, $2066 = 0.0, $2067 = 0.0, $2068 = 0.0, $2069 = 0.0, $207 = 0, $2070 = 0.0, $2071 = 0, $2072 = 0;
 var $2073 = 0, $2074 = 0, $2075 = 0, $2076 = 0, $2077 = 0, $2078 = 0, $2079 = 0, $208 = 0, $2080 = 0, $2081 = 0, $2082 = 0, $2083 = 0, $2084 = 0, $2085 = 0, $2086 = 0, $2087 = 0, $2088 = 0, $2089 = 0, $209 = 0, $2090 = 0;
 var $2091 = 0, $2092 = 0, $2093 = 0, $2094 = 0, $2095 = 0, $2096 = 0, $2097 = 0, $2098 = 0, $2099 = 0, $21 = 0, $210 = 0, $2100 = 0, $2101 = 0, $2102 = 0, $2103 = 0, $2104 = 0, $2105 = 0, $2106 = 0, $2107 = 0, $2108 = 0;
 var $2109 = 0, $211 = 0, $2110 = 0, $2111 = 0, $2112 = 0, $2113 = 0, $2114 = 0, $2115 = 0, $2116 = 0, $2117 = 0, $2118 = 0, $2119 = 0, $212 = 0, $2120 = 0, $2121 = 0, $2122 = 0, $2123 = 0, $2124 = 0, $2125 = 0, $2126 = 0;
 var $2127 = 0, $2128 = 0, $2129 = 0, $213 = 0.0, $2130 = 0, $2131 = 0, $2132 = 0, $2133 = 0, $2134 = 0, $2135 = 0, $2136 = 0, $2137 = 0, $2138 = 0, $2139 = 0, $214 = 0, $2140 = 0, $2141 = 0, $2142 = 0, $2143 = 0, $2144 = 0;
 var $2145 = 0, $2146 = 0, $2147 = 0, $2148 = 0, $2149 = 0, $215 = 0, $2150 = 0, $2151 = 0, $2152 = 0, $2153 = 0, $2154 = 0, $2155 = 0, $2156 = 0, $2157 = 0, $2158 = 0, $2159 = 0, $216 = 0, $2160 = 0, $2161 = 0, $2162 = 0;
 var $2163 = 0, $2164 = 0, $2165 = 0, $2166 = 0, $2167 = 0, $2168 = 0, $2169 = 0, $217 = 0, $2170 = 0, $2171 = 0, $2172 = 0, $2173 = 0, $2174 = 0, $2175 = 0, $2176 = 0, $2177 = 0, $2178 = 0, $2179 = 0, $218 = 0, $2180 = 0;
 var $2181 = 0, $2182 = 0, $2183 = 0, $2184 = 0, $2185 = 0, $2186 = 0, $2187 = 0, $2188 = 0, $2189 = 0, $219 = 0, $2190 = 0, $2191 = 0, $2192 = 0, $2193 = 0, $2194 = 0, $2195 = 0, $2196 = 0, $2197 = 0, $2198 = 0, $2199 = 0;
 var $22 = 0, $220 = 0.0, $2200 = 0, $2201 = 0, $2202 = 0, $2203 = 0, $2204 = 0, $2205 = 0, $2206 = 0, $2207 = 0, $2208 = 0, $2209 = 0, $221 = 0, $2210 = 0, $2211 = 0, $2212 = 0, $2213 = 0, $2214 = 0, $2215 = 0, $2216 = 0;
 var $2217 = 0, $2218 = 0, $2219 = 0, $222 = 0, $2220 = 0, $2221 = 0, $2222 = 0, $2223 = 0, $2224 = 0, $2225 = 0, $2226 = 0, $2227 = 0, $2228 = 0, $2229 = 0, $223 = 0, $2230 = 0, $2231 = 0, $2232 = 0, $2233 = 0, $2234 = 0;
 var $2235 = 0, $2236 = 0, $2237 = 0, $2238 = 0, $2239 = 0, $224 = 0, $2240 = 0, $2241 = 0, $2242 = 0, $2243 = 0, $2244 = 0, $2245 = 0, $2246 = 0, $2247 = 0, $2248 = 0, $2249 = 0, $225 = 0, $2250 = 0, $2251 = 0, $2252 = 0;
 var $2253 = 0, $2254 = 0, $2255 = 0, $2256 = 0, $2257 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0.0;
 var $24 = 0, $240 = 0.0, $241 = 0.0, $242 = 0, $243 = 0, $244 = 0, $245 = 0.0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0.0, $273 = 0.0, $274 = 0.0, $275 = 0.0;
 var $276 = 0.0, $277 = 0.0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0.0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0.0, $346 = 0.0, $347 = 0.0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0.0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0.0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0.0, $379 = 0.0, $38 = 0, $380 = 0.0, $381 = 0.0, $382 = 0.0, $383 = 0.0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0.0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0.0, $452 = 0.0, $453 = 0.0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0.0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0.0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0;
 var $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0.0, $485 = 0.0, $486 = 0.0, $487 = 0.0, $488 = 0.0, $489 = 0.0, $49 = 0, $490 = 0, $491 = 0;
 var $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0.0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0.0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0.0, $538 = 0.0, $539 = 0.0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0.0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0.0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0.0, $571 = 0.0, $572 = 0.0, $573 = 0.0, $574 = 0.0, $575 = 0.0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0.0, $603 = 0.0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0.0;
 var $636 = 0.0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0;
 var $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0.0, $696 = 0.0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0.0, $729 = 0.0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0;
 var $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0;
 var $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0.0, $789 = 0.0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0;
 var $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0;
 var $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0.0, $822 = 0.0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0;
 var $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0;
 var $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0;
 var $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0.0, $882 = 0.0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0;
 var $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0;
 var $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0.0, $915 = 0.0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0;
 var $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0;
 var $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0;
 var $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0;
 var $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0.0, $996 = 0.0;
 var $997 = 0, $998 = 0, $999 = 0, $aux$0521 = 0, $b$0 = 0, $b131$0 = 0, $base$0 = 0, $base$1 = 0, $base$1$lcssa = 0, $base$2 = 0, $c128$0 = 0, $ci$0 = 0, $exitcond = 0, $exitcond$i = 0, $f$0$i$i = 0.0, $i$0 = 0, $i$01$i = 0, $i$01$i168 = 0, $j$0517 = 0, $last$0519 = 0;
 var $m$0 = 0.0, $n$0 = 0, $n$1518 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i$i103 = 0, $or$cond$i$i108 = 0, $or$cond$i$i147 = 0, $or$cond$i$i152 = 0, $or$cond$i$i67 = 0, $or$cond$i$i72 = 0, $or$cond$i$i77 = 0, $or$cond$i$i82 = 0, $or$cond$i$i87 = 0, $or$cond$i$i92 = 0, $or$cond$i$i97 = 0, $or$cond828 = 0, $ra$0 = 0, $ra$1 = 0;
 var $storemerge = 0, $storemerge25 = 0, $storemerge27 = 0, $storemerge29 = 0, $v$i = 0, $v$i$i = 0, $v$i$i101 = 0, $v$i$i106 = 0, $v$i$i145 = 0, $v$i$i150 = 0, $v$i$i65 = 0, $v$i$i70 = 0, $v$i$i75 = 0, $v$i$i80 = 0, $v$i$i85 = 0, $v$i$i90 = 0, $v$i$i95 = 0, $v$i1$i = 0, $v$i115 = 0, $v$i119 = 0;
 var $v$i125 = 0, $v$i129 = 0, $v$i133 = 0, $v$i137 = 0, $v$i141 = 0, $v$i154 = 0, $v$i158 = 0, $v$i162 = 0, $v$i37 = 0, $v$i41 = 0, $v$i45 = 0, $v$i49 = 0, $v$i53 = 0, $v$i57 = 0, $v$i61 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 544|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 528|0;
 $vararg_buffer5 = sp + 520|0;
 $vararg_buffer3 = sp + 512|0;
 $vararg_buffer1 = sp + 504|0;
 $vararg_buffer = sp + 496|0;
 $v$i162 = sp + 480|0;
 $v$i158 = sp + 464|0;
 $v$i154 = sp + 448|0;
 $v$i1$i = sp + 432|0;
 $v$i$i150 = sp + 416|0;
 $v$i$i145 = sp + 400|0;
 $v$i141 = sp + 384|0;
 $v$i137 = sp + 368|0;
 $v$i133 = sp + 352|0;
 $v$i129 = sp + 336|0;
 $v$i125 = sp + 320|0;
 $v$i119 = sp + 304|0;
 $v$i115 = sp + 288|0;
 $v$i$i106 = sp + 272|0;
 $v$i$i101 = sp + 256|0;
 $v$i$i95 = sp + 240|0;
 $v$i$i90 = sp + 224|0;
 $v$i$i85 = sp + 208|0;
 $v$i$i80 = sp + 192|0;
 $v$i$i75 = sp + 176|0;
 $v$i$i70 = sp + 160|0;
 $v$i$i65 = sp + 144|0;
 $v$i$i = sp + 128|0;
 $v$i61 = sp + 112|0;
 $v$i57 = sp + 96|0;
 $v$i53 = sp + 80|0;
 $v$i49 = sp + 64|0;
 $v$i45 = sp + 48|0;
 $v$i41 = sp + 32|0;
 $v$i37 = sp + 16|0;
 $v$i = sp;
 $0 = ((($L)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($L)) + 108|0);
 $3 = ((($L)) + 12|0);
 $4 = ((($L)) + 8|0);
 $5 = ((($v$i37)) + 8|0);
 $6 = ((($v$i)) + 8|0);
 $7 = ((($v$i45)) + 8|0);
 $8 = ((($v$i41)) + 8|0);
 $9 = ((($v$i53)) + 8|0);
 $10 = ((($v$i49)) + 8|0);
 $11 = ((($v$i61)) + 8|0);
 $12 = ((($v$i57)) + 8|0);
 $13 = ((($v$i119)) + 8|0);
 $14 = ((($v$i115)) + 8|0);
 $15 = ((($v$i129)) + 8|0);
 $16 = ((($v$i125)) + 8|0);
 $17 = ((($v$i137)) + 8|0);
 $18 = ((($v$i133)) + 8|0);
 $19 = ((($v$i141)) + 8|0);
 $20 = ((($v$i1$i)) + 8|0);
 $21 = ((($v$i162)) + 8|0);
 $22 = ((($v$i158)) + 8|0);
 $23 = ((($v$i154)) + 8|0);
 $24 = ((($L)) + 24|0);
 $25 = ((($L)) + 100|0);
 $$phi$trans$insert760 = ((($v$i$i65)) + 8|0);
 $$phi$trans$insert757 = ((($v$i$i)) + 8|0);
 $$phi$trans$insert754 = ((($v$i$i75)) + 8|0);
 $$phi$trans$insert751 = ((($v$i$i70)) + 8|0);
 $$phi$trans$insert748 = ((($v$i$i85)) + 8|0);
 $$phi$trans$insert745 = ((($v$i$i80)) + 8|0);
 $$phi$trans$insert742 = ((($v$i$i95)) + 8|0);
 $$phi$trans$insert739 = ((($v$i$i90)) + 8|0);
 $$phi$trans$insert736 = ((($v$i$i106)) + 8|0);
 $$phi$trans$insert733 = ((($v$i$i101)) + 8|0);
 $ci$0 = $1;
 L1: while(1) {
  $26 = HEAP32[$ci$0>>2]|0;
  $27 = HEAP32[$26>>2]|0;
  $28 = ((($27)) + 12|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ((($29)) + 44|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = ((($ci$0)) + 16|0);
  $33 = HEAP32[$32>>2]|0;
  $34 = ((($ci$0)) + 20|0);
  $35 = ((($ci$0)) + 4|0);
  $base$0 = $33;
  L3: while(1) {
   $36 = HEAP32[$34>>2]|0;
   $37 = ((($36)) + 4|0);
   HEAP32[$34>>2] = $37;
   $38 = HEAP32[$36>>2]|0;
   $39 = HEAP8[$2>>0]|0;
   $40 = $39 & 12;
   $41 = ($40<<24>>24)==(0);
   if ($41) {
    $base$1 = $base$0;
   } else {
    $42 = HEAP32[$25>>2]|0;
    $43 = (($42) + -1)|0;
    HEAP32[$25>>2] = $43;
    $44 = ($43|0)!=(0);
    $45 = $39 & 4;
    $46 = ($45<<24>>24)==(0);
    $or$cond828 = $44 & $46;
    if ($or$cond828) {
     $base$1 = $base$0;
    } else {
     _luaG_traceexec($L);
     $47 = HEAP32[$32>>2]|0;
     $base$1 = $47;
    }
   }
   $48 = $38 >>> 6;
   $49 = $48 & 255;
   $50 = (($base$1) + ($49<<4)|0);
   $51 = $38 & 63;
   do {
    switch ($51|0) {
    case 2:  {
     $56 = HEAP32[$34>>2]|0;
     $57 = ((($56)) + 4|0);
     HEAP32[$34>>2] = $57;
     $58 = HEAP32[$56>>2]|0;
     $59 = $58 >>> 6;
     $60 = (($31) + ($59<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$60>>2]|0;HEAP32[$50+4>>2]=HEAP32[$60+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$60+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$60+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 10:  {
     $130 = $38 >>> 23;
     $131 = $130 & 256;
     $132 = ($131|0)==(0);
     $133 = $130 & 255;
     $134 = (($31) + ($133<<4)|0);
     $135 = (($base$1) + ($130<<4)|0);
     $136 = $132 ? $135 : $134;
     $137 = $38 >>> 14;
     $138 = $137 & 256;
     $139 = ($138|0)==(0);
     $140 = $137 & 255;
     $141 = (($31) + ($140<<4)|0);
     $142 = $137 & 511;
     $143 = (($base$1) + ($142<<4)|0);
     $144 = $139 ? $143 : $141;
     _luaV_settable($L,$50,$136,$144);
     $145 = HEAP32[$32>>2]|0;
     $base$0 = $145;
     continue L3;
     break;
    }
    case 13:  {
     $174 = $38 >>> 23;
     $175 = $174 & 256;
     $176 = ($175|0)==(0);
     $177 = $174 & 255;
     $178 = (($31) + ($177<<4)|0);
     $179 = (($base$1) + ($174<<4)|0);
     $180 = $176 ? $179 : $178;
     $181 = $38 >>> 14;
     $182 = $181 & 256;
     $183 = ($182|0)==(0);
     $184 = $181 & 255;
     $185 = (($31) + ($184<<4)|0);
     $186 = $181 & 511;
     $187 = (($base$1) + ($186<<4)|0);
     $188 = $183 ? $187 : $185;
     $189 = ((($180)) + 8|0);
     $190 = HEAP32[$189>>2]|0;
     do {
      if ((($190|0) == 19)) {
       $191 = ((($188)) + 8|0);
       $192 = HEAP32[$191>>2]|0;
       $193 = ($192|0)==(19);
       if ($193) {
        $194 = $180;
        $195 = $194;
        $196 = HEAP32[$195>>2]|0;
        $197 = (($194) + 4)|0;
        $198 = $197;
        $199 = HEAP32[$198>>2]|0;
        $200 = $188;
        $201 = $200;
        $202 = HEAP32[$201>>2]|0;
        $203 = (($200) + 4)|0;
        $204 = $203;
        $205 = HEAP32[$204>>2]|0;
        $206 = (_i64Add(($202|0),($205|0),($196|0),($199|0))|0);
        $207 = tempRet0;
        $208 = $50;
        $209 = $208;
        HEAP32[$209>>2] = $206;
        $210 = (($208) + 4)|0;
        $211 = $210;
        HEAP32[$211>>2] = $207;
        $212 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$212>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $214 = $180;
        $215 = $214;
        $216 = HEAP32[$215>>2]|0;
        $217 = (($214) + 4)|0;
        $218 = $217;
        $219 = HEAP32[$218>>2]|0;
        $220 = (+($216>>>0)) + (4294967296.0*(+($219|0)));
        $$ph = $220;
        label = 36;
        break;
       }
      } else if ((($190|0) == 3)) {
       $213 = +HEAPF64[$180>>3];
       $276 = $213;
       label = 37;
      } else {
       $221 = $190 & 15;
       $222 = ($221|0)==(4);
       if ($222) {
        $223 = HEAP32[$180>>2]|0;
        $224 = ((($223)) + 24|0);
        $225 = (_luaO_str2num($224,$v$i)|0);
        $226 = HEAP32[$180>>2]|0;
        $227 = ((($226)) + 12|0);
        $228 = HEAP32[$227>>2]|0;
        $229 = (($228) + 1)|0;
        $230 = ($225|0)==($229|0);
        if ($230) {
         $231 = HEAP32[$6>>2]|0;
         $232 = ($231|0)==(19);
         $233 = $v$i;
         $234 = $233;
         $235 = HEAP32[$234>>2]|0;
         $236 = (($233) + 4)|0;
         $237 = $236;
         $238 = HEAP32[$237>>2]|0;
         $239 = (+($235>>>0)) + (4294967296.0*(+($238|0)));
         HEAP32[tempDoublePtr>>2] = $235;HEAP32[tempDoublePtr+4>>2] = $238;$240 = +HEAPF64[tempDoublePtr>>3];
         $241 = $232 ? $239 : $240;
         $$ph = $241;
         label = 36;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 36) {
      label = 0;
      $276 = $$ph;
      label = 37;
     }
     L26: do {
      if ((label|0) == 37) {
       label = 0;
       $242 = ((($188)) + 8|0);
       $243 = HEAP32[$242>>2]|0;
       $244 = ($243|0)==(3);
       if ($244) {
        $245 = +HEAPF64[$188>>3];
        $277 = $245;
       } else {
        $246 = ($243|0)==(19);
        do {
         if ($246) {
          $247 = $188;
          $248 = $247;
          $249 = HEAP32[$248>>2]|0;
          $250 = (($247) + 4)|0;
          $251 = $250;
          $252 = HEAP32[$251>>2]|0;
          $253 = (+($249>>>0)) + (4294967296.0*(+($252|0)));
          $$ph173 = $253;
         } else {
          $254 = $243 & 15;
          $255 = ($254|0)==(4);
          if ($255) {
           $256 = HEAP32[$188>>2]|0;
           $257 = ((($256)) + 24|0);
           $258 = (_luaO_str2num($257,$v$i37)|0);
           $259 = HEAP32[$188>>2]|0;
           $260 = ((($259)) + 12|0);
           $261 = HEAP32[$260>>2]|0;
           $262 = (($261) + 1)|0;
           $263 = ($258|0)==($262|0);
           if ($263) {
            $264 = HEAP32[$5>>2]|0;
            $265 = ($264|0)==(19);
            $266 = $v$i37;
            $267 = $266;
            $268 = HEAP32[$267>>2]|0;
            $269 = (($266) + 4)|0;
            $270 = $269;
            $271 = HEAP32[$270>>2]|0;
            $272 = (+($268>>>0)) + (4294967296.0*(+($271|0)));
            HEAP32[tempDoublePtr>>2] = $268;HEAP32[tempDoublePtr+4>>2] = $271;$273 = +HEAPF64[tempDoublePtr>>3];
            $274 = $265 ? $272 : $273;
            $$ph173 = $274;
            break;
           }
          }
          break L26;
         }
        } while(0);
        $277 = $$ph173;
       }
       $275 = $276 + $277;
       HEAPF64[$50>>3] = $275;
       $278 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$278>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$180,$188,$50,6);
     $279 = HEAP32[$32>>2]|0;
     $base$0 = $279;
     continue L3;
     break;
    }
    case 1:  {
     $54 = $38 >>> 14;
     $55 = (($31) + ($54<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$55>>2]|0;HEAP32[$50+4>>2]=HEAP32[$55+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$55+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$55+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 8:  {
     $100 = (((($27)) + 16|0) + ($49<<2)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = HEAP32[$101>>2]|0;
     $103 = $38 >>> 23;
     $104 = $103 & 256;
     $105 = ($104|0)==(0);
     $106 = $103 & 255;
     $107 = (($31) + ($106<<4)|0);
     $108 = (($base$1) + ($103<<4)|0);
     $109 = $105 ? $108 : $107;
     $110 = $38 >>> 14;
     $111 = $110 & 256;
     $112 = ($111|0)==(0);
     $113 = $110 & 255;
     $114 = (($31) + ($113<<4)|0);
     $115 = $110 & 511;
     $116 = (($base$1) + ($115<<4)|0);
     $117 = $112 ? $116 : $114;
     _luaV_settable($L,$102,$109,$117);
     $118 = HEAP32[$32>>2]|0;
     $base$0 = $118;
     continue L3;
     break;
    }
    case 11:  {
     $146 = $38 >>> 23;
     $147 = $38 >>> 14;
     $148 = $147 & 511;
     $149 = (_luaH_new($L)|0);
     HEAP32[$50>>2] = $149;
     $150 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$150>>2] = 69;
     $151 = $148 | $146;
     $152 = ($151|0)==(0);
     if (!($152)) {
      $153 = (_luaO_fb2int($146)|0);
      $154 = (_luaO_fb2int($148)|0);
      _luaH_resize($L,$149,$153,$154);
     }
     $155 = HEAP32[$3>>2]|0;
     $156 = ((($155)) + 12|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)>(0);
     if ($158) {
      $$sum35 = (($49) + 1)|0;
      $159 = (($base$1) + ($$sum35<<4)|0);
      HEAP32[$4>>2] = $159;
      _luaC_step($L);
      $160 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $160;
     }
     $161 = HEAP32[$32>>2]|0;
     $base$0 = $161;
     continue L3;
     break;
    }
    case 15:  {
     $386 = $38 >>> 23;
     $387 = $386 & 256;
     $388 = ($387|0)==(0);
     $389 = $386 & 255;
     $390 = (($31) + ($389<<4)|0);
     $391 = (($base$1) + ($386<<4)|0);
     $392 = $388 ? $391 : $390;
     $393 = $38 >>> 14;
     $394 = $393 & 256;
     $395 = ($394|0)==(0);
     $396 = $393 & 255;
     $397 = (($31) + ($396<<4)|0);
     $398 = $393 & 511;
     $399 = (($base$1) + ($398<<4)|0);
     $400 = $395 ? $399 : $397;
     $401 = ((($392)) + 8|0);
     $402 = HEAP32[$401>>2]|0;
     do {
      if ((($402|0) == 19)) {
       $403 = ((($400)) + 8|0);
       $404 = HEAP32[$403>>2]|0;
       $405 = ($404|0)==(19);
       if ($405) {
        $406 = $392;
        $407 = $406;
        $408 = HEAP32[$407>>2]|0;
        $409 = (($406) + 4)|0;
        $410 = $409;
        $411 = HEAP32[$410>>2]|0;
        $412 = $400;
        $413 = $412;
        $414 = HEAP32[$413>>2]|0;
        $415 = (($412) + 4)|0;
        $416 = $415;
        $417 = HEAP32[$416>>2]|0;
        $418 = (___muldi3(($414|0),($417|0),($408|0),($411|0))|0);
        $419 = tempRet0;
        $420 = $50;
        $421 = $420;
        HEAP32[$421>>2] = $418;
        $422 = (($420) + 4)|0;
        $423 = $422;
        HEAP32[$423>>2] = $419;
        $424 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$424>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $426 = $392;
        $427 = $426;
        $428 = HEAP32[$427>>2]|0;
        $429 = (($426) + 4)|0;
        $430 = $429;
        $431 = HEAP32[$430>>2]|0;
        $432 = (+($428>>>0)) + (4294967296.0*(+($431|0)));
        $$ph186 = $432;
        label = 78;
        break;
       }
      } else if ((($402|0) == 3)) {
       $425 = +HEAPF64[$392>>3];
       $488 = $425;
       label = 79;
      } else {
       $433 = $402 & 15;
       $434 = ($433|0)==(4);
       if ($434) {
        $435 = HEAP32[$392>>2]|0;
        $436 = ((($435)) + 24|0);
        $437 = (_luaO_str2num($436,$v$i49)|0);
        $438 = HEAP32[$392>>2]|0;
        $439 = ((($438)) + 12|0);
        $440 = HEAP32[$439>>2]|0;
        $441 = (($440) + 1)|0;
        $442 = ($437|0)==($441|0);
        if ($442) {
         $443 = HEAP32[$10>>2]|0;
         $444 = ($443|0)==(19);
         $445 = $v$i49;
         $446 = $445;
         $447 = HEAP32[$446>>2]|0;
         $448 = (($445) + 4)|0;
         $449 = $448;
         $450 = HEAP32[$449>>2]|0;
         $451 = (+($447>>>0)) + (4294967296.0*(+($450|0)));
         HEAP32[tempDoublePtr>>2] = $447;HEAP32[tempDoublePtr+4>>2] = $450;$452 = +HEAPF64[tempDoublePtr>>3];
         $453 = $444 ? $451 : $452;
         $$ph186 = $453;
         label = 78;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 78) {
      label = 0;
      $488 = $$ph186;
      label = 79;
     }
     L64: do {
      if ((label|0) == 79) {
       label = 0;
       $454 = ((($400)) + 8|0);
       $455 = HEAP32[$454>>2]|0;
       $456 = ($455|0)==(3);
       if ($456) {
        $457 = +HEAPF64[$400>>3];
        $489 = $457;
       } else {
        $458 = ($455|0)==(19);
        do {
         if ($458) {
          $459 = $400;
          $460 = $459;
          $461 = HEAP32[$460>>2]|0;
          $462 = (($459) + 4)|0;
          $463 = $462;
          $464 = HEAP32[$463>>2]|0;
          $465 = (+($461>>>0)) + (4294967296.0*(+($464|0)));
          $$ph189 = $465;
         } else {
          $466 = $455 & 15;
          $467 = ($466|0)==(4);
          if ($467) {
           $468 = HEAP32[$400>>2]|0;
           $469 = ((($468)) + 24|0);
           $470 = (_luaO_str2num($469,$v$i53)|0);
           $471 = HEAP32[$400>>2]|0;
           $472 = ((($471)) + 12|0);
           $473 = HEAP32[$472>>2]|0;
           $474 = (($473) + 1)|0;
           $475 = ($470|0)==($474|0);
           if ($475) {
            $476 = HEAP32[$9>>2]|0;
            $477 = ($476|0)==(19);
            $478 = $v$i53;
            $479 = $478;
            $480 = HEAP32[$479>>2]|0;
            $481 = (($478) + 4)|0;
            $482 = $481;
            $483 = HEAP32[$482>>2]|0;
            $484 = (+($480>>>0)) + (4294967296.0*(+($483|0)));
            HEAP32[tempDoublePtr>>2] = $480;HEAP32[tempDoublePtr+4>>2] = $483;$485 = +HEAPF64[tempDoublePtr>>3];
            $486 = $477 ? $484 : $485;
            $$ph189 = $486;
            break;
           }
          }
          break L64;
         }
        } while(0);
        $489 = $$ph189;
       }
       $487 = $488 * $489;
       HEAPF64[$50>>3] = $487;
       $490 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$490>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$392,$400,$50,8);
     $491 = HEAP32[$32>>2]|0;
     $base$0 = $491;
     continue L3;
     break;
    }
    case 5:  {
     $72 = $38 >>> 23;
     $73 = (((($27)) + 16|0) + ($72<<2)|0);
     $74 = HEAP32[$73>>2]|0;
     $75 = HEAP32[$74>>2]|0;
     ;HEAP32[$50>>2]=HEAP32[$75>>2]|0;HEAP32[$50+4>>2]=HEAP32[$75+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$75+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$75+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 7:  {
     $89 = $38 >>> 23;
     $90 = (($base$1) + ($89<<4)|0);
     $91 = $38 >>> 14;
     $92 = $91 & 256;
     $93 = ($92|0)==(0);
     $94 = $91 & 255;
     $95 = (($31) + ($94<<4)|0);
     $96 = $91 & 511;
     $97 = (($base$1) + ($96<<4)|0);
     $98 = $93 ? $97 : $95;
     _luaV_gettable($L,$90,$98,$50);
     $99 = HEAP32[$32>>2]|0;
     $base$0 = $99;
     continue L3;
     break;
    }
    case 20:  {
     $578 = $38 >>> 23;
     $579 = $578 & 256;
     $580 = ($579|0)==(0);
     $581 = $578 & 255;
     $582 = (($31) + ($581<<4)|0);
     $583 = (($base$1) + ($578<<4)|0);
     $584 = $580 ? $583 : $582;
     $585 = $38 >>> 14;
     $586 = $585 & 256;
     $587 = ($586|0)==(0);
     $588 = $585 & 255;
     $589 = (($31) + ($588<<4)|0);
     $590 = $585 & 511;
     $591 = (($base$1) + ($590<<4)|0);
     $592 = $587 ? $591 : $589;
     $593 = ((($584)) + 8|0);
     $594 = HEAP32[$593>>2]|0;
     $595 = ($594|0)==(19);
     do {
      if ($595) {
       $596 = $584;
       $597 = $596;
       $598 = HEAP32[$597>>2]|0;
       $599 = (($596) + 4)|0;
       $600 = $599;
       $601 = HEAP32[$600>>2]|0;
       $661 = $598;$664 = $601;
       label = 123;
      } else {
       $$02$i$i = $584;$616 = $594;
       while(1) {
        if ((($616|0) == 3)) {
         $$02$i$i$lcssa = $$02$i$i;
         label = 114;
         break;
        } else if ((($616|0) == 19)) {
         $$02$i$i$lcssa959 = $$02$i$i;
         label = 117;
         break;
        }
        $615 = $616 & 15;
        $617 = ($615|0)==(4);
        if (!($617)) {
         label = 121;
         break;
        }
        $618 = HEAP32[$$02$i$i>>2]|0;
        $619 = ((($618)) + 24|0);
        $620 = (_luaO_str2num($619,$v$i$i)|0);
        $621 = HEAP32[$$02$i$i>>2]|0;
        $622 = ((($621)) + 12|0);
        $623 = HEAP32[$622>>2]|0;
        $624 = (($623) + 1)|0;
        $625 = ($620|0)==($624|0);
        if (!($625)) {
         label = 121;
         break;
        }
        $$pre758 = HEAP32[$$phi$trans$insert757>>2]|0;
        $$02$i$i = $v$i$i;$616 = $$pre758;
       }
       if ((label|0) == 114) {
        label = 0;
        $602 = +HEAPF64[$$02$i$i$lcssa>>3];
        $603 = (+Math_floor((+$602)));
        $604 = $602 != $603;
        if ($604) {
         label = 121;
        } else {
         $605 = $603 >= -9.2233720368547758E+18;
         $606 = $603 < 9.2233720368547758E+18;
         $or$cond$i$i = $605 & $606;
         if ($or$cond$i$i) {
          $607 = (~~$603)>>>0;
          $608 = +Math_abs($603) >= 1.0 ? $603 > 0.0 ? (~~+Math_min(+Math_floor($603 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($603 - +(~~$603 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2232 = $607;$2233 = $608;
          label = 122;
         } else {
          label = 121;
         }
        }
       }
       else if ((label|0) == 117) {
        label = 0;
        $609 = $$02$i$i$lcssa959;
        $610 = $609;
        $611 = HEAP32[$610>>2]|0;
        $612 = (($609) + 4)|0;
        $613 = $612;
        $614 = HEAP32[$613>>2]|0;
        $2232 = $611;$2233 = $614;
        label = 122;
       }
       if ((label|0) == 121) {
        label = 0;
        break;
       }
       else if ((label|0) == 122) {
        label = 0;
        $661 = $2232;$664 = $2233;
        label = 123;
        break;
       }
      }
     } while(0);
     L98: do {
      if ((label|0) == 123) {
       label = 0;
       $626 = ((($592)) + 8|0);
       $627 = HEAP32[$626>>2]|0;
       $628 = ($627|0)==(19);
       do {
        if ($628) {
         $629 = $592;
         $630 = $629;
         $631 = HEAP32[$630>>2]|0;
         $632 = (($629) + 4)|0;
         $633 = $632;
         $634 = HEAP32[$633>>2]|0;
         $660 = $631;$663 = $634;
        } else {
         $$02$i$i66 = $592;$649 = $627;
         while(1) {
          if ((($649|0) == 19)) {
           $$02$i$i66$lcssa961 = $$02$i$i66;
           label = 130;
           break;
          } else if ((($649|0) == 3)) {
           $$02$i$i66$lcssa = $$02$i$i66;
           label = 127;
           break;
          }
          $648 = $649 & 15;
          $650 = ($648|0)==(4);
          if (!($650)) {
           label = 134;
           break;
          }
          $651 = HEAP32[$$02$i$i66>>2]|0;
          $652 = ((($651)) + 24|0);
          $653 = (_luaO_str2num($652,$v$i$i65)|0);
          $654 = HEAP32[$$02$i$i66>>2]|0;
          $655 = ((($654)) + 12|0);
          $656 = HEAP32[$655>>2]|0;
          $657 = (($656) + 1)|0;
          $658 = ($653|0)==($657|0);
          if (!($658)) {
           label = 134;
           break;
          }
          $$pre761 = HEAP32[$$phi$trans$insert760>>2]|0;
          $$02$i$i66 = $v$i$i65;$649 = $$pre761;
         }
         if ((label|0) == 127) {
          label = 0;
          $635 = +HEAPF64[$$02$i$i66$lcssa>>3];
          $636 = (+Math_floor((+$635)));
          $637 = $635 != $636;
          if ($637) {
           label = 134;
          } else {
           $638 = $636 >= -9.2233720368547758E+18;
           $639 = $636 < 9.2233720368547758E+18;
           $or$cond$i$i67 = $638 & $639;
           if ($or$cond$i$i67) {
            $640 = (~~$636)>>>0;
            $641 = +Math_abs($636) >= 1.0 ? $636 > 0.0 ? (~~+Math_min(+Math_floor($636 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($636 - +(~~$636 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2234 = $640;$2235 = $641;
            label = 135;
           } else {
            label = 134;
           }
          }
         }
         else if ((label|0) == 130) {
          label = 0;
          $642 = $$02$i$i66$lcssa961;
          $643 = $642;
          $644 = HEAP32[$643>>2]|0;
          $645 = (($642) + 4)|0;
          $646 = $645;
          $647 = HEAP32[$646>>2]|0;
          $2234 = $644;$2235 = $647;
          label = 135;
         }
         if ((label|0) == 134) {
          label = 0;
          break L98;
         }
         else if ((label|0) == 135) {
          label = 0;
          $660 = $2234;$663 = $2235;
          break;
         }
        }
       } while(0);
       $659 = $660 & $661;
       $662 = $663 & $664;
       $665 = $50;
       $666 = $665;
       HEAP32[$666>>2] = $659;
       $667 = (($665) + 4)|0;
       $668 = $667;
       HEAP32[$668>>2] = $662;
       $669 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$669>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$584,$592,$50,13);
     $670 = HEAP32[$32>>2]|0;
     $base$0 = $670;
     continue L3;
     break;
    }
    case 14:  {
     $280 = $38 >>> 23;
     $281 = $280 & 256;
     $282 = ($281|0)==(0);
     $283 = $280 & 255;
     $284 = (($31) + ($283<<4)|0);
     $285 = (($base$1) + ($280<<4)|0);
     $286 = $282 ? $285 : $284;
     $287 = $38 >>> 14;
     $288 = $287 & 256;
     $289 = ($288|0)==(0);
     $290 = $287 & 255;
     $291 = (($31) + ($290<<4)|0);
     $292 = $287 & 511;
     $293 = (($base$1) + ($292<<4)|0);
     $294 = $289 ? $293 : $291;
     $295 = ((($286)) + 8|0);
     $296 = HEAP32[$295>>2]|0;
     do {
      if ((($296|0) == 19)) {
       $297 = ((($294)) + 8|0);
       $298 = HEAP32[$297>>2]|0;
       $299 = ($298|0)==(19);
       if ($299) {
        $300 = $286;
        $301 = $300;
        $302 = HEAP32[$301>>2]|0;
        $303 = (($300) + 4)|0;
        $304 = $303;
        $305 = HEAP32[$304>>2]|0;
        $306 = $294;
        $307 = $306;
        $308 = HEAP32[$307>>2]|0;
        $309 = (($306) + 4)|0;
        $310 = $309;
        $311 = HEAP32[$310>>2]|0;
        $312 = (_i64Subtract(($302|0),($305|0),($308|0),($311|0))|0);
        $313 = tempRet0;
        $314 = $50;
        $315 = $314;
        HEAP32[$315>>2] = $312;
        $316 = (($314) + 4)|0;
        $317 = $316;
        HEAP32[$317>>2] = $313;
        $318 = (((($base$1) + ($49<<4)|0)) + 8|0);
        HEAP32[$318>>2] = 19;
        $base$0 = $base$1;
        continue L3;
       } else {
        $320 = $286;
        $321 = $320;
        $322 = HEAP32[$321>>2]|0;
        $323 = (($320) + 4)|0;
        $324 = $323;
        $325 = HEAP32[$324>>2]|0;
        $326 = (+($322>>>0)) + (4294967296.0*(+($325|0)));
        $$ph178 = $326;
        label = 57;
        break;
       }
      } else if ((($296|0) == 3)) {
       $319 = +HEAPF64[$286>>3];
       $382 = $319;
       label = 58;
      } else {
       $327 = $296 & 15;
       $328 = ($327|0)==(4);
       if ($328) {
        $329 = HEAP32[$286>>2]|0;
        $330 = ((($329)) + 24|0);
        $331 = (_luaO_str2num($330,$v$i41)|0);
        $332 = HEAP32[$286>>2]|0;
        $333 = ((($332)) + 12|0);
        $334 = HEAP32[$333>>2]|0;
        $335 = (($334) + 1)|0;
        $336 = ($331|0)==($335|0);
        if ($336) {
         $337 = HEAP32[$8>>2]|0;
         $338 = ($337|0)==(19);
         $339 = $v$i41;
         $340 = $339;
         $341 = HEAP32[$340>>2]|0;
         $342 = (($339) + 4)|0;
         $343 = $342;
         $344 = HEAP32[$343>>2]|0;
         $345 = (+($341>>>0)) + (4294967296.0*(+($344|0)));
         HEAP32[tempDoublePtr>>2] = $341;HEAP32[tempDoublePtr+4>>2] = $344;$346 = +HEAPF64[tempDoublePtr>>3];
         $347 = $338 ? $345 : $346;
         $$ph178 = $347;
         label = 57;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 57) {
      label = 0;
      $382 = $$ph178;
      label = 58;
     }
     L132: do {
      if ((label|0) == 58) {
       label = 0;
       $348 = ((($294)) + 8|0);
       $349 = HEAP32[$348>>2]|0;
       $350 = ($349|0)==(3);
       if ($350) {
        $351 = +HEAPF64[$294>>3];
        $383 = $351;
       } else {
        $352 = ($349|0)==(19);
        do {
         if ($352) {
          $353 = $294;
          $354 = $353;
          $355 = HEAP32[$354>>2]|0;
          $356 = (($353) + 4)|0;
          $357 = $356;
          $358 = HEAP32[$357>>2]|0;
          $359 = (+($355>>>0)) + (4294967296.0*(+($358|0)));
          $$ph181 = $359;
         } else {
          $360 = $349 & 15;
          $361 = ($360|0)==(4);
          if ($361) {
           $362 = HEAP32[$294>>2]|0;
           $363 = ((($362)) + 24|0);
           $364 = (_luaO_str2num($363,$v$i45)|0);
           $365 = HEAP32[$294>>2]|0;
           $366 = ((($365)) + 12|0);
           $367 = HEAP32[$366>>2]|0;
           $368 = (($367) + 1)|0;
           $369 = ($364|0)==($368|0);
           if ($369) {
            $370 = HEAP32[$7>>2]|0;
            $371 = ($370|0)==(19);
            $372 = $v$i45;
            $373 = $372;
            $374 = HEAP32[$373>>2]|0;
            $375 = (($372) + 4)|0;
            $376 = $375;
            $377 = HEAP32[$376>>2]|0;
            $378 = (+($374>>>0)) + (4294967296.0*(+($377|0)));
            HEAP32[tempDoublePtr>>2] = $374;HEAP32[tempDoublePtr+4>>2] = $377;$379 = +HEAPF64[tempDoublePtr>>3];
            $380 = $371 ? $378 : $379;
            $$ph181 = $380;
            break;
           }
          }
          break L132;
         }
        } while(0);
        $383 = $$ph181;
       }
       $381 = $382 - $383;
       HEAPF64[$50>>3] = $381;
       $384 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$384>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$286,$294,$50,7);
     $385 = HEAP32[$32>>2]|0;
     $base$0 = $385;
     continue L3;
     break;
    }
    case 4:  {
     $67 = $38 >>> 23;
     $b$0 = $67;$ra$0 = $50;
     while(1) {
      $68 = ((($ra$0)) + 16|0);
      $69 = ((($ra$0)) + 8|0);
      HEAP32[$69>>2] = 0;
      $70 = (($b$0) + -1)|0;
      $71 = ($b$0|0)==(0);
      if ($71) {
       $base$0 = $base$1;
       continue L3;
      } else {
       $b$0 = $70;$ra$0 = $68;
      }
     }
     break;
    }
    case 3:  {
     $61 = $38 >>> 23;
     HEAP32[$50>>2] = $61;
     $62 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$62>>2] = 1;
     $63 = $38 & 8372224;
     $64 = ($63|0)==(0);
     if ($64) {
      $base$0 = $base$1;
      continue L3;
     }
     $65 = HEAP32[$34>>2]|0;
     $66 = ((($65)) + 4|0);
     HEAP32[$34>>2] = $66;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 6:  {
     $76 = $38 >>> 23;
     $77 = (((($27)) + 16|0) + ($76<<2)|0);
     $78 = HEAP32[$77>>2]|0;
     $79 = HEAP32[$78>>2]|0;
     $80 = $38 >>> 14;
     $81 = $80 & 256;
     $82 = ($81|0)==(0);
     $83 = $80 & 255;
     $84 = (($31) + ($83<<4)|0);
     $85 = $80 & 511;
     $86 = (($base$1) + ($85<<4)|0);
     $87 = $82 ? $86 : $84;
     _luaV_gettable($L,$79,$87,$50);
     $88 = HEAP32[$32>>2]|0;
     $base$0 = $88;
     continue L3;
     break;
    }
    case 18:  {
     $492 = $38 >>> 23;
     $493 = $492 & 256;
     $494 = ($493|0)==(0);
     $495 = $492 & 255;
     $496 = (($31) + ($495<<4)|0);
     $497 = (($base$1) + ($492<<4)|0);
     $498 = $494 ? $497 : $496;
     $499 = $38 >>> 14;
     $500 = $499 & 256;
     $501 = ($500|0)==(0);
     $502 = $499 & 255;
     $503 = (($31) + ($502<<4)|0);
     $504 = $499 & 511;
     $505 = (($base$1) + ($504<<4)|0);
     $506 = $501 ? $505 : $503;
     $507 = ((($498)) + 8|0);
     $508 = HEAP32[$507>>2]|0;
     $509 = ($508|0)==(3);
     L154: do {
      if ($509) {
       $510 = +HEAPF64[$498>>3];
       $574 = $510;
       label = 99;
      } else {
       $511 = ($508|0)==(19);
       do {
        if ($511) {
         $512 = $498;
         $513 = $512;
         $514 = HEAP32[$513>>2]|0;
         $515 = (($512) + 4)|0;
         $516 = $515;
         $517 = HEAP32[$516>>2]|0;
         $518 = (+($514>>>0)) + (4294967296.0*(+($517|0)));
         $$ph192 = $518;
        } else {
         $519 = $508 & 15;
         $520 = ($519|0)==(4);
         if ($520) {
          $521 = HEAP32[$498>>2]|0;
          $522 = ((($521)) + 24|0);
          $523 = (_luaO_str2num($522,$v$i57)|0);
          $524 = HEAP32[$498>>2]|0;
          $525 = ((($524)) + 12|0);
          $526 = HEAP32[$525>>2]|0;
          $527 = (($526) + 1)|0;
          $528 = ($523|0)==($527|0);
          if ($528) {
           $529 = HEAP32[$12>>2]|0;
           $530 = ($529|0)==(19);
           $531 = $v$i57;
           $532 = $531;
           $533 = HEAP32[$532>>2]|0;
           $534 = (($531) + 4)|0;
           $535 = $534;
           $536 = HEAP32[$535>>2]|0;
           $537 = (+($533>>>0)) + (4294967296.0*(+($536|0)));
           HEAP32[tempDoublePtr>>2] = $533;HEAP32[tempDoublePtr+4>>2] = $536;$538 = +HEAPF64[tempDoublePtr>>3];
           $539 = $530 ? $537 : $538;
           $$ph192 = $539;
           break;
          }
         }
         break L154;
        }
       } while(0);
       $574 = $$ph192;
       label = 99;
      }
     } while(0);
     L165: do {
      if ((label|0) == 99) {
       label = 0;
       $540 = ((($506)) + 8|0);
       $541 = HEAP32[$540>>2]|0;
       $542 = ($541|0)==(3);
       if ($542) {
        $543 = +HEAPF64[$506>>3];
        $575 = $543;
       } else {
        $544 = ($541|0)==(19);
        do {
         if ($544) {
          $545 = $506;
          $546 = $545;
          $547 = HEAP32[$546>>2]|0;
          $548 = (($545) + 4)|0;
          $549 = $548;
          $550 = HEAP32[$549>>2]|0;
          $551 = (+($547>>>0)) + (4294967296.0*(+($550|0)));
          $$ph195 = $551;
         } else {
          $552 = $541 & 15;
          $553 = ($552|0)==(4);
          if ($553) {
           $554 = HEAP32[$506>>2]|0;
           $555 = ((($554)) + 24|0);
           $556 = (_luaO_str2num($555,$v$i61)|0);
           $557 = HEAP32[$506>>2]|0;
           $558 = ((($557)) + 12|0);
           $559 = HEAP32[$558>>2]|0;
           $560 = (($559) + 1)|0;
           $561 = ($556|0)==($560|0);
           if ($561) {
            $562 = HEAP32[$11>>2]|0;
            $563 = ($562|0)==(19);
            $564 = $v$i61;
            $565 = $564;
            $566 = HEAP32[$565>>2]|0;
            $567 = (($564) + 4)|0;
            $568 = $567;
            $569 = HEAP32[$568>>2]|0;
            $570 = (+($566>>>0)) + (4294967296.0*(+($569|0)));
            HEAP32[tempDoublePtr>>2] = $566;HEAP32[tempDoublePtr+4>>2] = $569;$571 = +HEAPF64[tempDoublePtr>>3];
            $572 = $563 ? $570 : $571;
            $$ph195 = $572;
            break;
           }
          }
          break L165;
         }
        } while(0);
        $575 = $$ph195;
       }
       $573 = $574 / $575;
       HEAPF64[$50>>3] = $573;
       $576 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$576>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$498,$506,$50,11);
     $577 = HEAP32[$32>>2]|0;
     $base$0 = $577;
     continue L3;
     break;
    }
    case 9:  {
     $119 = $38 >>> 23;
     $120 = (((($27)) + 16|0) + ($119<<2)|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = HEAP32[$121>>2]|0;
     ;HEAP32[$122>>2]=HEAP32[$50>>2]|0;HEAP32[$122+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$122+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$122+12>>2]=HEAP32[$50+12>>2]|0;
     $123 = HEAP32[$121>>2]|0;
     $124 = ((($123)) + 8|0);
     $125 = HEAP32[$124>>2]|0;
     $126 = $125 & 64;
     $127 = ($126|0)!=(0);
     $128 = ((($121)) + 8|0);
     $129 = ($123|0)==($128|0);
     $or$cond = $129 & $127;
     if (!($or$cond)) {
      $base$0 = $base$1;
      continue L3;
     }
     _luaC_upvalbarrier_($L,$121);
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 0:  {
     $52 = $38 >>> 23;
     $53 = (($base$1) + ($52<<4)|0);
     ;HEAP32[$50>>2]=HEAP32[$53>>2]|0;HEAP32[$50+4>>2]=HEAP32[$53+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$53+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$53+12>>2]|0;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 12:  {
     $162 = $38 >>> 23;
     $163 = (($base$1) + ($162<<4)|0);
     $$sum34 = (($49) + 1)|0;
     $164 = (($base$1) + ($$sum34<<4)|0);
     ;HEAP32[$164>>2]=HEAP32[$163>>2]|0;HEAP32[$164+4>>2]=HEAP32[$163+4>>2]|0;HEAP32[$164+8>>2]=HEAP32[$163+8>>2]|0;HEAP32[$164+12>>2]=HEAP32[$163+12>>2]|0;
     $165 = $38 >>> 14;
     $166 = $165 & 256;
     $167 = ($166|0)==(0);
     $168 = $165 & 255;
     $169 = (($31) + ($168<<4)|0);
     $170 = $165 & 511;
     $171 = (($base$1) + ($170<<4)|0);
     $172 = $167 ? $171 : $169;
     _luaV_gettable($L,$163,$172,$50);
     $173 = HEAP32[$32>>2]|0;
     $base$0 = $173;
     continue L3;
     break;
    }
    case 21:  {
     $671 = $38 >>> 23;
     $672 = $671 & 256;
     $673 = ($672|0)==(0);
     $674 = $671 & 255;
     $675 = (($31) + ($674<<4)|0);
     $676 = (($base$1) + ($671<<4)|0);
     $677 = $673 ? $676 : $675;
     $678 = $38 >>> 14;
     $679 = $678 & 256;
     $680 = ($679|0)==(0);
     $681 = $678 & 255;
     $682 = (($31) + ($681<<4)|0);
     $683 = $678 & 511;
     $684 = (($base$1) + ($683<<4)|0);
     $685 = $680 ? $684 : $682;
     $686 = ((($677)) + 8|0);
     $687 = HEAP32[$686>>2]|0;
     $688 = ($687|0)==(19);
     do {
      if ($688) {
       $689 = $677;
       $690 = $689;
       $691 = HEAP32[$690>>2]|0;
       $692 = (($689) + 4)|0;
       $693 = $692;
       $694 = HEAP32[$693>>2]|0;
       $754 = $691;$757 = $694;
       label = 151;
      } else {
       $$02$i$i71 = $677;$709 = $687;
       while(1) {
        if ((($709|0) == 3)) {
         $$02$i$i71$lcssa = $$02$i$i71;
         label = 142;
         break;
        } else if ((($709|0) == 19)) {
         $$02$i$i71$lcssa955 = $$02$i$i71;
         label = 145;
         break;
        }
        $708 = $709 & 15;
        $710 = ($708|0)==(4);
        if (!($710)) {
         label = 149;
         break;
        }
        $711 = HEAP32[$$02$i$i71>>2]|0;
        $712 = ((($711)) + 24|0);
        $713 = (_luaO_str2num($712,$v$i$i70)|0);
        $714 = HEAP32[$$02$i$i71>>2]|0;
        $715 = ((($714)) + 12|0);
        $716 = HEAP32[$715>>2]|0;
        $717 = (($716) + 1)|0;
        $718 = ($713|0)==($717|0);
        if (!($718)) {
         label = 149;
         break;
        }
        $$pre752 = HEAP32[$$phi$trans$insert751>>2]|0;
        $$02$i$i71 = $v$i$i70;$709 = $$pre752;
       }
       if ((label|0) == 142) {
        label = 0;
        $695 = +HEAPF64[$$02$i$i71$lcssa>>3];
        $696 = (+Math_floor((+$695)));
        $697 = $695 != $696;
        if ($697) {
         label = 149;
        } else {
         $698 = $696 >= -9.2233720368547758E+18;
         $699 = $696 < 9.2233720368547758E+18;
         $or$cond$i$i72 = $698 & $699;
         if ($or$cond$i$i72) {
          $700 = (~~$696)>>>0;
          $701 = +Math_abs($696) >= 1.0 ? $696 > 0.0 ? (~~+Math_min(+Math_floor($696 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($696 - +(~~$696 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2236 = $700;$2237 = $701;
          label = 150;
         } else {
          label = 149;
         }
        }
       }
       else if ((label|0) == 145) {
        label = 0;
        $702 = $$02$i$i71$lcssa955;
        $703 = $702;
        $704 = HEAP32[$703>>2]|0;
        $705 = (($702) + 4)|0;
        $706 = $705;
        $707 = HEAP32[$706>>2]|0;
        $2236 = $704;$2237 = $707;
        label = 150;
       }
       if ((label|0) == 149) {
        label = 0;
        break;
       }
       else if ((label|0) == 150) {
        label = 0;
        $754 = $2236;$757 = $2237;
        label = 151;
        break;
       }
      }
     } while(0);
     L201: do {
      if ((label|0) == 151) {
       label = 0;
       $719 = ((($685)) + 8|0);
       $720 = HEAP32[$719>>2]|0;
       $721 = ($720|0)==(19);
       do {
        if ($721) {
         $722 = $685;
         $723 = $722;
         $724 = HEAP32[$723>>2]|0;
         $725 = (($722) + 4)|0;
         $726 = $725;
         $727 = HEAP32[$726>>2]|0;
         $753 = $724;$756 = $727;
        } else {
         $$02$i$i76 = $685;$742 = $720;
         while(1) {
          if ((($742|0) == 3)) {
           $$02$i$i76$lcssa = $$02$i$i76;
           label = 155;
           break;
          } else if ((($742|0) == 19)) {
           $$02$i$i76$lcssa957 = $$02$i$i76;
           label = 158;
           break;
          }
          $741 = $742 & 15;
          $743 = ($741|0)==(4);
          if (!($743)) {
           label = 162;
           break;
          }
          $744 = HEAP32[$$02$i$i76>>2]|0;
          $745 = ((($744)) + 24|0);
          $746 = (_luaO_str2num($745,$v$i$i75)|0);
          $747 = HEAP32[$$02$i$i76>>2]|0;
          $748 = ((($747)) + 12|0);
          $749 = HEAP32[$748>>2]|0;
          $750 = (($749) + 1)|0;
          $751 = ($746|0)==($750|0);
          if (!($751)) {
           label = 162;
           break;
          }
          $$pre755 = HEAP32[$$phi$trans$insert754>>2]|0;
          $$02$i$i76 = $v$i$i75;$742 = $$pre755;
         }
         if ((label|0) == 155) {
          label = 0;
          $728 = +HEAPF64[$$02$i$i76$lcssa>>3];
          $729 = (+Math_floor((+$728)));
          $730 = $728 != $729;
          if ($730) {
           label = 162;
          } else {
           $731 = $729 >= -9.2233720368547758E+18;
           $732 = $729 < 9.2233720368547758E+18;
           $or$cond$i$i77 = $731 & $732;
           if ($or$cond$i$i77) {
            $733 = (~~$729)>>>0;
            $734 = +Math_abs($729) >= 1.0 ? $729 > 0.0 ? (~~+Math_min(+Math_floor($729 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($729 - +(~~$729 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2238 = $733;$2239 = $734;
            label = 163;
           } else {
            label = 162;
           }
          }
         }
         else if ((label|0) == 158) {
          label = 0;
          $735 = $$02$i$i76$lcssa957;
          $736 = $735;
          $737 = HEAP32[$736>>2]|0;
          $738 = (($735) + 4)|0;
          $739 = $738;
          $740 = HEAP32[$739>>2]|0;
          $2238 = $737;$2239 = $740;
          label = 163;
         }
         if ((label|0) == 162) {
          label = 0;
          break L201;
         }
         else if ((label|0) == 163) {
          label = 0;
          $753 = $2238;$756 = $2239;
          break;
         }
        }
       } while(0);
       $752 = $753 | $754;
       $755 = $756 | $757;
       $758 = $50;
       $759 = $758;
       HEAP32[$759>>2] = $752;
       $760 = (($758) + 4)|0;
       $761 = $760;
       HEAP32[$761>>2] = $755;
       $762 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$762>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$677,$685,$50,14);
     $763 = HEAP32[$32>>2]|0;
     $base$0 = $763;
     continue L3;
     break;
    }
    case 22:  {
     $764 = $38 >>> 23;
     $765 = $764 & 256;
     $766 = ($765|0)==(0);
     $767 = $764 & 255;
     $768 = (($31) + ($767<<4)|0);
     $769 = (($base$1) + ($764<<4)|0);
     $770 = $766 ? $769 : $768;
     $771 = $38 >>> 14;
     $772 = $771 & 256;
     $773 = ($772|0)==(0);
     $774 = $771 & 255;
     $775 = (($31) + ($774<<4)|0);
     $776 = $771 & 511;
     $777 = (($base$1) + ($776<<4)|0);
     $778 = $773 ? $777 : $775;
     $779 = ((($770)) + 8|0);
     $780 = HEAP32[$779>>2]|0;
     $781 = ($780|0)==(19);
     do {
      if ($781) {
       $782 = $770;
       $783 = $782;
       $784 = HEAP32[$783>>2]|0;
       $785 = (($782) + 4)|0;
       $786 = $785;
       $787 = HEAP32[$786>>2]|0;
       $847 = $784;$850 = $787;
       label = 179;
      } else {
       $$02$i$i81 = $770;$802 = $780;
       while(1) {
        if ((($802|0) == 3)) {
         $$02$i$i81$lcssa = $$02$i$i81;
         label = 170;
         break;
        } else if ((($802|0) == 19)) {
         $$02$i$i81$lcssa951 = $$02$i$i81;
         label = 173;
         break;
        }
        $801 = $802 & 15;
        $803 = ($801|0)==(4);
        if (!($803)) {
         label = 177;
         break;
        }
        $804 = HEAP32[$$02$i$i81>>2]|0;
        $805 = ((($804)) + 24|0);
        $806 = (_luaO_str2num($805,$v$i$i80)|0);
        $807 = HEAP32[$$02$i$i81>>2]|0;
        $808 = ((($807)) + 12|0);
        $809 = HEAP32[$808>>2]|0;
        $810 = (($809) + 1)|0;
        $811 = ($806|0)==($810|0);
        if (!($811)) {
         label = 177;
         break;
        }
        $$pre746 = HEAP32[$$phi$trans$insert745>>2]|0;
        $$02$i$i81 = $v$i$i80;$802 = $$pre746;
       }
       if ((label|0) == 170) {
        label = 0;
        $788 = +HEAPF64[$$02$i$i81$lcssa>>3];
        $789 = (+Math_floor((+$788)));
        $790 = $788 != $789;
        if ($790) {
         label = 177;
        } else {
         $791 = $789 >= -9.2233720368547758E+18;
         $792 = $789 < 9.2233720368547758E+18;
         $or$cond$i$i82 = $791 & $792;
         if ($or$cond$i$i82) {
          $793 = (~~$789)>>>0;
          $794 = +Math_abs($789) >= 1.0 ? $789 > 0.0 ? (~~+Math_min(+Math_floor($789 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($789 - +(~~$789 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2240 = $793;$2241 = $794;
          label = 178;
         } else {
          label = 177;
         }
        }
       }
       else if ((label|0) == 173) {
        label = 0;
        $795 = $$02$i$i81$lcssa951;
        $796 = $795;
        $797 = HEAP32[$796>>2]|0;
        $798 = (($795) + 4)|0;
        $799 = $798;
        $800 = HEAP32[$799>>2]|0;
        $2240 = $797;$2241 = $800;
        label = 178;
       }
       if ((label|0) == 177) {
        label = 0;
        break;
       }
       else if ((label|0) == 178) {
        label = 0;
        $847 = $2240;$850 = $2241;
        label = 179;
        break;
       }
      }
     } while(0);
     L238: do {
      if ((label|0) == 179) {
       label = 0;
       $812 = ((($778)) + 8|0);
       $813 = HEAP32[$812>>2]|0;
       $814 = ($813|0)==(19);
       do {
        if ($814) {
         $815 = $778;
         $816 = $815;
         $817 = HEAP32[$816>>2]|0;
         $818 = (($815) + 4)|0;
         $819 = $818;
         $820 = HEAP32[$819>>2]|0;
         $846 = $817;$849 = $820;
        } else {
         $$02$i$i86 = $778;$835 = $813;
         while(1) {
          if ((($835|0) == 3)) {
           $$02$i$i86$lcssa = $$02$i$i86;
           label = 183;
           break;
          } else if ((($835|0) == 19)) {
           $$02$i$i86$lcssa953 = $$02$i$i86;
           label = 186;
           break;
          }
          $834 = $835 & 15;
          $836 = ($834|0)==(4);
          if (!($836)) {
           label = 190;
           break;
          }
          $837 = HEAP32[$$02$i$i86>>2]|0;
          $838 = ((($837)) + 24|0);
          $839 = (_luaO_str2num($838,$v$i$i85)|0);
          $840 = HEAP32[$$02$i$i86>>2]|0;
          $841 = ((($840)) + 12|0);
          $842 = HEAP32[$841>>2]|0;
          $843 = (($842) + 1)|0;
          $844 = ($839|0)==($843|0);
          if (!($844)) {
           label = 190;
           break;
          }
          $$pre749 = HEAP32[$$phi$trans$insert748>>2]|0;
          $$02$i$i86 = $v$i$i85;$835 = $$pre749;
         }
         if ((label|0) == 183) {
          label = 0;
          $821 = +HEAPF64[$$02$i$i86$lcssa>>3];
          $822 = (+Math_floor((+$821)));
          $823 = $821 != $822;
          if ($823) {
           label = 190;
          } else {
           $824 = $822 >= -9.2233720368547758E+18;
           $825 = $822 < 9.2233720368547758E+18;
           $or$cond$i$i87 = $824 & $825;
           if ($or$cond$i$i87) {
            $826 = (~~$822)>>>0;
            $827 = +Math_abs($822) >= 1.0 ? $822 > 0.0 ? (~~+Math_min(+Math_floor($822 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($822 - +(~~$822 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2242 = $826;$2243 = $827;
            label = 191;
           } else {
            label = 190;
           }
          }
         }
         else if ((label|0) == 186) {
          label = 0;
          $828 = $$02$i$i86$lcssa953;
          $829 = $828;
          $830 = HEAP32[$829>>2]|0;
          $831 = (($828) + 4)|0;
          $832 = $831;
          $833 = HEAP32[$832>>2]|0;
          $2242 = $830;$2243 = $833;
          label = 191;
         }
         if ((label|0) == 190) {
          label = 0;
          break L238;
         }
         else if ((label|0) == 191) {
          label = 0;
          $846 = $2242;$849 = $2243;
          break;
         }
        }
       } while(0);
       $845 = $846 ^ $847;
       $848 = $849 ^ $850;
       $851 = $50;
       $852 = $851;
       HEAP32[$852>>2] = $845;
       $853 = (($851) + 4)|0;
       $854 = $853;
       HEAP32[$854>>2] = $848;
       $855 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$855>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$770,$778,$50,15);
     $856 = HEAP32[$32>>2]|0;
     $base$0 = $856;
     continue L3;
     break;
    }
    case 23:  {
     $857 = $38 >>> 23;
     $858 = $857 & 256;
     $859 = ($858|0)==(0);
     $860 = $857 & 255;
     $861 = (($31) + ($860<<4)|0);
     $862 = (($base$1) + ($857<<4)|0);
     $863 = $859 ? $862 : $861;
     $864 = $38 >>> 14;
     $865 = $864 & 256;
     $866 = ($865|0)==(0);
     $867 = $864 & 255;
     $868 = (($31) + ($867<<4)|0);
     $869 = $864 & 511;
     $870 = (($base$1) + ($869<<4)|0);
     $871 = $866 ? $870 : $868;
     $872 = ((($863)) + 8|0);
     $873 = HEAP32[$872>>2]|0;
     $874 = ($873|0)==(19);
     do {
      if ($874) {
       $875 = $863;
       $876 = $875;
       $877 = HEAP32[$876>>2]|0;
       $878 = (($875) + 4)|0;
       $879 = $878;
       $880 = HEAP32[$879>>2]|0;
       $948 = $877;$949 = $880;
       label = 207;
      } else {
       $$02$i$i91 = $863;$895 = $873;
       while(1) {
        if ((($895|0) == 3)) {
         $$02$i$i91$lcssa = $$02$i$i91;
         label = 198;
         break;
        } else if ((($895|0) == 19)) {
         $$02$i$i91$lcssa947 = $$02$i$i91;
         label = 201;
         break;
        }
        $894 = $895 & 15;
        $896 = ($894|0)==(4);
        if (!($896)) {
         label = 205;
         break;
        }
        $897 = HEAP32[$$02$i$i91>>2]|0;
        $898 = ((($897)) + 24|0);
        $899 = (_luaO_str2num($898,$v$i$i90)|0);
        $900 = HEAP32[$$02$i$i91>>2]|0;
        $901 = ((($900)) + 12|0);
        $902 = HEAP32[$901>>2]|0;
        $903 = (($902) + 1)|0;
        $904 = ($899|0)==($903|0);
        if (!($904)) {
         label = 205;
         break;
        }
        $$pre740 = HEAP32[$$phi$trans$insert739>>2]|0;
        $$02$i$i91 = $v$i$i90;$895 = $$pre740;
       }
       if ((label|0) == 198) {
        label = 0;
        $881 = +HEAPF64[$$02$i$i91$lcssa>>3];
        $882 = (+Math_floor((+$881)));
        $883 = $881 != $882;
        if ($883) {
         label = 205;
        } else {
         $884 = $882 >= -9.2233720368547758E+18;
         $885 = $882 < 9.2233720368547758E+18;
         $or$cond$i$i92 = $884 & $885;
         if ($or$cond$i$i92) {
          $886 = (~~$882)>>>0;
          $887 = +Math_abs($882) >= 1.0 ? $882 > 0.0 ? (~~+Math_min(+Math_floor($882 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($882 - +(~~$882 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2244 = $886;$2245 = $887;
          label = 206;
         } else {
          label = 205;
         }
        }
       }
       else if ((label|0) == 201) {
        label = 0;
        $888 = $$02$i$i91$lcssa947;
        $889 = $888;
        $890 = HEAP32[$889>>2]|0;
        $891 = (($888) + 4)|0;
        $892 = $891;
        $893 = HEAP32[$892>>2]|0;
        $2244 = $890;$2245 = $893;
        label = 206;
       }
       if ((label|0) == 205) {
        label = 0;
        break;
       }
       else if ((label|0) == 206) {
        label = 0;
        $948 = $2244;$949 = $2245;
        label = 207;
        break;
       }
      }
     } while(0);
     L275: do {
      if ((label|0) == 207) {
       label = 0;
       $905 = ((($871)) + 8|0);
       $906 = HEAP32[$905>>2]|0;
       $907 = ($906|0)==(19);
       do {
        if ($907) {
         $908 = $871;
         $909 = $908;
         $910 = HEAP32[$909>>2]|0;
         $911 = (($908) + 4)|0;
         $912 = $911;
         $913 = HEAP32[$912>>2]|0;
         $939 = $913;$942 = $910;
        } else {
         $$02$i$i96 = $871;$928 = $906;
         while(1) {
          if ((($928|0) == 3)) {
           $$02$i$i96$lcssa = $$02$i$i96;
           label = 211;
           break;
          } else if ((($928|0) == 19)) {
           $$02$i$i96$lcssa949 = $$02$i$i96;
           label = 214;
           break;
          }
          $927 = $928 & 15;
          $929 = ($927|0)==(4);
          if (!($929)) {
           label = 218;
           break;
          }
          $930 = HEAP32[$$02$i$i96>>2]|0;
          $931 = ((($930)) + 24|0);
          $932 = (_luaO_str2num($931,$v$i$i95)|0);
          $933 = HEAP32[$$02$i$i96>>2]|0;
          $934 = ((($933)) + 12|0);
          $935 = HEAP32[$934>>2]|0;
          $936 = (($935) + 1)|0;
          $937 = ($932|0)==($936|0);
          if (!($937)) {
           label = 218;
           break;
          }
          $$pre743 = HEAP32[$$phi$trans$insert742>>2]|0;
          $$02$i$i96 = $v$i$i95;$928 = $$pre743;
         }
         if ((label|0) == 211) {
          label = 0;
          $914 = +HEAPF64[$$02$i$i96$lcssa>>3];
          $915 = (+Math_floor((+$914)));
          $916 = $914 != $915;
          if ($916) {
           label = 218;
          } else {
           $917 = $915 >= -9.2233720368547758E+18;
           $918 = $915 < 9.2233720368547758E+18;
           $or$cond$i$i97 = $917 & $918;
           if ($or$cond$i$i97) {
            $919 = (~~$915)>>>0;
            $920 = +Math_abs($915) >= 1.0 ? $915 > 0.0 ? (~~+Math_min(+Math_floor($915 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($915 - +(~~$915 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2246 = $919;$2247 = $920;
            label = 219;
           } else {
            label = 218;
           }
          }
         }
         else if ((label|0) == 214) {
          label = 0;
          $921 = $$02$i$i96$lcssa949;
          $922 = $921;
          $923 = HEAP32[$922>>2]|0;
          $924 = (($921) + 4)|0;
          $925 = $924;
          $926 = HEAP32[$925>>2]|0;
          $2246 = $923;$2247 = $926;
          label = 219;
         }
         if ((label|0) == 218) {
          label = 0;
          break L275;
         }
         else if ((label|0) == 219) {
          label = 0;
          $939 = $2247;$942 = $2246;
          break;
         }
        }
       } while(0);
       $938 = ($939|0)<(0);
       if ($938) {
        $940 = ($939|0)<(-1);
        $941 = ($942>>>0)<(4294967233);
        $943 = ($939|0)==(-1);
        $944 = $943 & $941;
        $945 = $940 | $944;
        $946 = (_i64Subtract(0,0,($942|0),($939|0))|0);
        $947 = tempRet0;
        $950 = (_bitshift64Lshr(($948|0),($949|0),($946|0))|0);
        $951 = tempRet0;
        $952 = $945 ? 0 : $950;
        $953 = $945 ? 0 : $951;
        $965 = $952;$968 = $953;
       } else {
        $954 = ($939|0)>(0);
        $955 = ($942>>>0)>(63);
        $956 = ($939|0)==(0);
        $957 = $956 & $955;
        $958 = $954 | $957;
        $959 = (_bitshift64Shl(($948|0),($949|0),($942|0))|0);
        $960 = tempRet0;
        $961 = $958 ? 0 : $959;
        $962 = $958 ? 0 : $960;
        $965 = $961;$968 = $962;
       }
       $963 = $50;
       $964 = $963;
       HEAP32[$964>>2] = $965;
       $966 = (($963) + 4)|0;
       $967 = $966;
       HEAP32[$967>>2] = $968;
       $969 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$969>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$863,$871,$50,16);
     $970 = HEAP32[$32>>2]|0;
     $base$0 = $970;
     continue L3;
     break;
    }
    case 24:  {
     $971 = $38 >>> 23;
     $972 = $971 & 256;
     $973 = ($972|0)==(0);
     $974 = $971 & 255;
     $975 = (($31) + ($974<<4)|0);
     $976 = (($base$1) + ($971<<4)|0);
     $977 = $973 ? $976 : $975;
     $978 = $38 >>> 14;
     $979 = $978 & 256;
     $980 = ($979|0)==(0);
     $981 = $978 & 255;
     $982 = (($31) + ($981<<4)|0);
     $983 = $978 & 511;
     $984 = (($base$1) + ($983<<4)|0);
     $985 = $980 ? $984 : $982;
     $986 = ((($977)) + 8|0);
     $987 = HEAP32[$986>>2]|0;
     $988 = ($987|0)==(19);
     do {
      if ($988) {
       $989 = $977;
       $990 = $989;
       $991 = HEAP32[$990>>2]|0;
       $992 = (($989) + 4)|0;
       $993 = $992;
       $994 = HEAP32[$993>>2]|0;
       $1064 = $991;$1065 = $994;
       label = 238;
      } else {
       $$02$i$i102 = $977;$1009 = $987;
       while(1) {
        if ((($1009|0) == 19)) {
         $$02$i$i102$lcssa943 = $$02$i$i102;
         label = 232;
         break;
        } else if ((($1009|0) == 3)) {
         $$02$i$i102$lcssa = $$02$i$i102;
         label = 229;
         break;
        }
        $1008 = $1009 & 15;
        $1010 = ($1008|0)==(4);
        if (!($1010)) {
         label = 236;
         break;
        }
        $1011 = HEAP32[$$02$i$i102>>2]|0;
        $1012 = ((($1011)) + 24|0);
        $1013 = (_luaO_str2num($1012,$v$i$i101)|0);
        $1014 = HEAP32[$$02$i$i102>>2]|0;
        $1015 = ((($1014)) + 12|0);
        $1016 = HEAP32[$1015>>2]|0;
        $1017 = (($1016) + 1)|0;
        $1018 = ($1013|0)==($1017|0);
        if (!($1018)) {
         label = 236;
         break;
        }
        $$pre734 = HEAP32[$$phi$trans$insert733>>2]|0;
        $$02$i$i102 = $v$i$i101;$1009 = $$pre734;
       }
       if ((label|0) == 229) {
        label = 0;
        $995 = +HEAPF64[$$02$i$i102$lcssa>>3];
        $996 = (+Math_floor((+$995)));
        $997 = $995 != $996;
        if ($997) {
         label = 236;
        } else {
         $998 = $996 >= -9.2233720368547758E+18;
         $999 = $996 < 9.2233720368547758E+18;
         $or$cond$i$i103 = $998 & $999;
         if ($or$cond$i$i103) {
          $1000 = (~~$996)>>>0;
          $1001 = +Math_abs($996) >= 1.0 ? $996 > 0.0 ? (~~+Math_min(+Math_floor($996 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($996 - +(~~$996 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2248 = $1000;$2249 = $1001;
          label = 237;
         } else {
          label = 236;
         }
        }
       }
       else if ((label|0) == 232) {
        label = 0;
        $1002 = $$02$i$i102$lcssa943;
        $1003 = $1002;
        $1004 = HEAP32[$1003>>2]|0;
        $1005 = (($1002) + 4)|0;
        $1006 = $1005;
        $1007 = HEAP32[$1006>>2]|0;
        $2248 = $1004;$2249 = $1007;
        label = 237;
       }
       if ((label|0) == 236) {
        label = 0;
        break;
       }
       else if ((label|0) == 237) {
        label = 0;
        $1064 = $2248;$1065 = $2249;
        label = 238;
        break;
       }
      }
     } while(0);
     L316: do {
      if ((label|0) == 238) {
       label = 0;
       $1019 = ((($985)) + 8|0);
       $1020 = HEAP32[$1019>>2]|0;
       $1021 = ($1020|0)==(19);
       do {
        if ($1021) {
         $1022 = $985;
         $1023 = $1022;
         $1024 = HEAP32[$1023>>2]|0;
         $1025 = (($1022) + 4)|0;
         $1026 = $1025;
         $1027 = HEAP32[$1026>>2]|0;
         $1053 = $1027;$1055 = $1024;
        } else {
         $$02$i$i107 = $985;$1042 = $1020;
         while(1) {
          if ((($1042|0) == 3)) {
           $$02$i$i107$lcssa = $$02$i$i107;
           label = 242;
           break;
          } else if ((($1042|0) == 19)) {
           $$02$i$i107$lcssa945 = $$02$i$i107;
           label = 245;
           break;
          }
          $1041 = $1042 & 15;
          $1043 = ($1041|0)==(4);
          if (!($1043)) {
           label = 249;
           break;
          }
          $1044 = HEAP32[$$02$i$i107>>2]|0;
          $1045 = ((($1044)) + 24|0);
          $1046 = (_luaO_str2num($1045,$v$i$i106)|0);
          $1047 = HEAP32[$$02$i$i107>>2]|0;
          $1048 = ((($1047)) + 12|0);
          $1049 = HEAP32[$1048>>2]|0;
          $1050 = (($1049) + 1)|0;
          $1051 = ($1046|0)==($1050|0);
          if (!($1051)) {
           label = 249;
           break;
          }
          $$pre737 = HEAP32[$$phi$trans$insert736>>2]|0;
          $$02$i$i107 = $v$i$i106;$1042 = $$pre737;
         }
         if ((label|0) == 242) {
          label = 0;
          $1028 = +HEAPF64[$$02$i$i107$lcssa>>3];
          $1029 = (+Math_floor((+$1028)));
          $1030 = $1028 != $1029;
          if ($1030) {
           label = 249;
          } else {
           $1031 = $1029 >= -9.2233720368547758E+18;
           $1032 = $1029 < 9.2233720368547758E+18;
           $or$cond$i$i108 = $1031 & $1032;
           if ($or$cond$i$i108) {
            $1033 = (~~$1029)>>>0;
            $1034 = +Math_abs($1029) >= 1.0 ? $1029 > 0.0 ? (~~+Math_min(+Math_floor($1029 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1029 - +(~~$1029 >>> 0)) / 4294967296.0) >>> 0 : 0;
            $2250 = $1033;$2251 = $1034;
            label = 250;
           } else {
            label = 249;
           }
          }
         }
         else if ((label|0) == 245) {
          label = 0;
          $1035 = $$02$i$i107$lcssa945;
          $1036 = $1035;
          $1037 = HEAP32[$1036>>2]|0;
          $1038 = (($1035) + 4)|0;
          $1039 = $1038;
          $1040 = HEAP32[$1039>>2]|0;
          $2250 = $1037;$2251 = $1040;
          label = 250;
         }
         if ((label|0) == 249) {
          label = 0;
          break L316;
         }
         else if ((label|0) == 250) {
          label = 0;
          $1053 = $2251;$1055 = $2250;
          break;
         }
        }
       } while(0);
       $1052 = ($1053|0)>(0);
       $1054 = ($1055>>>0)>(0);
       $1056 = ($1053|0)==(0);
       $1057 = $1056 & $1054;
       $1058 = $1052 | $1057;
       if ($1058) {
        $1059 = ($1053|0)>(0);
        $1060 = ($1055>>>0)>(63);
        $1061 = ($1053|0)==(0);
        $1062 = $1061 & $1060;
        $1063 = $1059 | $1062;
        $1066 = (_bitshift64Lshr(($1064|0),($1065|0),($1055|0))|0);
        $1067 = tempRet0;
        $1068 = $1063 ? 0 : $1066;
        $1069 = $1063 ? 0 : $1067;
        $1083 = $1068;$1086 = $1069;
       } else {
        $1070 = (_i64Subtract(0,0,($1055|0),($1053|0))|0);
        $1071 = tempRet0;
        $1072 = ($1053|0)<(-1);
        $1073 = ($1055>>>0)<(4294967233);
        $1074 = ($1053|0)==(-1);
        $1075 = $1074 & $1073;
        $1076 = $1072 | $1075;
        $1077 = (_bitshift64Shl(($1064|0),($1065|0),($1070|0))|0);
        $1078 = tempRet0;
        $1079 = $1076 ? 0 : $1077;
        $1080 = $1076 ? 0 : $1078;
        $1083 = $1079;$1086 = $1080;
       }
       $1081 = $50;
       $1082 = $1081;
       HEAP32[$1082>>2] = $1083;
       $1084 = (($1081) + 4)|0;
       $1085 = $1084;
       HEAP32[$1085>>2] = $1086;
       $1087 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1087>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$977,$985,$50,17);
     $1088 = HEAP32[$32>>2]|0;
     $base$0 = $1088;
     continue L3;
     break;
    }
    case 16:  {
     $1089 = $38 >>> 23;
     $1090 = $1089 & 256;
     $1091 = ($1090|0)==(0);
     $1092 = $1089 & 255;
     $1093 = (($31) + ($1092<<4)|0);
     $1094 = (($base$1) + ($1089<<4)|0);
     $1095 = $1091 ? $1094 : $1093;
     $1096 = $38 >>> 14;
     $1097 = $1096 & 256;
     $1098 = ($1097|0)==(0);
     $1099 = $1096 & 255;
     $1100 = (($31) + ($1099<<4)|0);
     $1101 = $1096 & 511;
     $1102 = (($base$1) + ($1101<<4)|0);
     $1103 = $1098 ? $1102 : $1100;
     $1104 = ((($1095)) + 8|0);
     $1105 = HEAP32[$1104>>2]|0;
     do {
      if ((($1105|0) == 19)) {
       $1106 = ((($1103)) + 8|0);
       $1107 = HEAP32[$1106>>2]|0;
       $1108 = ($1107|0)==(19);
       if (!($1108)) {
        $1150 = $1095;
        $1151 = $1150;
        $1152 = HEAP32[$1151>>2]|0;
        $1153 = (($1150) + 4)|0;
        $1154 = $1153;
        $1155 = HEAP32[$1154>>2]|0;
        $1156 = (+($1152>>>0)) + (4294967296.0*(+($1155|0)));
        $$ph230 = $1156;
        label = 269;
        break;
       }
       $1109 = $1095;
       $1110 = $1109;
       $1111 = HEAP32[$1110>>2]|0;
       $1112 = (($1109) + 4)|0;
       $1113 = $1112;
       $1114 = HEAP32[$1113>>2]|0;
       $1115 = $1103;
       $1116 = $1115;
       $1117 = HEAP32[$1116>>2]|0;
       $1118 = (($1115) + 4)|0;
       $1119 = $1118;
       $1120 = HEAP32[$1119>>2]|0;
       $1121 = (_i64Add(($1117|0),($1120|0),1,0)|0);
       $1122 = tempRet0;
       $1123 = ($1122>>>0)<(0);
       $1124 = ($1121>>>0)<(2);
       $1125 = ($1122|0)==(0);
       $1126 = $1125 & $1124;
       $1127 = $1123 | $1126;
       if ($1127) {
        $1128 = ($1117|0)==(0);
        $1129 = ($1120|0)==(0);
        $1130 = $1128 & $1129;
        if ($1130) {
         label = 260;
         break L1;
        } else {
         $1144 = 0;$1147 = 0;
        }
       } else {
        $1131 = (___remdi3(($1111|0),($1114|0),($1117|0),($1120|0))|0);
        $1132 = tempRet0;
        $1133 = ($1131|0)!=(0);
        $1134 = ($1132|0)!=(0);
        $1135 = $1133 | $1134;
        $1117 ^ $1111;
        $1136 = $1120 ^ $1114;
        $1137 = ($1136|0)<(0);
        $or$cond$i = $1137 & $1135;
        $1138 = $or$cond$i ? $1117 : 0;
        $1139 = $or$cond$i ? $1120 : 0;
        $1140 = (_i64Add(($1138|0),($1139|0),($1131|0),($1132|0))|0);
        $1141 = tempRet0;
        $1144 = $1140;$1147 = $1141;
       }
       $1142 = $50;
       $1143 = $1142;
       HEAP32[$1143>>2] = $1144;
       $1145 = (($1142) + 4)|0;
       $1146 = $1145;
       HEAP32[$1146>>2] = $1147;
       $1148 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1148>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1105|0) == 3)) {
       $1149 = +HEAPF64[$1095>>3];
       $1211 = $1149;
       label = 270;
      } else {
       $1157 = $1105 & 15;
       $1158 = ($1157|0)==(4);
       if ($1158) {
        $1159 = HEAP32[$1095>>2]|0;
        $1160 = ((($1159)) + 24|0);
        $1161 = (_luaO_str2num($1160,$v$i115)|0);
        $1162 = HEAP32[$1095>>2]|0;
        $1163 = ((($1162)) + 12|0);
        $1164 = HEAP32[$1163>>2]|0;
        $1165 = (($1164) + 1)|0;
        $1166 = ($1161|0)==($1165|0);
        if ($1166) {
         $1167 = HEAP32[$14>>2]|0;
         $1168 = ($1167|0)==(19);
         $1169 = $v$i115;
         $1170 = $1169;
         $1171 = HEAP32[$1170>>2]|0;
         $1172 = (($1169) + 4)|0;
         $1173 = $1172;
         $1174 = HEAP32[$1173>>2]|0;
         $1175 = (+($1171>>>0)) + (4294967296.0*(+($1174|0)));
         HEAP32[tempDoublePtr>>2] = $1171;HEAP32[tempDoublePtr+4>>2] = $1174;$1176 = +HEAPF64[tempDoublePtr>>3];
         $1177 = $1168 ? $1175 : $1176;
         $$ph230 = $1177;
         label = 269;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 269) {
      label = 0;
      $1211 = $$ph230;
      label = 270;
     }
     L358: do {
      if ((label|0) == 270) {
       label = 0;
       $1178 = ((($1103)) + 8|0);
       $1179 = HEAP32[$1178>>2]|0;
       $1180 = ($1179|0)==(3);
       if ($1180) {
        $1181 = +HEAPF64[$1103>>3];
        $1212 = $1181;
       } else {
        $1182 = ($1179|0)==(19);
        do {
         if ($1182) {
          $1183 = $1103;
          $1184 = $1183;
          $1185 = HEAP32[$1184>>2]|0;
          $1186 = (($1183) + 4)|0;
          $1187 = $1186;
          $1188 = HEAP32[$1187>>2]|0;
          $1189 = (+($1185>>>0)) + (4294967296.0*(+($1188|0)));
          $$ph233 = $1189;
         } else {
          $1190 = $1179 & 15;
          $1191 = ($1190|0)==(4);
          if ($1191) {
           $1192 = HEAP32[$1103>>2]|0;
           $1193 = ((($1192)) + 24|0);
           $1194 = (_luaO_str2num($1193,$v$i119)|0);
           $1195 = HEAP32[$1103>>2]|0;
           $1196 = ((($1195)) + 12|0);
           $1197 = HEAP32[$1196>>2]|0;
           $1198 = (($1197) + 1)|0;
           $1199 = ($1194|0)==($1198|0);
           if ($1199) {
            $1200 = HEAP32[$13>>2]|0;
            $1201 = ($1200|0)==(19);
            $1202 = $v$i119;
            $1203 = $1202;
            $1204 = HEAP32[$1203>>2]|0;
            $1205 = (($1202) + 4)|0;
            $1206 = $1205;
            $1207 = HEAP32[$1206>>2]|0;
            $1208 = (+($1204>>>0)) + (4294967296.0*(+($1207|0)));
            HEAP32[tempDoublePtr>>2] = $1204;HEAP32[tempDoublePtr+4>>2] = $1207;$1209 = +HEAPF64[tempDoublePtr>>3];
            $1210 = $1201 ? $1208 : $1209;
            $$ph233 = $1210;
            break;
           }
          }
          break L358;
         }
        } while(0);
        $1212 = $$ph233;
       }
       $1213 = (+_fmod($1211,$1212));
       $1214 = $1212 * $1213;
       $1215 = $1214 < 0.0;
       $1216 = $1212 + $1213;
       $m$0 = $1215 ? $1216 : $1213;
       HEAPF64[$50>>3] = $m$0;
       $1217 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1217>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1095,$1103,$50,9);
     $1218 = HEAP32[$32>>2]|0;
     $base$0 = $1218;
     continue L3;
     break;
    }
    case 19:  {
     $1219 = $38 >>> 23;
     $1220 = $1219 & 256;
     $1221 = ($1220|0)==(0);
     $1222 = $1219 & 255;
     $1223 = (($31) + ($1222<<4)|0);
     $1224 = (($base$1) + ($1219<<4)|0);
     $1225 = $1221 ? $1224 : $1223;
     $1226 = $38 >>> 14;
     $1227 = $1226 & 256;
     $1228 = ($1227|0)==(0);
     $1229 = $1226 & 255;
     $1230 = (($31) + ($1229<<4)|0);
     $1231 = $1226 & 511;
     $1232 = (($base$1) + ($1231<<4)|0);
     $1233 = $1228 ? $1232 : $1230;
     $1234 = ((($1225)) + 8|0);
     $1235 = HEAP32[$1234>>2]|0;
     do {
      if ((($1235|0) == 19)) {
       $1236 = ((($1233)) + 8|0);
       $1237 = HEAP32[$1236>>2]|0;
       $1238 = ($1237|0)==(19);
       if (!($1238)) {
        $1285 = $1225;
        $1286 = $1285;
        $1287 = HEAP32[$1286>>2]|0;
        $1288 = (($1285) + 4)|0;
        $1289 = $1288;
        $1290 = HEAP32[$1289>>2]|0;
        $1291 = (+($1287>>>0)) + (4294967296.0*(+($1290|0)));
        $$ph238 = $1291;
        label = 296;
        break;
       }
       $1239 = $1225;
       $1240 = $1239;
       $1241 = HEAP32[$1240>>2]|0;
       $1242 = (($1239) + 4)|0;
       $1243 = $1242;
       $1244 = HEAP32[$1243>>2]|0;
       $1245 = $1233;
       $1246 = $1245;
       $1247 = HEAP32[$1246>>2]|0;
       $1248 = (($1245) + 4)|0;
       $1249 = $1248;
       $1250 = HEAP32[$1249>>2]|0;
       $1251 = (_i64Add(($1247|0),($1250|0),1,0)|0);
       $1252 = tempRet0;
       $1253 = ($1252>>>0)<(0);
       $1254 = ($1251>>>0)<(2);
       $1255 = ($1252|0)==(0);
       $1256 = $1255 & $1254;
       $1257 = $1253 | $1256;
       if ($1257) {
        $1258 = ($1247|0)==(0);
        $1259 = ($1250|0)==(0);
        $1260 = $1258 & $1259;
        if ($1260) {
         label = 285;
         break L1;
        }
        $1261 = (_i64Subtract(0,0,($1241|0),($1244|0))|0);
        $1262 = tempRet0;
        $1279 = $1261;$1282 = $1262;
       } else {
        $1263 = (___divdi3(($1241|0),($1244|0),($1247|0),($1250|0))|0);
        $1264 = tempRet0;
        $1247 ^ $1241;
        $1265 = $1250 ^ $1244;
        $1266 = ($1265|0)<(0);
        if ($1266) {
         $1267 = (___remdi3(($1241|0),($1244|0),($1247|0),($1250|0))|0);
         $1268 = tempRet0;
         $1269 = ($1267|0)!=(0);
         $1270 = ($1268|0)!=(0);
         $1271 = $1269 | $1270;
         $1272 = $1271 << 31 >> 31;
         $1273 = ($1272|0)<(0);
         $1274 = $1273 << 31 >> 31;
         $1275 = (_i64Add(($1272|0),($1274|0),($1263|0),($1264|0))|0);
         $1276 = tempRet0;
         $1279 = $1275;$1282 = $1276;
        } else {
         $1279 = $1263;$1282 = $1264;
        }
       }
       $1277 = $50;
       $1278 = $1277;
       HEAP32[$1278>>2] = $1279;
       $1280 = (($1277) + 4)|0;
       $1281 = $1280;
       HEAP32[$1281>>2] = $1282;
       $1283 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1283>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1235|0) == 3)) {
       $1284 = +HEAPF64[$1225>>3];
       $1347 = $1284;
       label = 297;
      } else {
       $1292 = $1235 & 15;
       $1293 = ($1292|0)==(4);
       if ($1293) {
        $1294 = HEAP32[$1225>>2]|0;
        $1295 = ((($1294)) + 24|0);
        $1296 = (_luaO_str2num($1295,$v$i125)|0);
        $1297 = HEAP32[$1225>>2]|0;
        $1298 = ((($1297)) + 12|0);
        $1299 = HEAP32[$1298>>2]|0;
        $1300 = (($1299) + 1)|0;
        $1301 = ($1296|0)==($1300|0);
        if ($1301) {
         $1302 = HEAP32[$16>>2]|0;
         $1303 = ($1302|0)==(19);
         $1304 = $v$i125;
         $1305 = $1304;
         $1306 = HEAP32[$1305>>2]|0;
         $1307 = (($1304) + 4)|0;
         $1308 = $1307;
         $1309 = HEAP32[$1308>>2]|0;
         $1310 = (+($1306>>>0)) + (4294967296.0*(+($1309|0)));
         HEAP32[tempDoublePtr>>2] = $1306;HEAP32[tempDoublePtr+4>>2] = $1309;$1311 = +HEAPF64[tempDoublePtr>>3];
         $1312 = $1303 ? $1310 : $1311;
         $$ph238 = $1312;
         label = 296;
         break;
        }
       }
      }
     } while(0);
     if ((label|0) == 296) {
      label = 0;
      $1347 = $$ph238;
      label = 297;
     }
     L393: do {
      if ((label|0) == 297) {
       label = 0;
       $1313 = ((($1233)) + 8|0);
       $1314 = HEAP32[$1313>>2]|0;
       $1315 = ($1314|0)==(3);
       if ($1315) {
        $1316 = +HEAPF64[$1233>>3];
        $1348 = $1316;
       } else {
        $1317 = ($1314|0)==(19);
        do {
         if ($1317) {
          $1318 = $1233;
          $1319 = $1318;
          $1320 = HEAP32[$1319>>2]|0;
          $1321 = (($1318) + 4)|0;
          $1322 = $1321;
          $1323 = HEAP32[$1322>>2]|0;
          $1324 = (+($1320>>>0)) + (4294967296.0*(+($1323|0)));
          $$ph241 = $1324;
         } else {
          $1325 = $1314 & 15;
          $1326 = ($1325|0)==(4);
          if ($1326) {
           $1327 = HEAP32[$1233>>2]|0;
           $1328 = ((($1327)) + 24|0);
           $1329 = (_luaO_str2num($1328,$v$i129)|0);
           $1330 = HEAP32[$1233>>2]|0;
           $1331 = ((($1330)) + 12|0);
           $1332 = HEAP32[$1331>>2]|0;
           $1333 = (($1332) + 1)|0;
           $1334 = ($1329|0)==($1333|0);
           if ($1334) {
            $1335 = HEAP32[$15>>2]|0;
            $1336 = ($1335|0)==(19);
            $1337 = $v$i129;
            $1338 = $1337;
            $1339 = HEAP32[$1338>>2]|0;
            $1340 = (($1337) + 4)|0;
            $1341 = $1340;
            $1342 = HEAP32[$1341>>2]|0;
            $1343 = (+($1339>>>0)) + (4294967296.0*(+($1342|0)));
            HEAP32[tempDoublePtr>>2] = $1339;HEAP32[tempDoublePtr+4>>2] = $1342;$1344 = +HEAPF64[tempDoublePtr>>3];
            $1345 = $1336 ? $1343 : $1344;
            $$ph241 = $1345;
            break;
           }
          }
          break L393;
         }
        } while(0);
        $1348 = $$ph241;
       }
       $1346 = $1347 / $1348;
       $1349 = (+Math_floor((+$1346)));
       HEAPF64[$50>>3] = $1349;
       $1350 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1350>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1225,$1233,$50,12);
     $1351 = HEAP32[$32>>2]|0;
     $base$0 = $1351;
     continue L3;
     break;
    }
    case 17:  {
     $1352 = $38 >>> 23;
     $1353 = $1352 & 256;
     $1354 = ($1353|0)==(0);
     $1355 = $1352 & 255;
     $1356 = (($31) + ($1355<<4)|0);
     $1357 = (($base$1) + ($1352<<4)|0);
     $1358 = $1354 ? $1357 : $1356;
     $1359 = $38 >>> 14;
     $1360 = $1359 & 256;
     $1361 = ($1360|0)==(0);
     $1362 = $1359 & 255;
     $1363 = (($31) + ($1362<<4)|0);
     $1364 = $1359 & 511;
     $1365 = (($base$1) + ($1364<<4)|0);
     $1366 = $1361 ? $1365 : $1363;
     $1367 = ((($1358)) + 8|0);
     $1368 = HEAP32[$1367>>2]|0;
     $1369 = ($1368|0)==(3);
     L409: do {
      if ($1369) {
       $1370 = +HEAPF64[$1358>>3];
       $1433 = $1370;
       label = 317;
      } else {
       $1371 = ($1368|0)==(19);
       do {
        if ($1371) {
         $1372 = $1358;
         $1373 = $1372;
         $1374 = HEAP32[$1373>>2]|0;
         $1375 = (($1372) + 4)|0;
         $1376 = $1375;
         $1377 = HEAP32[$1376>>2]|0;
         $1378 = (+($1374>>>0)) + (4294967296.0*(+($1377|0)));
         $$ph244 = $1378;
        } else {
         $1379 = $1368 & 15;
         $1380 = ($1379|0)==(4);
         if ($1380) {
          $1381 = HEAP32[$1358>>2]|0;
          $1382 = ((($1381)) + 24|0);
          $1383 = (_luaO_str2num($1382,$v$i133)|0);
          $1384 = HEAP32[$1358>>2]|0;
          $1385 = ((($1384)) + 12|0);
          $1386 = HEAP32[$1385>>2]|0;
          $1387 = (($1386) + 1)|0;
          $1388 = ($1383|0)==($1387|0);
          if ($1388) {
           $1389 = HEAP32[$18>>2]|0;
           $1390 = ($1389|0)==(19);
           $1391 = $v$i133;
           $1392 = $1391;
           $1393 = HEAP32[$1392>>2]|0;
           $1394 = (($1391) + 4)|0;
           $1395 = $1394;
           $1396 = HEAP32[$1395>>2]|0;
           $1397 = (+($1393>>>0)) + (4294967296.0*(+($1396|0)));
           HEAP32[tempDoublePtr>>2] = $1393;HEAP32[tempDoublePtr+4>>2] = $1396;$1398 = +HEAPF64[tempDoublePtr>>3];
           $1399 = $1390 ? $1397 : $1398;
           $$ph244 = $1399;
           break;
          }
         }
         break L409;
        }
       } while(0);
       $1433 = $$ph244;
       label = 317;
      }
     } while(0);
     L420: do {
      if ((label|0) == 317) {
       label = 0;
       $1400 = ((($1366)) + 8|0);
       $1401 = HEAP32[$1400>>2]|0;
       $1402 = ($1401|0)==(3);
       if ($1402) {
        $1403 = +HEAPF64[$1366>>3];
        $1434 = $1403;
       } else {
        $1404 = ($1401|0)==(19);
        do {
         if ($1404) {
          $1405 = $1366;
          $1406 = $1405;
          $1407 = HEAP32[$1406>>2]|0;
          $1408 = (($1405) + 4)|0;
          $1409 = $1408;
          $1410 = HEAP32[$1409>>2]|0;
          $1411 = (+($1407>>>0)) + (4294967296.0*(+($1410|0)));
          $$ph247 = $1411;
         } else {
          $1412 = $1401 & 15;
          $1413 = ($1412|0)==(4);
          if ($1413) {
           $1414 = HEAP32[$1366>>2]|0;
           $1415 = ((($1414)) + 24|0);
           $1416 = (_luaO_str2num($1415,$v$i137)|0);
           $1417 = HEAP32[$1366>>2]|0;
           $1418 = ((($1417)) + 12|0);
           $1419 = HEAP32[$1418>>2]|0;
           $1420 = (($1419) + 1)|0;
           $1421 = ($1416|0)==($1420|0);
           if ($1421) {
            $1422 = HEAP32[$17>>2]|0;
            $1423 = ($1422|0)==(19);
            $1424 = $v$i137;
            $1425 = $1424;
            $1426 = HEAP32[$1425>>2]|0;
            $1427 = (($1424) + 4)|0;
            $1428 = $1427;
            $1429 = HEAP32[$1428>>2]|0;
            $1430 = (+($1426>>>0)) + (4294967296.0*(+($1429|0)));
            HEAP32[tempDoublePtr>>2] = $1426;HEAP32[tempDoublePtr+4>>2] = $1429;$1431 = +HEAPF64[tempDoublePtr>>3];
            $1432 = $1423 ? $1430 : $1431;
            $$ph247 = $1432;
            break;
           }
          }
          break L420;
         }
        } while(0);
        $1434 = $$ph247;
       }
       $1435 = (+Math_pow((+$1433),(+$1434)));
       HEAPF64[$50>>3] = $1435;
       $1436 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1436>>2] = 3;
       $base$0 = $base$1;
       continue L3;
      }
     } while(0);
     _luaT_trybinTM($L,$1358,$1366,$50,10);
     $1437 = HEAP32[$32>>2]|0;
     $base$0 = $1437;
     continue L3;
     break;
    }
    case 25:  {
     $1438 = $38 >>> 23;
     $1439 = (($base$1) + ($1438<<4)|0);
     $1440 = (((($base$1) + ($1438<<4)|0)) + 8|0);
     $1441 = HEAP32[$1440>>2]|0;
     do {
      if ((($1441|0) == 19)) {
       $1442 = $1439;
       $1443 = $1442;
       $1444 = HEAP32[$1443>>2]|0;
       $1445 = (($1442) + 4)|0;
       $1446 = $1445;
       $1447 = HEAP32[$1446>>2]|0;
       $1448 = (_i64Subtract(0,0,($1444|0),($1447|0))|0);
       $1449 = tempRet0;
       $1450 = $50;
       $1451 = $1450;
       HEAP32[$1451>>2] = $1448;
       $1452 = (($1450) + 4)|0;
       $1453 = $1452;
       HEAP32[$1453>>2] = $1449;
       $1454 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$1454>>2] = 19;
       $base$0 = $base$1;
       continue L3;
      } else if ((($1441|0) == 3)) {
       $1455 = +HEAPF64[$1439>>3];
       $1478 = $1455;
      } else {
       $1456 = $1441 & 15;
       $1457 = ($1456|0)==(4);
       if ($1457) {
        $1458 = HEAP32[$1439>>2]|0;
        $1459 = ((($1458)) + 24|0);
        $1460 = (_luaO_str2num($1459,$v$i141)|0);
        $1461 = HEAP32[$1439>>2]|0;
        $1462 = ((($1461)) + 12|0);
        $1463 = HEAP32[$1462>>2]|0;
        $1464 = (($1463) + 1)|0;
        $1465 = ($1460|0)==($1464|0);
        if ($1465) {
         $1466 = HEAP32[$19>>2]|0;
         $1467 = ($1466|0)==(19);
         $1468 = $v$i141;
         $1469 = $1468;
         $1470 = HEAP32[$1469>>2]|0;
         $1471 = (($1468) + 4)|0;
         $1472 = $1471;
         $1473 = HEAP32[$1472>>2]|0;
         $1474 = (+($1470>>>0)) + (4294967296.0*(+($1473|0)));
         HEAP32[tempDoublePtr>>2] = $1470;HEAP32[tempDoublePtr+4>>2] = $1473;$1475 = +HEAPF64[tempDoublePtr>>3];
         $1476 = $1467 ? $1474 : $1475;
         $1478 = $1476;
         break;
        }
       }
       _luaT_trybinTM($L,$1439,$1439,$50,18);
       $1480 = HEAP32[$32>>2]|0;
       $base$0 = $1480;
       continue L3;
      }
     } while(0);
     $1477 = -$1478;
     HEAPF64[$50>>3] = $1477;
     $1479 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1479>>2] = 3;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 26:  {
     $1481 = $38 >>> 23;
     $1482 = (($base$1) + ($1481<<4)|0);
     $1483 = (((($base$1) + ($1481<<4)|0)) + 8|0);
     $1484 = HEAP32[$1483>>2]|0;
     $1485 = ($1484|0)==(19);
     do {
      if ($1485) {
       $1486 = $1482;
       $1487 = $1486;
       $1488 = HEAP32[$1487>>2]|0;
       $1489 = (($1486) + 4)|0;
       $1490 = $1489;
       $1491 = HEAP32[$1490>>2]|0;
       $1518 = $1488;$1520 = $1491;
      } else {
       $$02$i$i146 = $1482;
       while(1) {
        $1492 = ((($$02$i$i146)) + 8|0);
        $1493 = HEAP32[$1492>>2]|0;
        if ((($1493|0) == 3)) {
         $$02$i$i146$lcssa = $$02$i$i146;
         label = 340;
         break;
        } else if ((($1493|0) == 19)) {
         $$02$i$i146$lcssa941 = $$02$i$i146;
         label = 343;
         break;
        }
        $1507 = $1493 & 15;
        $1508 = ($1507|0)==(4);
        if (!($1508)) {
         label = 348;
         break;
        }
        $1509 = HEAP32[$$02$i$i146>>2]|0;
        $1510 = ((($1509)) + 24|0);
        $1511 = (_luaO_str2num($1510,$v$i$i145)|0);
        $1512 = HEAP32[$$02$i$i146>>2]|0;
        $1513 = ((($1512)) + 12|0);
        $1514 = HEAP32[$1513>>2]|0;
        $1515 = (($1514) + 1)|0;
        $1516 = ($1511|0)==($1515|0);
        if ($1516) {
         $$02$i$i146 = $v$i$i145;
        } else {
         label = 348;
         break;
        }
       }
       if ((label|0) == 340) {
        label = 0;
        $1494 = +HEAPF64[$$02$i$i146$lcssa>>3];
        $1495 = (+Math_floor((+$1494)));
        $1496 = $1494 != $1495;
        if ($1496) {
         label = 348;
        } else {
         $1497 = $1495 >= -9.2233720368547758E+18;
         $1498 = $1495 < 9.2233720368547758E+18;
         $or$cond$i$i147 = $1497 & $1498;
         if ($or$cond$i$i147) {
          $1499 = (~~$1495)>>>0;
          $1500 = +Math_abs($1495) >= 1.0 ? $1495 > 0.0 ? (~~+Math_min(+Math_floor($1495 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($1495 - +(~~$1495 >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2252 = $1499;$2253 = $1500;
          label = 346;
         } else {
          label = 348;
         }
        }
       }
       else if ((label|0) == 343) {
        label = 0;
        $1501 = $$02$i$i146$lcssa941;
        $1502 = $1501;
        $1503 = HEAP32[$1502>>2]|0;
        $1504 = (($1501) + 4)|0;
        $1505 = $1504;
        $1506 = HEAP32[$1505>>2]|0;
        $2252 = $1503;$2253 = $1506;
        label = 346;
       }
       if ((label|0) == 346) {
        label = 0;
        $1518 = $2252;$1520 = $2253;
        break;
       }
       else if ((label|0) == 348) {
        label = 0;
        _luaT_trybinTM($L,$1482,$1482,$50,19);
        $1526 = HEAP32[$32>>2]|0;
        $base$0 = $1526;
        continue L3;
       }
      }
     } while(0);
     $1517 = $1518 ^ -1;
     $1519 = $1520 ^ -1;
     $1521 = $50;
     $1522 = $1521;
     HEAP32[$1522>>2] = $1517;
     $1523 = (($1521) + 4)|0;
     $1524 = $1523;
     HEAP32[$1524>>2] = $1519;
     $1525 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1525>>2] = 19;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 27:  {
     $1527 = $38 >>> 23;
     $1528 = (((($base$1) + ($1527<<4)|0)) + 8|0);
     $1529 = HEAP32[$1528>>2]|0;
     $1530 = ($1529|0)==(0);
     if ($1530) {
      $1536 = 1;
     } else {
      $1531 = ($1529|0)==(1);
      if ($1531) {
       $1532 = (($base$1) + ($1527<<4)|0);
       $1533 = HEAP32[$1532>>2]|0;
       $1534 = ($1533|0)==(0);
       $1536 = $1534;
      } else {
       $1536 = 0;
      }
     }
     $1535 = $1536&1;
     HEAP32[$50>>2] = $1535;
     $1537 = (((($base$1) + ($49<<4)|0)) + 8|0);
     HEAP32[$1537>>2] = 1;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 30:  {
     $1560 = ($49|0)==(0);
     if (!($1560)) {
      $1561 = HEAP32[$32>>2]|0;
      $$sum31 = (($49) + -1)|0;
      $1562 = (($1561) + ($$sum31<<4)|0);
      _luaF_close($L,$1562);
     }
     $1563 = $38 >>> 14;
     $1564 = (($1563) + -131071)|0;
     $1565 = HEAP32[$34>>2]|0;
     $1566 = (($1565) + ($1564<<2)|0);
     HEAP32[$34>>2] = $1566;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 28:  {
     $1538 = $38 >>> 23;
     $1539 = (($base$1) + ($1538<<4)|0);
     _luaV_objlen($L,$50,$1539);
     $1540 = HEAP32[$32>>2]|0;
     $base$0 = $1540;
     continue L3;
     break;
    }
    case 29:  {
     $1541 = $38 >>> 23;
     $1542 = $38 >>> 14;
     $1543 = $1542 & 511;
     $$sum32 = (($1543) + 1)|0;
     $1544 = (($base$1) + ($$sum32<<4)|0);
     HEAP32[$4>>2] = $1544;
     $1545 = (1 - ($1541))|0;
     $1546 = (($1545) + ($1543))|0;
     _luaV_concat($L,$1546);
     $1547 = HEAP32[$32>>2]|0;
     $1548 = (($1547) + ($49<<4)|0);
     $1549 = (($1547) + ($1541<<4)|0);
     ;HEAP32[$1548>>2]=HEAP32[$1549>>2]|0;HEAP32[$1548+4>>2]=HEAP32[$1549+4>>2]|0;HEAP32[$1548+8>>2]=HEAP32[$1549+8>>2]|0;HEAP32[$1548+12>>2]=HEAP32[$1549+12>>2]|0;
     $1550 = HEAP32[$3>>2]|0;
     $1551 = ((($1550)) + 12|0);
     $1552 = HEAP32[$1551>>2]|0;
     $1553 = ($1552|0)>(0);
     if ($1553) {
      $1554 = ($49>>>0)>=($1541>>>0);
      $$sum33 = (($49) + 1)|0;
      $1555 = (($1547) + ($$sum33<<4)|0);
      $1556 = $1554 ? $1555 : $1549;
      HEAP32[$4>>2] = $1556;
      _luaC_step($L);
      $1557 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $1557;
      $1559 = $1557;
     } else {
      $$pre731 = HEAP32[$35>>2]|0;
      $1559 = $$pre731;
     }
     $1558 = HEAP32[$32>>2]|0;
     HEAP32[$4>>2] = $1559;
     $base$0 = $1558;
     continue L3;
     break;
    }
    case 32:  {
     $1597 = $38 >>> 23;
     $1598 = $1597 & 256;
     $1599 = ($1598|0)==(0);
     $1600 = $1597 & 255;
     $1601 = (($31) + ($1600<<4)|0);
     $1602 = (($base$1) + ($1597<<4)|0);
     $1603 = $1599 ? $1602 : $1601;
     $1604 = $38 >>> 14;
     $1605 = $1604 & 256;
     $1606 = ($1605|0)==(0);
     $1607 = $1604 & 255;
     $1608 = (($31) + ($1607<<4)|0);
     $1609 = $1604 & 511;
     $1610 = (($base$1) + ($1609<<4)|0);
     $1611 = $1606 ? $1610 : $1608;
     $1612 = (_luaV_lessthan($L,$1603,$1611)|0);
     $1613 = ($1612|0)==($49|0);
     $1614 = HEAP32[$34>>2]|0;
     if ($1613) {
      $1616 = HEAP32[$1614>>2]|0;
      $1617 = $1616 >>> 6;
      $1618 = $1617 & 255;
      $1619 = ($1618|0)==(0);
      if ($1619) {
       $1625 = $1614;
      } else {
       $1620 = HEAP32[$32>>2]|0;
       $$sum28 = (($1618) + -1)|0;
       $1621 = (($1620) + ($$sum28<<4)|0);
       _luaF_close($L,$1621);
       $$pre728 = HEAP32[$34>>2]|0;
       $1625 = $$pre728;
      }
      $1622 = $1616 >>> 14;
      $1623 = (($1622) + -131070)|0;
      $1624 = (($1625) + ($1623<<2)|0);
      $storemerge27 = $1624;
     } else {
      $1615 = ((($1614)) + 4|0);
      $storemerge27 = $1615;
     }
     HEAP32[$34>>2] = $storemerge27;
     $1626 = HEAP32[$32>>2]|0;
     $base$0 = $1626;
     continue L3;
     break;
    }
    case 31:  {
     $1567 = $38 >>> 23;
     $1568 = $1567 & 256;
     $1569 = ($1568|0)==(0);
     $1570 = $1567 & 255;
     $1571 = (($31) + ($1570<<4)|0);
     $1572 = (($base$1) + ($1567<<4)|0);
     $1573 = $1569 ? $1572 : $1571;
     $1574 = $38 >>> 14;
     $1575 = $1574 & 256;
     $1576 = ($1575|0)==(0);
     $1577 = $1574 & 255;
     $1578 = (($31) + ($1577<<4)|0);
     $1579 = $1574 & 511;
     $1580 = (($base$1) + ($1579<<4)|0);
     $1581 = $1576 ? $1580 : $1578;
     $1582 = (_luaV_equalobj($L,$1573,$1581)|0);
     $1583 = ($1582|0)==($49|0);
     $1584 = HEAP32[$34>>2]|0;
     if ($1583) {
      $1586 = HEAP32[$1584>>2]|0;
      $1587 = $1586 >>> 6;
      $1588 = $1587 & 255;
      $1589 = ($1588|0)==(0);
      if ($1589) {
       $1595 = $1584;
      } else {
       $1590 = HEAP32[$32>>2]|0;
       $$sum30 = (($1588) + -1)|0;
       $1591 = (($1590) + ($$sum30<<4)|0);
       _luaF_close($L,$1591);
       $$pre729 = HEAP32[$34>>2]|0;
       $1595 = $$pre729;
      }
      $1592 = $1586 >>> 14;
      $1593 = (($1592) + -131070)|0;
      $1594 = (($1595) + ($1593<<2)|0);
      $storemerge29 = $1594;
     } else {
      $1585 = ((($1584)) + 4|0);
      $storemerge29 = $1585;
     }
     HEAP32[$34>>2] = $storemerge29;
     $1596 = HEAP32[$32>>2]|0;
     $base$0 = $1596;
     continue L3;
     break;
    }
    case 33:  {
     $1627 = $38 >>> 23;
     $1628 = $1627 & 256;
     $1629 = ($1628|0)==(0);
     $1630 = $1627 & 255;
     $1631 = (($31) + ($1630<<4)|0);
     $1632 = (($base$1) + ($1627<<4)|0);
     $1633 = $1629 ? $1632 : $1631;
     $1634 = $38 >>> 14;
     $1635 = $1634 & 256;
     $1636 = ($1635|0)==(0);
     $1637 = $1634 & 255;
     $1638 = (($31) + ($1637<<4)|0);
     $1639 = $1634 & 511;
     $1640 = (($base$1) + ($1639<<4)|0);
     $1641 = $1636 ? $1640 : $1638;
     $1642 = (_luaV_lessequal($L,$1633,$1641)|0);
     $1643 = ($1642|0)==($49|0);
     $1644 = HEAP32[$34>>2]|0;
     if ($1643) {
      $1646 = HEAP32[$1644>>2]|0;
      $1647 = $1646 >>> 6;
      $1648 = $1647 & 255;
      $1649 = ($1648|0)==(0);
      if ($1649) {
       $1655 = $1644;
      } else {
       $1650 = HEAP32[$32>>2]|0;
       $$sum26 = (($1648) + -1)|0;
       $1651 = (($1650) + ($$sum26<<4)|0);
       _luaF_close($L,$1651);
       $$pre727 = HEAP32[$34>>2]|0;
       $1655 = $$pre727;
      }
      $1652 = $1646 >>> 14;
      $1653 = (($1652) + -131070)|0;
      $1654 = (($1655) + ($1653<<2)|0);
      $storemerge25 = $1654;
     } else {
      $1645 = ((($1644)) + 4|0);
      $storemerge25 = $1645;
     }
     HEAP32[$34>>2] = $storemerge25;
     $1656 = HEAP32[$32>>2]|0;
     $base$0 = $1656;
     continue L3;
     break;
    }
    case 34:  {
     $1657 = $38 & 8372224;
     $1658 = ($1657|0)==(0);
     $1659 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1660 = HEAP32[$1659>>2]|0;
     $1661 = ($1660|0)==(0);
     if ($1658) {
      if (!($1661)) {
       $1665 = ($1660|0)==(1);
       if ($1665) {
        $1666 = HEAP32[$50>>2]|0;
        $1667 = ($1666|0)==(0);
        if (!($1667)) {
         label = 386;
        }
       } else {
        label = 386;
       }
      }
     } else {
      if ($1661) {
       label = 386;
      } else {
       $1662 = ($1660|0)==(1);
       if ($1662) {
        $1663 = HEAP32[$50>>2]|0;
        $1664 = ($1663|0)==(0);
        if ($1664) {
         label = 386;
        }
       }
      }
     }
     if ((label|0) == 386) {
      label = 0;
      $1668 = HEAP32[$34>>2]|0;
      $1669 = ((($1668)) + 4|0);
      HEAP32[$34>>2] = $1669;
      $base$0 = $base$1;
      continue L3;
     }
     $1670 = HEAP32[$34>>2]|0;
     $1671 = HEAP32[$1670>>2]|0;
     $1672 = $1671 >>> 6;
     $1673 = $1672 & 255;
     $1674 = ($1673|0)==(0);
     if ($1674) {
      $1680 = $1670;
     } else {
      $1675 = HEAP32[$32>>2]|0;
      $$sum24 = (($1673) + -1)|0;
      $1676 = (($1675) + ($$sum24<<4)|0);
      _luaF_close($L,$1676);
      $$pre726 = HEAP32[$34>>2]|0;
      $1680 = $$pre726;
     }
     $1677 = $1671 >>> 14;
     $1678 = (($1677) + -131070)|0;
     $1679 = (($1680) + ($1678<<2)|0);
     HEAP32[$34>>2] = $1679;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 35:  {
     $1681 = $38 >>> 23;
     $1682 = (($base$1) + ($1681<<4)|0);
     $1683 = $38 & 8372224;
     $1684 = ($1683|0)==(0);
     $1685 = (((($base$1) + ($1681<<4)|0)) + 8|0);
     $1686 = HEAP32[$1685>>2]|0;
     $1687 = ($1686|0)==(0);
     if ($1684) {
      if (!($1687)) {
       $1691 = ($1686|0)==(1);
       if ($1691) {
        $1692 = HEAP32[$1682>>2]|0;
        $1693 = ($1692|0)==(0);
        if (!($1693)) {
         label = 397;
        }
       } else {
        label = 397;
       }
      }
     } else {
      if ($1687) {
       label = 397;
      } else {
       $1688 = ($1686|0)==(1);
       if ($1688) {
        $1689 = HEAP32[$1682>>2]|0;
        $1690 = ($1689|0)==(0);
        if ($1690) {
         label = 397;
        }
       }
      }
     }
     if ((label|0) == 397) {
      label = 0;
      $1694 = HEAP32[$34>>2]|0;
      $1695 = ((($1694)) + 4|0);
      HEAP32[$34>>2] = $1695;
      $base$0 = $base$1;
      continue L3;
     }
     ;HEAP32[$50>>2]=HEAP32[$1682>>2]|0;HEAP32[$50+4>>2]=HEAP32[$1682+4>>2]|0;HEAP32[$50+8>>2]=HEAP32[$1682+8>>2]|0;HEAP32[$50+12>>2]=HEAP32[$1682+12>>2]|0;
     $1696 = HEAP32[$34>>2]|0;
     $1697 = HEAP32[$1696>>2]|0;
     $1698 = $1697 >>> 6;
     $1699 = $1698 & 255;
     $1700 = ($1699|0)==(0);
     if ($1700) {
      $1706 = $1696;
     } else {
      $1701 = HEAP32[$32>>2]|0;
      $$sum23 = (($1699) + -1)|0;
      $1702 = (($1701) + ($$sum23<<4)|0);
      _luaF_close($L,$1702);
      $$pre725 = HEAP32[$34>>2]|0;
      $1706 = $$pre725;
     }
     $1703 = $1697 >>> 14;
     $1704 = (($1703) + -131070)|0;
     $1705 = (($1706) + ($1704<<2)|0);
     HEAP32[$34>>2] = $1705;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 37:  {
     $1724 = $38 >>> 23;
     $1725 = ($1724|0)==(0);
     if (!($1725)) {
      $$sum21 = (($49) + ($1724))|0;
      $1726 = (($base$1) + ($$sum21<<4)|0);
      HEAP32[$4>>2] = $1726;
     }
     $1727 = (_luaD_precall($L,$50,-1)|0);
     $1728 = ($1727|0)==(0);
     if ($1728) {
      label = 412;
      break L3;
     }
     $1729 = HEAP32[$32>>2]|0;
     $base$0 = $1729;
     continue L3;
     break;
    }
    case 36:  {
     $1707 = $38 >>> 23;
     $1708 = $38 >>> 14;
     $1709 = $1708 & 511;
     $1710 = (($1709) + -1)|0;
     $1711 = ($1707|0)==(0);
     if (!($1711)) {
      $$sum22 = (($49) + ($1707))|0;
      $1712 = (($base$1) + ($$sum22<<4)|0);
      HEAP32[$4>>2] = $1712;
     }
     $1713 = (_luaD_precall($L,$50,$1710)|0);
     $1714 = ($1713|0)==(0);
     if ($1714) {
      label = 407;
      break L3;
     }
     $1715 = ($1709|0)==(0);
     if (!($1715)) {
      $1716 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $1716;
     }
     $1717 = HEAP32[$32>>2]|0;
     $base$0 = $1717;
     continue L3;
     break;
    }
    case 38:  {
     $$lcssa = $38;$$lcssa977 = $49;$$lcssa985 = $50;$base$1$lcssa = $base$1;
     label = 417;
     break L3;
     break;
    }
    case 39:  {
     $1793 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1794 = HEAP32[$1793>>2]|0;
     $1795 = ($1794|0)==(19);
     $$sum14 = (($49) + 2)|0;
     $1796 = (($base$1) + ($$sum14<<4)|0);
     if ($1795) {
      $1797 = $1796;
      $1798 = $1797;
      $1799 = HEAP32[$1798>>2]|0;
      $1800 = (($1797) + 4)|0;
      $1801 = $1800;
      $1802 = HEAP32[$1801>>2]|0;
      $1803 = $50;
      $1804 = $1803;
      $1805 = HEAP32[$1804>>2]|0;
      $1806 = (($1803) + 4)|0;
      $1807 = $1806;
      $1808 = HEAP32[$1807>>2]|0;
      $1809 = (_i64Add(($1805|0),($1808|0),($1799|0),($1802|0))|0);
      $1810 = tempRet0;
      $$sum17 = (($49) + 1)|0;
      $1811 = (($base$1) + ($$sum17<<4)|0);
      $1812 = $1811;
      $1813 = $1812;
      $1814 = HEAP32[$1813>>2]|0;
      $1815 = (($1812) + 4)|0;
      $1816 = $1815;
      $1817 = HEAP32[$1816>>2]|0;
      $1818 = ($1802|0)>(0);
      $1819 = ($1799>>>0)>(0);
      $1820 = ($1802|0)==(0);
      $1821 = $1820 & $1819;
      $1822 = $1818 | $1821;
      if ($1822) {
       $1823 = ($1810|0)>($1817|0);
       $1824 = ($1809>>>0)>($1814>>>0);
       $1825 = ($1810|0)==($1817|0);
       $1826 = $1825 & $1824;
       $1827 = $1823 | $1826;
       if ($1827) {
        $base$0 = $base$1;
        continue L3;
       }
      } else {
       $1828 = ($1817|0)>($1810|0);
       $1829 = ($1814>>>0)>($1809>>>0);
       $1830 = ($1817|0)==($1810|0);
       $1831 = $1830 & $1829;
       $1832 = $1828 | $1831;
       if ($1832) {
        $base$0 = $base$1;
        continue L3;
       }
      }
      $1833 = $38 >>> 14;
      $1834 = (($1833) + -131071)|0;
      $1835 = HEAP32[$34>>2]|0;
      $1836 = (($1835) + ($1834<<2)|0);
      HEAP32[$34>>2] = $1836;
      $1837 = $50;
      $1838 = $1837;
      HEAP32[$1838>>2] = $1809;
      $1839 = (($1837) + 4)|0;
      $1840 = $1839;
      HEAP32[$1840>>2] = $1810;
      HEAP32[$1793>>2] = 19;
      $$sum18 = (($49) + 3)|0;
      $1841 = (($base$1) + ($$sum18<<4)|0);
      $1842 = $1841;
      $1843 = $1842;
      HEAP32[$1843>>2] = $1809;
      $1844 = (($1842) + 4)|0;
      $1845 = $1844;
      HEAP32[$1845>>2] = $1810;
      $1846 = (((($base$1) + ($$sum18<<4)|0)) + 8|0);
      HEAP32[$1846>>2] = 19;
      $base$0 = $base$1;
      continue L3;
     } else {
      $1847 = +HEAPF64[$1796>>3];
      $1848 = +HEAPF64[$50>>3];
      $1849 = $1847 + $1848;
      $$sum15 = (($49) + 1)|0;
      $1850 = (($base$1) + ($$sum15<<4)|0);
      $1851 = +HEAPF64[$1850>>3];
      $1852 = $1847 > 0.0;
      if ($1852) {
       $1853 = !($1849 <= $1851);
       if ($1853) {
        $base$0 = $base$1;
        continue L3;
       }
      } else {
       $1854 = !($1851 <= $1849);
       if ($1854) {
        $base$0 = $base$1;
        continue L3;
       }
      }
      $1855 = $38 >>> 14;
      $1856 = (($1855) + -131071)|0;
      $1857 = HEAP32[$34>>2]|0;
      $1858 = (($1857) + ($1856<<2)|0);
      HEAP32[$34>>2] = $1858;
      HEAPF64[$50>>3] = $1849;
      HEAP32[$1793>>2] = 3;
      $$sum16 = (($49) + 3)|0;
      $1859 = (($base$1) + ($$sum16<<4)|0);
      HEAPF64[$1859>>3] = $1849;
      $1860 = (((($base$1) + ($$sum16<<4)|0)) + 8|0);
      HEAP32[$1860>>2] = 3;
      $base$0 = $base$1;
      continue L3;
     }
     break;
    }
    case 40:  {
     $$sum12 = (($49) + 1)|0;
     $1861 = (($base$1) + ($$sum12<<4)|0);
     $$sum13 = (($49) + 2)|0;
     $1862 = (($base$1) + ($$sum13<<4)|0);
     $1863 = (((($base$1) + ($49<<4)|0)) + 8|0);
     $1864 = HEAP32[$1863>>2]|0;
     $1865 = ($1864|0)==(19);
     L555: do {
      if ($1865) {
       $1866 = (((($base$1) + ($$sum13<<4)|0)) + 8|0);
       $1867 = HEAP32[$1866>>2]|0;
       $1868 = ($1867|0)==(19);
       if ($1868) {
        $1869 = $1862;
        $1870 = $1869;
        $1871 = HEAP32[$1870>>2]|0;
        $1872 = (($1869) + 4)|0;
        $1873 = $1872;
        $1874 = HEAP32[$1873>>2]|0;
        $1875 = ($1874|0)<(0);
        $$02$i$i151 = $1861;
        while(1) {
         $1876 = ((($$02$i$i151)) + 8|0);
         $1877 = HEAP32[$1876>>2]|0;
         if ((($1877|0) == 3)) {
          $$02$i$i151$lcssa = $$02$i$i151;
          label = 438;
          break;
         } else if ((($1877|0) == 19)) {
          $$02$i$i151$lcssa939 = $$02$i$i151;
          label = 440;
          break;
         }
         $1893 = $1877 & 15;
         $1894 = ($1893|0)==(4);
         if (!($1894)) {
          label = 444;
          break;
         }
         $1895 = HEAP32[$$02$i$i151>>2]|0;
         $1896 = ((($1895)) + 24|0);
         $1897 = (_luaO_str2num($1896,$v$i$i150)|0);
         $1898 = HEAP32[$$02$i$i151>>2]|0;
         $1899 = ((($1898)) + 12|0);
         $1900 = HEAP32[$1899>>2]|0;
         $1901 = (($1900) + 1)|0;
         $1902 = ($1897|0)==($1901|0);
         if ($1902) {
          $$02$i$i151 = $v$i$i150;
         } else {
          label = 444;
          break;
         }
        }
        if ((label|0) == 438) {
         label = 0;
         $1878 = +HEAPF64[$$02$i$i151$lcssa>>3];
         $1879 = (+Math_floor((+$1878)));
         $1880 = $1878 != $1879;
         $1881 = $1879 + 1.0;
         $1882 = $1875 & $1880;
         $f$0$i$i = $1882 ? $1881 : $1879;
         $1883 = $f$0$i$i >= -9.2233720368547758E+18;
         $1884 = $f$0$i$i < 9.2233720368547758E+18;
         $or$cond$i$i152 = $1883 & $1884;
         if ($or$cond$i$i152) {
          $1885 = (~~$f$0$i$i)>>>0;
          $1886 = +Math_abs($f$0$i$i) >= 1.0 ? $f$0$i$i > 0.0 ? (~~+Math_min(+Math_floor($f$0$i$i / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($f$0$i$i - +(~~$f$0$i$i >>> 0)) / 4294967296.0) >>> 0 : 0;
          $2254 = $1885;$2255 = $1886;
          label = 443;
         } else {
          label = 444;
         }
        }
        else if ((label|0) == 440) {
         label = 0;
         $1887 = $$02$i$i151$lcssa939;
         $1888 = $1887;
         $1889 = HEAP32[$1888>>2]|0;
         $1890 = (($1887) + 4)|0;
         $1891 = $1890;
         $1892 = HEAP32[$1891>>2]|0;
         $2254 = $1889;$2255 = $1892;
         label = 443;
        }
        do {
         if ((label|0) == 443) {
          label = 0;
          $$pre763 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
          $$pre762$pre$phiZZ2D = $$pre763;$2256 = $2254;$2257 = $2255;
          label = 456;
         }
         else if ((label|0) == 444) {
          label = 0;
          $1903 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
          $1904 = HEAP32[$1903>>2]|0;
          $1905 = ($1904|0)==(3);
          if ($1905) {
           $1906 = +HEAPF64[$1861>>3];
           $1937 = $1906;
          } else {
           $1907 = ($1904|0)==(19);
           do {
            if ($1907) {
             $1908 = $1861;
             $1909 = $1908;
             $1910 = HEAP32[$1909>>2]|0;
             $1911 = (($1908) + 4)|0;
             $1912 = $1911;
             $1913 = HEAP32[$1912>>2]|0;
             $1914 = (+($1910>>>0)) + (4294967296.0*(+($1913|0)));
             $$ph$i = $1914;
            } else {
             $1915 = $1904 & 15;
             $1916 = ($1915|0)==(4);
             if ($1916) {
              $1917 = HEAP32[$1861>>2]|0;
              $1918 = ((($1917)) + 24|0);
              $1919 = (_luaO_str2num($1918,$v$i1$i)|0);
              $1920 = HEAP32[$1861>>2]|0;
              $1921 = ((($1920)) + 12|0);
              $1922 = HEAP32[$1921>>2]|0;
              $1923 = (($1922) + 1)|0;
              $1924 = ($1919|0)==($1923|0);
              if ($1924) {
               $1925 = HEAP32[$20>>2]|0;
               $1926 = ($1925|0)==(19);
               $1927 = $v$i1$i;
               $1928 = $1927;
               $1929 = HEAP32[$1928>>2]|0;
               $1930 = (($1927) + 4)|0;
               $1931 = $1930;
               $1932 = HEAP32[$1931>>2]|0;
               $1933 = (+($1929>>>0)) + (4294967296.0*(+($1932|0)));
               HEAP32[tempDoublePtr>>2] = $1929;HEAP32[tempDoublePtr+4>>2] = $1932;$1934 = +HEAPF64[tempDoublePtr>>3];
               $1935 = $1926 ? $1933 : $1934;
               $$ph$i = $1935;
               break;
              }
             }
             label = 458;
             break L555;
            }
           } while(0);
           $1937 = $$ph$i;
          }
          $1936 = $1937 > 0.0;
          if ($1936) {
           if ($1875) {
            $$pre$phiZ2D = $1903;$1951 = -1;$1954 = 2147483647;$1961 = 0;$1962 = 0;
            break;
           } else {
            $$pre762$pre$phiZZ2D = $1903;$2256 = -1;$2257 = 2147483647;
            label = 456;
            break;
           }
          } else {
           $1938 = ($1874|0)>(-1);
           $1939 = ($1871>>>0)>(4294967295);
           $1940 = ($1874|0)==(-1);
           $1941 = $1940 & $1939;
           $1942 = $1938 | $1941;
           if ($1942) {
            $$pre$phiZ2D = $1903;$1951 = 0;$1954 = -2147483648;$1961 = 0;$1962 = 0;
            break;
           } else {
            $$pre762$pre$phiZZ2D = $1903;$2256 = 0;$2257 = -2147483648;
            label = 456;
            break;
           }
          }
         }
        } while(0);
        if ((label|0) == 456) {
         label = 0;
         $1943 = $50;
         $1944 = $1943;
         $1945 = HEAP32[$1944>>2]|0;
         $1946 = (($1943) + 4)|0;
         $1947 = $1946;
         $1948 = HEAP32[$1947>>2]|0;
         $$pre$phiZ2D = $$pre762$pre$phiZZ2D;$1951 = $2256;$1954 = $2257;$1961 = $1945;$1962 = $1948;
        }
        $1949 = $1861;
        $1950 = $1949;
        HEAP32[$1950>>2] = $1951;
        $1952 = (($1949) + 4)|0;
        $1953 = $1952;
        HEAP32[$1953>>2] = $1954;
        HEAP32[$$pre$phiZ2D>>2] = 19;
        $1955 = $1862;
        $1956 = $1955;
        $1957 = HEAP32[$1956>>2]|0;
        $1958 = (($1955) + 4)|0;
        $1959 = $1958;
        $1960 = HEAP32[$1959>>2]|0;
        $1963 = (_i64Subtract(($1961|0),($1962|0),($1957|0),($1960|0))|0);
        $1964 = tempRet0;
        $1965 = $50;
        $1966 = $1965;
        HEAP32[$1966>>2] = $1963;
        $1967 = (($1965) + 4)|0;
        $1968 = $1967;
        HEAP32[$1968>>2] = $1964;
        $storemerge = 19;
       } else {
        label = 458;
       }
      } else {
       label = 458;
      }
     } while(0);
     if ((label|0) == 458) {
      label = 0;
      $1969 = (((($base$1) + ($$sum12<<4)|0)) + 8|0);
      $1970 = HEAP32[$1969>>2]|0;
      $1971 = ($1970|0)==(3);
      if ($1971) {
       $1972 = +HEAPF64[$1861>>3];
       $$pre$phi765Z2D = $1861;$2002 = $1972;
      } else {
       $1973 = ($1970|0)==(19);
       if ($1973) {
        $1974 = $1861;
        $1975 = $1974;
        $1976 = HEAP32[$1975>>2]|0;
        $1977 = (($1974) + 4)|0;
        $1978 = $1977;
        $1979 = HEAP32[$1978>>2]|0;
        $1980 = (+($1976>>>0)) + (4294967296.0*(+($1979|0)));
        $$ph263 = $1980;
       } else {
        $1981 = $1970 & 15;
        $1982 = ($1981|0)==(4);
        if (!($1982)) {
         label = 466;
         break L1;
        }
        $1983 = HEAP32[$1861>>2]|0;
        $1984 = ((($1983)) + 24|0);
        $1985 = (_luaO_str2num($1984,$v$i154)|0);
        $1986 = HEAP32[$1861>>2]|0;
        $1987 = ((($1986)) + 12|0);
        $1988 = HEAP32[$1987>>2]|0;
        $1989 = (($1988) + 1)|0;
        $1990 = ($1985|0)==($1989|0);
        if (!($1990)) {
         label = 466;
         break L1;
        }
        $1991 = HEAP32[$23>>2]|0;
        $1992 = ($1991|0)==(19);
        $1993 = $v$i154;
        $1994 = $1993;
        $1995 = HEAP32[$1994>>2]|0;
        $1996 = (($1993) + 4)|0;
        $1997 = $1996;
        $1998 = HEAP32[$1997>>2]|0;
        $1999 = (+($1995>>>0)) + (4294967296.0*(+($1998|0)));
        HEAP32[tempDoublePtr>>2] = $1995;HEAP32[tempDoublePtr+4>>2] = $1998;$2000 = +HEAPF64[tempDoublePtr>>3];
        $2001 = $1992 ? $1999 : $2000;
        $$ph263 = $2001;
       }
       $$pre$phi765Z2D = $1861;$2002 = $$ph263;
      }
      HEAPF64[$$pre$phi765Z2D>>3] = $2002;
      HEAP32[$1969>>2] = 3;
      $2003 = (((($base$1) + ($$sum13<<4)|0)) + 8|0);
      $2004 = HEAP32[$2003>>2]|0;
      $2005 = ($2004|0)==(3);
      if ($2005) {
       $2006 = +HEAPF64[$1862>>3];
       $$pre$phi767Z2D = $1862;$2036 = $2006;
      } else {
       $2007 = ($2004|0)==(19);
       if ($2007) {
        $2008 = $1862;
        $2009 = $2008;
        $2010 = HEAP32[$2009>>2]|0;
        $2011 = (($2008) + 4)|0;
        $2012 = $2011;
        $2013 = HEAP32[$2012>>2]|0;
        $2014 = (+($2010>>>0)) + (4294967296.0*(+($2013|0)));
        $$ph266 = $2014;
       } else {
        $2015 = $2004 & 15;
        $2016 = ($2015|0)==(4);
        if (!($2016)) {
         label = 475;
         break L1;
        }
        $2017 = HEAP32[$1862>>2]|0;
        $2018 = ((($2017)) + 24|0);
        $2019 = (_luaO_str2num($2018,$v$i158)|0);
        $2020 = HEAP32[$1862>>2]|0;
        $2021 = ((($2020)) + 12|0);
        $2022 = HEAP32[$2021>>2]|0;
        $2023 = (($2022) + 1)|0;
        $2024 = ($2019|0)==($2023|0);
        if (!($2024)) {
         label = 475;
         break L1;
        }
        $2025 = HEAP32[$22>>2]|0;
        $2026 = ($2025|0)==(19);
        $2027 = $v$i158;
        $2028 = $2027;
        $2029 = HEAP32[$2028>>2]|0;
        $2030 = (($2027) + 4)|0;
        $2031 = $2030;
        $2032 = HEAP32[$2031>>2]|0;
        $2033 = (+($2029>>>0)) + (4294967296.0*(+($2032|0)));
        HEAP32[tempDoublePtr>>2] = $2029;HEAP32[tempDoublePtr+4>>2] = $2032;$2034 = +HEAPF64[tempDoublePtr>>3];
        $2035 = $2026 ? $2033 : $2034;
        $$ph266 = $2035;
       }
       $$pre$phi767Z2D = $1862;$2036 = $$ph266;
      }
      HEAPF64[$$pre$phi767Z2D>>3] = $2036;
      HEAP32[$2003>>2] = 3;
      $2037 = HEAP32[$1863>>2]|0;
      $2038 = ($2037|0)==(3);
      if ($2038) {
       $2039 = +HEAPF64[$50>>3];
       $$pre$phi769Z2D = $50;$2070 = $2039;
      } else {
       $2040 = ($2037|0)==(19);
       if ($2040) {
        $2041 = $50;
        $2042 = $2041;
        $2043 = HEAP32[$2042>>2]|0;
        $2044 = (($2041) + 4)|0;
        $2045 = $2044;
        $2046 = HEAP32[$2045>>2]|0;
        $2047 = (+($2043>>>0)) + (4294967296.0*(+($2046|0)));
        $$ph269 = $2047;
       } else {
        $2048 = $2037 & 15;
        $2049 = ($2048|0)==(4);
        if (!($2049)) {
         label = 484;
         break L1;
        }
        $2050 = HEAP32[$50>>2]|0;
        $2051 = ((($2050)) + 24|0);
        $2052 = (_luaO_str2num($2051,$v$i162)|0);
        $2053 = HEAP32[$50>>2]|0;
        $2054 = ((($2053)) + 12|0);
        $2055 = HEAP32[$2054>>2]|0;
        $2056 = (($2055) + 1)|0;
        $2057 = ($2052|0)==($2056|0);
        if (!($2057)) {
         label = 484;
         break L1;
        }
        $2058 = HEAP32[$21>>2]|0;
        $2059 = ($2058|0)==(19);
        $2060 = $v$i162;
        $2061 = $2060;
        $2062 = HEAP32[$2061>>2]|0;
        $2063 = (($2060) + 4)|0;
        $2064 = $2063;
        $2065 = HEAP32[$2064>>2]|0;
        $2066 = (+($2062>>>0)) + (4294967296.0*(+($2065|0)));
        HEAP32[tempDoublePtr>>2] = $2062;HEAP32[tempDoublePtr+4>>2] = $2065;$2067 = +HEAPF64[tempDoublePtr>>3];
        $2068 = $2059 ? $2066 : $2067;
        $$ph269 = $2068;
       }
       $$pre$phi769Z2D = $50;$2070 = $$ph269;
      }
      $2069 = $2070 - $2036;
      HEAPF64[$$pre$phi769Z2D>>3] = $2069;
      $storemerge = 3;
     }
     HEAP32[$1863>>2] = $storemerge;
     $2071 = $38 >>> 14;
     $2072 = (($2071) + -131071)|0;
     $2073 = HEAP32[$34>>2]|0;
     $2074 = (($2073) + ($2072<<2)|0);
     HEAP32[$34>>2] = $2074;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 41:  {
     $$sum6 = (($49) + 3)|0;
     $2075 = (($base$1) + ($$sum6<<4)|0);
     $$sum7 = (($49) + 5)|0;
     $2076 = (($base$1) + ($$sum7<<4)|0);
     $$sum8 = (($49) + 2)|0;
     $2077 = (($base$1) + ($$sum8<<4)|0);
     ;HEAP32[$2076>>2]=HEAP32[$2077>>2]|0;HEAP32[$2076+4>>2]=HEAP32[$2077+4>>2]|0;HEAP32[$2076+8>>2]=HEAP32[$2077+8>>2]|0;HEAP32[$2076+12>>2]=HEAP32[$2077+12>>2]|0;
     $$sum9 = (($49) + 4)|0;
     $2078 = (($base$1) + ($$sum9<<4)|0);
     $$sum10 = (($49) + 1)|0;
     $2079 = (($base$1) + ($$sum10<<4)|0);
     ;HEAP32[$2078>>2]=HEAP32[$2079>>2]|0;HEAP32[$2078+4>>2]=HEAP32[$2079+4>>2]|0;HEAP32[$2078+8>>2]=HEAP32[$2079+8>>2]|0;HEAP32[$2078+12>>2]=HEAP32[$2079+12>>2]|0;
     ;HEAP32[$2075>>2]=HEAP32[$50>>2]|0;HEAP32[$2075+4>>2]=HEAP32[$50+4>>2]|0;HEAP32[$2075+8>>2]=HEAP32[$50+8>>2]|0;HEAP32[$2075+12>>2]=HEAP32[$50+12>>2]|0;
     $$sum11 = (($49) + 6)|0;
     $2080 = (($base$1) + ($$sum11<<4)|0);
     HEAP32[$4>>2] = $2080;
     $2081 = $38 >>> 14;
     $2082 = $2081 & 511;
     _luaD_call($L,$2075,$2082,1);
     $2083 = HEAP32[$32>>2]|0;
     $2084 = HEAP32[$35>>2]|0;
     HEAP32[$4>>2] = $2084;
     $2085 = HEAP32[$34>>2]|0;
     $2086 = ((($2085)) + 4|0);
     HEAP32[$34>>2] = $2086;
     $2087 = HEAP32[$2085>>2]|0;
     $2088 = $2087 >>> 6;
     $2089 = $2088 & 255;
     $2090 = (($2083) + ($2089<<4)|0);
     $base$2 = $2083;$i$0 = $2087;$ra$1 = $2090;
     break;
    }
    case 43:  {
     $2099 = $38 >>> 23;
     $2100 = $38 >>> 14;
     $2101 = $2100 & 511;
     $2102 = ($2099|0)==(0);
     if ($2102) {
      $2103 = HEAP32[$4>>2]|0;
      $2104 = $2103;
      $2105 = $50;
      $2106 = (($2104) - ($2105))|0;
      $2107 = $2106 >> 4;
      $2108 = (($2107) + -1)|0;
      $n$0 = $2108;
     } else {
      $n$0 = $2099;
     }
     $2109 = ($2101|0)==(0);
     if ($2109) {
      $2110 = HEAP32[$34>>2]|0;
      $2111 = ((($2110)) + 4|0);
      HEAP32[$34>>2] = $2111;
      $2112 = HEAP32[$2110>>2]|0;
      $2113 = $2112 >>> 6;
      $c128$0 = $2113;
     } else {
      $c128$0 = $2101;
     }
     $2114 = HEAP32[$50>>2]|0;
     $2115 = ($c128$0*50)|0;
     $2116 = (($n$0) + -50)|0;
     $2117 = (($2116) + ($2115))|0;
     $2118 = ((($2114)) + 8|0);
     $2119 = HEAP32[$2118>>2]|0;
     $2120 = ($2117>>>0)>($2119>>>0);
     if ($2120) {
      _luaH_resizearray($L,$2114,$2117);
     }
     $2121 = ($n$0|0)>(0);
     if ($2121) {
      $2122 = ((($2114)) + 5|0);
      $last$0519 = $2117;$n$1518 = $n$0;
      while(1) {
       $$sum5 = (($n$1518) + ($49))|0;
       $2123 = (($base$1) + ($$sum5<<4)|0);
       $2124 = (($last$0519) + -1)|0;
       _luaH_setint($L,$2114,$last$0519,0,$2123);
       $2125 = (((($base$1) + ($$sum5<<4)|0)) + 8|0);
       $2126 = HEAP32[$2125>>2]|0;
       $2127 = $2126 & 64;
       $2128 = ($2127|0)==(0);
       if (!($2128)) {
        $2129 = HEAP8[$2122>>0]|0;
        $2130 = $2129 & 4;
        $2131 = ($2130<<24>>24)==(0);
        if (!($2131)) {
         $2132 = HEAP32[$2123>>2]|0;
         $2133 = ((($2132)) + 5|0);
         $2134 = HEAP8[$2133>>0]|0;
         $2135 = $2134 & 3;
         $2136 = ($2135<<24>>24)==(0);
         if (!($2136)) {
          _luaC_barrierback_($L,$2114);
         }
        }
       }
       $2137 = (($n$1518) + -1)|0;
       $2138 = ($n$1518|0)>(1);
       if ($2138) {
        $last$0519 = $2124;$n$1518 = $2137;
       } else {
        break;
       }
      }
     }
     $2139 = HEAP32[$35>>2]|0;
     HEAP32[$4>>2] = $2139;
     $base$0 = $base$1;
     continue L3;
     break;
    }
    case 42:  {
     $base$2 = $base$1;$i$0 = $38;$ra$1 = $50;
     break;
    }
    case 44:  {
     $2140 = $38 >>> 14;
     $2141 = HEAP32[$28>>2]|0;
     $2142 = ((($2141)) + 52|0);
     $2143 = HEAP32[$2142>>2]|0;
     $2144 = (($2143) + ($2140<<2)|0);
     $2145 = HEAP32[$2144>>2]|0;
     $2146 = ((($2145)) + 68|0);
     $2147 = HEAP32[$2146>>2]|0;
     $2148 = ($2147|0)==(0|0);
     $$phi$trans$insert = ((($2145)) + 12|0);
     $$pre = HEAP32[$$phi$trans$insert>>2]|0;
     $$phi$trans$insert723 = ((($2145)) + 64|0);
     $$pre724 = HEAP32[$$phi$trans$insert723>>2]|0;
     L642: do {
      if ($2148) {
       label = 511;
      } else {
       $2149 = ($$pre|0)>(0);
       if ($2149) {
        $i$01$i = 0;
        while(1) {
         $2152 = (((($$pre724) + ($i$01$i<<3)|0)) + 4|0);
         $2153 = HEAP8[$2152>>0]|0;
         $2154 = ($2153<<24>>24)==(0);
         $2155 = (((($$pre724) + ($i$01$i<<3)|0)) + 5|0);
         $2156 = HEAP8[$2155>>0]|0;
         $2157 = $2156&255;
         if ($2154) {
          $2159 = (((($27)) + 16|0) + ($2157<<2)|0);
          $2160 = HEAP32[$2159>>2]|0;
          $2161 = HEAP32[$2160>>2]|0;
          $2166 = $2161;
         } else {
          $2158 = (($base$1) + ($2157<<4)|0);
          $2166 = $2158;
         }
         $2162 = (((($2147)) + 16|0) + ($i$01$i<<2)|0);
         $2163 = HEAP32[$2162>>2]|0;
         $2164 = HEAP32[$2163>>2]|0;
         $2165 = ($2164|0)==($2166|0);
         $2151 = (($i$01$i) + 1)|0;
         if (!($2165)) {
          label = 511;
          break L642;
         }
         $2150 = ($2151|0)<($$pre|0);
         if ($2150) {
          $i$01$i = $2151;
         } else {
          break;
         }
        }
       }
       HEAP32[$50>>2] = $2147;
       $2193 = (((($base$1) + ($49<<4)|0)) + 8|0);
       HEAP32[$2193>>2] = 70;
      }
     } while(0);
     if ((label|0) == 511) {
      label = 0;
      $2167 = (_luaF_newLclosure($L,$$pre)|0);
      $2168 = ((($2167)) + 12|0);
      HEAP32[$2168>>2] = $2145;
      HEAP32[$50>>2] = $2167;
      $2169 = (((($base$1) + ($49<<4)|0)) + 8|0);
      HEAP32[$2169>>2] = 70;
      $2170 = ($$pre|0)>(0);
      if ($2170) {
       $i$01$i168 = 0;
       while(1) {
        $2171 = (((($$pre724) + ($i$01$i168<<3)|0)) + 4|0);
        $2172 = HEAP8[$2171>>0]|0;
        $2173 = ($2172<<24>>24)==(0);
        $2174 = (((($$pre724) + ($i$01$i168<<3)|0)) + 5|0);
        $2175 = HEAP8[$2174>>0]|0;
        $2176 = $2175&255;
        if ($2173) {
         $2180 = (((($27)) + 16|0) + ($2176<<2)|0);
         $2181 = HEAP32[$2180>>2]|0;
         $2182 = (((($2167)) + 16|0) + ($i$01$i168<<2)|0);
         HEAP32[$2182>>2] = $2181;
         $2183 = $2181;
         $2185 = $2183;
        } else {
         $2177 = (($base$1) + ($2176<<4)|0);
         $2178 = (_luaF_findupval($L,$2177)|0);
         $2179 = (((($2167)) + 16|0) + ($i$01$i168<<2)|0);
         HEAP32[$2179>>2] = $2178;
         $2185 = $2178;
        }
        $2184 = ((($2185)) + 4|0);
        $2186 = HEAP32[$2184>>2]|0;
        $2187 = (($2186) + 1)|0;
        HEAP32[$2184>>2] = $2187;
        $2188 = (($i$01$i168) + 1)|0;
        $exitcond$i = ($2188|0)==($$pre|0);
        if ($exitcond$i) {
         break;
        } else {
         $i$01$i168 = $2188;
        }
       }
      }
      $2189 = ((($2145)) + 5|0);
      $2190 = HEAP8[$2189>>0]|0;
      $2191 = $2190 & 4;
      $2192 = ($2191<<24>>24)==(0);
      if ($2192) {
       HEAP32[$2146>>2] = $2167;
      }
     }
     $2194 = HEAP32[$3>>2]|0;
     $2195 = ((($2194)) + 12|0);
     $2196 = HEAP32[$2195>>2]|0;
     $2197 = ($2196|0)>(0);
     if ($2197) {
      $$sum4 = (($49) + 1)|0;
      $2198 = (($base$1) + ($$sum4<<4)|0);
      HEAP32[$4>>2] = $2198;
      _luaC_step($L);
      $2199 = HEAP32[$35>>2]|0;
      HEAP32[$4>>2] = $2199;
     }
     $2200 = HEAP32[$32>>2]|0;
     $base$0 = $2200;
     continue L3;
     break;
    }
    case 45:  {
     $2201 = $38 >>> 23;
     $2202 = (($2201) + -1)|0;
     $2203 = HEAP32[$ci$0>>2]|0;
     $2204 = $base$1;
     $2205 = $2203;
     $2206 = (($2204) - ($2205))|0;
     $2207 = $2206 >> 4;
     $2208 = HEAP32[$28>>2]|0;
     $2209 = ((($2208)) + 6|0);
     $2210 = HEAP8[$2209>>0]|0;
     $2211 = $2210&255;
     $2212 = (($2207) - ($2211))|0;
     $2213 = (($2212) + -1)|0;
     $2214 = ($2201|0)==(0);
     if ($2214) {
      $2215 = HEAP32[$24>>2]|0;
      $2216 = HEAP32[$4>>2]|0;
      $2217 = $2215;
      $2218 = $2216;
      $2219 = (($2217) - ($2218))|0;
      $2220 = $2219 >> 4;
      $2221 = ($2220|0)>($2213|0);
      if (!($2221)) {
       _luaD_growstack($L,$2213);
      }
      $2222 = HEAP32[$32>>2]|0;
      $$sum3 = (($2213) + ($49))|0;
      $2223 = (($2222) + ($$sum3<<4)|0);
      HEAP32[$4>>2] = $2223;
      $2228 = $2222;$b131$0 = $2213;
     } else {
      $2228 = $base$1;$b131$0 = $2202;
     }
     $2224 = ($b131$0|0)>(0);
     if (!($2224)) {
      $base$0 = $2228;
      continue L3;
     }
     $2225 = (1 - ($2212))|0;
     $j$0517 = 0;
     while(1) {
      $2226 = ($j$0517|0)<($2213|0);
      $$sum = (($j$0517) + ($49))|0;
      if ($2226) {
       $2227 = (($2228) + ($$sum<<4)|0);
       $$sum2 = (($2225) + ($j$0517))|0;
       $2229 = (($2228) + ($$sum2<<4)|0);
       ;HEAP32[$2227>>2]=HEAP32[$2229>>2]|0;HEAP32[$2227+4>>2]=HEAP32[$2229+4>>2]|0;HEAP32[$2227+8>>2]=HEAP32[$2229+8>>2]|0;HEAP32[$2227+12>>2]=HEAP32[$2229+12>>2]|0;
      } else {
       $2230 = (((($2228) + ($$sum<<4)|0)) + 8|0);
       HEAP32[$2230>>2] = 0;
      }
      $2231 = (($j$0517) + 1)|0;
      $exitcond = ($2231|0)==($b131$0|0);
      if ($exitcond) {
       $base$0 = $2228;
       continue L3;
      } else {
       $j$0517 = $2231;
      }
     }
     break;
    }
    default: {
     $base$0 = $base$1;
     continue L3;
    }
    }
   } while(0);
   $2091 = ((($ra$1)) + 24|0);
   $2092 = HEAP32[$2091>>2]|0;
   $2093 = ($2092|0)==(0);
   if ($2093) {
    $base$0 = $base$2;
    continue;
   }
   $2094 = ((($ra$1)) + 16|0);
   ;HEAP32[$ra$1>>2]=HEAP32[$2094>>2]|0;HEAP32[$ra$1+4>>2]=HEAP32[$2094+4>>2]|0;HEAP32[$ra$1+8>>2]=HEAP32[$2094+8>>2]|0;HEAP32[$ra$1+12>>2]=HEAP32[$2094+12>>2]|0;
   $2095 = $i$0 >>> 14;
   $2096 = (($2095) + -131071)|0;
   $2097 = HEAP32[$34>>2]|0;
   $2098 = (($2097) + ($2096<<2)|0);
   HEAP32[$34>>2] = $2098;
   $base$0 = $base$2;
  }
  if ((label|0) == 407) {
   label = 0;
   $1718 = HEAP32[$0>>2]|0;
   $1719 = ((($1718)) + 34|0);
   $1720 = HEAP8[$1719>>0]|0;
   $1721 = $1720&255;
   $1722 = $1721 | 8;
   $1723 = $1722&255;
   HEAP8[$1719>>0] = $1723;
   $ci$0 = $1718;
   continue;
  }
  else if ((label|0) == 412) {
   label = 0;
   $1730 = HEAP32[$0>>2]|0;
   $1731 = ((($1730)) + 8|0);
   $1732 = HEAP32[$1731>>2]|0;
   $1733 = HEAP32[$1730>>2]|0;
   $1734 = HEAP32[$1732>>2]|0;
   $1735 = ((($1730)) + 16|0);
   $1736 = HEAP32[$1735>>2]|0;
   $1737 = HEAP32[$1733>>2]|0;
   $1738 = ((($1737)) + 12|0);
   $1739 = HEAP32[$1738>>2]|0;
   $1740 = ((($1739)) + 6|0);
   $1741 = HEAP8[$1740>>0]|0;
   $1742 = $1741&255;
   $1743 = (($1736) + ($1742<<4)|0);
   $1744 = HEAP32[$28>>2]|0;
   $1745 = ((($1744)) + 28|0);
   $1746 = HEAP32[$1745>>2]|0;
   $1747 = ($1746|0)>(0);
   if ($1747) {
    $1748 = ((($1732)) + 16|0);
    $1749 = HEAP32[$1748>>2]|0;
    _luaF_close($L,$1749);
   }
   $1750 = ($1733>>>0)<($1743>>>0);
   if ($1750) {
    $1752 = $1733;$aux$0521 = 0;
    while(1) {
     $1751 = (($1734) + ($aux$0521<<4)|0);
     ;HEAP32[$1751>>2]=HEAP32[$1752>>2]|0;HEAP32[$1751+4>>2]=HEAP32[$1752+4>>2]|0;HEAP32[$1751+8>>2]=HEAP32[$1752+8>>2]|0;HEAP32[$1751+12>>2]=HEAP32[$1752+12>>2]|0;
     $1753 = (($aux$0521) + 1)|0;
     $1754 = (($1733) + ($1753<<4)|0);
     $1755 = ($1754>>>0)<($1743>>>0);
     if ($1755) {
      $1752 = $1754;$aux$0521 = $1753;
     } else {
      break;
     }
    }
   }
   $1756 = HEAP32[$1735>>2]|0;
   $1757 = $1756;
   $1758 = $1733;
   $1759 = (($1757) - ($1758))|0;
   $1760 = $1759 >> 4;
   $1761 = (($1734) + ($1760<<4)|0);
   $1762 = ((($1732)) + 16|0);
   HEAP32[$1762>>2] = $1761;
   $1763 = HEAP32[$4>>2]|0;
   $1764 = $1763;
   $1765 = (($1764) - ($1758))|0;
   $1766 = $1765 >> 4;
   $1767 = (($1734) + ($1766<<4)|0);
   HEAP32[$4>>2] = $1767;
   $1768 = ((($1732)) + 4|0);
   HEAP32[$1768>>2] = $1767;
   $1769 = ((($1730)) + 20|0);
   $1770 = HEAP32[$1769>>2]|0;
   $1771 = ((($1732)) + 20|0);
   HEAP32[$1771>>2] = $1770;
   $1772 = ((($1732)) + 34|0);
   $1773 = HEAP8[$1772>>0]|0;
   $1774 = $1773&255;
   $1775 = $1774 | 32;
   $1776 = $1775&255;
   HEAP8[$1772>>0] = $1776;
   HEAP32[$0>>2] = $1732;
   $ci$0 = $1732;
   continue;
  }
  else if ((label|0) == 417) {
   label = 0;
   $1777 = $$lcssa >>> 23;
   $1778 = ($1777|0)==(0);
   if (!($1778)) {
    $$sum19 = (($1777) + -1)|0;
    $$sum20 = (($$sum19) + ($$lcssa977))|0;
    $1779 = (($base$1$lcssa) + ($$sum20<<4)|0);
    HEAP32[$4>>2] = $1779;
   }
   $1780 = HEAP32[$28>>2]|0;
   $1781 = ((($1780)) + 28|0);
   $1782 = HEAP32[$1781>>2]|0;
   $1783 = ($1782|0)>(0);
   if ($1783) {
    _luaF_close($L,$base$1$lcssa);
   }
   $1784 = (_luaD_poscall($L,$$lcssa985)|0);
   $1785 = ((($ci$0)) + 34|0);
   $1786 = HEAP8[$1785>>0]|0;
   $1787 = $1786 & 8;
   $1788 = ($1787<<24>>24)==(0);
   if ($1788) {
    label = 422;
    break;
   }
   $1789 = HEAP32[$0>>2]|0;
   $1790 = ($1784|0)==(0);
   if ($1790) {
    $ci$0 = $1789;
    continue;
   }
   $1791 = ((($1789)) + 4|0);
   $1792 = HEAP32[$1791>>2]|0;
   HEAP32[$4>>2] = $1792;
   $ci$0 = $1789;
   continue;
  }
 }
 if ((label|0) == 260) {
  _luaG_runerror($L,3744,$vararg_buffer);
  // unreachable;
 }
 else if ((label|0) == 285) {
  _luaG_runerror($L,3712,$vararg_buffer1);
  // unreachable;
 }
 else if ((label|0) == 422) {
  STACKTOP = sp;return;
 }
 else if ((label|0) == 466) {
  _luaG_runerror($L,3776,$vararg_buffer3);
  // unreachable;
 }
 else if ((label|0) == 475) {
  _luaG_runerror($L,3808,$vararg_buffer5);
  // unreachable;
 }
 else if ((label|0) == 484) {
  _luaG_runerror($L,3840,$vararg_buffer7);
  // unreachable;
 }
}
function _luaZ_fill($z) {
 $z = $z|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $size = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $size = sp;
 $0 = ((($z)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($z)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($z)) + 12|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (FUNCTION_TABLE_iiii[$3 & 511]($1,$5,$size)|0);
 $7 = ($6|0)==(0|0);
 $8 = HEAP32[$size>>2]|0;
 $9 = ($8|0)==(0);
 $or$cond = $7 | $9;
 if ($or$cond) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = (($8) + -1)|0;
 HEAP32[$z>>2] = $10;
 $11 = ((($z)) + 4|0);
 $12 = ((($6)) + 1|0);
 HEAP32[$11>>2] = $12;
 $13 = HEAP8[$6>>0]|0;
 $14 = $13&255;
 $$0 = $14;
 STACKTOP = sp;return ($$0|0);
}
function _luaZ_init($L,$z,$reader,$data) {
 $L = $L|0;
 $z = $z|0;
 $reader = $reader|0;
 $data = $data|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($z)) + 16|0);
 HEAP32[$0>>2] = $L;
 $1 = ((($z)) + 8|0);
 HEAP32[$1>>2] = $reader;
 $2 = ((($z)) + 12|0);
 HEAP32[$2>>2] = $data;
 HEAP32[$z>>2] = 0;
 $3 = ((($z)) + 4|0);
 HEAP32[$3>>2] = 0;
 return;
}
function _luaZ_read($z,$b,$n) {
 $z = $z|0;
 $b = $b|0;
 $n = $n|0;
 var $$$01 = 0, $$0 = 0, $$015 = 0, $$024 = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $size$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $size$i = sp;
 $0 = ($n|0)==(0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = ((($z)) + 16|0);
 $2 = ((($z)) + 8|0);
 $3 = ((($z)) + 12|0);
 $4 = ((($z)) + 4|0);
 $$pre = HEAP32[$z>>2]|0;
 $$015 = $n;$$024 = $b;$6 = $$pre;
 while(1) {
  $5 = ($6|0)==(0);
  if ($5) {
   $7 = HEAP32[$1>>2]|0;
   $8 = HEAP32[$2>>2]|0;
   $9 = HEAP32[$3>>2]|0;
   $10 = (FUNCTION_TABLE_iiii[$8 & 511]($7,$9,$size$i)|0);
   $11 = ($10|0)==(0|0);
   $12 = HEAP32[$size$i>>2]|0;
   $13 = ($12|0)==(0);
   $or$cond$i = $11 | $13;
   if ($or$cond$i) {
    $$0 = $$015;
    label = 8;
    break;
   }
   HEAP32[$z>>2] = $12;
   HEAP32[$4>>2] = $10;
   $15 = $12;$16 = $10;
  } else {
   $$pre7 = HEAP32[$4>>2]|0;
   $15 = $6;$16 = $$pre7;
  }
  $14 = ($$015>>>0)>($15>>>0);
  $$$01 = $14 ? $15 : $$015;
  _memcpy(($$024|0),($16|0),($$$01|0))|0;
  $17 = HEAP32[$z>>2]|0;
  $18 = (($17) - ($$$01))|0;
  HEAP32[$z>>2] = $18;
  $19 = HEAP32[$4>>2]|0;
  $20 = (($19) + ($$$01)|0);
  HEAP32[$4>>2] = $20;
  $21 = (($$024) + ($$$01)|0);
  $22 = (($$015) - ($$$01))|0;
  $23 = ($$015|0)==($$$01|0);
  if ($23) {
   $$0 = 0;
   label = 8;
   break;
  } else {
   $$015 = $22;$$024 = $21;$6 = $18;
  }
 }
 if ((label|0) == 8) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaZ_openspace($L,$buff,$n) {
 $L = $L|0;
 $buff = $buff|0;
 $n = $n|0;
 var $$n = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($buff)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1>>>0)<($n>>>0);
 if ($2) {
  $3 = ($n>>>0)<(32);
  $$n = $3 ? 32 : $n;
  $4 = HEAP32[$buff>>2]|0;
  $5 = (_luaM_realloc_($L,$4,$1,$$n)|0);
  HEAP32[$buff>>2] = $5;
  HEAP32[$0>>2] = $$n;
  $6 = $5;
  return ($6|0);
 } else {
  $$pre = HEAP32[$buff>>2]|0;
  $6 = $$pre;
  return ($6|0);
 }
 return (0)|0;
}
function _luaL_traceback($L,$L1,$msg,$level) {
 $L = $L|0;
 $L1 = $L1|0;
 $msg = $msg|0;
 $level = $level|0;
 var $$0$be = 0, $$in = 0, $$le$1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ar = 0, $ar$i = 0, $le$0$i = 0, $le$0$i$lcssa = 0, $le$1$lcssa$i = 0, $le$11$i = 0, $li$0$i = 0, $li$0$i$lcssa = 0, $li$0$i$phi = 0, $li$1$$i = 0;
 var $li$12$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0, $vararg_buffer14 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, $vararg_ptr13 = 0, $vararg_ptr17 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer14 = sp + 40|0;
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $ar$i = sp + 148|0;
 $ar = sp + 48|0;
 $0 = (_lua_gettop($L)|0);
 $le$0$i = 1;$li$0$i = 1;
 while(1) {
  $1 = (_lua_getstack($L1,$le$0$i,$ar$i)|0);
  $2 = ($1|0)==(0);
  $3 = $le$0$i << 1;
  if ($2) {
   $le$0$i$lcssa = $le$0$i;$li$0$i$lcssa = $li$0$i;
   break;
  } else {
   $li$0$i$phi = $le$0$i;$le$0$i = $3;$li$0$i = $li$0$i$phi;
  }
 }
 $4 = ($li$0$i$lcssa|0)<($le$0$i$lcssa|0);
 if ($4) {
  $le$11$i = $le$0$i$lcssa;$li$12$i = $li$0$i$lcssa;
  while(1) {
   $5 = (($le$11$i) + ($li$12$i))|0;
   $6 = (($5|0) / 2)&-1;
   $7 = (_lua_getstack($L1,$6,$ar$i)|0);
   $8 = ($7|0)==(0);
   $9 = (($6) + 1)|0;
   $$le$1$i = $8 ? $6 : $le$11$i;
   $li$1$$i = $8 ? $li$12$i : $9;
   $10 = ($li$1$$i|0)<($$le$1$i|0);
   if ($10) {
    $le$11$i = $$le$1$i;$li$12$i = $li$1$$i;
   } else {
    $le$1$lcssa$i = $$le$1$i;
    break;
   }
  }
 } else {
  $le$1$lcssa$i = $le$0$i$lcssa;
 }
 $11 = (($le$1$lcssa$i) + -1)|0;
 $12 = ($11|0)>(22);
 $13 = $12 ? 12 : 0;
 $14 = ($msg|0)==(0|0);
 if (!($14)) {
  HEAP32[$vararg_buffer>>2] = $msg;
  (_lua_pushfstring($L,8264,$vararg_buffer)|0);
 }
 (_lua_pushlstring($L,3880,16)|0);
 $15 = (_lua_getstack($L1,$level,$ar)|0);
 $16 = ($15|0)==(0);
 if ($16) {
  $45 = (_lua_gettop($L)|0);
  $46 = (($45) - ($0))|0;
  _lua_concat($L,$46);
  STACKTOP = sp;return;
 }
 $17 = (($le$1$lcssa$i) + -11)|0;
 $18 = ((($ar)) + 36|0);
 $19 = ((($ar)) + 20|0);
 $20 = ((($ar)) + 8|0);
 $21 = ((($ar)) + 12|0);
 $22 = ((($ar)) + 24|0);
 $23 = ((($ar)) + 4|0);
 $24 = ((($ar)) + 35|0);
 $$in = $level;
 while(1) {
  $25 = (($$in) + 1)|0;
  $26 = ($25|0)==($13|0);
  if ($26) {
   (_lua_pushlstring($L,3904,5)|0);
   $$0$be = $17;
  } else {
   (_lua_getinfo($L1,3912,$ar)|0);
   HEAP32[$vararg_buffer1>>2] = $18;
   (_lua_pushfstring($L,3920,$vararg_buffer1)|0);
   $27 = HEAP32[$19>>2]|0;
   $28 = ($27|0)>(0);
   if ($28) {
    HEAP32[$vararg_buffer4>>2] = $27;
    (_lua_pushfstring($L,3928,$vararg_buffer4)|0);
   }
   (_lua_pushlstring($L,3936,4)|0);
   $29 = (_pushglobalfuncname($L,$ar)|0);
   $30 = ($29|0)==(0);
   do {
    if ($30) {
     $32 = HEAP32[$20>>2]|0;
     $33 = HEAP8[$32>>0]|0;
     $34 = ($33<<24>>24)==(0);
     if (!($34)) {
      $35 = HEAP32[$23>>2]|0;
      HEAP32[$vararg_buffer10>>2] = $32;
      $vararg_ptr13 = ((($vararg_buffer10)) + 4|0);
      HEAP32[$vararg_ptr13>>2] = $35;
      (_lua_pushfstring($L,3960,$vararg_buffer10)|0);
      break;
     }
     $36 = HEAP32[$21>>2]|0;
     $37 = HEAP8[$36>>0]|0;
     if ((($37<<24>>24) == 67)) {
      (_lua_pushlstring($L,37376,1)|0);
      break;
     } else if ((($37<<24>>24) == 109)) {
      (_lua_pushlstring($L,3968,10)|0);
      break;
     } else {
      $38 = HEAP32[$22>>2]|0;
      HEAP32[$vararg_buffer14>>2] = $18;
      $vararg_ptr17 = ((($vararg_buffer14)) + 4|0);
      HEAP32[$vararg_ptr17>>2] = $38;
      (_lua_pushfstring($L,3984,$vararg_buffer14)|0);
      break;
     }
    } else {
     $31 = (_lua_tolstring($L,-1,0)|0);
     HEAP32[$vararg_buffer7>>2] = $31;
     (_lua_pushfstring($L,3944,$vararg_buffer7)|0);
     _lua_rotate($L,-2,-1);
     _lua_settop($L,-2);
    }
   } while(0);
   $39 = HEAP8[$24>>0]|0;
   $40 = ($39<<24>>24)==(0);
   if (!($40)) {
    (_lua_pushlstring($L,4008,20)|0);
   }
   $41 = (_lua_gettop($L)|0);
   $42 = (($41) - ($0))|0;
   _lua_concat($L,$42);
   $$0$be = $25;
  }
  $43 = (_lua_getstack($L1,$$0$be,$ar)|0);
  $44 = ($43|0)==(0);
  if ($44) {
   break;
  } else {
   $$in = $$0$be;
  }
 }
 $45 = (_lua_gettop($L)|0);
 $46 = (($45) - ($0))|0;
 _lua_concat($L,$46);
 STACKTOP = sp;return;
}
function _luaL_argerror($L,$arg,$extramsg) {
 $L = $L|0;
 $arg = $arg|0;
 $extramsg = $extramsg|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $ar = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $ar = sp + 28|0;
 $0 = (_lua_getstack($L,0,$ar)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP32[$vararg_buffer>>2] = $arg;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $extramsg;
  $2 = (_luaL_error($L,4032,$vararg_buffer)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 (_lua_getinfo($L,12048,$ar)|0);
 $3 = ((($ar)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (_strcmp($4,4056)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (($arg) + -1)|0;
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = ((($ar)) + 4|0);
   $10 = HEAP32[$9>>2]|0;
   HEAP32[$vararg_buffer2>>2] = $10;
   $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
   HEAP32[$vararg_ptr5>>2] = $extramsg;
   $11 = (_luaL_error($L,4064,$vararg_buffer2)|0);
   $$0 = $11;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$01 = $7;
  }
 } else {
  $$01 = $arg;
 }
 $12 = ((($ar)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $15 = (_pushglobalfuncname($L,$ar)|0);
  $16 = ($15|0)==(0);
  if ($16) {
   $18 = 37376;
  } else {
   $17 = (_lua_tolstring($L,-1,0)|0);
   $18 = $17;
  }
  HEAP32[$12>>2] = $18;
  $19 = $18;
 } else {
  $19 = $13;
 }
 HEAP32[$vararg_buffer6>>2] = $$01;
 $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
 HEAP32[$vararg_ptr9>>2] = $19;
 $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
 HEAP32[$vararg_ptr10>>2] = $extramsg;
 $20 = (_luaL_error($L,4096,$vararg_buffer6)|0);
 $$0 = $20;
 STACKTOP = sp;return ($$0|0);
}
function _luaL_error($L,$fmt,$varargs) {
 $L = $L|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ar$i = 0, $argp = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ar$i = sp + 24|0;
 $argp = sp + 8|0;
 HEAP32[$argp>>2] = $varargs;
 $0 = (_lua_getstack($L,1,$ar$i)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  (_lua_getinfo($L,4128,$ar$i)|0);
  $2 = ((($ar$i)) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)>(0);
  if ($4) {
   $5 = ((($ar$i)) + 36|0);
   HEAP32[$vararg_buffer>>2] = $5;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $3;
   (_lua_pushfstring($L,4136,$vararg_buffer)|0);
   (_lua_pushvfstring($L,$fmt,$argp)|0);
   _lua_concat($L,2);
   (_lua_error($L)|0);
   // unreachable;
  }
 }
 (_lua_pushlstring($L,37352,0)|0);
 (_lua_pushvfstring($L,$fmt,$argp)|0);
 _lua_concat($L,2);
 (_lua_error($L)|0);
 // unreachable;
 return (0)|0;
}
function _luaL_where($L,$level) {
 $L = $L|0;
 $level = $level|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $ar = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ar = sp + 8|0;
 $0 = (_lua_getstack($L,$level,$ar)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  (_lua_getinfo($L,4128,$ar)|0);
  $2 = ((($ar)) + 20|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)>(0);
  if ($4) {
   $5 = ((($ar)) + 36|0);
   HEAP32[$vararg_buffer>>2] = $5;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $3;
   (_lua_pushfstring($L,4136,$vararg_buffer)|0);
   STACKTOP = sp;return;
  }
 }
 (_lua_pushlstring($L,37352,0)|0);
 STACKTOP = sp;return;
}
function _luaL_fileresult($L,$stat,$fname) {
 $L = $L|0;
 $stat = $stat|0;
 $fname = $fname|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (___errno_location()|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($stat|0)==(0);
 if (!($2)) {
  _lua_pushboolean($L,1);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_pushnil($L);
 $3 = ($fname|0)==(0|0);
 $4 = (_strerror(($1|0))|0);
 if ($3) {
  (_lua_pushstring($L,$4)|0);
 } else {
  HEAP32[$vararg_buffer>>2] = $fname;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $4;
  (_lua_pushfstring($L,4144,$vararg_buffer)|0);
 }
 $5 = ($1|0)<(0);
 $6 = $5 << 31 >> 31;
 _lua_pushinteger($L,$1,$6);
 $$0 = 3;
 STACKTOP = sp;return ($$0|0);
}
function _luaL_execresult($L,$stat) {
 $L = $L|0;
 $stat = $stat|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($stat|0) == 0)) {
  _lua_pushboolean($L,1);
 } else if ((($stat|0) == -1)) {
  $0 = (___errno_location()|0);
  $1 = HEAP32[$0>>2]|0;
  _lua_pushnil($L);
  $2 = (_strerror(($1|0))|0);
  (_lua_pushstring($L,$2)|0);
  $3 = ($1|0)<(0);
  $4 = $3 << 31 >> 31;
  _lua_pushinteger($L,$1,$4);
  return 3;
 } else {
  _lua_pushnil($L);
 }
 (_lua_pushstring($L,9928)|0);
 $5 = ($stat|0)<(0);
 $6 = $5 << 31 >> 31;
 _lua_pushinteger($L,$stat,$6);
 return 3;
}
function _luaL_newmetatable($L,$tname) {
 $L = $L|0;
 $tname = $tname|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_getfield($L,-1001000,$tname)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 0;
  return ($$0|0);
 }
 _lua_settop($L,-2);
 _lua_createtable($L,0,0);
 (_lua_pushstring($L,$tname)|0);
 _lua_setfield($L,-2,4152);
 _lua_pushvalue($L,-1);
 _lua_setfield($L,-1001000,$tname);
 $$0 = 1;
 return ($$0|0);
}
function _luaL_setmetatable($L,$tname) {
 $L = $L|0;
 $tname = $tname|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_lua_getfield($L,-1001000,$tname)|0);
 (_lua_setmetatable($L,-2)|0);
 return;
}
function _luaL_testudata($L,$ud,$tname) {
 $L = $L|0;
 $ud = $ud|0;
 $tname = $tname|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_touserdata($L,$ud)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = (_lua_getmetatable($L,$ud)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 (_lua_getfield($L,-1001000,$tname)|0);
 $4 = (_lua_rawequal($L,-1,-2)|0);
 $5 = ($4|0)==(0);
 $$ = $5 ? 0 : $0;
 _lua_settop($L,-3);
 $$0 = $$;
 return ($$0|0);
}
function _luaL_checkudata($L,$ud,$tname) {
 $L = $L|0;
 $ud = $ud|0;
 $tname = $tname|0;
 var $$0$i1 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_touserdata($L,$ud)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (_lua_getmetatable($L,$ud)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   (_lua_getfield($L,-1001000,$tname)|0);
   $4 = (_lua_rawequal($L,-1,-2)|0);
   $5 = ($4|0)==(0);
   _lua_settop($L,-3);
   if (!($5)) {
    $$0$i1 = $0;
    return ($$0$i1|0);
   }
  }
 }
 _typeerror($L,$ud,$tname);
 $$0$i1 = 0;
 return ($$0$i1|0);
}
function _luaL_checkoption($L,$arg,$def,$lst) {
 $L = $L|0;
 $arg = $arg|0;
 $def = $def|0;
 $lst = $lst|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$02 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ($def|0)==(0|0);
 if ($0) {
  $6 = (_lua_tolstring($L,$arg,0)|0);
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = (_lua_typename($L,4)|0);
   _typeerror($L,$arg,$8);
   $12 = 0;
  } else {
   $12 = $6;
  }
 } else {
  $1 = (_lua_type($L,$arg)|0);
  $2 = ($1|0)<(1);
  if ($2) {
   $12 = $def;
  } else {
   $3 = (_lua_tolstring($L,$arg,0)|0);
   $4 = ($3|0)==(0|0);
   if ($4) {
    $5 = (_lua_typename($L,4)|0);
    _typeerror($L,$arg,$5);
    $12 = 0;
   } else {
    $12 = $3;
   }
  }
 }
 $9 = HEAP32[$lst>>2]|0;
 $10 = ($9|0)==(0|0);
 L8: do {
  if (!($10)) {
   $11 = $9;$i$02 = 0;
   while(1) {
    $13 = (_strcmp($11,$12)|0);
    $14 = ($13|0)==(0);
    if ($14) {
     $$0 = $i$02;
     break;
    }
    $15 = (($i$02) + 1)|0;
    $16 = (($lst) + ($15<<2)|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ($17|0)==(0|0);
    if ($18) {
     break L8;
    } else {
     $11 = $17;$i$02 = $15;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$vararg_buffer>>2] = $12;
 $19 = (_lua_pushfstring($L,4160,$vararg_buffer)|0);
 $20 = (_luaL_argerror($L,$arg,$19)|0);
 $$0 = $20;
 STACKTOP = sp;return ($$0|0);
}
function _luaL_optlstring($L,$arg,$def,$len) {
 $L = $L|0;
 $arg = $arg|0;
 $def = $def|0;
 $len = $len|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,$arg)|0);
 $1 = ($0|0)<(1);
 if (!($1)) {
  $6 = (_lua_tolstring($L,$arg,$len)|0);
  $7 = ($6|0)==(0|0);
  if (!($7)) {
   $$0 = $6;
   return ($$0|0);
  }
  $8 = (_lua_typename($L,4)|0);
  _typeerror($L,$arg,$8);
  $$0 = 0;
  return ($$0|0);
 }
 $2 = ($len|0)==(0|0);
 if ($2) {
  $$0 = $def;
  return ($$0|0);
 }
 $3 = ($def|0)==(0|0);
 if ($3) {
  $5 = 0;
 } else {
  $4 = (_strlen(($def|0))|0);
  $5 = $4;
 }
 HEAP32[$len>>2] = $5;
 $$0 = $def;
 return ($$0|0);
}
function _luaL_checklstring($L,$arg,$len) {
 $L = $L|0;
 $arg = $arg|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_tolstring($L,$arg,$len)|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  return ($0|0);
 }
 $2 = (_lua_typename($L,4)|0);
 _typeerror($L,$arg,$2);
 return ($0|0);
}
function _luaL_checkstack($L,$space,$msg) {
 $L = $L|0;
 $space = $space|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (($space) + 20)|0;
 $1 = (_lua_checkstack($L,$0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return;
 }
 $3 = ($msg|0)==(0|0);
 if ($3) {
  (_luaL_error($L,4208,$vararg_buffer1)|0);
  STACKTOP = sp;return;
 } else {
  HEAP32[$vararg_buffer>>2] = $msg;
  (_luaL_error($L,4184,$vararg_buffer)|0);
  STACKTOP = sp;return;
 }
}
function _luaL_checktype($L,$arg,$t) {
 $L = $L|0;
 $arg = $arg|0;
 $t = $t|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,$arg)|0);
 $1 = ($0|0)==($t|0);
 if ($1) {
  return;
 }
 $2 = (_lua_typename($L,$t)|0);
 _typeerror($L,$arg,$2);
 return;
}
function _luaL_checkany($L,$arg) {
 $L = $L|0;
 $arg = $arg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,$arg)|0);
 $1 = ($0|0)==(-1);
 if (!($1)) {
  return;
 }
 (_luaL_argerror($L,$arg,9768)|0);
 return;
}
function _luaL_checknumber($L,$arg) {
 $L = $L|0;
 $arg = $arg|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0, $isnum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $isnum = sp;
 $0 = (+_lua_tonumberx($L,$arg,$isnum));
 $1 = HEAP32[$isnum>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return (+$0);
 }
 $3 = (_lua_typename($L,3)|0);
 _typeerror($L,$arg,$3);
 STACKTOP = sp;return (+$0);
}
function _luaL_optnumber($L,$arg,$def) {
 $L = $L|0;
 $arg = $arg|0;
 $def = +$def;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $isnum$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $isnum$i = sp;
 $0 = (_lua_type($L,$arg)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $6 = $def;
  STACKTOP = sp;return (+$6);
 }
 $2 = (+_lua_tonumberx($L,$arg,$isnum$i));
 $3 = HEAP32[$isnum$i>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $5 = (_lua_typename($L,3)|0);
  _typeerror($L,$arg,$5);
 }
 $6 = $2;
 STACKTOP = sp;return (+$6);
}
function _luaL_checkinteger($L,$arg) {
 $L = $L|0;
 $arg = $arg|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $isnum = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $isnum = sp;
 $0 = (_lua_tointegerx($L,$arg,$isnum)|0);
 $1 = tempRet0;
 $2 = HEAP32[$isnum>>2]|0;
 $3 = ($2|0)==(0);
 do {
  if ($3) {
   $4 = (_lua_isnumber($L,$arg)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $6 = (_lua_typename($L,3)|0);
    _typeerror($L,$arg,$6);
    break;
   } else {
    (_luaL_argerror($L,$arg,4224)|0);
    break;
   }
  }
 } while(0);
 tempRet0 = ($1);
 STACKTOP = sp;return ($0|0);
}
function _luaL_optinteger($L,$arg,$0,$1) {
 $L = $L|0;
 $arg = $arg|0;
 $0 = $0|0;
 $1 = $1|0;
 var $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isnum$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $isnum$i = sp;
 $2 = (_lua_type($L,$arg)|0);
 $3 = ($2|0)<(1);
 if ($3) {
  $11 = $1;$12 = $0;
  tempRet0 = ($11);
  STACKTOP = sp;return ($12|0);
 }
 $4 = (_lua_tointegerx($L,$arg,$isnum$i)|0);
 $5 = tempRet0;
 $6 = HEAP32[$isnum$i>>2]|0;
 $7 = ($6|0)==(0);
 do {
  if ($7) {
   $8 = (_lua_isnumber($L,$arg)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = (_lua_typename($L,3)|0);
    _typeerror($L,$arg,$10);
    break;
   } else {
    (_luaL_argerror($L,$arg,4224)|0);
    break;
   }
  }
 } while(0);
 $11 = $5;$12 = $4;
 tempRet0 = ($11);
 STACKTOP = sp;return ($12|0);
}
function _luaL_prepbuffsize($B,$sz) {
 $B = $B|0;
 $sz = $sz|0;
 var $$ = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($B)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($B)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($B)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($3) - ($5))|0;
 $7 = ($6>>>0)<($sz>>>0);
 if (!($7)) {
  $$pre2 = HEAP32[$B>>2]|0;
  $22 = $$pre2;$23 = $5;
  $21 = (($22) + ($23)|0);
  STACKTOP = sp;return ($21|0);
 }
 $8 = $3 << 1;
 $9 = (($8) - ($5))|0;
 $10 = ($9>>>0)<($sz>>>0);
 $11 = (($5) + ($sz))|0;
 $$ = $10 ? $11 : $8;
 $12 = ($$>>>0)<($5>>>0);
 $13 = (($$) - ($5))|0;
 $14 = ($13>>>0)<($sz>>>0);
 $or$cond = $12 | $14;
 if ($or$cond) {
  (_luaL_error($1,4264,$vararg_buffer)|0);
 }
 $15 = (_lua_newuserdata($1,$$)|0);
 $16 = HEAP32[$B>>2]|0;
 $17 = HEAP32[$4>>2]|0;
 _memcpy(($15|0),($16|0),($17|0))|0;
 $18 = HEAP32[$B>>2]|0;
 $19 = ((($B)) + 16|0);
 $20 = ($18|0)==($19|0);
 if (!($20)) {
  _lua_rotate($1,-2,-1);
  _lua_settop($1,-2);
 }
 HEAP32[$B>>2] = $15;
 HEAP32[$2>>2] = $$;
 $$pre = HEAP32[$4>>2]|0;
 $22 = $15;$23 = $$pre;
 $21 = (($22) + ($23)|0);
 STACKTOP = sp;return ($21|0);
}
function _luaL_addlstring($B,$s,$l) {
 $B = $B|0;
 $s = $s|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_prepbuffsize($B,$l)|0);
 _memcpy(($0|0),($s|0),($l|0))|0;
 $1 = ((($B)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (($2) + ($l))|0;
 HEAP32[$1>>2] = $3;
 return;
}
function _luaL_addstring($B,$s) {
 $B = $B|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (_luaL_prepbuffsize($B,$0)|0);
 _memcpy(($1|0),($s|0),($0|0))|0;
 $2 = ((($B)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (($3) + ($0))|0;
 HEAP32[$2>>2] = $4;
 return;
}
function _luaL_pushresult($B) {
 $B = $B|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($B)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$B>>2]|0;
 $3 = ((($B)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 (_lua_pushlstring($1,$2,$4)|0);
 $5 = HEAP32[$B>>2]|0;
 $6 = ((($B)) + 16|0);
 $7 = ($5|0)==($6|0);
 if ($7) {
  return;
 }
 _lua_rotate($1,-2,-1);
 _lua_settop($1,-2);
 return;
}
function _luaL_pushresultsize($B,$sz) {
 $B = $B|0;
 $sz = $sz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($B)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + ($sz))|0;
 HEAP32[$0>>2] = $2;
 $3 = ((($B)) + 12|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = HEAP32[$B>>2]|0;
 (_lua_pushlstring($4,$5,$2)|0);
 $6 = HEAP32[$B>>2]|0;
 $7 = ((($B)) + 16|0);
 $8 = ($6|0)==($7|0);
 if ($8) {
  return;
 }
 _lua_rotate($4,-2,-1);
 _lua_settop($4,-2);
 return;
}
function _luaL_addvalue($B) {
 $B = $B|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp;
 $0 = ((($B)) + 12|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_lua_tolstring($1,-1,$l)|0);
 $3 = HEAP32[$B>>2]|0;
 $4 = ((($B)) + 16|0);
 $5 = ($3|0)==($4|0);
 if (!($5)) {
  _lua_rotate($1,-2,1);
 }
 $6 = HEAP32[$l>>2]|0;
 $7 = (_luaL_prepbuffsize($B,$6)|0);
 _memcpy(($7|0),($2|0),($6|0))|0;
 $8 = ((($B)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (($9) + ($6))|0;
 HEAP32[$8>>2] = $10;
 $11 = HEAP32[$B>>2]|0;
 $12 = ($11|0)!=($4|0);
 $13 = $12 ? -2 : -1;
 _lua_rotate($1,$13,-1);
 _lua_settop($1,-2);
 STACKTOP = sp;return;
}
function _luaL_buffinit($L,$B) {
 $L = $L|0;
 $B = $B|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($B)) + 12|0);
 HEAP32[$0>>2] = $L;
 $1 = ((($B)) + 16|0);
 HEAP32[$B>>2] = $1;
 $2 = ((($B)) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($B)) + 4|0);
 HEAP32[$3>>2] = 4096;
 return;
}
function _luaL_buffinitsize($L,$B,$sz) {
 $L = $L|0;
 $B = $B|0;
 $sz = $sz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($B)) + 12|0);
 HEAP32[$0>>2] = $L;
 $1 = ((($B)) + 16|0);
 HEAP32[$B>>2] = $1;
 $2 = ((($B)) + 8|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($B)) + 4|0);
 HEAP32[$3>>2] = 4096;
 $4 = (_luaL_prepbuffsize($B,$sz)|0);
 return ($4|0);
}
function _luaL_loadfilex($L,$filename,$mode) {
 $L = $L|0;
 $filename = $filename|0;
 $mode = $mode|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, $lf = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer6 = 0, $vararg_ptr10 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr4 = 0;
 var $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1088|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer11 = sp + 40|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $lf = sp + 56|0;
 $c = sp + 52|0;
 $0 = (_lua_gettop($L)|0);
 $1 = (($0) + 1)|0;
 $2 = ($filename|0)==(0|0);
 if ($2) {
  (_lua_pushlstring($L,4288,6)|0);
  $3 = HEAP32[_stdin>>2]|0;
  $4 = ((($lf)) + 4|0);
  HEAP32[$4>>2] = $3;
 } else {
  HEAP32[$vararg_buffer>>2] = $filename;
  (_lua_pushfstring($L,4296,$vararg_buffer)|0);
  $5 = (_fopen(($filename|0),(13328|0))|0);
  $6 = ((($lf)) + 4|0);
  HEAP32[$6>>2] = $5;
  $7 = ($5|0)==(0|0);
  if ($7) {
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (_strerror(($9|0))|0);
   $11 = (_lua_tolstring($L,$1,0)|0);
   $12 = ((($11)) + 1|0);
   HEAP32[$vararg_buffer1>>2] = 8912;
   $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr4>>2] = $12;
   $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
   HEAP32[$vararg_ptr5>>2] = $10;
   (_lua_pushfstring($L,4304,$vararg_buffer1)|0);
   _lua_rotate($L,$1,-1);
   _lua_settop($L,-2);
   $$0 = 7;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $13 = (_skipcomment($lf,$c)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $15 = HEAP32[$lf>>2]|0;
  $16 = (($15) + 1)|0;
  HEAP32[$lf>>2] = $16;
  $17 = (((($lf)) + 8|0) + ($15)|0);
  HEAP8[$17>>0] = 10;
 }
 $18 = HEAP32[$c>>2]|0;
 $19 = ($18|0)==(27);
 $20 = ($filename|0)!=(0|0);
 $or$cond = $20 & $19;
 do {
  if ($or$cond) {
   $21 = ((($lf)) + 4|0);
   $22 = HEAP32[$21>>2]|0;
   $23 = (_freopen(($filename|0),(4328|0),($22|0))|0);
   HEAP32[$21>>2] = $23;
   $24 = ($23|0)==(0|0);
   if (!($24)) {
    (_skipcomment($lf,$c)|0);
    $$pr = HEAP32[$c>>2]|0;
    $31 = $$pr;
    break;
   }
   $25 = (___errno_location()|0);
   $26 = HEAP32[$25>>2]|0;
   $27 = (_strerror(($26|0))|0);
   $28 = (_lua_tolstring($L,$1,0)|0);
   $29 = ((($28)) + 1|0);
   HEAP32[$vararg_buffer6>>2] = 4336;
   $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
   HEAP32[$vararg_ptr9>>2] = $29;
   $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
   HEAP32[$vararg_ptr10>>2] = $27;
   (_lua_pushfstring($L,4304,$vararg_buffer6)|0);
   _lua_rotate($L,$1,-1);
   _lua_settop($L,-2);
   $$0 = 7;
   STACKTOP = sp;return ($$0|0);
  } else {
   $31 = $18;
  }
 } while(0);
 $30 = ($31|0)==(-1);
 if (!($30)) {
  $32 = $31&255;
  $33 = HEAP32[$lf>>2]|0;
  $34 = (($33) + 1)|0;
  HEAP32[$lf>>2] = $34;
  $35 = (((($lf)) + 8|0) + ($33)|0);
  HEAP8[$35>>0] = $32;
 }
 $36 = (_lua_tolstring($L,-1,0)|0);
 $37 = (_lua_load($L,316,$lf,$36,$mode)|0);
 $38 = ((($lf)) + 4|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = (_ferror(($39|0))|0);
 if ($20) {
  (_fclose(($39|0))|0);
 }
 $41 = ($40|0)==(0);
 if ($41) {
  _lua_rotate($L,$1,-1);
  _lua_settop($L,-2);
  $$0 = $37;
  STACKTOP = sp;return ($$0|0);
 } else {
  _lua_settop($L,$1);
  $42 = (___errno_location()|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (_strerror(($43|0))|0);
  $45 = (_lua_tolstring($L,$1,0)|0);
  $46 = ((($45)) + 1|0);
  HEAP32[$vararg_buffer11>>2] = 8568;
  $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
  HEAP32[$vararg_ptr14>>2] = $46;
  $vararg_ptr15 = ((($vararg_buffer11)) + 8|0);
  HEAP32[$vararg_ptr15>>2] = $44;
  (_lua_pushfstring($L,4304,$vararg_buffer11)|0);
  _lua_rotate($L,$1,-1);
  _lua_settop($L,-2);
  $$0 = 7;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaL_loadbufferx($L,$buff,$size,$name,$mode) {
 $L = $L|0;
 $buff = $buff|0;
 $size = $size|0;
 $name = $name|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $ls = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ls = sp;
 HEAP32[$ls>>2] = $buff;
 $0 = ((($ls)) + 4|0);
 HEAP32[$0>>2] = $size;
 $1 = (_lua_load($L,317,$ls,$name,$mode)|0);
 STACKTOP = sp;return ($1|0);
}
function _luaL_getmetafield($L,$obj,$event) {
 $L = $L|0;
 $obj = $obj|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_getmetatable($L,$obj)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 (_lua_pushstring($L,$event)|0);
 $2 = (_lua_rawget($L,-2)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  _lua_settop($L,-3);
  $$0 = 0;
  return ($$0|0);
 } else {
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
  $$0 = $2;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaL_callmeta($L,$obj,$event) {
 $L = $L|0;
 $obj = $obj|0;
 $event = $event|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_absindex($L,$obj)|0);
 $1 = (_lua_getmetatable($L,$0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 (_lua_pushstring($L,$event)|0);
 $3 = (_lua_rawget($L,-2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  _lua_settop($L,-3);
  $$0 = 0;
  return ($$0|0);
 } else {
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
  _lua_pushvalue($L,$0);
  _lua_callk($L,1,1,0,0);
  $$0 = 1;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaL_len($L,$idx) {
 $L = $L|0;
 $idx = $idx|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $isnum = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $isnum = sp + 4|0;
 _lua_len($L,$idx);
 $0 = (_lua_tointegerx($L,-1,$isnum)|0);
 $1 = tempRet0;
 $2 = HEAP32[$isnum>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  (_luaL_error($L,4344,$vararg_buffer)|0);
 }
 _lua_settop($L,-2);
 tempRet0 = ($1);
 STACKTOP = sp;return ($0|0);
}
function _luaL_tolstring($L,$idx,$len) {
 $L = $L|0;
 $idx = $idx|0;
 $len = $len|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0;
 var $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_callmeta($L,$idx,8600)|0);
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $2 = (_lua_type($L,$idx)|0);
   if ((($2|0) == 4)) {
    _lua_pushvalue($L,$idx);
    break;
   } else if ((($2|0) == 0)) {
    (_lua_pushlstring($L,5784,3)|0);
    break;
   } else if ((($2|0) == 3)) {
    $3 = (_lua_isinteger($L,$idx)|0);
    $4 = ($3|0)==(0);
    if ($4) {
     $11 = (+_lua_tonumberx($L,$idx,0));
     HEAPF64[$vararg_buffer1>>3] = $11;
     (_lua_pushfstring($L,4384,$vararg_buffer1)|0);
     break;
    } else {
     $5 = (_lua_tointegerx($L,$idx,0)|0);
     $6 = tempRet0;
     $7 = $vararg_buffer;
     $8 = $7;
     HEAP32[$8>>2] = $5;
     $9 = (($7) + 4)|0;
     $10 = $9;
     HEAP32[$10>>2] = $6;
     (_lua_pushfstring($L,4376,$vararg_buffer)|0);
     break;
    }
   } else if ((($2|0) == 1)) {
    $12 = (_lua_toboolean($L,$idx)|0);
    $13 = ($12|0)!=(0);
    $14 = $13 ? 5816 : 5728;
    (_lua_pushstring($L,$14)|0);
    break;
   } else {
    $15 = (_lua_type($L,$idx)|0);
    $16 = (_lua_typename($L,$15)|0);
    $17 = (_lua_topointer($L,$idx)|0);
    HEAP32[$vararg_buffer4>>2] = $16;
    $vararg_ptr7 = ((($vararg_buffer4)) + 4|0);
    HEAP32[$vararg_ptr7>>2] = $17;
    (_lua_pushfstring($L,4392,$vararg_buffer4)|0);
    break;
   }
  }
 } while(0);
 $18 = (_lua_tolstring($L,-1,$len)|0);
 STACKTOP = sp;return ($18|0);
}
function _luaL_setfuncs($L,$l,$nup) {
 $L = $L|0;
 $l = $l|0;
 $nup = $nup|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01$us = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (($nup) + 20)|0;
 $1 = (_lua_checkstack($L,$0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 4400;
  (_luaL_error($L,4184,$vararg_buffer)|0);
 }
 $3 = HEAP32[$l>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $25 = $nup ^ -1;
  _lua_settop($L,$25);
  STACKTOP = sp;return;
 }
 $5 = ($nup|0)>(0);
 $6 = (-2 - ($nup))|0;
 $7 = (0 - ($nup))|0;
 if ($5) {
  $12 = $l;$9 = $l;
 } else {
  $18 = $l;$21 = $l;
  while(1) {
   $17 = ((($18)) + 4|0);
   $19 = HEAP32[$17>>2]|0;
   _lua_pushcclosure($L,$19,$nup);
   $20 = HEAP32[$21>>2]|0;
   _lua_setfield($L,$6,$20);
   $22 = ((($18)) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    break;
   } else {
    $18 = $22;$21 = $22;
   }
  }
  $25 = $nup ^ -1;
  _lua_settop($L,$25);
  STACKTOP = sp;return;
 }
 while(1) {
  $i$01$us = 0;
  while(1) {
   _lua_pushvalue($L,$7);
   $16 = (($i$01$us) + 1)|0;
   $exitcond = ($16|0)==($nup|0);
   if ($exitcond) {
    break;
   } else {
    $i$01$us = $16;
   }
  }
  $8 = ((($9)) + 4|0);
  $10 = HEAP32[$8>>2]|0;
  _lua_pushcclosure($L,$10,$nup);
  $11 = HEAP32[$12>>2]|0;
  _lua_setfield($L,$6,$11);
  $13 = ((($9)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   break;
  } else {
   $12 = $13;$9 = $13;
  }
 }
 $25 = $nup ^ -1;
 _lua_settop($L,$25);
 STACKTOP = sp;return;
}
function _luaL_getsubtable($L,$idx,$fname) {
 $L = $L|0;
 $idx = $idx|0;
 $fname = $fname|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_getfield($L,$idx,$fname)|0);
 $1 = ($0|0)==(5);
 if ($1) {
  $$0 = 1;
  return ($$0|0);
 }
 _lua_settop($L,-2);
 $2 = (_lua_absindex($L,$idx)|0);
 _lua_createtable($L,0,0);
 _lua_pushvalue($L,-1);
 _lua_setfield($L,$2,$fname);
 $$0 = 0;
 return ($$0|0);
}
function _luaL_requiref($L,$modname,$openf,$glb) {
 $L = $L|0;
 $modname = $modname|0;
 $openf = $openf|0;
 $glb = $glb|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_getfield($L,-1001000,12952)|0);
 $1 = ($0|0)==(5);
 if (!($1)) {
  _lua_settop($L,-2);
  $2 = (_lua_absindex($L,-1001000)|0);
  _lua_createtable($L,0,0);
  _lua_pushvalue($L,-1);
  _lua_setfield($L,$2,12952);
 }
 (_lua_getfield($L,-1,$modname)|0);
 $3 = (_lua_toboolean($L,-1)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  _lua_settop($L,-2);
  _lua_pushcclosure($L,$openf,0);
  (_lua_pushstring($L,$modname)|0);
  _lua_callk($L,1,1,0,0);
  _lua_pushvalue($L,-1);
  _lua_setfield($L,-3,$modname);
 }
 _lua_rotate($L,-2,-1);
 _lua_settop($L,-2);
 $5 = ($glb|0)==(0);
 if ($5) {
  return;
 }
 _lua_pushvalue($L,-1);
 _lua_setglobal($L,$modname);
 return;
}
function _luaL_gsub($L,$s,$p,$r) {
 $L = $L|0;
 $s = $s|0;
 $p = $p|0;
 $r = $r|0;
 var $$$i = 0, $$$i11 = 0, $$$i4 = 0, $$0$lcssa = 0, $$015 = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i6 = 0, $$pre17 = 0, $$pre18 = 0, $$pre2$i = 0, $$pre2$i2 = 0, $$pre2$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $b = 0;
 var $or$cond$i = 0, $or$cond$i12 = 0, $or$cond$i5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $b = sp + 24|0;
 $0 = (_strlen(($p|0))|0);
 $1 = ((($b)) + 12|0);
 HEAP32[$1>>2] = $L;
 $2 = ((($b)) + 16|0);
 HEAP32[$b>>2] = $2;
 $3 = ((($b)) + 8|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($b)) + 4|0);
 HEAP32[$4>>2] = 4096;
 $5 = (_strstr($s,$p)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $$0$lcssa = $s;$60 = 4096;$61 = 0;$70 = $L;
 } else {
  $$015 = $s;$12 = 4096;$13 = 0;$22 = $L;$8 = $5;
  while(1) {
   $7 = $8;
   $9 = $$015;
   $10 = (($7) - ($9))|0;
   $11 = (($12) - ($13))|0;
   $14 = ($11>>>0)<($10>>>0);
   if ($14) {
    $15 = $12 << 1;
    $16 = (($15) - ($13))|0;
    $17 = ($16>>>0)<($10>>>0);
    $18 = (($13) + ($10))|0;
    $$$i = $17 ? $18 : $15;
    $19 = ($$$i>>>0)<($13>>>0);
    $20 = (($$$i) - ($13))|0;
    $21 = ($20>>>0)<($10>>>0);
    $or$cond$i = $19 | $21;
    if ($or$cond$i) {
     (_luaL_error($22,4264,$vararg_buffer)|0);
    }
    $23 = (_lua_newuserdata($22,$$$i)|0);
    $24 = HEAP32[$b>>2]|0;
    $25 = HEAP32[$3>>2]|0;
    _memcpy(($23|0),($24|0),($25|0))|0;
    $26 = HEAP32[$b>>2]|0;
    $27 = ($26|0)==($2|0);
    if (!($27)) {
     _lua_rotate($22,-2,-1);
     _lua_settop($22,-2);
    }
    HEAP32[$b>>2] = $23;
    HEAP32[$4>>2] = $$$i;
    $$pre$i = HEAP32[$3>>2]|0;
    $29 = $23;$30 = $$pre$i;
   } else {
    $$pre2$i = HEAP32[$b>>2]|0;
    $29 = $$pre2$i;$30 = $13;
   }
   $28 = (($29) + ($30)|0);
   _memcpy(($28|0),($$015|0),($10|0))|0;
   $31 = HEAP32[$3>>2]|0;
   $32 = (($31) + ($10))|0;
   HEAP32[$3>>2] = $32;
   $33 = (_strlen(($r|0))|0);
   $34 = HEAP32[$1>>2]|0;
   $35 = HEAP32[$4>>2]|0;
   $36 = (($35) - ($32))|0;
   $37 = ($36>>>0)<($33>>>0);
   if ($37) {
    $38 = $35 << 1;
    $39 = (($38) - ($32))|0;
    $40 = ($39>>>0)<($33>>>0);
    $41 = (($32) + ($33))|0;
    $$$i4 = $40 ? $41 : $38;
    $42 = ($$$i4>>>0)<($32>>>0);
    $43 = (($$$i4) - ($32))|0;
    $44 = ($43>>>0)<($33>>>0);
    $or$cond$i5 = $42 | $44;
    if ($or$cond$i5) {
     (_luaL_error($34,4264,$vararg_buffer1)|0);
    }
    $45 = (_lua_newuserdata($34,$$$i4)|0);
    $46 = HEAP32[$b>>2]|0;
    $47 = HEAP32[$3>>2]|0;
    _memcpy(($45|0),($46|0),($47|0))|0;
    $48 = HEAP32[$b>>2]|0;
    $49 = ($48|0)==($2|0);
    if (!($49)) {
     _lua_rotate($34,-2,-1);
     _lua_settop($34,-2);
    }
    HEAP32[$b>>2] = $45;
    HEAP32[$4>>2] = $$$i4;
    $$pre$i6 = HEAP32[$3>>2]|0;
    $51 = $45;$52 = $$pre$i6;
   } else {
    $$pre2$i2 = HEAP32[$b>>2]|0;
    $51 = $$pre2$i2;$52 = $32;
   }
   $50 = (($51) + ($52)|0);
   _memcpy(($50|0),($r|0),($33|0))|0;
   $53 = HEAP32[$3>>2]|0;
   $54 = (($53) + ($33))|0;
   HEAP32[$3>>2] = $54;
   $55 = (($8) + ($0)|0);
   $56 = (_strstr($55,$p)|0);
   $57 = ($56|0)==(0|0);
   $$pre17 = HEAP32[$1>>2]|0;
   $$pre18 = HEAP32[$4>>2]|0;
   if ($57) {
    $$0$lcssa = $55;$60 = $$pre18;$61 = $54;$70 = $$pre17;
    break;
   } else {
    $$015 = $55;$12 = $$pre18;$13 = $54;$22 = $$pre17;$8 = $56;
   }
  }
 }
 $58 = (_strlen(($$0$lcssa|0))|0);
 $59 = (($60) - ($61))|0;
 $62 = ($59>>>0)<($58>>>0);
 if ($62) {
  $63 = $60 << 1;
  $64 = (($63) - ($61))|0;
  $65 = ($64>>>0)<($58>>>0);
  $66 = (($61) + ($58))|0;
  $$$i11 = $65 ? $66 : $63;
  $67 = ($$$i11>>>0)<($61>>>0);
  $68 = (($$$i11) - ($61))|0;
  $69 = ($68>>>0)<($58>>>0);
  $or$cond$i12 = $67 | $69;
  if ($or$cond$i12) {
   (_luaL_error($70,4264,$vararg_buffer3)|0);
  }
  $71 = (_lua_newuserdata($70,$$$i11)|0);
  $72 = HEAP32[$b>>2]|0;
  $73 = HEAP32[$3>>2]|0;
  _memcpy(($71|0),($72|0),($73|0))|0;
  $74 = HEAP32[$b>>2]|0;
  $75 = ($74|0)==($2|0);
  if (!($75)) {
   _lua_rotate($70,-2,-1);
   _lua_settop($70,-2);
  }
  HEAP32[$b>>2] = $71;
  HEAP32[$4>>2] = $$$i11;
  $$pre$i13 = HEAP32[$3>>2]|0;
  $77 = $71;$78 = $$pre$i13;
 } else {
  $$pre2$i9 = HEAP32[$b>>2]|0;
  $77 = $$pre2$i9;$78 = $61;
 }
 $76 = (($77) + ($78)|0);
 _memcpy(($76|0),($$0$lcssa|0),($58|0))|0;
 $79 = HEAP32[$3>>2]|0;
 $80 = (($79) + ($58))|0;
 HEAP32[$3>>2] = $80;
 $81 = HEAP32[$1>>2]|0;
 $82 = HEAP32[$b>>2]|0;
 (_lua_pushlstring($81,$82,$80)|0);
 $83 = HEAP32[$b>>2]|0;
 $84 = ($83|0)==($2|0);
 if ($84) {
  $85 = (_lua_tolstring($L,-1,0)|0);
  STACKTOP = sp;return ($85|0);
 }
 _lua_rotate($81,-2,-1);
 _lua_settop($81,-2);
 $85 = (_lua_tolstring($L,-1,0)|0);
 STACKTOP = sp;return ($85|0);
}
function _luaL_newstate() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_newstate(318,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  return ($0|0);
 }
 (_lua_atpanic($0,319)|0);
 return ($0|0);
}
function _luaL_checkversion_($L,$ver,$sz) {
 $L = $L|0;
 $ver = +$ver;
 $sz = $sz|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_lua_version($L)|0);
 $1 = ($sz|0)==(136);
 if (!($1)) {
  (_luaL_error($L,4424,$vararg_buffer)|0);
 }
 $2 = (_lua_version(0)|0);
 $3 = ($0|0)==($2|0);
 if (!($3)) {
  (_luaL_error($L,4480,$vararg_buffer1)|0);
  STACKTOP = sp;return;
 }
 $4 = +HEAPF64[$0>>3];
 $5 = $4 != $ver;
 if (!($5)) {
  STACKTOP = sp;return;
 }
 HEAPF64[$vararg_buffer3>>3] = $ver;
 $vararg_ptr5 = ((($vararg_buffer3)) + 8|0);
 HEAPF64[$vararg_ptr5>>3] = $4;
 (_luaL_error($L,4512,$vararg_buffer3)|0);
 STACKTOP = sp;return;
}
function _pushglobalfuncname($L,$ar) {
 $L = $L|0;
 $ar = $ar|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 (_lua_getinfo($L,4664,$ar)|0);
 (_lua_getfield($L,-1001000,12952)|0);
 $1 = (($0) + 1)|0;
 $2 = (_findfield($L,$1,2)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  _lua_settop($L,$0);
  $$0 = 0;
  return ($$0|0);
 }
 $4 = (_lua_tolstring($L,-1,0)|0);
 $5 = (_strncmp($4,4672,3)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = ((($4)) + 3|0);
  (_lua_pushstring($L,$7)|0);
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
 }
 _lua_copy($L,-1,$1);
 _lua_settop($L,-3);
 $$0 = 1;
 return ($$0|0);
}
function _typeerror($L,$arg,$tname) {
 $L = $L|0;
 $arg = $arg|0;
 $tname = $tname|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $typearg$0 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_lua_getmetatable($L,$arg)|0);
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   label = 6;
  } else {
   (_lua_pushstring($L,4152)|0);
   $2 = (_lua_rawget($L,-2)|0);
   $3 = ($2|0)==(0);
   if ($3) {
    _lua_settop($L,-3);
    label = 6;
    break;
   }
   _lua_rotate($L,-2,-1);
   _lua_settop($L,-2);
   $4 = ($2|0)==(4);
   if ($4) {
    $5 = (_lua_tolstring($L,-1,0)|0);
    $typearg$0 = $5;
   } else {
    label = 6;
   }
  }
 } while(0);
 if ((label|0) == 6) {
  $6 = (_lua_type($L,$arg)|0);
  $7 = ($6|0)==(2);
  if ($7) {
   $typearg$0 = 4624;
  } else {
   $8 = (_lua_type($L,$arg)|0);
   $9 = (_lua_typename($L,$8)|0);
   $typearg$0 = $9;
  }
 }
 HEAP32[$vararg_buffer>>2] = $tname;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $typearg$0;
 $10 = (_lua_pushfstring($L,4640,$vararg_buffer)|0);
 (_luaL_argerror($L,$arg,$10)|0);
 STACKTOP = sp;return;
}
function _skipcomment($lf,$cp) {
 $lf = $lf|0;
 $cp = $cp|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$lf>>2] = 0;
 $0 = ((($lf)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_getc(($1|0))|0);
 do {
  if ((($2|0) == -1)) {
   label = 5;
  } else if ((($2|0) == 239)) {
   $3 = HEAP32[$lf>>2]|0;
   $4 = (($3) + 1)|0;
   HEAP32[$lf>>2] = $4;
   $5 = (((($lf)) + 8|0) + ($3)|0);
   HEAP8[$5>>0] = -17;
   $6 = HEAP32[$0>>2]|0;
   $7 = (_getc(($6|0))|0);
   if ((($7|0) == -1)) {
    label = 5;
    break;
   } else if (!((($7|0) == 187))) {
    $$0$i = $7;
    break;
   }
   $8 = HEAP32[$lf>>2]|0;
   $9 = (($8) + 1)|0;
   HEAP32[$lf>>2] = $9;
   $10 = (((($lf)) + 8|0) + ($8)|0);
   HEAP8[$10>>0] = -69;
   $11 = HEAP32[$0>>2]|0;
   $12 = (_getc(($11|0))|0);
   if ((($12|0) == -1)) {
    label = 5;
    break;
   } else if (!((($12|0) == 191))) {
    $$0$i = $12;
    break;
   }
   $13 = HEAP32[$lf>>2]|0;
   $14 = (((($lf)) + 8|0) + ($13)|0);
   HEAP8[$14>>0] = -65;
   HEAP32[$lf>>2] = 0;
   $15 = HEAP32[$0>>2]|0;
   $16 = (_getc(($15|0))|0);
   $$0$i = $16;
  } else {
   $$0$i = $2;
  }
 } while(0);
 if ((label|0) == 5) {
  HEAP32[$cp>>2] = -1;
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[$cp>>2] = $$0$i;
 $17 = ($$0$i|0)==(35);
 if (!($17)) {
  $$0 = 0;
  return ($$0|0);
 }
 while(1) {
  $18 = HEAP32[$0>>2]|0;
  $19 = (_getc(($18|0))|0);
  if ((($19|0) == 10) | (($19|0) == -1)) {
   break;
  }
 }
 $20 = HEAP32[$0>>2]|0;
 $21 = (_getc(($20|0))|0);
 HEAP32[$cp>>2] = $21;
 $$0 = 1;
 return ($$0|0);
}
function _getF($L,$ud,$size) {
 $L = $L|0;
 $ud = $ud|0;
 $size = $size|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ud>>2]|0;
 $1 = ($0|0)>(0);
 if ($1) {
  HEAP32[$size>>2] = $0;
  HEAP32[$ud>>2] = 0;
  $$pre = ((($ud)) + 8|0);
  $$0 = $$pre;
  return ($$0|0);
 }
 $2 = ((($ud)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_feof(($3|0))|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = 0;
  return ($$0|0);
 }
 $6 = ((($ud)) + 8|0);
 $7 = HEAP32[$2>>2]|0;
 $8 = (_fread(($6|0),1,1024,($7|0))|0);
 HEAP32[$size>>2] = $8;
 $$0 = $6;
 return ($$0|0);
}
function _getS($L,$ud,$size) {
 $L = $L|0;
 $ud = $ud|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ud)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[$size>>2] = $1;
 HEAP32[$0>>2] = 0;
 $3 = HEAP32[$ud>>2]|0;
 $$0 = $3;
 return ($$0|0);
}
function _l_alloc($ud,$ptr,$osize,$nsize) {
 $ud = $ud|0;
 $ptr = $ptr|0;
 $osize = $osize|0;
 $nsize = $nsize|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($nsize|0)==(0);
 if ($0) {
  _free($ptr);
  $$0 = 0;
  return ($$0|0);
 } else {
  $1 = (_realloc($ptr,$nsize)|0);
  $$0 = $1;
  return ($$0|0);
 }
 return (0)|0;
}
function _panic($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 $1 = (_lua_tolstring($L,-1,0)|0);
 HEAP32[$vararg_buffer>>2] = $1;
 (_fprintf(($0|0),(4568|0),($vararg_buffer|0))|0);
 (_fflush(($0|0))|0);
 STACKTOP = sp;return 0;
}
function _findfield($L,$objidx,$level) {
 $L = $L|0;
 $objidx = $objidx|0;
 $level = $level|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($level|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = (_lua_type($L,-1)|0);
 $2 = ($1|0)==(5);
 if (!($2)) {
  $$0 = 0;
  return ($$0|0);
 }
 _lua_pushnil($L);
 $3 = (_lua_next($L,-2)|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = (($level) + -1)|0;
 while(1) {
  $6 = (_lua_type($L,-2)|0);
  $7 = ($6|0)==(4);
  if ($7) {
   $8 = (_lua_rawequal($L,$objidx,-1)|0);
   $9 = ($8|0)==(0);
   if (!($9)) {
    label = 7;
    break;
   }
   $10 = (_findfield($L,$objidx,$5)|0);
   $11 = ($10|0)==(0);
   if (!($11)) {
    label = 9;
    break;
   }
  }
  _lua_settop($L,-2);
  $12 = (_lua_next($L,-2)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   $$0 = 0;
   label = 11;
   break;
  }
 }
 if ((label|0) == 7) {
  _lua_settop($L,-2);
  $$0 = 1;
  return ($$0|0);
 }
 else if ((label|0) == 9) {
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
  (_lua_pushlstring($L,73176,1)|0);
  _lua_rotate($L,-2,1);
  _lua_concat($L,3);
  $$0 = 1;
  return ($$0|0);
 }
 else if ((label|0) == 11) {
  return ($$0|0);
 }
 return (0)|0;
}
function _luaL_openlibs($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_requiref($L,6176,320,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4680,321,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4688,322,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4704,323,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4712,324,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4720,325,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,5608,326,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4728,327,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,36016,328,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,7584,329,1);
 _lua_settop($L,-2);
 _luaL_requiref($L,4736,330,1);
 _lua_settop($L,-2);
 return;
}
function _luaK_nil($fs,$from,$n) {
 $fs = $fs|0;
 $from = $from|0;
 $n = $n|0;
 var $$from = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$0 = 0;
 var $or$cond = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($n) + ($from))|0;
 $1 = (($0) + -1)|0;
 $2 = ((($fs)) + 16|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($fs)) + 20|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($3|0)>($5|0);
 do {
  if ($6) {
   $7 = (($3) + -1)|0;
   $8 = HEAP32[$fs>>2]|0;
   $9 = ((($8)) + 48|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($10) + ($7<<2)|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = $12 & 63;
   $14 = ($13|0)==(4);
   if ($14) {
    $15 = $12 >>> 6;
    $16 = $15 & 255;
    $17 = $12 >>> 23;
    $18 = (($16) + ($17))|0;
    $19 = ($16|0)>($from|0);
    $20 = (($18) + 1)|0;
    $21 = ($20|0)<($from|0);
    $or$cond = $19 | $21;
    if ($or$cond) {
     $22 = ($16|0)<($from|0);
     $23 = ($16|0)>($0|0);
     $or$cond2 = $22 | $23;
     if ($or$cond2) {
      break;
     }
    }
    $24 = ($16|0)<($from|0);
    $$from = $24 ? $16 : $from;
    $25 = ($18|0)>($1|0);
    $l$0 = $25 ? $18 : $1;
    $26 = $12 & 8372287;
    $27 = $$from << 6;
    $28 = $27 & 16320;
    $29 = (($l$0) - ($$from))|0;
    $30 = $29 << 23;
    $31 = $30 | $28;
    $32 = $31 | $26;
    HEAP32[$11>>2] = $32;
    return;
   }
  }
 } while(0);
 $33 = $from << 6;
 $34 = $n << 23;
 $35 = (($34) + -8388608)|0;
 $36 = $33 | $35;
 $37 = $36 | 4;
 (_luaK_code($fs,$37)|0);
 return;
}
function _luaK_codeABC($fs,$o,$a,$b,$c) {
 $fs = $fs|0;
 $o = $o|0;
 $a = $a|0;
 $b = $b|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a << 6;
 $1 = $0 | $o;
 $2 = $b << 23;
 $3 = $1 | $2;
 $4 = $c << 14;
 $5 = $3 | $4;
 $6 = (_luaK_code($fs,$5)|0);
 return ($6|0);
}
function _luaK_jump($fs) {
 $fs = $fs|0;
 var $$0$i$i = 0, $$lcssa = 0, $$lcssa6 = 0, $$neg$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $ispos$i$i = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 24|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[$0>>2] = -1;
 $2 = (_luaK_code($fs,2147450910)|0);
 $3 = ($1|0)==(-1);
 if ($3) {
  $22 = $2;
  return ($22|0);
 }
 $4 = ($2|0)==(-1);
 if ($4) {
  $22 = $1;
  return ($22|0);
 }
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
 $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
 $list$0$i = $2;
 while(1) {
  $5 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = $6 >>> 14;
  $8 = (($7) + -131071)|0;
  $9 = ($8|0)==(-1);
  $10 = (($list$0$i) + 1)|0;
  $11 = (($10) + ($8))|0;
  $$0$i$i = $9 ? -1 : $11;
  $12 = ($$0$i$i|0)==(-1);
  if ($12) {
   $$lcssa = $5;$$lcssa6 = $6;$list$0$i$lcssa = $list$0$i;
   break;
  } else {
   $list$0$i = $$0$i$i;
  }
 }
 $$neg$i$i = $list$0$i$lcssa ^ -1;
 $13 = (($1) + ($$neg$i$i))|0;
 $ispos$i$i = ($13|0)>(-1);
 $neg$i$i = (0 - ($13))|0;
 $14 = $ispos$i$i ? $13 : $neg$i$i;
 $15 = ($14|0)>(131071);
 if ($15) {
  $16 = ((($fs)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  _luaX_syntaxerror($17,4744);
  // unreachable;
 }
 $18 = $$lcssa6 & 16383;
 $19 = $13 << 14;
 $20 = (($19) + 2147467264)|0;
 $21 = $20 | $18;
 HEAP32[$$lcssa>>2] = $21;
 $22 = $2;
 return ($22|0);
}
function _luaK_codeABx($fs,$o,$a,$bc) {
 $fs = $fs|0;
 $o = $o|0;
 $a = $a|0;
 $bc = $bc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $a << 6;
 $1 = $0 | $o;
 $2 = $bc << 14;
 $3 = $1 | $2;
 $4 = (_luaK_code($fs,$3)|0);
 return ($4|0);
}
function _luaK_concat($fs,$l1,$l2) {
 $fs = $fs|0;
 $l1 = $l1|0;
 $l2 = $l2|0;
 var $$0$i = 0, $$lcssa = 0, $$lcssa4 = 0, $$neg$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$val = 0, $ispos$i = 0, $list$0 = 0, $list$0$lcssa = 0, $neg$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($l2|0)==(-1);
 if ($0) {
  return;
 }
 $1 = HEAP32[$l1>>2]|0;
 $2 = ($1|0)==(-1);
 if ($2) {
  HEAP32[$l1>>2] = $l2;
  return;
 }
 $fs$idx$val = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
 $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
 $list$0 = $1;
 while(1) {
  $3 = (($fs$idx$val$idx$val) + ($list$0<<2)|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = $4 >>> 14;
  $6 = (($5) + -131071)|0;
  $7 = ($6|0)==(-1);
  $8 = (($list$0) + 1)|0;
  $9 = (($8) + ($6))|0;
  $$0$i = $7 ? -1 : $9;
  $10 = ($$0$i|0)==(-1);
  if ($10) {
   $$lcssa = $3;$$lcssa4 = $4;$list$0$lcssa = $list$0;
   break;
  } else {
   $list$0 = $$0$i;
  }
 }
 $$neg$i = $list$0$lcssa ^ -1;
 $11 = (($$neg$i) + ($l2))|0;
 $ispos$i = ($11|0)>(-1);
 $neg$i = (0 - ($11))|0;
 $12 = $ispos$i ? $11 : $neg$i;
 $13 = ($12|0)>(131071);
 if ($13) {
  $14 = ((($fs)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  _luaX_syntaxerror($15,4744);
  // unreachable;
 }
 $16 = $$lcssa4 & 16383;
 $17 = $11 << 14;
 $18 = (($17) + 2147467264)|0;
 $19 = $16 | $18;
 HEAP32[$$lcssa>>2] = $19;
 return;
}
function _luaK_ret($fs,$first,$nret) {
 $fs = $fs|0;
 $first = $first|0;
 $nret = $nret|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $first << 6;
 $1 = $nret << 23;
 $2 = (($1) + 8388608)|0;
 $3 = $0 | $2;
 $4 = $3 | 38;
 (_luaK_code($fs,$4)|0);
 return;
}
function _luaK_getlabel($fs) {
 $fs = $fs|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 20|0);
 HEAP32[$2>>2] = $1;
 return ($1|0);
}
function _luaK_patchlist($fs,$list,$target) {
 $fs = $fs|0;
 $list = $list|0;
 $target = $target|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i1 = 0, $$02$i = 0, $$lcssa = 0, $$lcssa10 = 0, $$neg$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i$i = 0, $fs$idx$val$i$pre = 0;
 var $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$phi$trans$insert = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$pre = 0, $ispos$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $list$0$i$i = 0, $list$0$i$i$lcssa = 0, $neg$i = 0, $neg$i$i = 0, $neg$i$i$i = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==($target|0);
 if ($2) {
  $3 = ((($fs)) + 20|0);
  HEAP32[$3>>2] = $target;
  $4 = ((($fs)) + 24|0);
  $5 = ($list|0)==(-1);
  if ($5) {
   return;
  }
  $6 = HEAP32[$4>>2]|0;
  $7 = ($6|0)==(-1);
  if ($7) {
   HEAP32[$4>>2] = $list;
   return;
  }
  $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
  $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
  $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
  $list$0$i$i = $6;
  while(1) {
   $8 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = $9 >>> 14;
   $11 = (($10) + -131071)|0;
   $12 = ($11|0)==(-1);
   $13 = (($list$0$i$i) + 1)|0;
   $14 = (($13) + ($11))|0;
   $$0$i$i$i = $12 ? -1 : $14;
   $15 = ($$0$i$i$i|0)==(-1);
   if ($15) {
    $$lcssa = $8;$$lcssa10 = $9;$list$0$i$i$lcssa = $list$0$i$i;
    break;
   } else {
    $list$0$i$i = $$0$i$i$i;
   }
  }
  $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
  $16 = (($$neg$i$i$i) + ($list))|0;
  $ispos$i$i$i = ($16|0)>(-1);
  $neg$i$i$i = (0 - ($16))|0;
  $17 = $ispos$i$i$i ? $16 : $neg$i$i$i;
  $18 = ($17|0)>(131071);
  if ($18) {
   $19 = ((($fs)) + 8|0);
   $20 = HEAP32[$19>>2]|0;
   _luaX_syntaxerror($20,4744);
   // unreachable;
  }
  $21 = $$lcssa10 & 16383;
  $22 = $16 << 14;
  $23 = (($22) + 2147467264)|0;
  $24 = $23 | $21;
  HEAP32[$$lcssa>>2] = $24;
  return;
 }
 $25 = ($list|0)==(-1);
 if ($25) {
  return;
 }
 $fs$idx$val$i$pre = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$phi$trans$insert = ((($fs$idx$val$i$pre)) + 48|0);
 $fs$idx$val$idx$val$i$pre = HEAP32[$fs$idx$val$idx$i$phi$trans$insert>>2]|0;
 $$02$i = $list;
 while(1) {
  $26 = (($fs$idx$val$idx$val$i$pre) + ($$02$i<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 >>> 14;
  $29 = (($28) + -131071)|0;
  $30 = ($29|0)==(-1);
  $31 = (($$02$i) + 1)|0;
  $32 = (($31) + ($29))|0;
  $$0$i$i = $30 ? -1 : $32;
  $33 = ($$02$i|0)>(0);
  if ($33) {
   $$sum$i$i = (($$02$i) + -1)|0;
   $34 = (($fs$idx$val$idx$val$i$pre) + ($$sum$i$i<<2)|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = $35 & 63;
   $37 = (1960 + ($36)|0);
   $38 = HEAP8[$37>>0]|0;
   $39 = ($38<<24>>24)<(0);
   if ($39) {
    $$0$i$i1 = $34;$41 = $35;
   } else {
    label = 14;
   }
  } else {
   label = 14;
  }
  if ((label|0) == 14) {
   label = 0;
   $$0$i$i1 = $26;$41 = $27;
  }
  $40 = $41 & 63;
  $42 = ($40|0)==(35);
  if ($42) {
   $43 = $41 >>> 23;
   $44 = $43 << 6;
   $45 = $41 & 8372224;
   $46 = $45 | $44;
   $47 = $46 | 34;
   HEAP32[$$0$i$i1>>2] = $47;
   $$neg$i = $$02$i ^ -1;
   $48 = (($$neg$i) + ($target))|0;
   $ispos$i = ($48|0)>(-1);
   $neg$i = (0 - ($48))|0;
   $49 = $ispos$i ? $48 : $neg$i;
   $50 = ($49|0)>(131071);
   if ($50) {
    label = 17;
    break;
   }
   $53 = HEAP32[$26>>2]|0;
   $54 = $53 & 16383;
   $55 = $48 << 14;
   $56 = (($55) + 2147467264)|0;
   $57 = $54 | $56;
   $storemerge = $57;
  } else {
   $$neg$i$i = $$02$i ^ -1;
   $58 = (($$neg$i$i) + ($target))|0;
   $ispos$i$i = ($58|0)>(-1);
   $neg$i$i = (0 - ($58))|0;
   $59 = $ispos$i$i ? $58 : $neg$i$i;
   $60 = ($59|0)>(131071);
   if ($60) {
    label = 20;
    break;
   }
   $63 = $27 & 16383;
   $64 = $58 << 14;
   $65 = (($64) + 2147467264)|0;
   $66 = $63 | $65;
   $storemerge = $66;
  }
  HEAP32[$26>>2] = $storemerge;
  $67 = ($$0$i$i|0)==(-1);
  if ($67) {
   label = 23;
   break;
  } else {
   $$02$i = $$0$i$i;
  }
 }
 if ((label|0) == 17) {
  $51 = ((($fs)) + 8|0);
  $52 = HEAP32[$51>>2]|0;
  _luaX_syntaxerror($52,4744);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $61 = ((($fs)) + 8|0);
  $62 = HEAP32[$61>>2]|0;
  _luaX_syntaxerror($62,4744);
  // unreachable;
 }
 else if ((label|0) == 23) {
  return;
 }
}
function _luaK_patchtohere($fs,$list) {
 $fs = $fs|0;
 $list = $list|0;
 var $$0$i$i = 0, $$lcssa = 0, $$lcssa6 = 0, $$neg$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $ispos$i$i = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($fs)) + 20|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($fs)) + 24|0);
 $4 = ($list|0)==(-1);
 if ($4) {
  return;
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(-1);
 if ($6) {
  HEAP32[$3>>2] = $list;
  return;
 }
 $fs$idx$val$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
 $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
 $list$0$i = $5;
 while(1) {
  $7 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = $8 >>> 14;
  $10 = (($9) + -131071)|0;
  $11 = ($10|0)==(-1);
  $12 = (($list$0$i) + 1)|0;
  $13 = (($12) + ($10))|0;
  $$0$i$i = $11 ? -1 : $13;
  $14 = ($$0$i$i|0)==(-1);
  if ($14) {
   $$lcssa = $7;$$lcssa6 = $8;$list$0$i$lcssa = $list$0$i;
   break;
  } else {
   $list$0$i = $$0$i$i;
  }
 }
 $$neg$i$i = $list$0$i$lcssa ^ -1;
 $15 = (($$neg$i$i) + ($list))|0;
 $ispos$i$i = ($15|0)>(-1);
 $neg$i$i = (0 - ($15))|0;
 $16 = $ispos$i$i ? $15 : $neg$i$i;
 $17 = ($16|0)>(131071);
 if ($17) {
  $18 = ((($fs)) + 8|0);
  $19 = HEAP32[$18>>2]|0;
  _luaX_syntaxerror($19,4744);
  // unreachable;
 }
 $20 = $$lcssa6 & 16383;
 $21 = $15 << 14;
 $22 = (($21) + 2147467264)|0;
 $23 = $22 | $20;
 HEAP32[$$lcssa>>2] = $23;
 return;
}
function _luaK_patchclose($fs,$list,$level) {
 $fs = $fs|0;
 $list = $list|0;
 $level = $level|0;
 var $$ = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fs$idx$val = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$val = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = ($list|0)==(-1);
 if ($0) {
  return;
 }
 $fs$idx$val = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
 $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
 $1 = $level << 6;
 $2 = (($1) + 64)|0;
 $3 = $2 & 16320;
 $$01 = $list;
 while(1) {
  $4 = (($fs$idx$val$idx$val) + ($$01<<2)|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 >>> 14;
  $7 = (($6) + -131071)|0;
  $8 = ($7|0)==(-1);
  $9 = (($$01) + 1)|0;
  $10 = (($9) + ($7))|0;
  $11 = $5 & -16321;
  $12 = $11 | $3;
  HEAP32[$4>>2] = $12;
  $$ = $8 ? -1 : $10;
  $13 = ($$|0)==(-1);
  if ($13) {
   break;
  } else {
   $$01 = $$;
  }
 }
 return;
}
function _luaK_codek($fs,$reg,$k) {
 $fs = $fs|0;
 $reg = $reg|0;
 $k = $k|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($k|0)<(262144);
 $1 = $reg << 6;
 if ($0) {
  $2 = $k << 14;
  $3 = $1 | $2;
  $4 = $3 | 1;
  $5 = (_luaK_code($fs,$4)|0);
  $$0 = $5;
  return ($$0|0);
 } else {
  $6 = $1 | 2;
  $7 = (_luaK_code($fs,$6)|0);
  $8 = $k << 6;
  $9 = $8 | 46;
  (_luaK_code($fs,$9)|0);
  $$0 = $7;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaK_checkstack($fs,$n) {
 $fs = $fs|0;
 $n = $n|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($2) + ($n))|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ($3|0)>($7|0);
 if (!($8)) {
  return;
 }
 $9 = ($3|0)>(249);
 if ($9) {
  $10 = ((($fs)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  _luaX_syntaxerror($11,4776);
  // unreachable;
 }
 $12 = $3&255;
 HEAP8[$5>>0] = $12;
 return;
}
function _luaK_reserveregs($fs,$n) {
 $fs = $fs|0;
 $n = $n|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 44|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = (($2) + ($n))|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($4)) + 8|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6&255;
 $8 = ($3|0)>($7|0);
 if (!($8)) {
  $$pre = $3&255;
  $$pre$phiZ2D = $$pre;
  HEAP8[$0>>0] = $$pre$phiZ2D;
  return;
 }
 $9 = ($3|0)>(249);
 if ($9) {
  $10 = ((($fs)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  _luaX_syntaxerror($11,4776);
  // unreachable;
 }
 $12 = $3&255;
 HEAP8[$5>>0] = $12;
 $$pre$phiZ2D = $12;
 HEAP8[$0>>0] = $$pre$phiZ2D;
 return;
}
function _luaK_stringK($fs,$s) {
 $fs = $fs|0;
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $o = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $o = sp;
 HEAP32[$o>>2] = $s;
 $0 = ((($s)) + 4|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1&255;
 $3 = $2 | 64;
 $4 = ((($o)) + 8|0);
 HEAP32[$4>>2] = $3;
 $5 = (_addk($fs,$o,$o)|0);
 STACKTOP = sp;return ($5|0);
}
function _luaK_intK($fs,$0,$1) {
 $fs = $fs|0;
 $0 = $0|0;
 $1 = $1|0;
 var $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k = 0, $o = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k = sp + 16|0;
 $o = sp;
 $2 = $0;
 HEAP32[$k>>2] = $2;
 $3 = ((($k)) + 8|0);
 HEAP32[$3>>2] = 2;
 $4 = $o;
 $5 = $4;
 HEAP32[$5>>2] = $0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = $1;
 $8 = ((($o)) + 8|0);
 HEAP32[$8>>2] = 19;
 $9 = (_addk($fs,$k,$o)|0);
 STACKTOP = sp;return ($9|0);
}
function _luaK_setreturns($fs,$e,$nresults) {
 $fs = $fs|0;
 $e = $e|0;
 $nresults = $nresults|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 if ((($0|0) == 13)) {
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$fs>>2]|0;
  $4 = ((($3)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($2<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 & -8372225;
  $9 = $nresults << 14;
  $10 = (($9) + 16384)|0;
  $11 = $10 & 8372224;
  $12 = $8 | $11;
  HEAP32[$6>>2] = $12;
  return;
 } else if ((($0|0) == 14)) {
  $13 = ((($e)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = HEAP32[$fs>>2]|0;
  $16 = ((($15)) + 48|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = (($17) + ($14<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 & 8388607;
  $21 = $nresults << 23;
  $22 = (($21) + 8388608)|0;
  $23 = $20 | $22;
  HEAP32[$18>>2] = $23;
  $24 = HEAP32[$13>>2]|0;
  $25 = (($17) + ($24<<2)|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = $26 & -16321;
  $28 = ((($fs)) + 44|0);
  $29 = HEAP8[$28>>0]|0;
  $30 = $29&255;
  $31 = $30 << 6;
  $32 = $31 | $27;
  HEAP32[$25>>2] = $32;
  $33 = (($30) + 1)|0;
  $34 = ((($15)) + 8|0);
  $35 = HEAP8[$34>>0]|0;
  $36 = $35&255;
  $37 = ($33>>>0)>($36>>>0);
  do {
   if ($37) {
    $38 = ($33>>>0)>(249);
    if ($38) {
     $39 = ((($fs)) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     _luaX_syntaxerror($40,4776);
     // unreachable;
    } else {
     $41 = $33&255;
     HEAP8[$34>>0] = $41;
     $$pre$phi$iZ2D = $41;
     break;
    }
   } else {
    $$pre$i = $33&255;
    $$pre$phi$iZ2D = $$pre$i;
   }
  } while(0);
  HEAP8[$28>>0] = $$pre$phi$iZ2D;
  return;
 } else {
  return;
 }
}
function _luaK_setoneret($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 if ((($0|0) == 13)) {
  HEAP32[$e>>2] = 7;
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = HEAP32[$fs>>2]|0;
  $4 = ((($3)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($2<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = $7 >>> 6;
  $9 = $8 & 255;
  HEAP32[$1>>2] = $9;
  return;
 } else if ((($0|0) == 14)) {
  $10 = ((($e)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = HEAP32[$fs>>2]|0;
  $13 = ((($12)) + 48|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = (($14) + ($11<<2)|0);
  $16 = HEAP32[$15>>2]|0;
  $17 = $16 & 8388607;
  $18 = $17 | 16777216;
  HEAP32[$15>>2] = $18;
  HEAP32[$e>>2] = 12;
  return;
 } else {
  return;
 }
}
function _luaK_dischargevars($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $op$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 switch ($0|0) {
 case 9:  {
  $1 = ((($e)) + 8|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 << 23;
  $4 = $3 | 5;
  $5 = (_luaK_code($fs,$4)|0);
  HEAP32[$1>>2] = $5;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 case 8:  {
  HEAP32[$e>>2] = 7;
  return;
  break;
 }
 case 10:  {
  $6 = ((($e)) + 8|0);
  $7 = HEAP16[$6>>1]|0;
  $8 = $7 << 16 >> 16;
  $9 = $8 & 256;
  $10 = ($9|0)==(0);
  if ($10) {
   $11 = ((($fs)) + 42|0);
   $12 = HEAP8[$11>>0]|0;
   $13 = $12&255;
   $14 = ($13|0)>($8|0);
   if (!($14)) {
    $15 = ((($fs)) + 44|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (($16) + -1)<<24>>24;
    HEAP8[$15>>0] = $17;
   }
  }
  $18 = ((($6)) + 3|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = ($19<<24>>24)==(8);
  $21 = ((($6)) + 2|0);
  $22 = HEAP8[$21>>0]|0;
  if ($20) {
   $23 = ((($fs)) + 42|0);
   $24 = HEAP8[$23>>0]|0;
   $25 = ($24&255)>($22&255);
   if ($25) {
    $op$0 = 7;
   } else {
    $26 = ((($fs)) + 44|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = (($27) + -1)<<24>>24;
    HEAP8[$26>>0] = $28;
    $op$0 = 7;
   }
  } else {
   $op$0 = 6;
  }
  $29 = $22&255;
  $30 = $29 << 23;
  $31 = $30 | $op$0;
  $32 = $8 << 14;
  $33 = $31 | $32;
  $34 = (_luaK_code($fs,$33)|0);
  HEAP32[$6>>2] = $34;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 case 14:  {
  $44 = ((($e)) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = HEAP32[$fs>>2]|0;
  $47 = ((($46)) + 48|0);
  $48 = HEAP32[$47>>2]|0;
  $49 = (($48) + ($45<<2)|0);
  $50 = HEAP32[$49>>2]|0;
  $51 = $50 & 8388607;
  $52 = $51 | 16777216;
  HEAP32[$49>>2] = $52;
  HEAP32[$e>>2] = 12;
  return;
  break;
 }
 case 13:  {
  HEAP32[$e>>2] = 7;
  $35 = ((($e)) + 8|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = HEAP32[$fs>>2]|0;
  $38 = ((($37)) + 48|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = (($39) + ($36<<2)|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = $41 >>> 6;
  $43 = $42 & 255;
  HEAP32[$35>>2] = $43;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _luaK_exp2nextreg($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(7);
 if ($1) {
  $2 = ((($e)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 & 256;
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = ((($fs)) + 42|0);
   $7 = HEAP8[$6>>0]|0;
   $8 = $7&255;
   $9 = ($8|0)>($3|0);
   if (!($9)) {
    $10 = ((($fs)) + 44|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = (($11) + -1)<<24>>24;
    HEAP8[$10>>0] = $12;
   }
  }
 }
 $13 = ((($fs)) + 44|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 $16 = (($15) + 1)|0;
 $17 = HEAP32[$fs>>2]|0;
 $18 = ((($17)) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($16>>>0)>($20>>>0);
 if (!($21)) {
  $$pre$i = $16&255;
  $$pre$phi$iZ2D = $$pre$i;
  HEAP8[$13>>0] = $$pre$phi$iZ2D;
  $26 = $$pre$phi$iZ2D&255;
  $27 = (($26) + -1)|0;
  _exp2reg($fs,$e,$27);
  return;
 }
 $22 = ($16>>>0)>(249);
 if ($22) {
  $23 = ((($fs)) + 8|0);
  $24 = HEAP32[$23>>2]|0;
  _luaX_syntaxerror($24,4776);
  // unreachable;
 }
 $25 = $16&255;
 HEAP8[$18>>0] = $25;
 $$pre$phi$iZ2D = $25;
 HEAP8[$13>>0] = $$pre$phi$iZ2D;
 $26 = $$pre$phi$iZ2D&255;
 $27 = (($26) + -1)|0;
 _exp2reg($fs,$e,$27);
 return;
}
function _luaK_exp2anyreg($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0 = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(7);
 if ($1) {
  $2 = ((($e)) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($e)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)==($5|0);
  $7 = ((($e)) + 8|0);
  $8 = HEAP32[$7>>2]|0;
  if ($6) {
   $$0 = $8;
   return ($$0|0);
  }
  $9 = ((($fs)) + 42|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = ($8|0)<($11|0);
  if (!($12)) {
   _exp2reg($fs,$e,$8);
   $13 = HEAP32[$7>>2]|0;
   $$0 = $13;
   return ($$0|0);
  }
 }
 _luaK_dischargevars($fs,$e);
 $14 = HEAP32[$e>>2]|0;
 $15 = ($14|0)==(7);
 if ($15) {
  $16 = ((($e)) + 8|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = $17 & 256;
  $19 = ($18|0)==(0);
  if ($19) {
   $20 = ((($fs)) + 42|0);
   $21 = HEAP8[$20>>0]|0;
   $22 = $21&255;
   $23 = ($22|0)>($17|0);
   if (!($23)) {
    $24 = ((($fs)) + 44|0);
    $25 = HEAP8[$24>>0]|0;
    $26 = (($25) + -1)<<24>>24;
    HEAP8[$24>>0] = $26;
   }
  }
 }
 $27 = ((($fs)) + 44|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28&255;
 $30 = (($29) + 1)|0;
 $31 = HEAP32[$fs>>2]|0;
 $32 = ((($31)) + 8|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = ($30>>>0)>($34>>>0);
 do {
  if ($35) {
   $36 = ($30>>>0)>(249);
   if ($36) {
    $37 = ((($fs)) + 8|0);
    $38 = HEAP32[$37>>2]|0;
    _luaX_syntaxerror($38,4776);
    // unreachable;
   } else {
    $39 = $30&255;
    HEAP8[$32>>0] = $39;
    $$pre$phi$i$iZ2D = $39;
    break;
   }
  } else {
   $$pre$i$i = $30&255;
   $$pre$phi$i$iZ2D = $$pre$i$i;
  }
 } while(0);
 HEAP8[$27>>0] = $$pre$phi$i$iZ2D;
 $40 = $$pre$phi$i$iZ2D&255;
 $41 = (($40) + -1)|0;
 _exp2reg($fs,$e,$41);
 $42 = ((($e)) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $$0 = $43;
 return ($$0|0);
}
function _luaK_exp2anyregup($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(9);
 if ($1) {
  $2 = ((($e)) + 16|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($e)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($3|0)==($5|0);
  if ($6) {
   return;
  }
 }
 (_luaK_exp2anyreg($fs,$e)|0);
 return;
}
function _luaK_exp2val($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($e)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($e)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  _luaK_dischargevars($fs,$e);
  return;
 } else {
  (_luaK_exp2anyreg($fs,$e)|0);
  return;
 }
}
function _luaK_exp2RK($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0.0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $k$i = 0, $k$i1 = 0, $o$i = 0, $o$i2 = 0, $o$i3 = 0, $v$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $o$i3 = sp + 80|0;
 $k$i1 = sp + 64|0;
 $o$i2 = sp + 48|0;
 $o$i = sp + 32|0;
 $k$i = sp + 16|0;
 $v$i = sp;
 $0 = ((($e)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($e)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1|0)==($3|0);
 if ($4) {
  _luaK_dischargevars($fs,$e);
 } else {
  (_luaK_exp2anyreg($fs,$e)|0);
 }
 $5 = HEAP32[$e>>2]|0;
 switch ($5|0) {
 case 1: case 3: case 2:  {
  $6 = ((($fs)) + 28|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)<(256);
  if ($8) {
   $9 = ($5|0)==(1);
   if ($9) {
    $10 = ((($v$i)) + 8|0);
    HEAP32[$10>>2] = 0;
    $11 = ((($fs)) + 8|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ((($12)) + 64|0);
    $14 = HEAP32[$13>>2]|0;
    HEAP32[$k$i>>2] = $14;
    $15 = ((($k$i)) + 8|0);
    HEAP32[$15>>2] = 69;
    $16 = (_addk($fs,$k$i,$v$i)|0);
    $22 = $16;
   } else {
    $17 = ($5|0)==(2);
    $18 = $17&1;
    HEAP32[$o$i>>2] = $18;
    $19 = ((($o$i)) + 8|0);
    HEAP32[$19>>2] = 1;
    $20 = (_addk($fs,$o$i,$o$i)|0);
    $22 = $20;
   }
   $21 = ((($e)) + 8|0);
   HEAP32[$21>>2] = $22;
   HEAP32[$e>>2] = 4;
   $23 = $22 | 256;
   $$0 = $23;
   STACKTOP = sp;return ($$0|0);
  }
  break;
 }
 case 4:  {
  $$phi$trans$insert = ((($e)) + 8|0);
  $$pre = HEAP32[$$phi$trans$insert>>2]|0;
  $44 = $$pre;
  label = 13;
  break;
 }
 case 5:  {
  $39 = ((($e)) + 8|0);
  $40 = +HEAPF64[$39>>3];
  HEAPF64[$o$i3>>3] = $40;
  $41 = ((($o$i3)) + 8|0);
  HEAP32[$41>>2] = 3;
  $42 = (_addk($fs,$o$i3,$o$i3)|0);
  HEAP32[$39>>2] = $42;
  HEAP32[$e>>2] = 4;
  $44 = $42;
  label = 13;
  break;
 }
 case 6:  {
  $24 = ((($e)) + 8|0);
  $25 = $24;
  $26 = $25;
  $27 = HEAP32[$26>>2]|0;
  $28 = (($25) + 4)|0;
  $29 = $28;
  $30 = HEAP32[$29>>2]|0;
  $31 = $27;
  HEAP32[$k$i1>>2] = $31;
  $32 = ((($k$i1)) + 8|0);
  HEAP32[$32>>2] = 2;
  $33 = $o$i2;
  $34 = $33;
  HEAP32[$34>>2] = $27;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = $30;
  $37 = ((($o$i2)) + 8|0);
  HEAP32[$37>>2] = 19;
  $38 = (_addk($fs,$k$i1,$o$i2)|0);
  HEAP32[$24>>2] = $38;
  HEAP32[$e>>2] = 4;
  $44 = $38;
  label = 13;
  break;
 }
 default: {
 }
 }
 if ((label|0) == 13) {
  $43 = ($44|0)<(256);
  if ($43) {
   $45 = $44 | 256;
   $$0 = $45;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $46 = (_luaK_exp2anyreg($fs,$e)|0);
 $$0 = $46;
 STACKTOP = sp;return ($$0|0);
}
function _luaK_storevar($fs,$var,$ex) {
 $fs = $fs|0;
 $var = $var|0;
 $ex = $ex|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$var>>2]|0;
 if ((($0|0) == 8)) {
  $1 = HEAP32[$ex>>2]|0;
  $2 = ($1|0)==(7);
  if ($2) {
   $3 = ((($ex)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = $4 & 256;
   $6 = ($5|0)==(0);
   if ($6) {
    $7 = ((($fs)) + 42|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8&255;
    $10 = ($9|0)>($4|0);
    if (!($10)) {
     $11 = ((($fs)) + 44|0);
     $12 = HEAP8[$11>>0]|0;
     $13 = (($12) + -1)<<24>>24;
     HEAP8[$11>>0] = $13;
    }
   }
  }
  $14 = ((($var)) + 8|0);
  $15 = HEAP32[$14>>2]|0;
  _exp2reg($fs,$ex,$15);
  return;
 } else if ((($0|0) == 9)) {
  $16 = (_luaK_exp2anyreg($fs,$ex)|0);
  $17 = ((($var)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $16 << 6;
  $20 = $18 << 23;
  $21 = $19 | $20;
  $22 = $21 | 9;
  (_luaK_code($fs,$22)|0);
 } else if ((($0|0) == 10)) {
  $23 = ((($var)) + 8|0);
  $24 = ((($23)) + 3|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = ($25<<24>>24)==(8);
  $27 = $26 ? 10 : 8;
  $28 = (_luaK_exp2RK($fs,$ex)|0);
  $29 = ((($23)) + 2|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = HEAP16[$23>>1]|0;
  $33 = $32&65535;
  $34 = $31 << 6;
  $35 = $33 << 23;
  $36 = $28 << 14;
  $37 = $36 | $27;
  $38 = $37 | $34;
  $39 = $38 | $35;
  (_luaK_code($fs,$39)|0);
 }
 $40 = HEAP32[$ex>>2]|0;
 $41 = ($40|0)==(7);
 if (!($41)) {
  return;
 }
 $42 = ((($ex)) + 8|0);
 $43 = HEAP32[$42>>2]|0;
 $44 = $43 & 256;
 $45 = ($44|0)==(0);
 if (!($45)) {
  return;
 }
 $46 = ((($fs)) + 42|0);
 $47 = HEAP8[$46>>0]|0;
 $48 = $47&255;
 $49 = ($48|0)>($43|0);
 if ($49) {
  return;
 }
 $50 = ((($fs)) + 44|0);
 $51 = HEAP8[$50>>0]|0;
 $52 = (($51) + -1)<<24>>24;
 HEAP8[$50>>0] = $52;
 return;
}
function _luaK_self($fs,$e,$key) {
 $fs = $fs|0;
 $e = $e|0;
 $key = $key|0;
 var $$pre$i = 0, $$pre$phi$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_luaK_exp2anyreg($fs,$e)|0);
 $0 = ((($e)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$e>>2]|0;
 $3 = ($2|0)==(7);
 $4 = $1 & 256;
 $5 = ($4|0)==(0);
 $or$cond = $3 & $5;
 if ($or$cond) {
  $6 = ((($fs)) + 42|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = $7&255;
  $9 = ($8|0)>($1|0);
  if (!($9)) {
   $10 = ((($fs)) + 44|0);
   $11 = HEAP8[$10>>0]|0;
   $12 = (($11) + -1)<<24>>24;
   HEAP8[$10>>0] = $12;
  }
 }
 $13 = ((($fs)) + 44|0);
 $14 = HEAP8[$13>>0]|0;
 $15 = $14&255;
 HEAP32[$0>>2] = $15;
 HEAP32[$e>>2] = 7;
 $16 = (($15) + 2)|0;
 $17 = HEAP32[$fs>>2]|0;
 $18 = ((($17)) + 8|0);
 $19 = HEAP8[$18>>0]|0;
 $20 = $19&255;
 $21 = ($16>>>0)>($20>>>0);
 do {
  if ($21) {
   $22 = ($16>>>0)>(249);
   if ($22) {
    $23 = ((($fs)) + 8|0);
    $24 = HEAP32[$23>>2]|0;
    _luaX_syntaxerror($24,4776);
    // unreachable;
   } else {
    $25 = $16&255;
    HEAP8[$18>>0] = $25;
    $$pre$phi$iZ2D = $25;
    break;
   }
  } else {
   $$pre$i = $16&255;
   $$pre$phi$iZ2D = $$pre$i;
  }
 } while(0);
 HEAP8[$13>>0] = $$pre$phi$iZ2D;
 $26 = (_luaK_exp2RK($fs,$key)|0);
 $27 = $15 << 6;
 $28 = $1 << 23;
 $29 = $26 << 14;
 $30 = $28 | $27;
 $31 = $30 | $29;
 $32 = $31 | 12;
 (_luaK_code($fs,$32)|0);
 $33 = HEAP32[$key>>2]|0;
 $34 = ($33|0)==(7);
 if (!($34)) {
  return;
 }
 $35 = ((($key)) + 8|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = $36 & 256;
 $38 = ($37|0)==(0);
 if (!($38)) {
  return;
 }
 $39 = ((($fs)) + 42|0);
 $40 = HEAP8[$39>>0]|0;
 $41 = $40&255;
 $42 = ($41|0)>($36|0);
 if ($42) {
  return;
 }
 $43 = HEAP8[$13>>0]|0;
 $44 = (($43) + -1)<<24>>24;
 HEAP8[$13>>0] = $44;
 return;
}
function _luaK_goiftrue($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i8 = 0, $$0$i$i1 = 0, $$lcssa = 0, $$lcssa52 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$lcssa56 = 0, $$lcssa57 = 0, $$lcssa58 = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i$i = 0, $$neg$i$i$i$i9 = 0, $$pr = 0, $$pre = 0, $$pre$i = 0;
 var $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $$sum$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val = 0, $fs$idx$val$i = 0, $fs$idx$val$i$i = 0;
 var $fs$idx$val$i$i$i = 0, $fs$idx$val$i$i$i3 = 0, $fs$idx$val$idx = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$i$i$i4 = 0, $fs$idx$val$idx$val = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $fs$idx$val$idx$val$i$i$i5 = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i$i = 0, $ispos$i$i$i$i10 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0;
 var $list$0$i$i$i7 = 0, $list$0$i$i$i7$lcssa = 0, $list$0$i$i$lcssa = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i$i = 0, $neg$i$i$i$i11 = 0, $pc$0 = 0, $pc$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 L1: do {
  switch ($0|0) {
  case 11:  {
   $fs$idx$val = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx = ((($fs$idx$val)) + 48|0);
   $fs$idx$val$idx$val = HEAP32[$fs$idx$val$idx>>2]|0;
   $1 = ((($e)) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $3 = (($fs$idx$val$idx$val) + ($2<<2)|0);
   $4 = ($2|0)>(0);
   if ($4) {
    $$sum$i$i = (($2) + -1)|0;
    $5 = (($fs$idx$val$idx$val) + ($$sum$i$i<<2)|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = $6 & 63;
    $8 = (1960 + ($7)|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)<(0);
    if ($10) {
     $$0$i$i = $5;$12 = $6;
    } else {
     label = 4;
    }
   } else {
    label = 4;
   }
   if ((label|0) == 4) {
    $$pre$i = HEAP32[$3>>2]|0;
    $$0$i$i = $3;$12 = $$pre$i;
   }
   $11 = $12 & -16321;
   $13 = $12 & 16320;
   $14 = ($13|0)==(0);
   $15 = $14&1;
   $16 = $15 << 6;
   $17 = $16 | $11;
   HEAP32[$$0$i$i>>2] = $17;
   $18 = HEAP32[$1>>2]|0;
   $pc$0 = $18;
   label = 32;
   break;
  }
  case 2: case 6: case 5: case 4:  {
   break;
  }
  default: {
   $19 = ((($e)) + 8|0);
   if ((($0|0) == 7)) {
    label = 22;
   } else if ((($0|0) == 12)) {
    $20 = HEAP32[$19>>2]|0;
    $21 = HEAP32[$fs>>2]|0;
    $22 = ((($21)) + 48|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (($23) + ($20<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = $25 & 63;
    $27 = ($26|0)==(27);
    if ($27) {
     $28 = ((($fs)) + 16|0);
     $29 = HEAP32[$28>>2]|0;
     $30 = (($29) + -1)|0;
     HEAP32[$28>>2] = $30;
     $31 = $25 >>> 23;
     $32 = $31 << 6;
     $33 = $32 | 16418;
     (_luaK_code($fs,$33)|0);
     $34 = ((($fs)) + 24|0);
     $35 = HEAP32[$34>>2]|0;
     HEAP32[$34>>2] = -1;
     $36 = (_luaK_code($fs,2147450910)|0);
     $37 = ($35|0)==(-1);
     if ($37) {
      $pc$0 = $36;
      label = 32;
      break L1;
     }
     $38 = ($36|0)==(-1);
     if ($38) {
      $pc$014 = $35;
      label = 33;
      break L1;
     }
     $fs$idx$val$i$i$i3 = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i4 = ((($fs$idx$val$i$i$i3)) + 48|0);
     $fs$idx$val$idx$val$i$i$i5 = HEAP32[$fs$idx$val$idx$i$i$i4>>2]|0;
     $list$0$i$i$i7 = $36;
     while(1) {
      $39 = (($fs$idx$val$idx$val$i$i$i5) + ($list$0$i$i$i7<<2)|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = $40 >>> 14;
      $42 = (($41) + -131071)|0;
      $43 = ($42|0)==(-1);
      $44 = (($list$0$i$i$i7) + 1)|0;
      $45 = (($44) + ($42))|0;
      $$0$i$i$i$i8 = $43 ? -1 : $45;
      $46 = ($$0$i$i$i$i8|0)==(-1);
      if ($46) {
       $$lcssa57 = $39;$$lcssa58 = $40;$list$0$i$i$i7$lcssa = $list$0$i$i$i7;
       break;
      } else {
       $list$0$i$i$i7 = $$0$i$i$i$i8;
      }
     }
     $$neg$i$i$i$i9 = $list$0$i$i$i7$lcssa ^ -1;
     $47 = (($35) + ($$neg$i$i$i$i9))|0;
     $ispos$i$i$i$i10 = ($47|0)>(-1);
     $neg$i$i$i$i11 = (0 - ($47))|0;
     $48 = $ispos$i$i$i$i10 ? $47 : $neg$i$i$i$i11;
     $49 = ($48|0)>(131071);
     if ($49) {
      $50 = ((($fs)) + 8|0);
      $51 = HEAP32[$50>>2]|0;
      _luaX_syntaxerror($51,4744);
      // unreachable;
     } else {
      $52 = $$lcssa58 & 16383;
      $53 = $47 << 14;
      $54 = (($53) + 2147467264)|0;
      $55 = $54 | $52;
      HEAP32[$$lcssa57>>2] = $55;
      $pc$0 = $36;
      label = 32;
      break L1;
     }
    } else {
     label = 15;
    }
   } else {
    label = 15;
   }
   if ((label|0) == 15) {
    $56 = ((($fs)) + 44|0);
    $57 = HEAP8[$56>>0]|0;
    $58 = $57&255;
    $59 = (($58) + 1)|0;
    $60 = HEAP32[$fs>>2]|0;
    $61 = ((($60)) + 8|0);
    $62 = HEAP8[$61>>0]|0;
    $63 = $62&255;
    $64 = ($59>>>0)>($63>>>0);
    do {
     if ($64) {
      $65 = ($59>>>0)>(249);
      if ($65) {
       $66 = ((($fs)) + 8|0);
       $67 = HEAP32[$66>>2]|0;
       _luaX_syntaxerror($67,4776);
       // unreachable;
      } else {
       $68 = $59&255;
       HEAP8[$61>>0] = $68;
       $$pre$phi$i$iZ2D = $68;
       break;
      }
     } else {
      $$pre$i$i = $59&255;
      $$pre$phi$i$iZ2D = $$pre$i$i;
     }
    } while(0);
    HEAP8[$56>>0] = $$pre$phi$i$iZ2D;
    $69 = $$pre$phi$i$iZ2D&255;
    $70 = (($69) + -1)|0;
    _discharge2reg($fs,$e,$70);
    $$pr = HEAP32[$e>>2]|0;
    $71 = ($$pr|0)==(7);
    if ($71) {
     label = 22;
    } else {
     $$pre = HEAP32[$19>>2]|0;
     $83 = $$pre;
    }
   }
   if ((label|0) == 22) {
    $72 = HEAP32[$19>>2]|0;
    $73 = $72 & 256;
    $74 = ($73|0)==(0);
    if ($74) {
     $75 = ((($fs)) + 42|0);
     $76 = HEAP8[$75>>0]|0;
     $77 = $76&255;
     $78 = ($77|0)>($72|0);
     if ($78) {
      $83 = $72;
     } else {
      $79 = ((($fs)) + 44|0);
      $80 = HEAP8[$79>>0]|0;
      $81 = (($80) + -1)<<24>>24;
      HEAP8[$79>>0] = $81;
      $83 = $72;
     }
    } else {
     $83 = $72;
    }
   }
   $82 = $83 << 23;
   $84 = $82 | 16355;
   (_luaK_code($fs,$84)|0);
   $85 = ((($fs)) + 24|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$85>>2] = -1;
   $87 = (_luaK_code($fs,2147450910)|0);
   $88 = ($86|0)==(-1);
   if ($88) {
    $pc$0 = $87;
    label = 32;
   } else {
    $89 = ($87|0)==(-1);
    if ($89) {
     $pc$014 = $86;
     label = 33;
    } else {
     $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
     $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
     $list$0$i$i$i = $87;
     while(1) {
      $90 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
      $91 = HEAP32[$90>>2]|0;
      $92 = $91 >>> 14;
      $93 = (($92) + -131071)|0;
      $94 = ($93|0)==(-1);
      $95 = (($list$0$i$i$i) + 1)|0;
      $96 = (($95) + ($93))|0;
      $$0$i$i$i$i = $94 ? -1 : $96;
      $97 = ($$0$i$i$i$i|0)==(-1);
      if ($97) {
       $$lcssa55 = $90;$$lcssa56 = $91;$list$0$i$i$i$lcssa = $list$0$i$i$i;
       break;
      } else {
       $list$0$i$i$i = $$0$i$i$i$i;
      }
     }
     $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
     $98 = (($86) + ($$neg$i$i$i$i))|0;
     $ispos$i$i$i$i = ($98|0)>(-1);
     $neg$i$i$i$i = (0 - ($98))|0;
     $99 = $ispos$i$i$i$i ? $98 : $neg$i$i$i$i;
     $100 = ($99|0)>(131071);
     if ($100) {
      $101 = ((($fs)) + 8|0);
      $102 = HEAP32[$101>>2]|0;
      _luaX_syntaxerror($102,4744);
      // unreachable;
     } else {
      $103 = $$lcssa56 & 16383;
      $104 = $98 << 14;
      $105 = (($104) + 2147467264)|0;
      $106 = $105 | $103;
      HEAP32[$$lcssa55>>2] = $106;
      $pc$0 = $87;
      label = 32;
      break L1;
     }
    }
   }
  }
  }
 } while(0);
 if ((label|0) == 32) {
  $107 = ($pc$0|0)==(-1);
  if (!($107)) {
   $pc$014 = $pc$0;
   label = 33;
  }
 }
 do {
  if ((label|0) == 33) {
   $108 = ((($e)) + 20|0);
   $109 = HEAP32[$108>>2]|0;
   $110 = ($109|0)==(-1);
   if ($110) {
    HEAP32[$108>>2] = $pc$014;
    break;
   }
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $list$0$i = $109;
   while(1) {
    $111 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
    $112 = HEAP32[$111>>2]|0;
    $113 = $112 >>> 14;
    $114 = (($113) + -131071)|0;
    $115 = ($114|0)==(-1);
    $116 = (($list$0$i) + 1)|0;
    $117 = (($116) + ($114))|0;
    $$0$i$i1 = $115 ? -1 : $117;
    $118 = ($$0$i$i1|0)==(-1);
    if ($118) {
     $$lcssa53 = $111;$$lcssa54 = $112;$list$0$i$lcssa = $list$0$i;
     break;
    } else {
     $list$0$i = $$0$i$i1;
    }
   }
   $$neg$i$i = $list$0$i$lcssa ^ -1;
   $119 = (($pc$014) + ($$neg$i$i))|0;
   $ispos$i$i = ($119|0)>(-1);
   $neg$i$i = (0 - ($119))|0;
   $120 = $ispos$i$i ? $119 : $neg$i$i;
   $121 = ($120|0)>(131071);
   if ($121) {
    $122 = ((($fs)) + 8|0);
    $123 = HEAP32[$122>>2]|0;
    _luaX_syntaxerror($123,4744);
    // unreachable;
   } else {
    $124 = $$lcssa54 & 16383;
    $125 = $119 << 14;
    $126 = (($125) + 2147467264)|0;
    $127 = $126 | $124;
    HEAP32[$$lcssa53>>2] = $127;
    break;
   }
  }
 } while(0);
 $128 = ((($e)) + 16|0);
 $129 = HEAP32[$128>>2]|0;
 $130 = ((($fs)) + 16|0);
 $131 = HEAP32[$130>>2]|0;
 $132 = ((($fs)) + 20|0);
 HEAP32[$132>>2] = $131;
 $133 = ((($fs)) + 24|0);
 $134 = ($129|0)==(-1);
 if ($134) {
  HEAP32[$128>>2] = -1;
  return;
 }
 $135 = HEAP32[$133>>2]|0;
 $136 = ($135|0)==(-1);
 if ($136) {
  HEAP32[$133>>2] = $129;
  HEAP32[$128>>2] = -1;
  return;
 }
 $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
 $list$0$i$i = $135;
 while(1) {
  $137 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
  $138 = HEAP32[$137>>2]|0;
  $139 = $138 >>> 14;
  $140 = (($139) + -131071)|0;
  $141 = ($140|0)==(-1);
  $142 = (($list$0$i$i) + 1)|0;
  $143 = (($142) + ($140))|0;
  $$0$i$i$i = $141 ? -1 : $143;
  $144 = ($$0$i$i$i|0)==(-1);
  if ($144) {
   $$lcssa = $137;$$lcssa52 = $138;$list$0$i$i$lcssa = $list$0$i$i;
   break;
  } else {
   $list$0$i$i = $$0$i$i$i;
  }
 }
 $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
 $145 = (($129) + ($$neg$i$i$i))|0;
 $ispos$i$i$i = ($145|0)>(-1);
 $neg$i$i$i = (0 - ($145))|0;
 $146 = $ispos$i$i$i ? $145 : $neg$i$i$i;
 $147 = ($146|0)>(131071);
 if ($147) {
  $148 = ((($fs)) + 8|0);
  $149 = HEAP32[$148>>2]|0;
  _luaX_syntaxerror($149,4744);
  // unreachable;
 }
 $150 = $$lcssa52 & 16383;
 $151 = $145 << 14;
 $152 = (($151) + 2147467264)|0;
 $153 = $152 | $150;
 HEAP32[$$lcssa>>2] = $153;
 HEAP32[$128>>2] = -1;
 return;
}
function _luaK_goiffalse($fs,$e) {
 $fs = $fs|0;
 $e = $e|0;
 var $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i$i7 = 0, $$lcssa = 0, $$lcssa51 = 0, $$lcssa52 = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$lcssa56 = 0, $$lcssa57 = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i$i = 0, $$neg$i$i$i$i8 = 0, $$pr = 0, $$pre = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val$i = 0, $fs$idx$val$i$i = 0;
 var $fs$idx$val$i$i$i = 0, $fs$idx$val$i$i$i2 = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$i$i$i3 = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $fs$idx$val$idx$val$i$i$i4 = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i$i = 0, $ispos$i$i$i$i9 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0, $list$0$i$i$i6 = 0, $list$0$i$i$i6$lcssa = 0;
 var $list$0$i$i$lcssa = 0, $list$0$i$lcssa = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i$i = 0, $neg$i$i$i$i10 = 0, $pc$0 = 0, $pc$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 do {
  if ((($0|0) == 11)) {
   $1 = ((($e)) + 8|0);
   $2 = HEAP32[$1>>2]|0;
   $pc$0 = $2;
   label = 29;
  } else if (!((($0|0) == 3) | (($0|0) == 1))) {
   $3 = ((($e)) + 8|0);
   if ((($0|0) == 12)) {
    $4 = HEAP32[$3>>2]|0;
    $5 = HEAP32[$fs>>2]|0;
    $6 = ((($5)) + 48|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = (($7) + ($4<<2)|0);
    $9 = HEAP32[$8>>2]|0;
    $10 = $9 & 63;
    $11 = ($10|0)==(27);
    if ($11) {
     $12 = ((($fs)) + 16|0);
     $13 = HEAP32[$12>>2]|0;
     $14 = (($13) + -1)|0;
     HEAP32[$12>>2] = $14;
     $15 = $9 >>> 23;
     $16 = $15 << 6;
     $17 = $16 | 34;
     (_luaK_code($fs,$17)|0);
     $18 = ((($fs)) + 24|0);
     $19 = HEAP32[$18>>2]|0;
     HEAP32[$18>>2] = -1;
     $20 = (_luaK_code($fs,2147450910)|0);
     $21 = ($19|0)==(-1);
     if ($21) {
      $pc$0 = $20;
      label = 29;
      break;
     }
     $22 = ($20|0)==(-1);
     if ($22) {
      $pc$013 = $19;
      label = 30;
      break;
     }
     $fs$idx$val$i$i$i2 = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i3 = ((($fs$idx$val$i$i$i2)) + 48|0);
     $fs$idx$val$idx$val$i$i$i4 = HEAP32[$fs$idx$val$idx$i$i$i3>>2]|0;
     $list$0$i$i$i6 = $20;
     while(1) {
      $23 = (($fs$idx$val$idx$val$i$i$i4) + ($list$0$i$i$i6<<2)|0);
      $24 = HEAP32[$23>>2]|0;
      $25 = $24 >>> 14;
      $26 = (($25) + -131071)|0;
      $27 = ($26|0)==(-1);
      $28 = (($list$0$i$i$i6) + 1)|0;
      $29 = (($28) + ($26))|0;
      $$0$i$i$i$i7 = $27 ? -1 : $29;
      $30 = ($$0$i$i$i$i7|0)==(-1);
      if ($30) {
       $$lcssa56 = $23;$$lcssa57 = $24;$list$0$i$i$i6$lcssa = $list$0$i$i$i6;
       break;
      } else {
       $list$0$i$i$i6 = $$0$i$i$i$i7;
      }
     }
     $$neg$i$i$i$i8 = $list$0$i$i$i6$lcssa ^ -1;
     $31 = (($19) + ($$neg$i$i$i$i8))|0;
     $ispos$i$i$i$i9 = ($31|0)>(-1);
     $neg$i$i$i$i10 = (0 - ($31))|0;
     $32 = $ispos$i$i$i$i9 ? $31 : $neg$i$i$i$i10;
     $33 = ($32|0)>(131071);
     if ($33) {
      $34 = ((($fs)) + 8|0);
      $35 = HEAP32[$34>>2]|0;
      _luaX_syntaxerror($35,4744);
      // unreachable;
     } else {
      $36 = $$lcssa57 & 16383;
      $37 = $31 << 14;
      $38 = (($37) + 2147467264)|0;
      $39 = $38 | $36;
      HEAP32[$$lcssa56>>2] = $39;
      $pc$0 = $20;
      label = 29;
      break;
     }
    } else {
     label = 12;
    }
   } else if ((($0|0) == 7)) {
    label = 19;
   } else {
    label = 12;
   }
   if ((label|0) == 12) {
    $40 = ((($fs)) + 44|0);
    $41 = HEAP8[$40>>0]|0;
    $42 = $41&255;
    $43 = (($42) + 1)|0;
    $44 = HEAP32[$fs>>2]|0;
    $45 = ((($44)) + 8|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = ($43>>>0)>($47>>>0);
    do {
     if ($48) {
      $49 = ($43>>>0)>(249);
      if ($49) {
       $50 = ((($fs)) + 8|0);
       $51 = HEAP32[$50>>2]|0;
       _luaX_syntaxerror($51,4776);
       // unreachable;
      } else {
       $52 = $43&255;
       HEAP8[$45>>0] = $52;
       $$pre$phi$i$iZ2D = $52;
       break;
      }
     } else {
      $$pre$i$i = $43&255;
      $$pre$phi$i$iZ2D = $$pre$i$i;
     }
    } while(0);
    HEAP8[$40>>0] = $$pre$phi$i$iZ2D;
    $53 = $$pre$phi$i$iZ2D&255;
    $54 = (($53) + -1)|0;
    _discharge2reg($fs,$e,$54);
    $$pr = HEAP32[$e>>2]|0;
    $55 = ($$pr|0)==(7);
    if ($55) {
     label = 19;
    } else {
     $$pre = HEAP32[$3>>2]|0;
     $67 = $$pre;
    }
   }
   if ((label|0) == 19) {
    $56 = HEAP32[$3>>2]|0;
    $57 = $56 & 256;
    $58 = ($57|0)==(0);
    if ($58) {
     $59 = ((($fs)) + 42|0);
     $60 = HEAP8[$59>>0]|0;
     $61 = $60&255;
     $62 = ($61|0)>($56|0);
     if ($62) {
      $67 = $56;
     } else {
      $63 = ((($fs)) + 44|0);
      $64 = HEAP8[$63>>0]|0;
      $65 = (($64) + -1)<<24>>24;
      HEAP8[$63>>0] = $65;
      $67 = $56;
     }
    } else {
     $67 = $56;
    }
   }
   $66 = $67 << 23;
   $68 = $66 | 32739;
   (_luaK_code($fs,$68)|0);
   $69 = ((($fs)) + 24|0);
   $70 = HEAP32[$69>>2]|0;
   HEAP32[$69>>2] = -1;
   $71 = (_luaK_code($fs,2147450910)|0);
   $72 = ($70|0)==(-1);
   if ($72) {
    $pc$0 = $71;
    label = 29;
   } else {
    $73 = ($71|0)==(-1);
    if ($73) {
     $pc$013 = $70;
     label = 30;
    } else {
     $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
     $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
     $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
     $list$0$i$i$i = $71;
     while(1) {
      $74 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      $76 = $75 >>> 14;
      $77 = (($76) + -131071)|0;
      $78 = ($77|0)==(-1);
      $79 = (($list$0$i$i$i) + 1)|0;
      $80 = (($79) + ($77))|0;
      $$0$i$i$i$i = $78 ? -1 : $80;
      $81 = ($$0$i$i$i$i|0)==(-1);
      if ($81) {
       $$lcssa54 = $74;$$lcssa55 = $75;$list$0$i$i$i$lcssa = $list$0$i$i$i;
       break;
      } else {
       $list$0$i$i$i = $$0$i$i$i$i;
      }
     }
     $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
     $82 = (($70) + ($$neg$i$i$i$i))|0;
     $ispos$i$i$i$i = ($82|0)>(-1);
     $neg$i$i$i$i = (0 - ($82))|0;
     $83 = $ispos$i$i$i$i ? $82 : $neg$i$i$i$i;
     $84 = ($83|0)>(131071);
     if ($84) {
      $85 = ((($fs)) + 8|0);
      $86 = HEAP32[$85>>2]|0;
      _luaX_syntaxerror($86,4744);
      // unreachable;
     } else {
      $87 = $$lcssa55 & 16383;
      $88 = $82 << 14;
      $89 = (($88) + 2147467264)|0;
      $90 = $89 | $87;
      HEAP32[$$lcssa54>>2] = $90;
      $pc$0 = $71;
      label = 29;
      break;
     }
    }
   }
  }
 } while(0);
 if ((label|0) == 29) {
  $91 = ($pc$0|0)==(-1);
  if (!($91)) {
   $pc$013 = $pc$0;
   label = 30;
  }
 }
 do {
  if ((label|0) == 30) {
   $92 = ((($e)) + 16|0);
   $93 = HEAP32[$92>>2]|0;
   $94 = ($93|0)==(-1);
   if ($94) {
    HEAP32[$92>>2] = $pc$013;
    break;
   }
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $list$0$i = $93;
   while(1) {
    $95 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
    $96 = HEAP32[$95>>2]|0;
    $97 = $96 >>> 14;
    $98 = (($97) + -131071)|0;
    $99 = ($98|0)==(-1);
    $100 = (($list$0$i) + 1)|0;
    $101 = (($100) + ($98))|0;
    $$0$i$i = $99 ? -1 : $101;
    $102 = ($$0$i$i|0)==(-1);
    if ($102) {
     $$lcssa52 = $95;$$lcssa53 = $96;$list$0$i$lcssa = $list$0$i;
     break;
    } else {
     $list$0$i = $$0$i$i;
    }
   }
   $$neg$i$i = $list$0$i$lcssa ^ -1;
   $103 = (($pc$013) + ($$neg$i$i))|0;
   $ispos$i$i = ($103|0)>(-1);
   $neg$i$i = (0 - ($103))|0;
   $104 = $ispos$i$i ? $103 : $neg$i$i;
   $105 = ($104|0)>(131071);
   if ($105) {
    $106 = ((($fs)) + 8|0);
    $107 = HEAP32[$106>>2]|0;
    _luaX_syntaxerror($107,4744);
    // unreachable;
   } else {
    $108 = $$lcssa53 & 16383;
    $109 = $103 << 14;
    $110 = (($109) + 2147467264)|0;
    $111 = $110 | $108;
    HEAP32[$$lcssa52>>2] = $111;
    break;
   }
  }
 } while(0);
 $112 = ((($e)) + 20|0);
 $113 = HEAP32[$112>>2]|0;
 $114 = ((($fs)) + 16|0);
 $115 = HEAP32[$114>>2]|0;
 $116 = ((($fs)) + 20|0);
 HEAP32[$116>>2] = $115;
 $117 = ((($fs)) + 24|0);
 $118 = ($113|0)==(-1);
 if ($118) {
  HEAP32[$112>>2] = -1;
  return;
 }
 $119 = HEAP32[$117>>2]|0;
 $120 = ($119|0)==(-1);
 if ($120) {
  HEAP32[$117>>2] = $113;
  HEAP32[$112>>2] = -1;
  return;
 }
 $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
 $list$0$i$i = $119;
 while(1) {
  $121 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
  $122 = HEAP32[$121>>2]|0;
  $123 = $122 >>> 14;
  $124 = (($123) + -131071)|0;
  $125 = ($124|0)==(-1);
  $126 = (($list$0$i$i) + 1)|0;
  $127 = (($126) + ($124))|0;
  $$0$i$i$i = $125 ? -1 : $127;
  $128 = ($$0$i$i$i|0)==(-1);
  if ($128) {
   $$lcssa = $121;$$lcssa51 = $122;$list$0$i$i$lcssa = $list$0$i$i;
   break;
  } else {
   $list$0$i$i = $$0$i$i$i;
  }
 }
 $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
 $129 = (($113) + ($$neg$i$i$i))|0;
 $ispos$i$i$i = ($129|0)>(-1);
 $neg$i$i$i = (0 - ($129))|0;
 $130 = $ispos$i$i$i ? $129 : $neg$i$i$i;
 $131 = ($130|0)>(131071);
 if ($131) {
  $132 = ((($fs)) + 8|0);
  $133 = HEAP32[$132>>2]|0;
  _luaX_syntaxerror($133,4744);
  // unreachable;
 }
 $134 = $$lcssa51 & 16383;
 $135 = $129 << 14;
 $136 = (($135) + 2147467264)|0;
 $137 = $136 | $134;
 HEAP32[$$lcssa>>2] = $137;
 HEAP32[$112>>2] = -1;
 return;
}
function _luaK_indexed($fs,$t,$k) {
 $fs = $fs|0;
 $t = $t|0;
 $k = $k|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($t)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1&255;
 $3 = ((($0)) + 2|0);
 HEAP8[$3>>0] = $2;
 $4 = (_luaK_exp2RK($fs,$k)|0);
 $5 = $4&65535;
 HEAP16[$0>>1] = $5;
 $6 = HEAP32[$t>>2]|0;
 $7 = ($6|0)==(9);
 $8 = $7 ? 9 : 8;
 $9 = ((($0)) + 3|0);
 HEAP8[$9>>0] = $8;
 HEAP32[$t>>2] = 10;
 return;
}
function _luaK_prefix($fs,$op,$e,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e = $e|0;
 $line = $line|0;
 var $$$i$i = 0, $$$i11$i = 0, $$0$i$i$i = 0, $$0$i$i$i$i = 0, $$0$i$i$i9$i = 0, $$03$i$i = 0, $$03$i6$i = 0, $$phi$trans$insert$i = 0, $$pr$i = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i$i14$i = 0, $$pre$i$i8$i = 0, $$pre$phi$i$i$iZ2D = 0, $$pre$phi17$iZ2D = 0, $$pre16$i = 0, $$sum$i$i$i = 0, $$sum$i$i$i$i = 0, $$sum$i$i$i7$i = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0;
 var $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $e2 = 0, $fs$idx$val$i = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$val$i = 0, $fs$idx1$val$idx$phi$trans$insert$i$i = 0, $fs$idx1$val$idx$phi$trans$insert$i3$i = 0, $fs$idx1$val$idx$val$pre$i$i = 0, $fs$idx1$val$idx$val$pre$i4$i = 0, $fs$idx1$val$pre$i$i = 0, $fs$idx1$val$pre$i2$i = 0, $phitmp$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $e2 = sp;
 $0 = ((($e2)) + 20|0);
 HEAP32[$0>>2] = -1;
 $1 = ((($e2)) + 16|0);
 HEAP32[$1>>2] = -1;
 HEAP32[$e2>>2] = 6;
 $2 = ((($e2)) + 8|0);
 $3 = $2;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 if ((($op|0) == 2)) {
  _luaK_dischargevars($fs,$e);
  $8 = HEAP32[$e>>2]|0;
  switch ($8|0) {
  case 3: case 1:  {
   HEAP32[$e>>2] = 2;
   break;
  }
  case 11:  {
   $fs$idx$val$i = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
   $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
   $9 = ((($e)) + 8|0);
   $10 = HEAP32[$9>>2]|0;
   $11 = (($fs$idx$val$idx$val$i) + ($10<<2)|0);
   $12 = ($10|0)>(0);
   if ($12) {
    $$sum$i$i$i = (($10) + -1)|0;
    $13 = (($fs$idx$val$idx$val$i) + ($$sum$i$i$i<<2)|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $14 & 63;
    $16 = (1960 + ($15)|0);
    $17 = HEAP8[$16>>0]|0;
    $18 = ($17<<24>>24)<(0);
    if ($18) {
     $$0$i$i$i = $13;$20 = $14;
    } else {
     label = 8;
    }
   } else {
    label = 8;
   }
   if ((label|0) == 8) {
    $$pre$i$i = HEAP32[$11>>2]|0;
    $$0$i$i$i = $11;$20 = $$pre$i$i;
   }
   $19 = $20 & -16321;
   $21 = $20 & 16320;
   $22 = ($21|0)==(0);
   $23 = $22&1;
   $24 = $23 << 6;
   $25 = $24 | $19;
   HEAP32[$$0$i$i$i>>2] = $25;
   break;
  }
  case 2: case 6: case 5: case 4:  {
   HEAP32[$e>>2] = 3;
   break;
  }
  case 7:  {
   label = 17;
   break;
  }
  case 12:  {
   $26 = ((($fs)) + 44|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = (($28) + 1)|0;
   $30 = HEAP32[$fs>>2]|0;
   $31 = ((($30)) + 8|0);
   $32 = HEAP8[$31>>0]|0;
   $33 = $32&255;
   $34 = ($29>>>0)>($33>>>0);
   do {
    if ($34) {
     $35 = ($29>>>0)>(249);
     if ($35) {
      $36 = ((($fs)) + 8|0);
      $37 = HEAP32[$36>>2]|0;
      _luaX_syntaxerror($37,4776);
      // unreachable;
     } else {
      $38 = $29&255;
      HEAP8[$31>>0] = $38;
      $$pre$phi$i$i$iZ2D = $38;
      break;
     }
    } else {
     $$pre$i$i14$i = $29&255;
     $$pre$phi$i$i$iZ2D = $$pre$i$i14$i;
    }
   } while(0);
   HEAP8[$26>>0] = $$pre$phi$i$i$iZ2D;
   $39 = $$pre$phi$i$i$iZ2D&255;
   $40 = (($39) + -1)|0;
   _discharge2reg($fs,$e,$40);
   $$pre$i = HEAP32[$e>>2]|0;
   $phitmp$i = ($$pre$i|0)==(7);
   if ($phitmp$i) {
    label = 17;
   } else {
    $$phi$trans$insert$i = ((($e)) + 8|0);
    $$pre16$i = HEAP32[$$phi$trans$insert$i>>2]|0;
    $$pre$phi17$iZ2D = $$phi$trans$insert$i;$53 = $$pre16$i;
    label = 20;
   }
   break;
  }
  default: {
  }
  }
  if ((label|0) == 17) {
   $41 = ((($e)) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = $42 & 256;
   $44 = ($43|0)==(0);
   if ($44) {
    $45 = ((($fs)) + 42|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46&255;
    $48 = ($47|0)>($42|0);
    if ($48) {
     $$pre$phi17$iZ2D = $41;$53 = $42;
     label = 20;
    } else {
     $49 = ((($fs)) + 44|0);
     $50 = HEAP8[$49>>0]|0;
     $51 = (($50) + -1)<<24>>24;
     HEAP8[$49>>0] = $51;
     $$pre$phi17$iZ2D = $41;$53 = $42;
     label = 20;
    }
   } else {
    $$pre$phi17$iZ2D = $41;$53 = $42;
    label = 20;
   }
  }
  if ((label|0) == 20) {
   $52 = $53 << 23;
   $54 = $52 | 27;
   $55 = (_luaK_code($fs,$54)|0);
   HEAP32[$$pre$phi17$iZ2D>>2] = $55;
   HEAP32[$e>>2] = 12;
  }
  $56 = ((($e)) + 20|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = ((($e)) + 16|0);
  $59 = HEAP32[$58>>2]|0;
  HEAP32[$56>>2] = $59;
  HEAP32[$58>>2] = $57;
  $60 = ($59|0)==(-1);
  if ($60) {
   $85 = $57;
  } else {
   $fs$idx1$val$pre$i2$i = HEAP32[$fs>>2]|0;
   $fs$idx1$val$idx$phi$trans$insert$i3$i = ((($fs$idx1$val$pre$i2$i)) + 48|0);
   $fs$idx1$val$idx$val$pre$i4$i = HEAP32[$fs$idx1$val$idx$phi$trans$insert$i3$i>>2]|0;
   $$03$i6$i = $59;
   while(1) {
    $61 = (($fs$idx1$val$idx$val$pre$i4$i) + ($$03$i6$i<<2)|0);
    $62 = ($$03$i6$i|0)>(0);
    if ($62) {
     $$sum$i$i$i7$i = (($$03$i6$i) + -1)|0;
     $63 = (($fs$idx1$val$idx$val$pre$i4$i) + ($$sum$i$i$i7$i<<2)|0);
     $64 = HEAP32[$63>>2]|0;
     $65 = $64 & 63;
     $66 = (1960 + ($65)|0);
     $67 = HEAP8[$66>>0]|0;
     $68 = ($67<<24>>24)<(0);
     if ($68) {
      $$0$i$i$i9$i = $63;$70 = $64;
     } else {
      label = 25;
     }
    } else {
     label = 25;
    }
    if ((label|0) == 25) {
     label = 0;
     $$pre$i$i8$i = HEAP32[$61>>2]|0;
     $$0$i$i$i9$i = $61;$70 = $$pre$i$i8$i;
    }
    $69 = $70 & 63;
    $71 = ($69|0)==(35);
    if ($71) {
     $72 = $70 >>> 23;
     $73 = $72 << 6;
     $74 = $70 & 8372224;
     $75 = $74 | $73;
     $76 = $75 | 34;
     HEAP32[$$0$i$i$i9$i>>2] = $76;
    }
    $77 = HEAP32[$61>>2]|0;
    $78 = $77 >>> 14;
    $79 = (($78) + -131071)|0;
    $80 = ($79|0)==(-1);
    $81 = (($$03$i6$i) + 1)|0;
    $82 = (($81) + ($79))|0;
    $$$i11$i = $80 ? -1 : $82;
    $83 = ($$$i11$i|0)==(-1);
    if ($83) {
     break;
    } else {
     $$03$i6$i = $$$i11$i;
    }
   }
   $$pr$i = HEAP32[$58>>2]|0;
   $85 = $$pr$i;
  }
  $84 = ($85|0)==(-1);
  if ($84) {
   STACKTOP = sp;return;
  }
  $fs$idx1$val$pre$i$i = HEAP32[$fs>>2]|0;
  $fs$idx1$val$idx$phi$trans$insert$i$i = ((($fs$idx1$val$pre$i$i)) + 48|0);
  $fs$idx1$val$idx$val$pre$i$i = HEAP32[$fs$idx1$val$idx$phi$trans$insert$i$i>>2]|0;
  $$03$i$i = $85;
  while(1) {
   $86 = (($fs$idx1$val$idx$val$pre$i$i) + ($$03$i$i<<2)|0);
   $87 = ($$03$i$i|0)>(0);
   if ($87) {
    $$sum$i$i$i$i = (($$03$i$i) + -1)|0;
    $88 = (($fs$idx1$val$idx$val$pre$i$i) + ($$sum$i$i$i$i<<2)|0);
    $89 = HEAP32[$88>>2]|0;
    $90 = $89 & 63;
    $91 = (1960 + ($90)|0);
    $92 = HEAP8[$91>>0]|0;
    $93 = ($92<<24>>24)<(0);
    if ($93) {
     $$0$i$i$i$i = $88;$95 = $89;
    } else {
     label = 34;
    }
   } else {
    label = 34;
   }
   if ((label|0) == 34) {
    label = 0;
    $$pre$i$i$i = HEAP32[$86>>2]|0;
    $$0$i$i$i$i = $86;$95 = $$pre$i$i$i;
   }
   $94 = $95 & 63;
   $96 = ($94|0)==(35);
   if ($96) {
    $97 = $95 >>> 23;
    $98 = $97 << 6;
    $99 = $95 & 8372224;
    $100 = $99 | $98;
    $101 = $100 | 34;
    HEAP32[$$0$i$i$i$i>>2] = $101;
   }
   $102 = HEAP32[$86>>2]|0;
   $103 = $102 >>> 14;
   $104 = (($103) + -131071)|0;
   $105 = ($104|0)==(-1);
   $106 = (($$03$i$i) + 1)|0;
   $107 = (($106) + ($104))|0;
   $$$i$i = $105 ? -1 : $107;
   $108 = ($$$i$i|0)==(-1);
   if ($108) {
    break;
   } else {
    $$03$i$i = $$$i$i;
   }
  }
  STACKTOP = sp;return;
 } else if ((($op|0) == 3) | (($op|0) == 1) | (($op|0) == 0)) {
  $7 = (($op) + 25)|0;
  _codeexpval($fs,$7,$e,$e2,$line);
  STACKTOP = sp;return;
 } else {
  STACKTOP = sp;return;
 }
}
function _luaK_infix($fs,$op,$v) {
 $fs = $fs|0;
 $op = $op|0;
 $v = $v|0;
 var $$off = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 switch ($op|0) {
 case 19:  {
  _luaK_goiftrue($fs,$v);
  return;
  break;
 }
 case 12:  {
  _luaK_dischargevars($fs,$v);
  $0 = HEAP32[$v>>2]|0;
  $1 = ($0|0)==(7);
  if ($1) {
   $2 = ((($v)) + 8|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = $3 & 256;
   $5 = ($4|0)==(0);
   if ($5) {
    $6 = ((($fs)) + 42|0);
    $7 = HEAP8[$6>>0]|0;
    $8 = $7&255;
    $9 = ($8|0)>($3|0);
    if (!($9)) {
     $10 = ((($fs)) + 44|0);
     $11 = HEAP8[$10>>0]|0;
     $12 = (($11) + -1)<<24>>24;
     HEAP8[$10>>0] = $12;
    }
   }
  }
  $13 = ((($fs)) + 44|0);
  $14 = HEAP8[$13>>0]|0;
  $15 = $14&255;
  $16 = (($15) + 1)|0;
  $17 = HEAP32[$fs>>2]|0;
  $18 = ((($17)) + 8|0);
  $19 = HEAP8[$18>>0]|0;
  $20 = $19&255;
  $21 = ($16>>>0)>($20>>>0);
  do {
   if ($21) {
    $22 = ($16>>>0)>(249);
    if ($22) {
     $23 = ((($fs)) + 8|0);
     $24 = HEAP32[$23>>2]|0;
     _luaX_syntaxerror($24,4776);
     // unreachable;
    } else {
     $25 = $16&255;
     HEAP8[$18>>0] = $25;
     $$pre$phi$i$iZ2D = $25;
     break;
    }
   } else {
    $$pre$i$i = $16&255;
    $$pre$phi$i$iZ2D = $$pre$i$i;
   }
  } while(0);
  HEAP8[$13>>0] = $$pre$phi$i$iZ2D;
  $26 = $$pre$phi$i$iZ2D&255;
  $27 = (($26) + -1)|0;
  _exp2reg($fs,$v,$27);
  return;
  break;
 }
 case 20:  {
  _luaK_goiffalse($fs,$v);
  return;
  break;
 }
 case 11: case 10: case 9: case 8: case 7: case 4: case 3: case 6: case 5: case 2: case 1: case 0:  {
  $28 = ((($v)) + 16|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = ($29|0)==(-1);
  if ($30) {
   $31 = ((($v)) + 20|0);
   $32 = HEAP32[$31>>2]|0;
   $33 = ($32|0)==(-1);
   if ($33) {
    $34 = HEAP32[$v>>2]|0;
    $$off = (($34) + -5)|0;
    $switch = ($$off>>>0)<(2);
    if ($switch) {
     return;
    }
   }
  }
  (_luaK_exp2RK($fs,$v)|0);
  return;
  break;
 }
 default: {
  (_luaK_exp2RK($fs,$v)|0);
  return;
 }
 }
}
function _luaK_posfix($fs,$op,$e1,$e2,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 $line = $line|0;
 var $$0$i$i = 0, $$0$i$i7 = 0, $$lcssa = 0, $$lcssa31 = 0, $$lcssa32 = 0, $$lcssa33 = 0, $$neg$i$i = 0, $$neg$i$i8 = 0, $$pre$i$i = 0, $$pre$phi$i$iZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $fs$idx$val$i = 0, $fs$idx$val$i2 = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i3 = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i4 = 0, $ispos$i$i = 0, $ispos$i$i9 = 0, $list$0$i = 0, $list$0$i$lcssa = 0, $list$0$i6 = 0, $list$0$i6$lcssa = 0, $neg$i$i = 0, $neg$i$i10 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 switch ($op|0) {
 case 19:  {
  _luaK_dischargevars($fs,$e2);
  $0 = ((($e2)) + 20|0);
  $1 = ((($e1)) + 20|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = ($2|0)==(-1);
  do {
   if (!($3)) {
    $4 = HEAP32[$0>>2]|0;
    $5 = ($4|0)==(-1);
    if ($5) {
     HEAP32[$0>>2] = $2;
     break;
    }
    $fs$idx$val$i = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
    $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
    $list$0$i = $4;
    while(1) {
     $6 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
     $7 = HEAP32[$6>>2]|0;
     $8 = $7 >>> 14;
     $9 = (($8) + -131071)|0;
     $10 = ($9|0)==(-1);
     $11 = (($list$0$i) + 1)|0;
     $12 = (($11) + ($9))|0;
     $$0$i$i = $10 ? -1 : $12;
     $13 = ($$0$i$i|0)==(-1);
     if ($13) {
      $$lcssa = $6;$$lcssa31 = $7;$list$0$i$lcssa = $list$0$i;
      break;
     } else {
      $list$0$i = $$0$i$i;
     }
    }
    $$neg$i$i = $list$0$i$lcssa ^ -1;
    $14 = (($2) + ($$neg$i$i))|0;
    $ispos$i$i = ($14|0)>(-1);
    $neg$i$i = (0 - ($14))|0;
    $15 = $ispos$i$i ? $14 : $neg$i$i;
    $16 = ($15|0)>(131071);
    if ($16) {
     $17 = ((($fs)) + 8|0);
     $18 = HEAP32[$17>>2]|0;
     _luaX_syntaxerror($18,4744);
     // unreachable;
    } else {
     $19 = $$lcssa31 & 16383;
     $20 = $14 << 14;
     $21 = (($20) + 2147467264)|0;
     $22 = $21 | $19;
     HEAP32[$$lcssa>>2] = $22;
     break;
    }
   }
  } while(0);
  ;HEAP32[$e1>>2]=HEAP32[$e2>>2]|0;HEAP32[$e1+4>>2]=HEAP32[$e2+4>>2]|0;HEAP32[$e1+8>>2]=HEAP32[$e2+8>>2]|0;HEAP32[$e1+12>>2]=HEAP32[$e2+12>>2]|0;HEAP32[$e1+16>>2]=HEAP32[$e2+16>>2]|0;HEAP32[$e1+20>>2]=HEAP32[$e2+20>>2]|0;
  return;
  break;
 }
 case 11: case 10: case 9: case 8: case 7: case 4: case 3: case 6: case 5: case 2: case 1: case 0:  {
  $107 = (($op) + 13)|0;
  _codeexpval($fs,$107,$e1,$e2,$line);
  return;
  break;
 }
 case 15: case 14: case 13:  {
  $108 = (($op) + 18)|0;
  _codecomp($fs,$108,1,$e1,$e2);
  return;
  break;
 }
 case 12:  {
  $46 = ((($e2)) + 16|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ((($e2)) + 20|0);
  $49 = HEAP32[$48>>2]|0;
  $50 = ($47|0)==($49|0);
  if ($50) {
   _luaK_dischargevars($fs,$e2);
  } else {
   (_luaK_exp2anyreg($fs,$e2)|0);
  }
  $51 = HEAP32[$e2>>2]|0;
  $52 = ($51|0)==(12);
  if ($52) {
   $53 = ((($e2)) + 8|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = HEAP32[$fs>>2]|0;
   $56 = ((($55)) + 48|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = (($57) + ($54<<2)|0);
   $59 = HEAP32[$58>>2]|0;
   $60 = $59 & 63;
   $61 = ($60|0)==(29);
   if ($61) {
    $62 = HEAP32[$e1>>2]|0;
    $63 = ($62|0)==(7);
    $64 = ((($e1)) + 8|0);
    $65 = HEAP32[$64>>2]|0;
    $66 = $65 & 256;
    $67 = ($66|0)==(0);
    $or$cond = $63 & $67;
    if ($or$cond) {
     $68 = ((($fs)) + 42|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = $69&255;
     $71 = ($70|0)>($65|0);
     if (!($71)) {
      $72 = ((($fs)) + 44|0);
      $73 = HEAP8[$72>>0]|0;
      $74 = (($73) + -1)<<24>>24;
      HEAP8[$72>>0] = $74;
     }
    }
    $75 = $59 & 8388607;
    $76 = $65 << 23;
    $77 = $76 | $75;
    HEAP32[$58>>2] = $77;
    HEAP32[$e1>>2] = 12;
    $78 = HEAP32[$53>>2]|0;
    HEAP32[$64>>2] = $78;
    return;
   }
  }
  _luaK_dischargevars($fs,$e2);
  $79 = HEAP32[$e2>>2]|0;
  $80 = ($79|0)==(7);
  if ($80) {
   $81 = ((($e2)) + 8|0);
   $82 = HEAP32[$81>>2]|0;
   $83 = $82 & 256;
   $84 = ($83|0)==(0);
   if ($84) {
    $85 = ((($fs)) + 42|0);
    $86 = HEAP8[$85>>0]|0;
    $87 = $86&255;
    $88 = ($87|0)>($82|0);
    if (!($88)) {
     $89 = ((($fs)) + 44|0);
     $90 = HEAP8[$89>>0]|0;
     $91 = (($90) + -1)<<24>>24;
     HEAP8[$89>>0] = $91;
    }
   }
  }
  $92 = ((($fs)) + 44|0);
  $93 = HEAP8[$92>>0]|0;
  $94 = $93&255;
  $95 = (($94) + 1)|0;
  $96 = HEAP32[$fs>>2]|0;
  $97 = ((($96)) + 8|0);
  $98 = HEAP8[$97>>0]|0;
  $99 = $98&255;
  $100 = ($95>>>0)>($99>>>0);
  do {
   if ($100) {
    $101 = ($95>>>0)>(249);
    if ($101) {
     $102 = ((($fs)) + 8|0);
     $103 = HEAP32[$102>>2]|0;
     _luaX_syntaxerror($103,4776);
     // unreachable;
    } else {
     $104 = $95&255;
     HEAP8[$97>>0] = $104;
     $$pre$phi$i$iZ2D = $104;
     break;
    }
   } else {
    $$pre$i$i = $95&255;
    $$pre$phi$i$iZ2D = $$pre$i$i;
   }
  } while(0);
  HEAP8[$92>>0] = $$pre$phi$i$iZ2D;
  $105 = $$pre$phi$i$iZ2D&255;
  $106 = (($105) + -1)|0;
  _exp2reg($fs,$e2,$106);
  _codeexpval($fs,29,$e1,$e2,$line);
  return;
  break;
 }
 case 18: case 17: case 16:  {
  $109 = (($op) + 15)|0;
  _codecomp($fs,$109,0,$e1,$e2);
  return;
  break;
 }
 case 20:  {
  _luaK_dischargevars($fs,$e2);
  $23 = ((($e2)) + 16|0);
  $24 = ((($e1)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $26 = ($25|0)==(-1);
  do {
   if (!($26)) {
    $27 = HEAP32[$23>>2]|0;
    $28 = ($27|0)==(-1);
    if ($28) {
     HEAP32[$23>>2] = $25;
     break;
    }
    $fs$idx$val$i2 = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i3 = ((($fs$idx$val$i2)) + 48|0);
    $fs$idx$val$idx$val$i4 = HEAP32[$fs$idx$val$idx$i3>>2]|0;
    $list$0$i6 = $27;
    while(1) {
     $29 = (($fs$idx$val$idx$val$i4) + ($list$0$i6<<2)|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = $30 >>> 14;
     $32 = (($31) + -131071)|0;
     $33 = ($32|0)==(-1);
     $34 = (($list$0$i6) + 1)|0;
     $35 = (($34) + ($32))|0;
     $$0$i$i7 = $33 ? -1 : $35;
     $36 = ($$0$i$i7|0)==(-1);
     if ($36) {
      $$lcssa32 = $29;$$lcssa33 = $30;$list$0$i6$lcssa = $list$0$i6;
      break;
     } else {
      $list$0$i6 = $$0$i$i7;
     }
    }
    $$neg$i$i8 = $list$0$i6$lcssa ^ -1;
    $37 = (($25) + ($$neg$i$i8))|0;
    $ispos$i$i9 = ($37|0)>(-1);
    $neg$i$i10 = (0 - ($37))|0;
    $38 = $ispos$i$i9 ? $37 : $neg$i$i10;
    $39 = ($38|0)>(131071);
    if ($39) {
     $40 = ((($fs)) + 8|0);
     $41 = HEAP32[$40>>2]|0;
     _luaX_syntaxerror($41,4744);
     // unreachable;
    } else {
     $42 = $$lcssa33 & 16383;
     $43 = $37 << 14;
     $44 = (($43) + 2147467264)|0;
     $45 = $44 | $42;
     HEAP32[$$lcssa32>>2] = $45;
     break;
    }
   }
  } while(0);
  ;HEAP32[$e1>>2]=HEAP32[$e2>>2]|0;HEAP32[$e1+4>>2]=HEAP32[$e2+4>>2]|0;HEAP32[$e1+8>>2]=HEAP32[$e2+8>>2]|0;HEAP32[$e1+12>>2]=HEAP32[$e2+12>>2]|0;HEAP32[$e1+16>>2]=HEAP32[$e2+16>>2]|0;HEAP32[$e1+20>>2]=HEAP32[$e2+20>>2]|0;
  return;
  break;
 }
 default: {
  return;
 }
 }
}
function _luaK_fixline($fs,$line) {
 $fs = $fs|0;
 $line = $line|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (($1) + -1)|0;
 $3 = HEAP32[$fs>>2]|0;
 $4 = ((($3)) + 56|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (($5) + ($2<<2)|0);
 HEAP32[$6>>2] = $line;
 return;
}
function _luaK_setlist($fs,$base,$nelems,$tostore) {
 $fs = $fs|0;
 $base = $base|0;
 $nelems = $nelems|0;
 $tostore = $tostore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($nelems) + -1)|0;
 $1 = (($0|0) / 50)&-1;
 $2 = (($1) + 1)|0;
 $3 = ($tostore|0)==(-1);
 $4 = $3 ? 0 : $tostore;
 $5 = ($2|0)<(512);
 if ($5) {
  $6 = $base << 6;
  $7 = $4 << 23;
  $8 = $2 << 14;
  $9 = $6 | $7;
  $10 = $9 | $8;
  $11 = $10 | 43;
  (_luaK_code($fs,$11)|0);
  $21 = (($base) + 1)|0;
  $22 = $21&255;
  $23 = ((($fs)) + 44|0);
  HEAP8[$23>>0] = $22;
  return;
 }
 $12 = ($2|0)<(67108864);
 if (!($12)) {
  $19 = ((($fs)) + 8|0);
  $20 = HEAP32[$19>>2]|0;
  _luaX_syntaxerror($20,4816);
  // unreachable;
 }
 $13 = $base << 6;
 $14 = $4 << 23;
 $15 = $13 | $14;
 $16 = $15 | 43;
 (_luaK_code($fs,$16)|0);
 $17 = $2 << 6;
 $18 = $17 | 46;
 (_luaK_code($fs,$18)|0);
 $21 = (($base) + 1)|0;
 $22 = $21&255;
 $23 = ((($fs)) + 44|0);
 HEAP8[$23>>0] = $22;
 return;
}
function _luaK_code($fs,$i) {
 $fs = $fs|0;
 $i = $i|0;
 var $$0$i$i$i = 0, $$0$i$i1$i = 0, $$02$i$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phi7Z2D = 0, $$pre1 = 0, $$pre2 = 0, $$pre3 = 0, $$pre4 = 0, $$pre6 = 0, $$sum$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $fs$idx$val$idx$i$phi$trans$insert$i = 0, $fs$idx$val$idx$val$i$pre$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $neg$i$i = 0, $neg$i$i$i = 0;
 var $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$fs>>2]|0;
 $1 = ((($fs)) + 24|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($fs)) + 16|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($2|0)==(-1);
 do {
  if ($5) {
   $51 = $4;
  } else {
   $fs$idx$val$idx$i$phi$trans$insert$i = ((($0)) + 48|0);
   $fs$idx$val$idx$val$i$pre$i = HEAP32[$fs$idx$val$idx$i$phi$trans$insert$i>>2]|0;
   $$02$i$i = $2;
   while(1) {
    $6 = (($fs$idx$val$idx$val$i$pre$i) + ($$02$i$i<<2)|0);
    $7 = HEAP32[$6>>2]|0;
    $8 = $7 >>> 14;
    $9 = (($8) + -131071)|0;
    $10 = ($9|0)==(-1);
    $11 = (($$02$i$i) + 1)|0;
    $12 = (($11) + ($9))|0;
    $$0$i$i$i = $10 ? -1 : $12;
    $13 = ($$02$i$i|0)>(0);
    if ($13) {
     $$sum$i$i$i = (($$02$i$i) + -1)|0;
     $14 = (($fs$idx$val$idx$val$i$pre$i) + ($$sum$i$i$i<<2)|0);
     $15 = HEAP32[$14>>2]|0;
     $16 = $15 & 63;
     $17 = (1960 + ($16)|0);
     $18 = HEAP8[$17>>0]|0;
     $19 = ($18<<24>>24)<(0);
     if ($19) {
      $$0$i$i1$i = $14;$21 = $15;
     } else {
      label = 5;
     }
    } else {
     label = 5;
    }
    if ((label|0) == 5) {
     label = 0;
     $$0$i$i1$i = $6;$21 = $7;
    }
    $20 = $21 & 63;
    $22 = ($20|0)==(35);
    if ($22) {
     $23 = $21 >>> 23;
     $24 = $23 << 6;
     $25 = $21 & 8372224;
     $26 = $25 | $24;
     $27 = $26 | 34;
     HEAP32[$$0$i$i1$i>>2] = $27;
     $$neg$i$i = $$02$i$i ^ -1;
     $28 = (($4) + ($$neg$i$i))|0;
     $ispos$i$i = ($28|0)>(-1);
     $neg$i$i = (0 - ($28))|0;
     $29 = $ispos$i$i ? $28 : $neg$i$i;
     $30 = ($29|0)>(131071);
     if ($30) {
      label = 8;
      break;
     }
     $33 = HEAP32[$6>>2]|0;
     $34 = $33 & 16383;
     $35 = $28 << 14;
     $36 = (($35) + 2147467264)|0;
     $37 = $34 | $36;
     $storemerge$i = $37;
    } else {
     $$neg$i$i$i = $$02$i$i ^ -1;
     $38 = (($4) + ($$neg$i$i$i))|0;
     $ispos$i$i$i = ($38|0)>(-1);
     $neg$i$i$i = (0 - ($38))|0;
     $39 = $ispos$i$i$i ? $38 : $neg$i$i$i;
     $40 = ($39|0)>(131071);
     if ($40) {
      label = 11;
      break;
     }
     $43 = $7 & 16383;
     $44 = $38 << 14;
     $45 = (($44) + 2147467264)|0;
     $46 = $45 | $43;
     $storemerge$i = $46;
    }
    HEAP32[$6>>2] = $storemerge$i;
    $47 = ($$0$i$i$i|0)==(-1);
    if ($47) {
     label = 14;
     break;
    } else {
     $$02$i$i = $$0$i$i$i;
    }
   }
   if ((label|0) == 8) {
    $31 = ((($fs)) + 8|0);
    $32 = HEAP32[$31>>2]|0;
    _luaX_syntaxerror($32,4744);
    // unreachable;
   }
   else if ((label|0) == 11) {
    $41 = ((($fs)) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    _luaX_syntaxerror($42,4744);
    // unreachable;
   }
   else if ((label|0) == 14) {
    $$pre = HEAP32[$3>>2]|0;
    $51 = $$pre;
    break;
   }
  }
 } while(0);
 HEAP32[$1>>2] = -1;
 $48 = ((($0)) + 20|0);
 $49 = HEAP32[$48>>2]|0;
 $50 = ($51|0)<($49|0);
 if ($50) {
  $$phi$trans$insert = ((($0)) + 48|0);
  $$pre2 = HEAP32[$$phi$trans$insert>>2]|0;
  $60 = $$pre2;$61 = $51;
 } else {
  $52 = ((($fs)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  $54 = ((($53)) + 52|0);
  $55 = HEAP32[$54>>2]|0;
  $56 = ((($0)) + 48|0);
  $57 = HEAP32[$56>>2]|0;
  $58 = (_luaM_growaux_($55,$57,$48,4,2147483647,4856)|0);
  HEAP32[$56>>2] = $58;
  $$pre1 = HEAP32[$3>>2]|0;
  $60 = $58;$61 = $$pre1;
 }
 $59 = (($60) + ($61<<2)|0);
 HEAP32[$59>>2] = $i;
 $62 = HEAP32[$3>>2]|0;
 $63 = ((($0)) + 24|0);
 $64 = HEAP32[$63>>2]|0;
 $65 = ($62|0)<($64|0);
 $$pre4 = ((($fs)) + 8|0);
 if ($65) {
  $$pre6 = ((($0)) + 56|0);
  $$pre$phi7Z2D = $$pre6;$77 = $62;
  $72 = HEAP32[$$pre4>>2]|0;
  $73 = ((($72)) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$$pre$phi7Z2D>>2]|0;
  $76 = (($75) + ($77<<2)|0);
  HEAP32[$76>>2] = $74;
  $78 = HEAP32[$3>>2]|0;
  $79 = (($78) + 1)|0;
  HEAP32[$3>>2] = $79;
  return ($78|0);
 } else {
  $66 = HEAP32[$$pre4>>2]|0;
  $67 = ((($66)) + 52|0);
  $68 = HEAP32[$67>>2]|0;
  $69 = ((($0)) + 56|0);
  $70 = HEAP32[$69>>2]|0;
  $71 = (_luaM_growaux_($68,$70,$63,4,2147483647,4856)|0);
  HEAP32[$69>>2] = $71;
  $$pre3 = HEAP32[$3>>2]|0;
  $$pre$phi7Z2D = $69;$77 = $$pre3;
  $72 = HEAP32[$$pre4>>2]|0;
  $73 = ((($72)) + 8|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = HEAP32[$$pre$phi7Z2D>>2]|0;
  $76 = (($75) + ($77<<2)|0);
  HEAP32[$76>>2] = $74;
  $78 = HEAP32[$3>>2]|0;
  $79 = (($78) + 1)|0;
  HEAP32[$3>>2] = $79;
  return ($78|0);
 }
 return (0)|0;
}
function _addk($fs,$key,$v) {
 $fs = $fs|0;
 $key = $key|0;
 $v = $v|0;
 var $$0 = 0, $$pre = 0, $$pre$phi5Z2D = 0, $$pre$phi7Z2D = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $oldsize$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($fs)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 52|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[$fs>>2]|0;
 $5 = ((($1)) + 64|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_luaH_set($3,$6,$key)|0);
 $8 = ((($7)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(19);
 if ($10) {
  $11 = $7;
  $12 = $11;
  $13 = HEAP32[$12>>2]|0;
  $14 = (($11) + 4)|0;
  $15 = $14;
  $16 = HEAP32[$15>>2]|0;
  $17 = ((($fs)) + 28|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = ($13|0)<($18|0);
  if ($19) {
   $20 = ((($4)) + 44|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = (((($21) + ($13<<4)|0)) + 8|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($v)) + 8|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 ^ $23;
   $27 = $26 & 63;
   $28 = ($27|0)==(0);
   if ($28) {
    $29 = (($21) + ($13<<4)|0);
    $30 = (_luaV_equalobj(0,$29,$v)|0);
    $31 = ($30|0)==(0);
    if ($31) {
     $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
    } else {
     $$0 = $13;
     return ($$0|0);
    }
   } else {
    $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
   }
  } else {
   $$pre$phi5Z2D = $17;$$pre$phi7Z2D = $7;
  }
 } else {
  $$pre4 = ((($fs)) + 28|0);
  $$pre$phi5Z2D = $$pre4;$$pre$phi7Z2D = $7;
 }
 $32 = ((($4)) + 16|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $35 = ($34|0)<(0);
 $36 = $35 << 31 >> 31;
 $37 = $$pre$phi7Z2D;
 $38 = $37;
 HEAP32[$38>>2] = $34;
 $39 = (($37) + 4)|0;
 $40 = $39;
 HEAP32[$40>>2] = $36;
 HEAP32[$8>>2] = 19;
 $41 = ($34|0)<($33|0);
 if ($41) {
  $46 = $33;
 } else {
  $42 = ((($4)) + 44|0);
  $43 = HEAP32[$42>>2]|0;
  $44 = (_luaM_growaux_($3,$43,$32,16,67108863,4840)|0);
  HEAP32[$42>>2] = $44;
  $$pre = HEAP32[$32>>2]|0;
  $46 = $$pre;
 }
 $45 = ($33|0)<($46|0);
 $47 = ((($4)) + 44|0);
 $48 = HEAP32[$47>>2]|0;
 if ($45) {
  $oldsize$01 = $33;
  while(1) {
   $49 = (($oldsize$01) + 1)|0;
   $50 = (((($48) + ($oldsize$01<<4)|0)) + 8|0);
   HEAP32[$50>>2] = 0;
   $51 = ($49|0)<($46|0);
   if ($51) {
    $oldsize$01 = $49;
   } else {
    break;
   }
  }
 }
 $52 = (($48) + ($34<<4)|0);
 ;HEAP32[$52>>2]=HEAP32[$v>>2]|0;HEAP32[$52+4>>2]=HEAP32[$v+4>>2]|0;HEAP32[$52+8>>2]=HEAP32[$v+8>>2]|0;HEAP32[$52+12>>2]=HEAP32[$v+12>>2]|0;
 $53 = HEAP32[$$pre$phi5Z2D>>2]|0;
 $54 = (($53) + 1)|0;
 HEAP32[$$pre$phi5Z2D>>2] = $54;
 $55 = ((($v)) + 8|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = $56 & 64;
 $58 = ($57|0)==(0);
 if ($58) {
  $$0 = $34;
  return ($$0|0);
 }
 $59 = ((($4)) + 5|0);
 $60 = HEAP8[$59>>0]|0;
 $61 = $60 & 4;
 $62 = ($61<<24>>24)==(0);
 if ($62) {
  $$0 = $34;
  return ($$0|0);
 }
 $63 = HEAP32[$v>>2]|0;
 $64 = ((($63)) + 5|0);
 $65 = HEAP8[$64>>0]|0;
 $66 = $65 & 3;
 $67 = ($66<<24>>24)==(0);
 if ($67) {
  $$0 = $34;
  return ($$0|0);
 }
 _luaC_barrier_($3,$4,$63);
 $$0 = $34;
 return ($$0|0);
}
function _exp2reg($fs,$e,$reg) {
 $fs = $fs|0;
 $e = $e|0;
 $reg = $reg|0;
 var $$$i = 0, $$$i20 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i$i35 = 0, $$0$i$i26 = 0, $$0$i$i26$us = 0, $$0$i$i46 = 0, $$0$i$i59 = 0, $$0$i$i6 = 0, $$0$i$i6$us = 0, $$014$i = 0, $$014$i16 = 0, $$02$i = 0, $$02$i$us = 0, $$02$i42 = 0, $$lcssa = 0, $$lcssa119 = 0, $$lcssa120 = 0, $$lcssa121 = 0;
 var $$lcssa122 = 0, $$lcssa123 = 0, $$neg$i = 0, $$neg$i$i = 0, $$neg$i$i$i = 0, $$neg$i$i$i36 = 0, $$neg$i$i47 = 0, $$neg$i$i7 = 0, $$neg$i$i7$us = 0, $$neg$i$us = 0, $$neg$i53 = 0, $$pre$i = 0, $$pre$i18 = 0, $$pre88 = 0, $$sum$i$i = 0, $$sum$i$i17 = 0, $$sum$i$i24 = 0, $$sum$i$i24$us = 0, $$sum$i$i57 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $fs$idx$val$i = 0;
 var $fs$idx$val$i$i = 0, $fs$idx$val$i$i30 = 0, $fs$idx$val$i3$us$pre = 0, $fs$idx$val$i43$pre = 0, $fs$idx$val$idx$i = 0, $fs$idx$val$idx$i$i = 0, $fs$idx$val$idx$i$i31 = 0, $fs$idx$val$idx$i4$us$phi$trans$insert = 0, $fs$idx$val$idx$i44$phi$trans$insert = 0, $fs$idx$val$idx$val$i = 0, $fs$idx$val$idx$val$i$i = 0, $fs$idx$val$idx$val$i$i32 = 0, $fs$idx$val$idx$val$i45$pre = 0, $fs$idx$val$idx$val$i5$us$pre = 0, $fs$idx2$val$i = 0, $fs$idx2$val$i12 = 0, $fs$idx2$val$idx$i = 0, $fs$idx2$val$idx$i13 = 0, $fs$idx2$val$idx$val$i = 0, $fs$idx2$val$idx$val$i14 = 0;
 var $ispos$i = 0, $ispos$i$i = 0, $ispos$i$i$i = 0, $ispos$i$i$i37 = 0, $ispos$i$i48 = 0, $ispos$i$i8 = 0, $ispos$i$i8$us = 0, $ispos$i$us = 0, $ispos$i54 = 0, $list$0$i = 0, $list$0$i$i = 0, $list$0$i$i$lcssa = 0, $list$0$i$i34 = 0, $list$0$i$i34$lcssa = 0, $list$0$i$lcssa = 0, $neg$i = 0, $neg$i$i = 0, $neg$i$i$i = 0, $neg$i$i$i38 = 0, $neg$i$i49 = 0;
 var $neg$i$i9 = 0, $neg$i$i9$us = 0, $neg$i$us = 0, $neg$i55 = 0, $or$cond$i61 = 0, $p_f$0 = 0, $p_t$0 = 0, $storemerge = 0, $storemerge$i = 0, $storemerge$i62 = 0, $storemerge90 = 0, $storemerge91 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _discharge2reg($fs,$e,$reg);
 $0 = HEAP32[$e>>2]|0;
 $1 = ($0|0)==(11);
 $2 = ((($e)) + 16|0);
 do {
  if ($1) {
   $3 = ((($e)) + 8|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(-1);
   if (!($5)) {
    $6 = HEAP32[$2>>2]|0;
    $7 = ($6|0)==(-1);
    if ($7) {
     HEAP32[$2>>2] = $4;
     break;
    }
    $fs$idx$val$i = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i = ((($fs$idx$val$i)) + 48|0);
    $fs$idx$val$idx$val$i = HEAP32[$fs$idx$val$idx$i>>2]|0;
    $list$0$i = $6;
    while(1) {
     $8 = (($fs$idx$val$idx$val$i) + ($list$0$i<<2)|0);
     $9 = HEAP32[$8>>2]|0;
     $10 = $9 >>> 14;
     $11 = (($10) + -131071)|0;
     $12 = ($11|0)==(-1);
     $13 = (($list$0$i) + 1)|0;
     $14 = (($13) + ($11))|0;
     $$0$i$i = $12 ? -1 : $14;
     $15 = ($$0$i$i|0)==(-1);
     if ($15) {
      $$lcssa122 = $8;$$lcssa123 = $9;$list$0$i$lcssa = $list$0$i;
      break;
     } else {
      $list$0$i = $$0$i$i;
     }
    }
    $$neg$i$i = $list$0$i$lcssa ^ -1;
    $16 = (($4) + ($$neg$i$i))|0;
    $ispos$i$i = ($16|0)>(-1);
    $neg$i$i = (0 - ($16))|0;
    $17 = $ispos$i$i ? $16 : $neg$i$i;
    $18 = ($17|0)>(131071);
    if ($18) {
     $19 = ((($fs)) + 8|0);
     $20 = HEAP32[$19>>2]|0;
     _luaX_syntaxerror($20,4744);
     // unreachable;
    } else {
     $21 = $$lcssa123 & 16383;
     $22 = $16 << 14;
     $23 = (($22) + 2147467264)|0;
     $24 = $23 | $21;
     HEAP32[$$lcssa122>>2] = $24;
     break;
    }
   }
  }
 } while(0);
 $25 = HEAP32[$2>>2]|0;
 $26 = ((($e)) + 20|0);
 $27 = HEAP32[$26>>2]|0;
 $28 = ($25|0)==($27|0);
 if ($28) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
 $29 = ($25|0)==(-1);
 L17: do {
  if ($29) {
   label = 18;
  } else {
   $fs$idx2$val$i = HEAP32[$fs>>2]|0;
   $fs$idx2$val$idx$i = ((($fs$idx2$val$i)) + 48|0);
   $fs$idx2$val$idx$val$i = HEAP32[$fs$idx2$val$idx$i>>2]|0;
   $$014$i = $25;
   while(1) {
    $30 = (($fs$idx2$val$idx$val$i) + ($$014$i<<2)|0);
    $31 = ($$014$i|0)>(0);
    if ($31) {
     $$sum$i$i = (($$014$i) + -1)|0;
     $32 = (($fs$idx2$val$idx$val$i) + ($$sum$i$i<<2)|0);
     $33 = HEAP32[$32>>2]|0;
     $34 = $33 & 63;
     $35 = (1960 + ($34)|0);
     $36 = HEAP8[$35>>0]|0;
     $37 = ($36<<24>>24)<(0);
     if ($37) {
      $39 = $33;
     } else {
      label = 15;
     }
    } else {
     label = 15;
    }
    if ((label|0) == 15) {
     label = 0;
     $$pre$i = HEAP32[$30>>2]|0;
     $39 = $$pre$i;
    }
    $38 = $39 & 63;
    $40 = ($38|0)==(35);
    if (!($40)) {
     label = 25;
     break L17;
    }
    $41 = HEAP32[$30>>2]|0;
    $42 = $41 >>> 14;
    $43 = (($42) + -131071)|0;
    $44 = ($43|0)==(-1);
    $45 = (($$014$i) + 1)|0;
    $46 = (($45) + ($43))|0;
    $$$i = $44 ? -1 : $46;
    $47 = ($$$i|0)==(-1);
    if ($47) {
     label = 18;
     break;
    } else {
     $$014$i = $$$i;
    }
   }
  }
 } while(0);
 L27: do {
  if ((label|0) == 18) {
   $48 = ($27|0)==(-1);
   if ($48) {
    $p_f$0 = -1;$p_t$0 = -1;
   } else {
    $fs$idx2$val$i12 = HEAP32[$fs>>2]|0;
    $fs$idx2$val$idx$i13 = ((($fs$idx2$val$i12)) + 48|0);
    $fs$idx2$val$idx$val$i14 = HEAP32[$fs$idx2$val$idx$i13>>2]|0;
    $$014$i16 = $27;
    while(1) {
     $49 = (($fs$idx2$val$idx$val$i14) + ($$014$i16<<2)|0);
     $50 = ($$014$i16|0)>(0);
     if ($50) {
      $$sum$i$i17 = (($$014$i16) + -1)|0;
      $51 = (($fs$idx2$val$idx$val$i14) + ($$sum$i$i17<<2)|0);
      $52 = HEAP32[$51>>2]|0;
      $53 = $52 & 63;
      $54 = (1960 + ($53)|0);
      $55 = HEAP8[$54>>0]|0;
      $56 = ($55<<24>>24)<(0);
      if ($56) {
       $58 = $52;
      } else {
       label = 22;
      }
     } else {
      label = 22;
     }
     if ((label|0) == 22) {
      label = 0;
      $$pre$i18 = HEAP32[$49>>2]|0;
      $58 = $$pre$i18;
     }
     $57 = $58 & 63;
     $59 = ($57|0)==(35);
     if (!($59)) {
      label = 25;
      break L27;
     }
     $60 = HEAP32[$49>>2]|0;
     $61 = $60 >>> 14;
     $62 = (($61) + -131071)|0;
     $63 = ($62|0)==(-1);
     $64 = (($$014$i16) + 1)|0;
     $65 = (($64) + ($62))|0;
     $$$i20 = $63 ? -1 : $65;
     $66 = ($$$i20|0)==(-1);
     if ($66) {
      $p_f$0 = -1;$p_t$0 = -1;
      break;
     } else {
      $$014$i16 = $$$i20;
     }
    }
   }
  }
 } while(0);
 do {
  if ((label|0) == 25) {
   $$pre88 = ((($fs)) + 24|0);
   do {
    if ($1) {
     $99 = -1;
    } else {
     $67 = HEAP32[$$pre88>>2]|0;
     HEAP32[$$pre88>>2] = -1;
     $68 = (_luaK_code($fs,2147450910)|0);
     $69 = ($67|0)==(-1);
     if ($69) {
      $99 = $68;
     } else {
      $70 = ($68|0)==(-1);
      if ($70) {
       $99 = $67;
      } else {
       $fs$idx$val$i$i = HEAP32[$fs>>2]|0;
       $fs$idx$val$idx$i$i = ((($fs$idx$val$i$i)) + 48|0);
       $fs$idx$val$idx$val$i$i = HEAP32[$fs$idx$val$idx$i$i>>2]|0;
       $list$0$i$i = $68;
       while(1) {
        $71 = (($fs$idx$val$idx$val$i$i) + ($list$0$i$i<<2)|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = $72 >>> 14;
        $74 = (($73) + -131071)|0;
        $75 = ($74|0)==(-1);
        $76 = (($list$0$i$i) + 1)|0;
        $77 = (($76) + ($74))|0;
        $$0$i$i$i = $75 ? -1 : $77;
        $78 = ($$0$i$i$i|0)==(-1);
        if ($78) {
         $$lcssa120 = $71;$$lcssa121 = $72;$list$0$i$i$lcssa = $list$0$i$i;
         break;
        } else {
         $list$0$i$i = $$0$i$i$i;
        }
       }
       $$neg$i$i$i = $list$0$i$i$lcssa ^ -1;
       $79 = (($67) + ($$neg$i$i$i))|0;
       $ispos$i$i$i = ($79|0)>(-1);
       $neg$i$i$i = (0 - ($79))|0;
       $80 = $ispos$i$i$i ? $79 : $neg$i$i$i;
       $81 = ($80|0)>(131071);
       if ($81) {
        $82 = ((($fs)) + 8|0);
        $83 = HEAP32[$82>>2]|0;
        _luaX_syntaxerror($83,4744);
        // unreachable;
       } else {
        $84 = $$lcssa121 & 16383;
        $85 = $79 << 14;
        $86 = (($85) + 2147467264)|0;
        $87 = $86 | $84;
        HEAP32[$$lcssa120>>2] = $87;
        $99 = $68;
        break;
       }
      }
     }
    }
   } while(0);
   $88 = ((($fs)) + 16|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ((($fs)) + 20|0);
   HEAP32[$90>>2] = $89;
   $91 = $reg << 6;
   $92 = $91 | 16387;
   $93 = (_luaK_code($fs,$92)|0);
   $94 = HEAP32[$88>>2]|0;
   HEAP32[$90>>2] = $94;
   $95 = $91 | 8388611;
   $96 = (_luaK_code($fs,$95)|0);
   $97 = HEAP32[$88>>2]|0;
   HEAP32[$90>>2] = $97;
   $98 = ($99|0)==(-1);
   if ($98) {
    $p_f$0 = $93;$p_t$0 = $96;
   } else {
    $100 = HEAP32[$$pre88>>2]|0;
    $101 = ($100|0)==(-1);
    if ($101) {
     HEAP32[$$pre88>>2] = $99;
     $p_f$0 = $93;$p_t$0 = $96;
     break;
    }
    $fs$idx$val$i$i30 = HEAP32[$fs>>2]|0;
    $fs$idx$val$idx$i$i31 = ((($fs$idx$val$i$i30)) + 48|0);
    $fs$idx$val$idx$val$i$i32 = HEAP32[$fs$idx$val$idx$i$i31>>2]|0;
    $list$0$i$i34 = $100;
    while(1) {
     $102 = (($fs$idx$val$idx$val$i$i32) + ($list$0$i$i34<<2)|0);
     $103 = HEAP32[$102>>2]|0;
     $104 = $103 >>> 14;
     $105 = (($104) + -131071)|0;
     $106 = ($105|0)==(-1);
     $107 = (($list$0$i$i34) + 1)|0;
     $108 = (($107) + ($105))|0;
     $$0$i$i$i35 = $106 ? -1 : $108;
     $109 = ($$0$i$i$i35|0)==(-1);
     if ($109) {
      $$lcssa = $102;$$lcssa119 = $103;$list$0$i$i34$lcssa = $list$0$i$i34;
      break;
     } else {
      $list$0$i$i34 = $$0$i$i$i35;
     }
    }
    $$neg$i$i$i36 = $list$0$i$i34$lcssa ^ -1;
    $110 = (($99) + ($$neg$i$i$i36))|0;
    $ispos$i$i$i37 = ($110|0)>(-1);
    $neg$i$i$i38 = (0 - ($110))|0;
    $111 = $ispos$i$i$i37 ? $110 : $neg$i$i$i38;
    $112 = ($111|0)>(131071);
    if ($112) {
     $113 = ((($fs)) + 8|0);
     $114 = HEAP32[$113>>2]|0;
     _luaX_syntaxerror($114,4744);
     // unreachable;
    } else {
     $115 = $$lcssa119 & 16383;
     $116 = $110 << 14;
     $117 = (($116) + 2147467264)|0;
     $118 = $117 | $115;
     HEAP32[$$lcssa>>2] = $118;
     $p_f$0 = $93;$p_t$0 = $96;
     break;
    }
   }
  }
 } while(0);
 $119 = ((($fs)) + 16|0);
 $120 = HEAP32[$119>>2]|0;
 $121 = ((($fs)) + 20|0);
 HEAP32[$121>>2] = $120;
 $122 = HEAP32[$26>>2]|0;
 $123 = ($122|0)==(-1);
 L62: do {
  if (!($123)) {
   $124 = ($reg|0)==(255);
   $125 = $reg << 6;
   $126 = $125 & 16320;
   $fs$idx$val$i43$pre = HEAP32[$fs>>2]|0;
   $fs$idx$val$idx$i44$phi$trans$insert = ((($fs$idx$val$i43$pre)) + 48|0);
   $fs$idx$val$idx$val$i45$pre = HEAP32[$fs$idx$val$idx$i44$phi$trans$insert>>2]|0;
   $$02$i42 = $122;
   while(1) {
    $127 = (($fs$idx$val$idx$val$i45$pre) + ($$02$i42<<2)|0);
    $128 = HEAP32[$127>>2]|0;
    $129 = $128 >>> 14;
    $130 = (($129) + -131071)|0;
    $131 = ($130|0)==(-1);
    $132 = (($$02$i42) + 1)|0;
    $133 = (($132) + ($130))|0;
    $$0$i$i46 = $131 ? -1 : $133;
    $134 = ($$02$i42|0)>(0);
    if ($134) {
     $$sum$i$i57 = (($$02$i42) + -1)|0;
     $135 = (($fs$idx$val$idx$val$i45$pre) + ($$sum$i$i57<<2)|0);
     $136 = HEAP32[$135>>2]|0;
     $137 = $136 & 63;
     $138 = (1960 + ($137)|0);
     $139 = HEAP8[$138>>0]|0;
     $140 = ($139<<24>>24)<(0);
     if ($140) {
      $$0$i$i59 = $135;$142 = $136;
     } else {
      label = 45;
     }
    } else {
     label = 45;
    }
    if ((label|0) == 45) {
     label = 0;
     $$0$i$i59 = $127;$142 = $128;
    }
    $141 = $142 & 63;
    $143 = ($141|0)==(35);
    if ($143) {
     $144 = $142 >>> 23;
     $145 = ($144|0)==($reg|0);
     $or$cond$i61 = $124 | $145;
     if ($or$cond$i61) {
      $148 = $144 << 6;
      $149 = $142 & 8372224;
      $150 = $149 | $148;
      $151 = $150 | 34;
      $storemerge$i62 = $151;
     } else {
      $146 = $142 & -16321;
      $147 = $146 | $126;
      $storemerge$i62 = $147;
     }
     HEAP32[$$0$i$i59>>2] = $storemerge$i62;
     $$neg$i53 = $$02$i42 ^ -1;
     $152 = (($120) + ($$neg$i53))|0;
     $ispos$i54 = ($152|0)>(-1);
     $neg$i55 = (0 - ($152))|0;
     $153 = $ispos$i54 ? $152 : $neg$i55;
     $154 = ($153|0)>(131071);
     if ($154) {
      label = 51;
      break;
     }
     $157 = HEAP32[$127>>2]|0;
     $158 = $157 & 16383;
     $159 = $152 << 14;
     $160 = (($159) + 2147467264)|0;
     $161 = $158 | $160;
     $storemerge = $161;
    } else {
     $$neg$i$i47 = $$02$i42 ^ -1;
     $162 = (($p_f$0) + ($$neg$i$i47))|0;
     $ispos$i$i48 = ($162|0)>(-1);
     $neg$i$i49 = (0 - ($162))|0;
     $163 = $ispos$i$i48 ? $162 : $neg$i$i49;
     $164 = ($163|0)>(131071);
     if ($164) {
      label = 54;
      break;
     }
     $167 = $128 & 16383;
     $168 = $162 << 14;
     $169 = (($168) + 2147467264)|0;
     $170 = $167 | $169;
     $storemerge = $170;
    }
    HEAP32[$127>>2] = $storemerge;
    $171 = ($$0$i$i46|0)==(-1);
    if ($171) {
     break L62;
    } else {
     $$02$i42 = $$0$i$i46;
    }
   }
   if ((label|0) == 51) {
    $155 = ((($fs)) + 8|0);
    $156 = HEAP32[$155>>2]|0;
    _luaX_syntaxerror($156,4744);
    // unreachable;
   }
   else if ((label|0) == 54) {
    $165 = ((($fs)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    _luaX_syntaxerror($166,4744);
    // unreachable;
   }
  }
 } while(0);
 $172 = HEAP32[$2>>2]|0;
 $173 = ($172|0)==(-1);
 if ($173) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
 $174 = ($reg|0)==(255);
 $175 = $reg << 6;
 $176 = $175 & 16320;
 $fs$idx$val$i3$us$pre = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i4$us$phi$trans$insert = ((($fs$idx$val$i3$us$pre)) + 48|0);
 $fs$idx$val$idx$val$i5$us$pre = HEAP32[$fs$idx$val$idx$i4$us$phi$trans$insert>>2]|0;
 if ($174) {
  $$02$i$us = $172;
  while(1) {
   $177 = (($fs$idx$val$idx$val$i5$us$pre) + ($$02$i$us<<2)|0);
   $178 = HEAP32[$177>>2]|0;
   $179 = $178 >>> 14;
   $180 = (($179) + -131071)|0;
   $181 = ($180|0)==(-1);
   $182 = (($$02$i$us) + 1)|0;
   $183 = (($182) + ($180))|0;
   $$0$i$i6$us = $181 ? -1 : $183;
   $184 = ($$02$i$us|0)>(0);
   if ($184) {
    $$sum$i$i24$us = (($$02$i$us) + -1)|0;
    $185 = (($fs$idx$val$idx$val$i5$us$pre) + ($$sum$i$i24$us<<2)|0);
    $186 = HEAP32[$185>>2]|0;
    $187 = $186 & 63;
    $188 = (1960 + ($187)|0);
    $189 = HEAP8[$188>>0]|0;
    $190 = ($189<<24>>24)<(0);
    if ($190) {
     $$0$i$i26$us = $185;$192 = $186;
    } else {
     label = 61;
    }
   } else {
    label = 61;
   }
   if ((label|0) == 61) {
    label = 0;
    $$0$i$i26$us = $177;$192 = $178;
   }
   $191 = $192 & 63;
   $193 = ($191|0)==(35);
   if ($193) {
    $201 = $192 >>> 23;
    $202 = $201 << 6;
    $203 = $192 & 8372224;
    $204 = $203 | $202;
    $205 = $204 | 34;
    HEAP32[$$0$i$i26$us>>2] = $205;
    $$neg$i$us = $$02$i$us ^ -1;
    $206 = (($120) + ($$neg$i$us))|0;
    $ispos$i$us = ($206|0)>(-1);
    $neg$i$us = (0 - ($206))|0;
    $207 = $ispos$i$us ? $206 : $neg$i$us;
    $208 = ($207|0)>(131071);
    if ($208) {
     label = 76;
     break;
    }
    $209 = HEAP32[$177>>2]|0;
    $210 = $209 & 16383;
    $211 = $206 << 14;
    $212 = (($211) + 2147467264)|0;
    $213 = $210 | $212;
    $storemerge91 = $213;
   } else {
    $$neg$i$i7$us = $$02$i$us ^ -1;
    $194 = (($p_t$0) + ($$neg$i$i7$us))|0;
    $ispos$i$i8$us = ($194|0)>(-1);
    $neg$i$i9$us = (0 - ($194))|0;
    $195 = $ispos$i$i8$us ? $194 : $neg$i$i9$us;
    $196 = ($195|0)>(131071);
    if ($196) {
     label = 79;
     break;
    }
    $197 = $178 & 16383;
    $198 = $194 << 14;
    $199 = (($198) + 2147467264)|0;
    $200 = $197 | $199;
    $storemerge91 = $200;
   }
   HEAP32[$177>>2] = $storemerge91;
   $214 = ($$0$i$i6$us|0)==(-1);
   if ($214) {
    label = 82;
    break;
   } else {
    $$02$i$us = $$0$i$i6$us;
   }
  }
  if ((label|0) == 76) {
   $242 = ((($fs)) + 8|0);
   $243 = HEAP32[$242>>2]|0;
   _luaX_syntaxerror($243,4744);
   // unreachable;
  }
  else if ((label|0) == 79) {
   $252 = ((($fs)) + 8|0);
   $253 = HEAP32[$252>>2]|0;
   _luaX_syntaxerror($253,4744);
   // unreachable;
  }
  else if ((label|0) == 82) {
   HEAP32[$2>>2] = -1;
   HEAP32[$26>>2] = -1;
   $259 = ((($e)) + 8|0);
   HEAP32[$259>>2] = $reg;
   HEAP32[$e>>2] = 7;
   return;
  }
 } else {
  $$02$i = $172;
 }
 while(1) {
  $215 = (($fs$idx$val$idx$val$i5$us$pre) + ($$02$i<<2)|0);
  $216 = HEAP32[$215>>2]|0;
  $217 = $216 >>> 14;
  $218 = (($217) + -131071)|0;
  $219 = ($218|0)==(-1);
  $220 = (($$02$i) + 1)|0;
  $221 = (($220) + ($218))|0;
  $$0$i$i6 = $219 ? -1 : $221;
  $222 = ($$02$i|0)>(0);
  if ($222) {
   $$sum$i$i24 = (($$02$i) + -1)|0;
   $223 = (($fs$idx$val$idx$val$i5$us$pre) + ($$sum$i$i24<<2)|0);
   $224 = HEAP32[$223>>2]|0;
   $225 = $224 & 63;
   $226 = (1960 + ($225)|0);
   $227 = HEAP8[$226>>0]|0;
   $228 = ($227<<24>>24)<(0);
   if ($228) {
    $$0$i$i26 = $223;$230 = $224;
   } else {
    label = 70;
   }
  } else {
   label = 70;
  }
  if ((label|0) == 70) {
   label = 0;
   $$0$i$i26 = $215;$230 = $216;
  }
  $229 = $230 & 63;
  $231 = ($229|0)==(35);
  if ($231) {
   $232 = $230 >>> 23;
   $233 = ($232|0)==($reg|0);
   if ($233) {
    $236 = $230 & 8372224;
    $237 = $236 | $175;
    $238 = $237 | 34;
    $storemerge$i = $238;
   } else {
    $234 = $230 & -16321;
    $235 = $234 | $176;
    $storemerge$i = $235;
   }
   HEAP32[$$0$i$i26>>2] = $storemerge$i;
   $$neg$i = $$02$i ^ -1;
   $239 = (($120) + ($$neg$i))|0;
   $ispos$i = ($239|0)>(-1);
   $neg$i = (0 - ($239))|0;
   $240 = $ispos$i ? $239 : $neg$i;
   $241 = ($240|0)>(131071);
   if ($241) {
    label = 76;
    break;
   }
   $244 = HEAP32[$215>>2]|0;
   $245 = $244 & 16383;
   $246 = $239 << 14;
   $247 = (($246) + 2147467264)|0;
   $248 = $245 | $247;
   $storemerge90 = $248;
  } else {
   $$neg$i$i7 = $$02$i ^ -1;
   $249 = (($p_t$0) + ($$neg$i$i7))|0;
   $ispos$i$i8 = ($249|0)>(-1);
   $neg$i$i9 = (0 - ($249))|0;
   $250 = $ispos$i$i8 ? $249 : $neg$i$i9;
   $251 = ($250|0)>(131071);
   if ($251) {
    label = 79;
    break;
   }
   $254 = $216 & 16383;
   $255 = $249 << 14;
   $256 = (($255) + 2147467264)|0;
   $257 = $254 | $256;
   $storemerge90 = $257;
  }
  HEAP32[$215>>2] = $storemerge90;
  $258 = ($$0$i$i6|0)==(-1);
  if ($258) {
   label = 82;
   break;
  } else {
   $$02$i = $$0$i$i6;
  }
 }
 if ((label|0) == 76) {
  $242 = ((($fs)) + 8|0);
  $243 = HEAP32[$242>>2]|0;
  _luaX_syntaxerror($243,4744);
  // unreachable;
 }
 else if ((label|0) == 79) {
  $252 = ((($fs)) + 8|0);
  $253 = HEAP32[$252>>2]|0;
  _luaX_syntaxerror($253,4744);
  // unreachable;
 }
 else if ((label|0) == 82) {
  HEAP32[$2>>2] = -1;
  HEAP32[$26>>2] = -1;
  $259 = ((($e)) + 8|0);
  HEAP32[$259>>2] = $reg;
  HEAP32[$e>>2] = 7;
  return;
 }
}
function _discharge2reg($fs,$e,$reg) {
 $fs = $fs|0;
 $e = $e|0;
 $reg = $reg|0;
 var $$from$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0.0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $k$i = 0, $l$0$i = 0, $o$i = 0, $o$i3 = 0, $or$cond$i = 0, $or$cond2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $k$i = sp + 32|0;
 $o$i3 = sp + 16|0;
 $o$i = sp;
 _luaK_dischargevars($fs,$e);
 $0 = HEAP32[$e>>2]|0;
 L1: do {
  switch ($0|0) {
  case 4:  {
   $41 = ((($e)) + 8|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)<(262144);
   $44 = $reg << 6;
   if ($43) {
    $45 = $42 << 14;
    $46 = $44 | $45;
    $47 = $46 | 1;
    (_luaK_code($fs,$47)|0);
    break L1;
   } else {
    $48 = $44 | 2;
    (_luaK_code($fs,$48)|0);
    $49 = $42 << 6;
    $50 = $49 | 46;
    (_luaK_code($fs,$50)|0);
    break L1;
   }
   break;
  }
  case 6:  {
   $63 = ((($e)) + 8|0);
   $64 = $63;
   $65 = $64;
   $66 = HEAP32[$65>>2]|0;
   $67 = (($64) + 4)|0;
   $68 = $67;
   $69 = HEAP32[$68>>2]|0;
   $70 = $66;
   HEAP32[$k$i>>2] = $70;
   $71 = ((($k$i)) + 8|0);
   HEAP32[$71>>2] = 2;
   $72 = $o$i3;
   $73 = $72;
   HEAP32[$73>>2] = $66;
   $74 = (($72) + 4)|0;
   $75 = $74;
   HEAP32[$75>>2] = $69;
   $76 = ((($o$i3)) + 8|0);
   HEAP32[$76>>2] = 19;
   $77 = (_addk($fs,$k$i,$o$i3)|0);
   $78 = ($77|0)<(262144);
   $79 = $reg << 6;
   if ($78) {
    $80 = $77 << 14;
    $81 = $79 | $80;
    $82 = $81 | 1;
    (_luaK_code($fs,$82)|0);
    break L1;
   } else {
    $83 = $79 | 2;
    (_luaK_code($fs,$83)|0);
    $84 = $77 << 6;
    $85 = $84 | 46;
    (_luaK_code($fs,$85)|0);
    break L1;
   }
   break;
  }
  case 7:  {
   $97 = ((($e)) + 8|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==($reg|0);
   if (!($99)) {
    $100 = $reg << 6;
    $101 = $98 << 23;
    $102 = $101 | $100;
    (_luaK_code($fs,$102)|0);
   }
   break;
  }
  case 1:  {
   $1 = (($reg) + 1)|0;
   $2 = ((($fs)) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ((($fs)) + 20|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($3|0)>($5|0);
   do {
    if ($6) {
     $7 = (($3) + -1)|0;
     $8 = HEAP32[$fs>>2]|0;
     $9 = ((($8)) + 48|0);
     $10 = HEAP32[$9>>2]|0;
     $11 = (($10) + ($7<<2)|0);
     $12 = HEAP32[$11>>2]|0;
     $13 = $12 & 63;
     $14 = ($13|0)==(4);
     if ($14) {
      $15 = $12 >>> 6;
      $16 = $15 & 255;
      $17 = $12 >>> 23;
      $18 = (($16) + ($17))|0;
      $19 = ($16|0)>($reg|0);
      $20 = (($18) + 1)|0;
      $21 = ($20|0)<($reg|0);
      $or$cond$i = $19 | $21;
      if ($or$cond$i) {
       $22 = ($16|0)<($reg|0);
       $23 = ($16|0)>($1|0);
       $or$cond2$i = $22 | $23;
       if ($or$cond2$i) {
        break;
       }
      }
      $24 = ($16|0)<($reg|0);
      $$from$i = $24 ? $16 : $reg;
      $25 = ($18|0)>($reg|0);
      $l$0$i = $25 ? $18 : $reg;
      $26 = $12 & 8372287;
      $27 = $$from$i << 6;
      $28 = $27 & 16320;
      $29 = (($l$0$i) - ($$from$i))|0;
      $30 = $29 << 23;
      $31 = $28 | $26;
      $32 = $31 | $30;
      HEAP32[$11>>2] = $32;
      break L1;
     }
    }
   } while(0);
   $33 = $reg << 6;
   $34 = $33 | 4;
   (_luaK_code($fs,$34)|0);
   break;
  }
  case 2: case 3:  {
   $35 = ($0|0)==(2);
   $36 = $35&1;
   $37 = $reg << 6;
   $38 = $36 << 23;
   $39 = $37 | $38;
   $40 = $39 | 3;
   (_luaK_code($fs,$40)|0);
   break;
  }
  case 5:  {
   $51 = ((($e)) + 8|0);
   $52 = +HEAPF64[$51>>3];
   HEAPF64[$o$i>>3] = $52;
   $53 = ((($o$i)) + 8|0);
   HEAP32[$53>>2] = 3;
   $54 = (_addk($fs,$o$i,$o$i)|0);
   $55 = ($54|0)<(262144);
   $56 = $reg << 6;
   if ($55) {
    $57 = $54 << 14;
    $58 = $56 | $57;
    $59 = $58 | 1;
    (_luaK_code($fs,$59)|0);
    break L1;
   } else {
    $60 = $56 | 2;
    (_luaK_code($fs,$60)|0);
    $61 = $54 << 6;
    $62 = $61 | 46;
    (_luaK_code($fs,$62)|0);
    break L1;
   }
   break;
  }
  case 12:  {
   $86 = ((($e)) + 8|0);
   $87 = HEAP32[$86>>2]|0;
   $88 = HEAP32[$fs>>2]|0;
   $89 = ((($88)) + 48|0);
   $90 = HEAP32[$89>>2]|0;
   $91 = (($90) + ($87<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = $92 & -16321;
   $94 = $reg << 6;
   $95 = $94 & 16320;
   $96 = $93 | $95;
   HEAP32[$91>>2] = $96;
   break;
  }
  default: {
   STACKTOP = sp;return;
  }
  }
 } while(0);
 $103 = ((($e)) + 8|0);
 HEAP32[$103>>2] = $reg;
 HEAP32[$e>>2] = 7;
 STACKTOP = sp;return;
}
function _codeexpval($fs,$op,$e1,$e2,$line) {
 $fs = $fs|0;
 $op = $op|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 $line = $line|0;
 var $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0.0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0.0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0.0, $65 = 0, $66 = 0, $67 = 0.0, $68 = 0.0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0.0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $i$i$i = 0, $o1$0 = 0, $o2$0 = 0, $or$cond$i = 0, $phitmp$i$i = 0, $res$i = 0, $v1$i = 0, $v2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $i$i$i = sp + 48|0;
 $v1$i = sp + 32|0;
 $v2$i = sp + 16|0;
 $res$i = sp;
 $0 = ($op>>>0)<(27);
 L1: do {
  if ($0) {
   $1 = (($op) + -13)|0;
   $2 = ((($e1)) + 16|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = ($3|0)==(-1);
   L3: do {
    if ($4) {
     $5 = ((($e1)) + 20|0);
     $6 = HEAP32[$5>>2]|0;
     $7 = ($6|0)==(-1);
     if ($7) {
      $8 = HEAP32[$e1>>2]|0;
      if ((($8|0) == 5)) {
       $21 = ((($e1)) + 8|0);
       $22 = +HEAPF64[$21>>3];
       HEAPF64[$v1$i>>3] = $22;
       $23 = ((($v1$i)) + 8|0);
       HEAP32[$23>>2] = 3;
       HEAPF64[tempDoublePtr>>3] = $22;$24 = HEAP32[tempDoublePtr>>2]|0;
       $25 = HEAP32[tempDoublePtr+4>>2]|0;
       $51 = 3;$54 = $24;$57 = $25;
      } else if ((($8|0) == 6)) {
       $9 = ((($e1)) + 8|0);
       $10 = $9;
       $11 = $10;
       $12 = HEAP32[$11>>2]|0;
       $13 = (($10) + 4)|0;
       $14 = $13;
       $15 = HEAP32[$14>>2]|0;
       $16 = $v1$i;
       $17 = $16;
       HEAP32[$17>>2] = $12;
       $18 = (($16) + 4)|0;
       $19 = $18;
       HEAP32[$19>>2] = $15;
       $20 = ((($v1$i)) + 8|0);
       HEAP32[$20>>2] = 19;
       $51 = 19;$54 = $12;$57 = $15;
      } else {
       break;
      }
      $26 = ((($e2)) + 16|0);
      $27 = HEAP32[$26>>2]|0;
      $28 = ($27|0)==(-1);
      if ($28) {
       $29 = ((($e2)) + 20|0);
       $30 = HEAP32[$29>>2]|0;
       $31 = ($30|0)==(-1);
       if ($31) {
        $32 = HEAP32[$e2>>2]|0;
        if ((($32|0) == 6)) {
         $33 = ((($e2)) + 8|0);
         $34 = $33;
         $35 = $34;
         $36 = HEAP32[$35>>2]|0;
         $37 = (($34) + 4)|0;
         $38 = $37;
         $39 = HEAP32[$38>>2]|0;
         $40 = $v2$i;
         $41 = $40;
         HEAP32[$41>>2] = $36;
         $42 = (($40) + 4)|0;
         $43 = $42;
         HEAP32[$43>>2] = $39;
         $44 = ((($v2$i)) + 8|0);
         HEAP32[$44>>2] = 19;
         $63 = 19;$65 = $36;$66 = $39;
        } else if ((($32|0) == 5)) {
         $45 = ((($e2)) + 8|0);
         $46 = +HEAPF64[$45>>3];
         HEAPF64[$v2$i>>3] = $46;
         $47 = ((($v2$i)) + 8|0);
         HEAP32[$47>>2] = 3;
         HEAPF64[tempDoublePtr>>3] = $46;$48 = HEAP32[tempDoublePtr>>2]|0;
         $49 = HEAP32[tempDoublePtr+4>>2]|0;
         $63 = 3;$65 = $48;$66 = $49;
        } else {
         break;
        }
        L16: do {
         switch ($op|0) {
         case 26: case 24: case 23: case 22: case 21: case 20:  {
          $50 = ($51|0)==(19);
          do {
           if ($50) {
            $52 = $i$i$i;
            $53 = $52;
            HEAP32[$53>>2] = $54;
            $55 = (($52) + 4)|0;
            $56 = $55;
            HEAP32[$56>>2] = $57;
            $61 = $63;
           } else {
            $58 = (_luaV_tointeger_($v1$i,$i$i$i)|0);
            $59 = ($58|0)==(0);
            if ($59) {
             break L3;
            } else {
             $$phi$trans$insert$i = ((($v2$i)) + 8|0);
             $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
             $61 = $$pre$i;
             break;
            }
           }
          } while(0);
          $60 = ($61|0)==(19);
          if ($60) {
           break L16;
          }
          $70 = (_luaV_tointeger_($v2$i,$i$i$i)|0);
          $phitmp$i$i = ($70|0)==(0);
          if ($phitmp$i$i) {
           break L1;
          }
          break;
         }
         case 16: case 19: case 18:  {
          $62 = ($63|0)==(19);
          $64 = (+($65>>>0)) + (4294967296.0*(+($66|0)));
          HEAP32[tempDoublePtr>>2] = $65;HEAP32[tempDoublePtr+4>>2] = $66;$67 = +HEAPF64[tempDoublePtr>>3];
          $68 = $62 ? $64 : $67;
          $69 = $68 != 0.0;
          if (!($69)) {
           break L3;
          }
          break;
         }
         default: {
         }
         }
        } while(0);
        $71 = ((($fs)) + 8|0);
        $72 = HEAP32[$71>>2]|0;
        $73 = ((($72)) + 52|0);
        $74 = HEAP32[$73>>2]|0;
        _luaO_arith($74,$1,$v1$i,$v2$i,$res$i);
        $75 = ((($res$i)) + 8|0);
        $76 = HEAP32[$75>>2]|0;
        $77 = ($76|0)==(19);
        if ($77) {
         HEAP32[$e1>>2] = 6;
         $78 = $res$i;
         $79 = $78;
         $80 = HEAP32[$79>>2]|0;
         $81 = (($78) + 4)|0;
         $82 = $81;
         $83 = HEAP32[$82>>2]|0;
         $84 = ((($e1)) + 8|0);
         $85 = $84;
         $86 = $85;
         HEAP32[$86>>2] = $80;
         $87 = (($85) + 4)|0;
         $88 = $87;
         HEAP32[$88>>2] = $83;
         STACKTOP = sp;return;
        }
        $89 = +HEAPF64[$res$i>>3];
        $90 = ($89 != $89) | (0.0 != 0.0);
        $91 = $89 == 0.0;
        $or$cond$i = $90 | $91;
        if ($or$cond$i) {
         break L1;
        }
        HEAP32[$e1>>2] = 5;
        $92 = ((($e1)) + 8|0);
        HEAPF64[$92>>3] = $89;
        STACKTOP = sp;return;
       }
      }
     }
    }
   } while(0);
  }
 } while(0);
 if ((($op|0) == 25) | (($op|0) == 26) | (($op|0) == 28)) {
  $93 = (_luaK_exp2anyreg($fs,$e1)|0);
  $o1$0 = $93;$o2$0 = 0;
 } else {
  $94 = (_luaK_exp2RK($fs,$e2)|0);
  $95 = (_luaK_exp2RK($fs,$e1)|0);
  $o1$0 = $95;$o2$0 = $94;
 }
 $96 = ($o1$0|0)>($o2$0|0);
 if ($96) {
  $97 = HEAP32[$e1>>2]|0;
  $98 = ($97|0)==(7);
  if ($98) {
   $99 = ((($e1)) + 8|0);
   $100 = HEAP32[$99>>2]|0;
   $101 = $100 & 256;
   $102 = ($101|0)==(0);
   if ($102) {
    $103 = ((($fs)) + 42|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = $104&255;
    $106 = ($105|0)>($100|0);
    if (!($106)) {
     $107 = ((($fs)) + 44|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = (($108) + -1)<<24>>24;
     HEAP8[$107>>0] = $109;
    }
   }
  }
  $110 = HEAP32[$e2>>2]|0;
  $111 = ($110|0)==(7);
  if ($111) {
   $112 = ((($e2)) + 8|0);
   $113 = HEAP32[$112>>2]|0;
   $114 = $113 & 256;
   $115 = ($114|0)==(0);
   if ($115) {
    $116 = ((($fs)) + 42|0);
    $117 = HEAP8[$116>>0]|0;
    $118 = $117&255;
    $119 = ($118|0)>($113|0);
    if ($119) {
     $$pre$phiZ2D = $e1;
    } else {
     $120 = ((($fs)) + 44|0);
     $121 = HEAP8[$120>>0]|0;
     $122 = (($121) + -1)<<24>>24;
     HEAP8[$120>>0] = $122;
     $$pre$phiZ2D = $e1;
    }
   } else {
    $$pre$phiZ2D = $e1;
   }
  } else {
   $$pre$phiZ2D = $e1;
  }
 } else {
  $123 = HEAP32[$e2>>2]|0;
  $124 = ($123|0)==(7);
  if ($124) {
   $125 = ((($e2)) + 8|0);
   $126 = HEAP32[$125>>2]|0;
   $127 = $126 & 256;
   $128 = ($127|0)==(0);
   if ($128) {
    $129 = ((($fs)) + 42|0);
    $130 = HEAP8[$129>>0]|0;
    $131 = $130&255;
    $132 = ($131|0)>($126|0);
    if (!($132)) {
     $133 = ((($fs)) + 44|0);
     $134 = HEAP8[$133>>0]|0;
     $135 = (($134) + -1)<<24>>24;
     HEAP8[$133>>0] = $135;
    }
   }
  }
  $136 = HEAP32[$e1>>2]|0;
  $137 = ($136|0)==(7);
  if ($137) {
   $138 = ((($e1)) + 8|0);
   $139 = HEAP32[$138>>2]|0;
   $140 = $139 & 256;
   $141 = ($140|0)==(0);
   if ($141) {
    $142 = ((($fs)) + 42|0);
    $143 = HEAP8[$142>>0]|0;
    $144 = $143&255;
    $145 = ($144|0)>($139|0);
    if ($145) {
     $$pre$phiZ2D = $e1;
    } else {
     $146 = ((($fs)) + 44|0);
     $147 = HEAP8[$146>>0]|0;
     $148 = (($147) + -1)<<24>>24;
     HEAP8[$146>>0] = $148;
     $$pre$phiZ2D = $e1;
    }
   } else {
    $$pre$phiZ2D = $e1;
   }
  } else {
   $$pre$phiZ2D = $e1;
  }
 }
 $149 = $o1$0 << 23;
 $150 = $149 | $op;
 $151 = $o2$0 << 14;
 $152 = $150 | $151;
 $153 = (_luaK_code($fs,$152)|0);
 $154 = ((($e1)) + 8|0);
 HEAP32[$154>>2] = $153;
 HEAP32[$$pre$phiZ2D>>2] = 12;
 $155 = ((($fs)) + 16|0);
 $156 = HEAP32[$155>>2]|0;
 $157 = (($156) + -1)|0;
 $158 = HEAP32[$fs>>2]|0;
 $159 = ((($158)) + 56|0);
 $160 = HEAP32[$159>>2]|0;
 $161 = (($160) + ($157<<2)|0);
 HEAP32[$161>>2] = $line;
 STACKTOP = sp;return;
}
function _codecomp($fs,$op,$cond,$e1,$e2) {
 $fs = $fs|0;
 $op = $op|0;
 $cond = $cond|0;
 $e1 = $e1|0;
 $e2 = $e2|0;
 var $$ = 0, $$0$i$i$i$i = 0, $$2 = 0, $$lcssa = 0, $$lcssa9 = 0, $$neg$i$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond$op = 0, $fs$idx$val$i$i$i = 0, $fs$idx$val$idx$i$i$i = 0, $fs$idx$val$idx$val$i$i$i = 0, $ispos$i$i$i$i = 0, $list$0$i$i$i = 0, $list$0$i$i$i$lcssa = 0, $neg$i$i$i$i = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaK_exp2RK($fs,$e1)|0);
 $1 = (_luaK_exp2RK($fs,$e2)|0);
 $2 = HEAP32[$e2>>2]|0;
 $3 = ($2|0)==(7);
 if ($3) {
  $4 = ((($e2)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = $5 & 256;
  $7 = ($6|0)==(0);
  if ($7) {
   $8 = ((($fs)) + 42|0);
   $9 = HEAP8[$8>>0]|0;
   $10 = $9&255;
   $11 = ($10|0)>($5|0);
   if (!($11)) {
    $12 = ((($fs)) + 44|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = (($13) + -1)<<24>>24;
    HEAP8[$12>>0] = $14;
   }
  }
 }
 $15 = HEAP32[$e1>>2]|0;
 $16 = ($15|0)==(7);
 if ($16) {
  $17 = ((($e1)) + 8|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = $18 & 256;
  $20 = ($19|0)==(0);
  if ($20) {
   $21 = ((($fs)) + 42|0);
   $22 = HEAP8[$21>>0]|0;
   $23 = $22&255;
   $24 = ($23|0)>($18|0);
   if (!($24)) {
    $25 = ((($fs)) + 44|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = (($26) + -1)<<24>>24;
    HEAP8[$25>>0] = $27;
   }
  }
 }
 $28 = ($cond|0)==(0);
 $29 = ($op|0)!=(31);
 $or$cond = $29 & $28;
 $$ = $or$cond ? $1 : $0;
 $$2 = $or$cond ? $0 : $1;
 $cond$op = $cond << 6;
 $30 = $or$cond ? 64 : $cond$op;
 $31 = $30 | $op;
 $32 = $$ << 23;
 $33 = $31 | $32;
 $34 = $$2 << 14;
 $35 = $33 | $34;
 (_luaK_code($fs,$35)|0);
 $36 = ((($fs)) + 24|0);
 $37 = HEAP32[$36>>2]|0;
 HEAP32[$36>>2] = -1;
 $38 = (_luaK_code($fs,2147450910)|0);
 $39 = ($37|0)==(-1);
 if ($39) {
  $59 = $38;
  $58 = ((($e1)) + 8|0);
  HEAP32[$58>>2] = $59;
  HEAP32[$e1>>2] = 11;
  return;
 }
 $40 = ($38|0)==(-1);
 if ($40) {
  $59 = $37;
  $58 = ((($e1)) + 8|0);
  HEAP32[$58>>2] = $59;
  HEAP32[$e1>>2] = 11;
  return;
 }
 $fs$idx$val$i$i$i = HEAP32[$fs>>2]|0;
 $fs$idx$val$idx$i$i$i = ((($fs$idx$val$i$i$i)) + 48|0);
 $fs$idx$val$idx$val$i$i$i = HEAP32[$fs$idx$val$idx$i$i$i>>2]|0;
 $list$0$i$i$i = $38;
 while(1) {
  $41 = (($fs$idx$val$idx$val$i$i$i) + ($list$0$i$i$i<<2)|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = $42 >>> 14;
  $44 = (($43) + -131071)|0;
  $45 = ($44|0)==(-1);
  $46 = (($list$0$i$i$i) + 1)|0;
  $47 = (($46) + ($44))|0;
  $$0$i$i$i$i = $45 ? -1 : $47;
  $48 = ($$0$i$i$i$i|0)==(-1);
  if ($48) {
   $$lcssa = $41;$$lcssa9 = $42;$list$0$i$i$i$lcssa = $list$0$i$i$i;
   break;
  } else {
   $list$0$i$i$i = $$0$i$i$i$i;
  }
 }
 $$neg$i$i$i$i = $list$0$i$i$i$lcssa ^ -1;
 $49 = (($37) + ($$neg$i$i$i$i))|0;
 $ispos$i$i$i$i = ($49|0)>(-1);
 $neg$i$i$i$i = (0 - ($49))|0;
 $50 = $ispos$i$i$i$i ? $49 : $neg$i$i$i$i;
 $51 = ($50|0)>(131071);
 if ($51) {
  $52 = ((($fs)) + 8|0);
  $53 = HEAP32[$52>>2]|0;
  _luaX_syntaxerror($53,4744);
  // unreachable;
 }
 $54 = $$lcssa9 & 16383;
 $55 = $49 << 14;
 $56 = (($55) + 2147467264)|0;
 $57 = $56 | $54;
 HEAP32[$$lcssa>>2] = $57;
 $59 = $38;
 $58 = ((($e1)) + 8|0);
 HEAP32[$58>>2] = $59;
 HEAP32[$e1>>2] = 11;
 return;
}
function _luaX_init($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaS_new($L,5128)|0);
 _luaC_fix($L,$0);
 $i$01 = 0;
 while(1) {
  $1 = (5136 + ($i$01<<2)|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = (_luaS_new($L,$2)|0);
  _luaC_fix($L,$3);
  $4 = (($i$01) + 1)|0;
  $5 = $4&255;
  $6 = ((($3)) + 6|0);
  HEAP8[$6>>0] = $5;
  $exitcond = ($4|0)==(22);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $4;
  }
 }
 return;
}
function _luaX_token2str($ls,$token) {
 $ls = $ls|0;
 $token = $token|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ($token|0)<(257);
 if ($0) {
  $1 = ((($ls)) + 52|0);
  $2 = HEAP32[$1>>2]|0;
  HEAP32[$vararg_buffer>>2] = $token;
  $3 = (_luaO_pushfstring($2,5288,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (($token) + -257)|0;
 $5 = (5136 + ($4<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($token|0)<(289);
 if (!($7)) {
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ((($ls)) + 52|0);
 $9 = HEAP32[$8>>2]|0;
 HEAP32[$vararg_buffer1>>2] = $6;
 $10 = (_luaO_pushfstring($9,5296,$vararg_buffer1)|0);
 $$0 = $10;
 STACKTOP = sp;return ($$0|0);
}
function _luaX_syntaxerror($ls,$msg) {
 $ls = $ls|0;
 $msg = $msg|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 _lexerror($ls,$msg,$1);
 // unreachable;
}
function _luaX_newstring($ls,$str,$l) {
 $ls = $ls|0;
 $str = $str|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ts$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 52|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_luaS_newlstr($1,$str,$l)|0);
 $3 = ((($1)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 16|0);
 HEAP32[$3>>2] = $5;
 HEAP32[$4>>2] = $2;
 $6 = ((($2)) + 4|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = $7&255;
 $9 = $8 | 64;
 $10 = ((($4)) + 8|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($ls)) + 64|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = HEAP32[$3>>2]|0;
 $14 = ((($13)) + -16|0);
 $15 = (_luaH_set($1,$12,$14)|0);
 $16 = ((($15)) + 8|0);
 $17 = HEAP32[$16>>2]|0;
 $18 = ($17|0)==(0);
 if ($18) {
  HEAP32[$15>>2] = 1;
  HEAP32[$16>>2] = 1;
  $19 = ((($1)) + 12|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = ((($20)) + 12|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)>(0);
  if ($23) {
   _luaC_step($1);
   $ts$0 = $2;
  } else {
   $ts$0 = $2;
  }
 } else {
  $24 = ((($15)) + 16|0);
  $25 = HEAP32[$24>>2]|0;
  $ts$0 = $25;
 }
 $26 = HEAP32[$3>>2]|0;
 $27 = ((($26)) + -16|0);
 HEAP32[$3>>2] = $27;
 return ($ts$0|0);
}
function _luaX_setinput($L,$ls,$z,$source,$firstchar) {
 $L = $L|0;
 $ls = $ls|0;
 $z = $z|0;
 $source = $source|0;
 $firstchar = $firstchar|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 16|0);
 HEAP32[$0>>2] = 0;
 $1 = ((($ls)) + 80|0);
 HEAP8[$1>>0] = 46;
 $2 = ((($ls)) + 52|0);
 HEAP32[$2>>2] = $L;
 HEAP32[$ls>>2] = $firstchar;
 $3 = ((($ls)) + 32|0);
 HEAP32[$3>>2] = 289;
 $4 = ((($ls)) + 56|0);
 HEAP32[$4>>2] = $z;
 $5 = ((($ls)) + 48|0);
 HEAP32[$5>>2] = 0;
 $6 = ((($ls)) + 4|0);
 HEAP32[$6>>2] = 1;
 $7 = ((($ls)) + 8|0);
 HEAP32[$7>>2] = 1;
 $8 = ((($ls)) + 72|0);
 HEAP32[$8>>2] = $source;
 $9 = (_luaS_new($L,5128)|0);
 $10 = ((($ls)) + 76|0);
 HEAP32[$10>>2] = $9;
 $11 = HEAP32[$2>>2]|0;
 $12 = ((($ls)) + 60|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = HEAP32[$13>>2]|0;
 $15 = ((($13)) + 8|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = (_luaM_realloc_($11,$14,$16,32)|0);
 $18 = HEAP32[$12>>2]|0;
 HEAP32[$18>>2] = $17;
 $19 = ((($18)) + 8|0);
 HEAP32[$19>>2] = 32;
 return;
}
function _luaX_next($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($ls)) + 8|0);
 HEAP32[$2>>2] = $1;
 $3 = ((($ls)) + 32|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(289);
 if ($5) {
  $7 = ((($ls)) + 24|0);
  $8 = (_llex($ls,$7)|0);
  $9 = ((($ls)) + 16|0);
  HEAP32[$9>>2] = $8;
  return;
 } else {
  $6 = ((($ls)) + 16|0);
  ;HEAP32[$6>>2]=HEAP32[$3>>2]|0;HEAP32[$6+4>>2]=HEAP32[$3+4>>2]|0;HEAP32[$6+8>>2]=HEAP32[$3+8>>2]|0;HEAP32[$6+12>>2]=HEAP32[$3+12>>2]|0;
  HEAP32[$3>>2] = 289;
  return;
 }
}
function _luaX_lookahead($ls) {
 $ls = $ls|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ls)) + 40|0);
 $1 = (_llex($ls,$0)|0);
 $2 = ((($ls)) + 32|0);
 HEAP32[$2>>2] = $1;
 return ($1|0);
}
function _lexerror($ls,$msg,$token) {
 $ls = $ls|0;
 $msg = $msg|0;
 $token = $token|0;
 var $$0$i = 0, $$off$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $buff = 0, $switch$i = 0, $vararg_buffer = 0, $vararg_buffer12 = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr15 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer9 = sp + 32|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $buff = sp + 48|0;
 $0 = ((($ls)) + 72|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 24|0);
 _luaO_chunkid($buff,$2,60);
 $3 = ((($ls)) + 52|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($ls)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 HEAP32[$vararg_buffer>>2] = $buff;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $6;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = $msg;
 $7 = (_luaO_pushfstring($4,5672,$vararg_buffer)|0);
 $8 = ($token|0)==(0);
 if ($8) {
  $37 = HEAP32[$3>>2]|0;
  _luaD_throw($37,3);
  // unreachable;
 }
 $9 = HEAP32[$3>>2]|0;
 $$off$i = (($token) + -290)|0;
 $switch$i = ($$off$i>>>0)<(4);
 do {
  if ($switch$i) {
   $10 = ((($ls)) + 60|0);
   $11 = HEAP32[$10>>2]|0;
   $12 = ((($11)) + 4|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = (($13) + 1)|0;
   $15 = ((($11)) + 8|0);
   $16 = HEAP32[$15>>2]|0;
   $17 = ($14>>>0)>($16>>>0);
   do {
    if ($17) {
     $18 = ($16>>>0)>(2147483646);
     if ($18) {
      _lexerror($ls,5368,0);
      // unreachable;
     } else {
      $19 = $16 << 1;
      $20 = HEAP32[$11>>2]|0;
      $21 = (_luaM_realloc_($9,$20,$16,$19)|0);
      HEAP32[$11>>2] = $21;
      HEAP32[$15>>2] = $19;
      $$pre = HEAP32[$12>>2]|0;
      $23 = $$pre;$25 = $21;
      break;
     }
    } else {
     $$pre1 = HEAP32[$11>>2]|0;
     $23 = $13;$25 = $$pre1;
    }
   } while(0);
   $22 = (($23) + 1)|0;
   HEAP32[$12>>2] = $22;
   $24 = (($25) + ($23)|0);
   HEAP8[$24>>0] = 0;
   $26 = HEAP32[$3>>2]|0;
   $27 = HEAP32[$10>>2]|0;
   $28 = HEAP32[$27>>2]|0;
   HEAP32[$vararg_buffer3>>2] = $28;
   $29 = (_luaO_pushfstring($26,5296,$vararg_buffer3)|0);
   $$0$i = $29;
  } else {
   $30 = ($token|0)<(257);
   if ($30) {
    HEAP32[$vararg_buffer6>>2] = $token;
    $31 = (_luaO_pushfstring($9,5288,$vararg_buffer6)|0);
    $$0$i = $31;
    break;
   }
   $32 = (($token) + -257)|0;
   $33 = (5136 + ($32<<2)|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($token|0)<(289);
   if ($35) {
    HEAP32[$vararg_buffer9>>2] = $34;
    $36 = (_luaO_pushfstring($9,5296,$vararg_buffer9)|0);
    $$0$i = $36;
   } else {
    $$0$i = $34;
   }
  }
 } while(0);
 HEAP32[$vararg_buffer12>>2] = $7;
 $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
 HEAP32[$vararg_ptr15>>2] = $$0$i;
 (_luaO_pushfstring($9,5688,$vararg_buffer12)|0);
 $37 = HEAP32[$3>>2]|0;
 _luaD_throw($37,3);
 // unreachable;
}
function _llex($ls,$seminfo) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 var $$0 = 0, $$be$i = 0, $$be43$i = 0, $$lcssa = 0, $$lcssa$lcssa = 0, $$lcssa376 = 0, $$lcssa380 = 0, $$lcssa389 = 0, $$lcssa395 = 0, $$lcssa398 = 0, $$lcssa399 = 0, $$lcssa400 = 0, $$lcssa401 = 0, $$lcssa410 = 0, $$pr = 0, $$pr$i = 0, $$pr166 = 0, $$pr40$i = 0, $$pre$i = 0, $$pre$i$i = 0;
 var $$pre$i$i$i = 0, $$pre$i$i$i$i = 0, $$pre$i$i17$i = 0, $$pre$i$i9$i = 0, $$pre$i11$i$i = 0, $$pre$i11$i$i$i = 0, $$pre$i16$i$i = 0, $$pre$i16$i$i$i = 0, $$pre$i22$i$i$i = 0, $$pre$i23$i = 0, $$pre$i27$i$i$i = 0, $$pre$i28$i = 0, $$pre$i30 = 0, $$pre$i32$i$i$i = 0, $$pre$i33$i = 0, $$pre$i38$i = 0, $$pre$i4$i = 0, $$pre$i4$i$i = 0, $$pre$i4$i$i$i = 0, $$pre$i5$i$i = 0;
 var $$pre1$i = 0, $$pre1$i$i = 0, $$pre1$i$i$i = 0, $$pre1$i$i$i$i = 0, $$pre1$i$i15$i = 0, $$pre1$i$i7$i = 0, $$pre1$i14$i$i = 0, $$pre1$i14$i$i$i = 0, $$pre1$i2$i = 0, $$pre1$i2$i$i = 0, $$pre1$i2$i$i$i = 0, $$pre1$i20$i$i$i = 0, $$pre1$i21$i = 0, $$pre1$i25$i$i$i = 0, $$pre1$i26$i = 0, $$pre1$i28 = 0, $$pre1$i3$i$i = 0, $$pre1$i30$i$i$i = 0, $$pre1$i31$i = 0, $$pre1$i36$i = 0;
 var $$pre1$i9$i$i = 0, $$pre1$i9$i$i$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0;
 var $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0;
 var $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0;
 var $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0;
 var $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0, $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0;
 var $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0, $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0;
 var $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0, $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0;
 var $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0, $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0;
 var $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0, $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $buff$i$i = 0, $c$0$i = 0, $c$1$i = 0, $i$0$i$i$i = 0;
 var $i$0$i$i$i$lcssa355 = 0, $i$0$lcssa$i$i = 0, $i$08$i$i = 0, $n$06$i$i = 0, $r$0$i$i$i = 0, $r$0$i$i$i$lcssa353 = 0, $r$0$lcssa$i$i = 0, $r$09$i$i = 0, $ts$0$i = 0, $ts$0$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buff$i$i = sp;
 $0 = ((($ls)) + 60|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($ls)) + 56|0);
 $4 = ((($ls)) + 4|0);
 L1: while(1) {
  $$pr166 = HEAP32[$ls>>2]|0;
  $5 = $$pr166;
  L3: while(1) {
   switch ($5|0) {
   case 13: case 10:  {
    $$lcssa401 = $5;
    label = 4;
    break L3;
    break;
   }
   case 62:  {
    label = 59;
    break L1;
    break;
   }
   case 45:  {
    break L3;
    break;
   }
   case 60:  {
    label = 47;
    break L1;
    break;
   }
   case 39: case 34:  {
    $$lcssa410 = $5;
    label = 95;
    break L1;
    break;
   }
   case 61:  {
    label = 39;
    break L1;
    break;
   }
   case 91:  {
    label = 35;
    break L1;
    break;
   }
   case 47:  {
    label = 71;
    break L1;
    break;
   }
   case 58:  {
    label = 87;
    break L1;
    break;
   }
   case 11: case 9: case 12: case 32:  {
    break;
   }
   case 126:  {
    label = 79;
    break L1;
    break;
   }
   case 46:  {
    label = 349;
    break L1;
    break;
   }
   case 57: case 56: case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
    label = 368;
    break L1;
    break;
   }
   case -1:  {
    $$0 = 289;
    label = 391;
    break L1;
    break;
   }
   default: {
    $$lcssa400 = $5;
    label = 369;
    break L1;
   }
   }
   $32 = HEAP32[$3>>2]|0;
   $33 = HEAP32[$32>>2]|0;
   $34 = (($33) + -1)|0;
   HEAP32[$32>>2] = $34;
   $35 = ($33|0)==(0);
   if ($35) {
    $41 = (_luaZ_fill($32)|0);
    $42 = $41;
   } else {
    $36 = ((($32)) + 4|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($37)) + 1|0);
    HEAP32[$36>>2] = $38;
    $39 = HEAP8[$37>>0]|0;
    $40 = $39&255;
    $42 = $40;
   }
   HEAP32[$ls>>2] = $42;
   $5 = $42;
  }
  if ((label|0) == 4) {
   label = 0;
   $6 = HEAP32[$3>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = (($7) + -1)|0;
   HEAP32[$6>>2] = $8;
   $9 = ($7|0)==(0);
   if ($9) {
    $15 = (_luaZ_fill($6)|0);
    $16 = $15;
   } else {
    $10 = ((($6)) + 4|0);
    $11 = HEAP32[$10>>2]|0;
    $12 = ((($11)) + 1|0);
    HEAP32[$10>>2] = $12;
    $13 = HEAP8[$11>>0]|0;
    $14 = $13&255;
    $16 = $14;
   }
   HEAP32[$ls>>2] = $16;
   if ((($16|0) == 13) | (($16|0) == 10)) {
    $17 = ($16|0)==($$lcssa401|0);
    if (!($17)) {
     $18 = HEAP32[$3>>2]|0;
     $19 = HEAP32[$18>>2]|0;
     $20 = (($19) + -1)|0;
     HEAP32[$18>>2] = $20;
     $21 = ($19|0)==(0);
     if ($21) {
      $27 = (_luaZ_fill($18)|0);
      $28 = $27;
     } else {
      $22 = ((($18)) + 4|0);
      $23 = HEAP32[$22>>2]|0;
      $24 = ((($23)) + 1|0);
      HEAP32[$22>>2] = $24;
      $25 = HEAP8[$23>>0]|0;
      $26 = $25&255;
      $28 = $26;
     }
     HEAP32[$ls>>2] = $28;
    }
   }
   $29 = HEAP32[$4>>2]|0;
   $30 = (($29) + 1)|0;
   HEAP32[$4>>2] = $30;
   $31 = ($30|0)==(2147483647);
   if ($31) {
    label = 14;
    break;
   } else {
    continue;
   }
  }
  $43 = HEAP32[$3>>2]|0;
  $44 = HEAP32[$43>>2]|0;
  $45 = (($44) + -1)|0;
  HEAP32[$43>>2] = $45;
  $46 = ($44|0)==(0);
  if ($46) {
   $52 = (_luaZ_fill($43)|0);
   $53 = $52;
  } else {
   $47 = ((($43)) + 4|0);
   $48 = HEAP32[$47>>2]|0;
   $49 = ((($48)) + 1|0);
   HEAP32[$47>>2] = $49;
   $50 = HEAP8[$48>>0]|0;
   $51 = $50&255;
   $53 = $51;
  }
  HEAP32[$ls>>2] = $53;
  $54 = ($53|0)==(45);
  if (!($54)) {
   $$0 = 45;
   label = 391;
   break;
  }
  $55 = HEAP32[$3>>2]|0;
  $56 = HEAP32[$55>>2]|0;
  $57 = (($56) + -1)|0;
  HEAP32[$55>>2] = $57;
  $58 = ($56|0)==(0);
  if ($58) {
   $64 = (_luaZ_fill($55)|0);
   $65 = $64;
  } else {
   $59 = ((($55)) + 4|0);
   $60 = HEAP32[$59>>2]|0;
   $61 = ((($60)) + 1|0);
   HEAP32[$59>>2] = $61;
   $62 = HEAP8[$60>>0]|0;
   $63 = $62&255;
   $65 = $63;
  }
  HEAP32[$ls>>2] = $65;
  $66 = ($65|0)==(91);
  do {
   if ($66) {
    $67 = (_skip_sep($ls)|0);
    $68 = HEAP32[$0>>2]|0;
    $69 = ((($68)) + 4|0);
    HEAP32[$69>>2] = 0;
    $70 = ($67|0)>(-1);
    if ($70) {
     _read_long_string($ls,0,$67);
     $71 = HEAP32[$0>>2]|0;
     $72 = ((($71)) + 4|0);
     HEAP32[$72>>2] = 0;
     continue L1;
    } else {
     $$pr = HEAP32[$ls>>2]|0;
     $1152 = $$pr;
     break;
    }
   } else {
    $1152 = $65;
   }
  } while(0);
  while(1) {
   if ((($1152|0) == -1) | (($1152|0) == 13) | (($1152|0) == 10)) {
    continue L1;
   }
   $73 = HEAP32[$3>>2]|0;
   $74 = HEAP32[$73>>2]|0;
   $75 = (($74) + -1)|0;
   HEAP32[$73>>2] = $75;
   $76 = ($74|0)==(0);
   if ($76) {
    $82 = (_luaZ_fill($73)|0);
    $83 = $82;
   } else {
    $77 = ((($73)) + 4|0);
    $78 = HEAP32[$77>>2]|0;
    $79 = ((($78)) + 1|0);
    HEAP32[$77>>2] = $79;
    $80 = HEAP8[$78>>0]|0;
    $81 = $80&255;
    $83 = $81;
   }
   HEAP32[$ls>>2] = $83;
   $1152 = $83;
  }
 }
 switch (label|0) {
  case 14: {
   _lexerror($ls,5304,0);
   // unreachable;
   break;
  }
  case 35: {
   $84 = (_skip_sep($ls)|0);
   $85 = ($84|0)>(-1);
   if ($85) {
    _read_long_string($ls,$seminfo,$84);
    $$0 = 293;
    STACKTOP = sp;return ($$0|0);
   }
   $86 = ($84|0)==(-1);
   if ($86) {
    $$0 = 91;
    STACKTOP = sp;return ($$0|0);
   } else {
    _lexerror($ls,5336,293);
    // unreachable;
   }
   break;
  }
  case 39: {
   $87 = HEAP32[$3>>2]|0;
   $88 = HEAP32[$87>>2]|0;
   $89 = (($88) + -1)|0;
   HEAP32[$87>>2] = $89;
   $90 = ($88|0)==(0);
   if ($90) {
    $96 = (_luaZ_fill($87)|0);
    $97 = $96;
   } else {
    $91 = ((($87)) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ((($92)) + 1|0);
    HEAP32[$91>>2] = $93;
    $94 = HEAP8[$92>>0]|0;
    $95 = $94&255;
    $97 = $95;
   }
   HEAP32[$ls>>2] = $97;
   $98 = ($97|0)==(61);
   if (!($98)) {
    $$0 = 61;
    STACKTOP = sp;return ($$0|0);
   }
   $99 = HEAP32[$3>>2]|0;
   $100 = HEAP32[$99>>2]|0;
   $101 = (($100) + -1)|0;
   HEAP32[$99>>2] = $101;
   $102 = ($100|0)==(0);
   if ($102) {
    $108 = (_luaZ_fill($99)|0);
    $109 = $108;
   } else {
    $103 = ((($99)) + 4|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ((($104)) + 1|0);
    HEAP32[$103>>2] = $105;
    $106 = HEAP8[$104>>0]|0;
    $107 = $106&255;
    $109 = $107;
   }
   HEAP32[$ls>>2] = $109;
   $$0 = 282;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 47: {
   $110 = HEAP32[$3>>2]|0;
   $111 = HEAP32[$110>>2]|0;
   $112 = (($111) + -1)|0;
   HEAP32[$110>>2] = $112;
   $113 = ($111|0)==(0);
   if ($113) {
    $119 = (_luaZ_fill($110)|0);
    $120 = $119;
   } else {
    $114 = ((($110)) + 4|0);
    $115 = HEAP32[$114>>2]|0;
    $116 = ((($115)) + 1|0);
    HEAP32[$114>>2] = $116;
    $117 = HEAP8[$115>>0]|0;
    $118 = $117&255;
    $120 = $118;
   }
   HEAP32[$ls>>2] = $120;
   if ((($120|0) == 60)) {
    $132 = HEAP32[$3>>2]|0;
    $133 = HEAP32[$132>>2]|0;
    $134 = (($133) + -1)|0;
    HEAP32[$132>>2] = $134;
    $135 = ($133|0)==(0);
    if ($135) {
     $141 = (_luaZ_fill($132)|0);
     $142 = $141;
    } else {
     $136 = ((($132)) + 4|0);
     $137 = HEAP32[$136>>2]|0;
     $138 = ((($137)) + 1|0);
     HEAP32[$136>>2] = $138;
     $139 = HEAP8[$137>>0]|0;
     $140 = $139&255;
     $142 = $140;
    }
    HEAP32[$ls>>2] = $142;
    $$0 = 286;
    STACKTOP = sp;return ($$0|0);
   } else if ((($120|0) == 61)) {
    $121 = HEAP32[$3>>2]|0;
    $122 = HEAP32[$121>>2]|0;
    $123 = (($122) + -1)|0;
    HEAP32[$121>>2] = $123;
    $124 = ($122|0)==(0);
    if ($124) {
     $130 = (_luaZ_fill($121)|0);
     $131 = $130;
    } else {
     $125 = ((($121)) + 4|0);
     $126 = HEAP32[$125>>2]|0;
     $127 = ((($126)) + 1|0);
     HEAP32[$125>>2] = $127;
     $128 = HEAP8[$126>>0]|0;
     $129 = $128&255;
     $131 = $129;
    }
    HEAP32[$ls>>2] = $131;
    $$0 = 284;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0 = 60;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 59: {
   $143 = HEAP32[$3>>2]|0;
   $144 = HEAP32[$143>>2]|0;
   $145 = (($144) + -1)|0;
   HEAP32[$143>>2] = $145;
   $146 = ($144|0)==(0);
   if ($146) {
    $152 = (_luaZ_fill($143)|0);
    $153 = $152;
   } else {
    $147 = ((($143)) + 4|0);
    $148 = HEAP32[$147>>2]|0;
    $149 = ((($148)) + 1|0);
    HEAP32[$147>>2] = $149;
    $150 = HEAP8[$148>>0]|0;
    $151 = $150&255;
    $153 = $151;
   }
   HEAP32[$ls>>2] = $153;
   if ((($153|0) == 61)) {
    $154 = HEAP32[$3>>2]|0;
    $155 = HEAP32[$154>>2]|0;
    $156 = (($155) + -1)|0;
    HEAP32[$154>>2] = $156;
    $157 = ($155|0)==(0);
    if ($157) {
     $163 = (_luaZ_fill($154)|0);
     $164 = $163;
    } else {
     $158 = ((($154)) + 4|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ((($159)) + 1|0);
     HEAP32[$158>>2] = $160;
     $161 = HEAP8[$159>>0]|0;
     $162 = $161&255;
     $164 = $162;
    }
    HEAP32[$ls>>2] = $164;
    $$0 = 283;
    STACKTOP = sp;return ($$0|0);
   } else if ((($153|0) == 62)) {
    $165 = HEAP32[$3>>2]|0;
    $166 = HEAP32[$165>>2]|0;
    $167 = (($166) + -1)|0;
    HEAP32[$165>>2] = $167;
    $168 = ($166|0)==(0);
    if ($168) {
     $174 = (_luaZ_fill($165)|0);
     $175 = $174;
    } else {
     $169 = ((($165)) + 4|0);
     $170 = HEAP32[$169>>2]|0;
     $171 = ((($170)) + 1|0);
     HEAP32[$169>>2] = $171;
     $172 = HEAP8[$170>>0]|0;
     $173 = $172&255;
     $175 = $173;
    }
    HEAP32[$ls>>2] = $175;
    $$0 = 287;
    STACKTOP = sp;return ($$0|0);
   } else {
    $$0 = 62;
    STACKTOP = sp;return ($$0|0);
   }
   break;
  }
  case 71: {
   $176 = HEAP32[$3>>2]|0;
   $177 = HEAP32[$176>>2]|0;
   $178 = (($177) + -1)|0;
   HEAP32[$176>>2] = $178;
   $179 = ($177|0)==(0);
   if ($179) {
    $185 = (_luaZ_fill($176)|0);
    $186 = $185;
   } else {
    $180 = ((($176)) + 4|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = ((($181)) + 1|0);
    HEAP32[$180>>2] = $182;
    $183 = HEAP8[$181>>0]|0;
    $184 = $183&255;
    $186 = $184;
   }
   HEAP32[$ls>>2] = $186;
   $187 = ($186|0)==(47);
   if (!($187)) {
    $$0 = 47;
    STACKTOP = sp;return ($$0|0);
   }
   $188 = HEAP32[$3>>2]|0;
   $189 = HEAP32[$188>>2]|0;
   $190 = (($189) + -1)|0;
   HEAP32[$188>>2] = $190;
   $191 = ($189|0)==(0);
   if ($191) {
    $197 = (_luaZ_fill($188)|0);
    $198 = $197;
   } else {
    $192 = ((($188)) + 4|0);
    $193 = HEAP32[$192>>2]|0;
    $194 = ((($193)) + 1|0);
    HEAP32[$192>>2] = $194;
    $195 = HEAP8[$193>>0]|0;
    $196 = $195&255;
    $198 = $196;
   }
   HEAP32[$ls>>2] = $198;
   $$0 = 279;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 79: {
   $199 = HEAP32[$3>>2]|0;
   $200 = HEAP32[$199>>2]|0;
   $201 = (($200) + -1)|0;
   HEAP32[$199>>2] = $201;
   $202 = ($200|0)==(0);
   if ($202) {
    $208 = (_luaZ_fill($199)|0);
    $209 = $208;
   } else {
    $203 = ((($199)) + 4|0);
    $204 = HEAP32[$203>>2]|0;
    $205 = ((($204)) + 1|0);
    HEAP32[$203>>2] = $205;
    $206 = HEAP8[$204>>0]|0;
    $207 = $206&255;
    $209 = $207;
   }
   HEAP32[$ls>>2] = $209;
   $210 = ($209|0)==(61);
   if (!($210)) {
    $$0 = 126;
    STACKTOP = sp;return ($$0|0);
   }
   $211 = HEAP32[$3>>2]|0;
   $212 = HEAP32[$211>>2]|0;
   $213 = (($212) + -1)|0;
   HEAP32[$211>>2] = $213;
   $214 = ($212|0)==(0);
   if ($214) {
    $220 = (_luaZ_fill($211)|0);
    $221 = $220;
   } else {
    $215 = ((($211)) + 4|0);
    $216 = HEAP32[$215>>2]|0;
    $217 = ((($216)) + 1|0);
    HEAP32[$215>>2] = $217;
    $218 = HEAP8[$216>>0]|0;
    $219 = $218&255;
    $221 = $219;
   }
   HEAP32[$ls>>2] = $221;
   $$0 = 285;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 87: {
   $222 = HEAP32[$3>>2]|0;
   $223 = HEAP32[$222>>2]|0;
   $224 = (($223) + -1)|0;
   HEAP32[$222>>2] = $224;
   $225 = ($223|0)==(0);
   if ($225) {
    $231 = (_luaZ_fill($222)|0);
    $232 = $231;
   } else {
    $226 = ((($222)) + 4|0);
    $227 = HEAP32[$226>>2]|0;
    $228 = ((($227)) + 1|0);
    HEAP32[$226>>2] = $228;
    $229 = HEAP8[$227>>0]|0;
    $230 = $229&255;
    $232 = $230;
   }
   HEAP32[$ls>>2] = $232;
   $233 = ($232|0)==(58);
   if (!($233)) {
    $$0 = 58;
    STACKTOP = sp;return ($$0|0);
   }
   $234 = HEAP32[$3>>2]|0;
   $235 = HEAP32[$234>>2]|0;
   $236 = (($235) + -1)|0;
   HEAP32[$234>>2] = $236;
   $237 = ($235|0)==(0);
   if ($237) {
    $243 = (_luaZ_fill($234)|0);
    $244 = $243;
   } else {
    $238 = ((($234)) + 4|0);
    $239 = HEAP32[$238>>2]|0;
    $240 = ((($239)) + 1|0);
    HEAP32[$238>>2] = $240;
    $241 = HEAP8[$239>>0]|0;
    $242 = $241&255;
    $244 = $242;
   }
   HEAP32[$ls>>2] = $244;
   $$0 = 288;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 95: {
   $245 = HEAP32[$0>>2]|0;
   $246 = ((($245)) + 4|0);
   $247 = HEAP32[$246>>2]|0;
   $248 = (($247) + 1)|0;
   $249 = ((($245)) + 8|0);
   $250 = HEAP32[$249>>2]|0;
   $251 = ($248>>>0)>($250>>>0);
   do {
    if ($251) {
     $252 = ($250>>>0)>(2147483646);
     if ($252) {
      _lexerror($ls,5368,0);
      // unreachable;
     } else {
      $253 = $250 << 1;
      $254 = ((($ls)) + 52|0);
      $255 = HEAP32[$254>>2]|0;
      $256 = HEAP32[$245>>2]|0;
      $257 = (_luaM_realloc_($255,$256,$250,$253)|0);
      HEAP32[$245>>2] = $257;
      HEAP32[$249>>2] = $253;
      $$pre$i$i = HEAP32[$246>>2]|0;
      $260 = $$pre$i$i;$262 = $257;
      break;
     }
    } else {
     $$pre1$i$i = HEAP32[$245>>2]|0;
     $260 = $247;$262 = $$pre1$i$i;
    }
   } while(0);
   $258 = $$lcssa410&255;
   $259 = (($260) + 1)|0;
   HEAP32[$246>>2] = $259;
   $261 = (($262) + ($260)|0);
   HEAP8[$261>>0] = $258;
   $263 = HEAP32[$3>>2]|0;
   $264 = HEAP32[$263>>2]|0;
   $265 = (($264) + -1)|0;
   HEAP32[$263>>2] = $265;
   $266 = ($264|0)==(0);
   if ($266) {
    $272 = (_luaZ_fill($263)|0);
    $273 = $272;
   } else {
    $267 = ((($263)) + 4|0);
    $268 = HEAP32[$267>>2]|0;
    $269 = ((($268)) + 1|0);
    HEAP32[$267>>2] = $269;
    $270 = HEAP8[$268>>0]|0;
    $271 = $270&255;
    $273 = $271;
   }
   HEAP32[$ls>>2] = $273;
   $274 = ($273|0)==($$lcssa410|0);
   L97: do {
    if (!($274)) {
     $275 = ((($ls)) + 52|0);
     $925 = $273;
     L99: while(1) {
      L101: do {
       if ((($925|0) == -1)) {
        label = 107;
        break L99;
       } else if ((($925|0) == 13) | (($925|0) == 10)) {
        label = 108;
        break L99;
       } else if ((($925|0) == 92)) {
        $276 = HEAP32[$0>>2]|0;
        $277 = ((($276)) + 4|0);
        $278 = HEAP32[$277>>2]|0;
        $279 = (($278) + 1)|0;
        $280 = ((($276)) + 8|0);
        $281 = HEAP32[$280>>2]|0;
        $282 = ($279>>>0)>($281>>>0);
        if ($282) {
         $283 = ($281>>>0)>(2147483646);
         if ($283) {
          label = 112;
          break L99;
         }
         $284 = $281 << 1;
         $285 = HEAP32[$275>>2]|0;
         $286 = HEAP32[$276>>2]|0;
         $287 = (_luaM_realloc_($285,$286,$281,$284)|0);
         HEAP32[$276>>2] = $287;
         HEAP32[$280>>2] = $284;
         $$pre$i4$i = HEAP32[$277>>2]|0;
         $289 = $$pre$i4$i;$291 = $287;
        } else {
         $$pre1$i2$i = HEAP32[$276>>2]|0;
         $289 = $278;$291 = $$pre1$i2$i;
        }
        $288 = (($289) + 1)|0;
        HEAP32[$277>>2] = $288;
        $290 = (($291) + ($289)|0);
        HEAP8[$290>>0] = 92;
        $292 = HEAP32[$3>>2]|0;
        $293 = HEAP32[$292>>2]|0;
        $294 = (($293) + -1)|0;
        HEAP32[$292>>2] = $294;
        $295 = ($293|0)==(0);
        if ($295) {
         $301 = (_luaZ_fill($292)|0);
         $302 = $301;
        } else {
         $296 = ((($292)) + 4|0);
         $297 = HEAP32[$296>>2]|0;
         $298 = ((($297)) + 1|0);
         HEAP32[$296>>2] = $298;
         $299 = HEAP8[$297>>0]|0;
         $300 = $299&255;
         $302 = $300;
        }
        HEAP32[$ls>>2] = $302;
        do {
         switch ($302|0) {
         case 117:  {
          $436 = HEAP32[$0>>2]|0;
          $437 = ((($436)) + 4|0);
          $438 = HEAP32[$437>>2]|0;
          $439 = (($438) + 1)|0;
          $440 = ((($436)) + 8|0);
          $441 = HEAP32[$440>>2]|0;
          $442 = ($439>>>0)>($441>>>0);
          if ($442) {
           $443 = ($441>>>0)>(2147483646);
           if ($443) {
            label = 169;
            break L99;
           }
           $444 = $441 << 1;
           $445 = HEAP32[$275>>2]|0;
           $446 = HEAP32[$436>>2]|0;
           $447 = (_luaM_realloc_($445,$446,$441,$444)|0);
           HEAP32[$436>>2] = $447;
           HEAP32[$440>>2] = $444;
           $$pre$i$i$i$i = HEAP32[$437>>2]|0;
           $449 = $$pre$i$i$i$i;$451 = $447;
          } else {
           $$pre1$i$i$i$i = HEAP32[$436>>2]|0;
           $449 = $438;$451 = $$pre1$i$i$i$i;
          }
          $448 = (($449) + 1)|0;
          HEAP32[$437>>2] = $448;
          $450 = (($451) + ($449)|0);
          HEAP8[$450>>0] = 117;
          $452 = HEAP32[$3>>2]|0;
          $453 = HEAP32[$452>>2]|0;
          $454 = (($453) + -1)|0;
          HEAP32[$452>>2] = $454;
          $455 = ($453|0)==(0);
          if ($455) {
           $461 = (_luaZ_fill($452)|0);
           $462 = $461;
          } else {
           $456 = ((($452)) + 4|0);
           $457 = HEAP32[$456>>2]|0;
           $458 = ((($457)) + 1|0);
           HEAP32[$456>>2] = $458;
           $459 = HEAP8[$457>>0]|0;
           $460 = $459&255;
           $462 = $460;
          }
          HEAP32[$ls>>2] = $462;
          if ((($462|0) == -1)) {
           label = 184;
           break L99;
          } else if (!((($462|0) == 123))) {
           $$lcssa380 = $462;
           label = 175;
           break L99;
          }
          $491 = HEAP32[$0>>2]|0;
          $492 = ((($491)) + 4|0);
          $493 = HEAP32[$492>>2]|0;
          $494 = (($493) + 1)|0;
          $495 = ((($491)) + 8|0);
          $496 = HEAP32[$495>>2]|0;
          $497 = ($494>>>0)>($496>>>0);
          if ($497) {
           $498 = ($496>>>0)>(2147483646);
           if ($498) {
            label = 188;
            break L99;
           }
           $499 = $496 << 1;
           $500 = HEAP32[$275>>2]|0;
           $501 = HEAP32[$491>>2]|0;
           $502 = (_luaM_realloc_($500,$501,$496,$499)|0);
           HEAP32[$491>>2] = $502;
           HEAP32[$495>>2] = $499;
           $$pre$i16$i$i$i = HEAP32[$492>>2]|0;
           $504 = $$pre$i16$i$i$i;$506 = $502;
          } else {
           $$pre1$i14$i$i$i = HEAP32[$491>>2]|0;
           $504 = $493;$506 = $$pre1$i14$i$i$i;
          }
          $503 = (($504) + 1)|0;
          HEAP32[$492>>2] = $503;
          $505 = (($506) + ($504)|0);
          HEAP8[$505>>0] = 123;
          $507 = HEAP32[$3>>2]|0;
          $508 = HEAP32[$507>>2]|0;
          $509 = (($508) + -1)|0;
          HEAP32[$507>>2] = $509;
          $510 = ($508|0)==(0);
          if ($510) {
           $516 = (_luaZ_fill($507)|0);
           $517 = $516;
          } else {
           $511 = ((($507)) + 4|0);
           $512 = HEAP32[$511>>2]|0;
           $513 = ((($512)) + 1|0);
           HEAP32[$511>>2] = $513;
           $514 = HEAP8[$512>>0]|0;
           $515 = $514&255;
           $517 = $515;
          }
          HEAP32[$ls>>2] = $517;
          $518 = (($517) + 1)|0;
          $519 = (4864 + ($518)|0);
          $520 = HEAP8[$519>>0]|0;
          $521 = $520 & 16;
          $522 = ($521<<24>>24)==(0);
          if ($522) {
           $$lcssa389 = $517;
           label = 194;
           break L99;
          }
          $552 = (_luaO_hexavalue($517)|0);
          $i$0$i$i$i = 4;$r$0$i$i$i = $552;
          while(1) {
           $553 = HEAP32[$ls>>2]|0;
           $554 = HEAP32[$0>>2]|0;
           $555 = ((($554)) + 4|0);
           $556 = HEAP32[$555>>2]|0;
           $557 = (($556) + 1)|0;
           $558 = ((($554)) + 8|0);
           $559 = HEAP32[$558>>2]|0;
           $560 = ($557>>>0)>($559>>>0);
           if ($560) {
            $561 = ($559>>>0)>(2147483646);
            if ($561) {
             label = 209;
             break L99;
            }
            $562 = $559 << 1;
            $563 = HEAP32[$275>>2]|0;
            $564 = HEAP32[$554>>2]|0;
            $565 = (_luaM_realloc_($563,$564,$559,$562)|0);
            HEAP32[$554>>2] = $565;
            HEAP32[$558>>2] = $562;
            $$pre$i4$i$i$i = HEAP32[$555>>2]|0;
            $568 = $$pre$i4$i$i$i;$570 = $565;
           } else {
            $$pre1$i2$i$i$i = HEAP32[$554>>2]|0;
            $568 = $556;$570 = $$pre1$i2$i$i$i;
           }
           $566 = $553&255;
           $567 = (($568) + 1)|0;
           HEAP32[$555>>2] = $567;
           $569 = (($570) + ($568)|0);
           HEAP8[$569>>0] = $566;
           $571 = HEAP32[$3>>2]|0;
           $572 = HEAP32[$571>>2]|0;
           $573 = (($572) + -1)|0;
           HEAP32[$571>>2] = $573;
           $574 = ($572|0)==(0);
           if ($574) {
            $580 = (_luaZ_fill($571)|0);
            $581 = $580;
           } else {
            $575 = ((($571)) + 4|0);
            $576 = HEAP32[$575>>2]|0;
            $577 = ((($576)) + 1|0);
            HEAP32[$575>>2] = $577;
            $578 = HEAP8[$576>>0]|0;
            $579 = $578&255;
            $581 = $579;
           }
           HEAP32[$ls>>2] = $581;
           $582 = (($581) + 1)|0;
           $583 = (4864 + ($582)|0);
           $584 = HEAP8[$583>>0]|0;
           $585 = $584 & 16;
           $586 = ($585<<24>>24)==(0);
           if ($586) {
            $$lcssa = $581;$i$0$i$i$i$lcssa355 = $i$0$i$i$i;$r$0$i$i$i$lcssa353 = $r$0$i$i$i;
            break;
           }
           $587 = (($i$0$i$i$i) + 1)|0;
           $588 = $r$0$i$i$i << 4;
           $589 = (_luaO_hexavalue($581)|0);
           $590 = (($589) + ($588))|0;
           $591 = ($590>>>0)<(1114112);
           if ($591) {
            $i$0$i$i$i = $587;$r$0$i$i$i = $590;
           } else {
            label = 216;
            break L99;
           }
          }
          if ((($$lcssa|0) == -1)) {
           label = 237;
           break L99;
          } else if (!((($$lcssa|0) == 125))) {
           $$lcssa$lcssa = $$lcssa;
           label = 228;
           break L99;
          }
          $650 = HEAP32[$3>>2]|0;
          $651 = HEAP32[$650>>2]|0;
          $652 = (($651) + -1)|0;
          HEAP32[$650>>2] = $652;
          $653 = ($651|0)==(0);
          if ($653) {
           $659 = (_luaZ_fill($650)|0);
           $660 = $659;
          } else {
           $654 = ((($650)) + 4|0);
           $655 = HEAP32[$654>>2]|0;
           $656 = ((($655)) + 1|0);
           HEAP32[$654>>2] = $656;
           $657 = HEAP8[$655>>0]|0;
           $658 = $657&255;
           $660 = $658;
          }
          HEAP32[$ls>>2] = $660;
          $661 = HEAP32[$0>>2]|0;
          $662 = ((($661)) + 4|0);
          $663 = HEAP32[$662>>2]|0;
          $664 = (($663) - ($i$0$i$i$i$lcssa355))|0;
          HEAP32[$662>>2] = $664;
          $665 = (_luaO_utf8esc($buff$i$i,$r$0$i$i$i$lcssa353)|0);
          $666 = ($665|0)>(0);
          if ($666) {
           $n$06$i$i = $665;
           while(1) {
            $667 = (8 - ($n$06$i$i))|0;
            $668 = (($buff$i$i) + ($667)|0);
            $669 = HEAP8[$668>>0]|0;
            $670 = HEAP32[$0>>2]|0;
            $671 = ((($670)) + 4|0);
            $672 = HEAP32[$671>>2]|0;
            $673 = (($672) + 1)|0;
            $674 = ((($670)) + 8|0);
            $675 = HEAP32[$674>>2]|0;
            $676 = ($673>>>0)>($675>>>0);
            if ($676) {
             $677 = ($675>>>0)>(2147483646);
             if ($677) {
              label = 245;
              break L99;
             }
             $678 = $675 << 1;
             $679 = HEAP32[$275>>2]|0;
             $680 = HEAP32[$670>>2]|0;
             $681 = (_luaM_realloc_($679,$680,$675,$678)|0);
             HEAP32[$670>>2] = $681;
             HEAP32[$674>>2] = $678;
             $$pre$i$i9$i = HEAP32[$671>>2]|0;
             $683 = $$pre$i$i9$i;$685 = $681;
            } else {
             $$pre1$i$i7$i = HEAP32[$670>>2]|0;
             $683 = $672;$685 = $$pre1$i$i7$i;
            }
            $682 = (($683) + 1)|0;
            HEAP32[$671>>2] = $682;
            $684 = (($685) + ($683)|0);
            HEAP8[$684>>0] = $669;
            $686 = (($n$06$i$i) + -1)|0;
            $687 = ($n$06$i$i|0)>(1);
            if ($687) {
             $n$06$i$i = $686;
            } else {
             break;
            }
           }
          }
          break;
         }
         case -1:  {
          $$be43$i = -1;
          break L101;
          break;
         }
         case 98:  {
          $c$0$i = 8;
          label = 317;
          break;
         }
         case 102:  {
          $c$0$i = 12;
          label = 317;
          break;
         }
         case 110:  {
          $c$0$i = 10;
          label = 317;
          break;
         }
         case 114:  {
          $c$0$i = 13;
          label = 317;
          break;
         }
         case 116:  {
          $c$0$i = 9;
          label = 317;
          break;
         }
         case 118:  {
          $c$0$i = 11;
          label = 317;
          break;
         }
         case 120:  {
          $304 = HEAP32[$0>>2]|0;
          $305 = ((($304)) + 4|0);
          $306 = HEAP32[$305>>2]|0;
          $307 = (($306) + 1)|0;
          $308 = ((($304)) + 8|0);
          $309 = HEAP32[$308>>2]|0;
          $310 = ($307>>>0)>($309>>>0);
          if ($310) {
           $311 = ($309>>>0)>(2147483646);
           if ($311) {
            label = 128;
            break L99;
           }
           $312 = $309 << 1;
           $313 = HEAP32[$275>>2]|0;
           $314 = HEAP32[$304>>2]|0;
           $315 = (_luaM_realloc_($313,$314,$309,$312)|0);
           HEAP32[$304>>2] = $315;
           HEAP32[$308>>2] = $312;
           $$pre$i$i$i = HEAP32[$305>>2]|0;
           $317 = $$pre$i$i$i;$319 = $315;
          } else {
           $$pre1$i$i$i = HEAP32[$304>>2]|0;
           $317 = $306;$319 = $$pre1$i$i$i;
          }
          $316 = (($317) + 1)|0;
          HEAP32[$305>>2] = $316;
          $318 = (($319) + ($317)|0);
          HEAP8[$318>>0] = 120;
          $320 = HEAP32[$3>>2]|0;
          $321 = HEAP32[$320>>2]|0;
          $322 = (($321) + -1)|0;
          HEAP32[$320>>2] = $322;
          $323 = ($321|0)==(0);
          if ($323) {
           $329 = (_luaZ_fill($320)|0);
           $330 = $329;
          } else {
           $324 = ((($320)) + 4|0);
           $325 = HEAP32[$324>>2]|0;
           $326 = ((($325)) + 1|0);
           HEAP32[$324>>2] = $326;
           $327 = HEAP8[$325>>0]|0;
           $328 = $327&255;
           $330 = $328;
          }
          HEAP32[$ls>>2] = $330;
          $331 = (($330) + 1)|0;
          $332 = (4864 + ($331)|0);
          $333 = HEAP8[$332>>0]|0;
          $334 = $333 & 16;
          $335 = ($334<<24>>24)==(0);
          if ($335) {
           $$lcssa395 = $330;
           label = 134;
           break L99;
          }
          $365 = (_luaO_hexavalue($330)|0);
          $366 = $365 << 4;
          $367 = HEAP32[$ls>>2]|0;
          $368 = HEAP32[$0>>2]|0;
          $369 = ((($368)) + 4|0);
          $370 = HEAP32[$369>>2]|0;
          $371 = (($370) + 1)|0;
          $372 = ((($368)) + 8|0);
          $373 = HEAP32[$372>>2]|0;
          $374 = ($371>>>0)>($373>>>0);
          if ($374) {
           $375 = ($373>>>0)>(2147483646);
           if ($375) {
            label = 148;
            break L99;
           }
           $376 = $373 << 1;
           $377 = HEAP32[$275>>2]|0;
           $378 = HEAP32[$368>>2]|0;
           $379 = (_luaM_realloc_($377,$378,$373,$376)|0);
           HEAP32[$368>>2] = $379;
           HEAP32[$372>>2] = $376;
           $$pre$i5$i$i = HEAP32[$369>>2]|0;
           $382 = $$pre$i5$i$i;$384 = $379;
          } else {
           $$pre1$i3$i$i = HEAP32[$368>>2]|0;
           $382 = $370;$384 = $$pre1$i3$i$i;
          }
          $380 = $367&255;
          $381 = (($382) + 1)|0;
          HEAP32[$369>>2] = $381;
          $383 = (($384) + ($382)|0);
          HEAP8[$383>>0] = $380;
          $385 = HEAP32[$3>>2]|0;
          $386 = HEAP32[$385>>2]|0;
          $387 = (($386) + -1)|0;
          HEAP32[$385>>2] = $387;
          $388 = ($386|0)==(0);
          if ($388) {
           $394 = (_luaZ_fill($385)|0);
           $395 = $394;
          } else {
           $389 = ((($385)) + 4|0);
           $390 = HEAP32[$389>>2]|0;
           $391 = ((($390)) + 1|0);
           HEAP32[$389>>2] = $391;
           $392 = HEAP8[$390>>0]|0;
           $393 = $392&255;
           $395 = $393;
          }
          HEAP32[$ls>>2] = $395;
          $396 = (($395) + 1)|0;
          $397 = (4864 + ($396)|0);
          $398 = HEAP8[$397>>0]|0;
          $399 = $398 & 16;
          $400 = ($399<<24>>24)==(0);
          if ($400) {
           $$lcssa398 = $395;
           label = 154;
           break L99;
          }
          $430 = (_luaO_hexavalue($395)|0);
          $431 = (($430) + ($366))|0;
          $432 = HEAP32[$0>>2]|0;
          $433 = ((($432)) + 4|0);
          $434 = HEAP32[$433>>2]|0;
          $435 = (($434) + -2)|0;
          HEAP32[$433>>2] = $435;
          $c$0$i = $431;
          label = 317;
          break;
         }
         case 13: case 10:  {
          $688 = HEAP32[$3>>2]|0;
          $689 = HEAP32[$688>>2]|0;
          $690 = (($689) + -1)|0;
          HEAP32[$688>>2] = $690;
          $691 = ($689|0)==(0);
          if ($691) {
           $697 = (_luaZ_fill($688)|0);
           $698 = $697;
          } else {
           $692 = ((($688)) + 4|0);
           $693 = HEAP32[$692>>2]|0;
           $694 = ((($693)) + 1|0);
           HEAP32[$692>>2] = $694;
           $695 = HEAP8[$693>>0]|0;
           $696 = $695&255;
           $698 = $696;
          }
          HEAP32[$ls>>2] = $698;
          if ((($698|0) == 13) | (($698|0) == 10)) {
           $699 = ($698|0)==($302|0);
           if (!($699)) {
            $700 = HEAP32[$3>>2]|0;
            $701 = HEAP32[$700>>2]|0;
            $702 = (($701) + -1)|0;
            HEAP32[$700>>2] = $702;
            $703 = ($701|0)==(0);
            if ($703) {
             $709 = (_luaZ_fill($700)|0);
             $710 = $709;
            } else {
             $704 = ((($700)) + 4|0);
             $705 = HEAP32[$704>>2]|0;
             $706 = ((($705)) + 1|0);
             HEAP32[$704>>2] = $706;
             $707 = HEAP8[$705>>0]|0;
             $708 = $707&255;
             $710 = $708;
            }
            HEAP32[$ls>>2] = $710;
           }
          }
          $711 = HEAP32[$4>>2]|0;
          $712 = (($711) + 1)|0;
          HEAP32[$4>>2] = $712;
          $713 = ($712|0)==(2147483647);
          if ($713) {
           label = 259;
           break L99;
          } else {
           $c$1$i = 10;
           label = 321;
          }
          break;
         }
         case 39: case 34: case 92:  {
          $c$0$i = $302;
          label = 317;
          break;
         }
         case 122:  {
          $714 = HEAP32[$0>>2]|0;
          $715 = ((($714)) + 4|0);
          $716 = HEAP32[$715>>2]|0;
          $717 = (($716) + -1)|0;
          HEAP32[$715>>2] = $717;
          $718 = HEAP32[$3>>2]|0;
          $719 = HEAP32[$718>>2]|0;
          $720 = (($719) + -1)|0;
          HEAP32[$718>>2] = $720;
          $721 = ($719|0)==(0);
          if ($721) {
           $727 = (_luaZ_fill($718)|0);
           $728 = $727;
          } else {
           $722 = ((($718)) + 4|0);
           $723 = HEAP32[$722>>2]|0;
           $724 = ((($723)) + 1|0);
           HEAP32[$722>>2] = $724;
           $725 = HEAP8[$723>>0]|0;
           $726 = $725&255;
           $728 = $726;
          }
          HEAP32[$ls>>2] = $728;
          $729 = (($728) + 1)|0;
          $730 = (4864 + ($729)|0);
          $731 = HEAP8[$730>>0]|0;
          $732 = $731 & 8;
          $733 = ($732<<24>>24)==(0);
          if (!($733)) {
           $746 = $728;
           while(1) {
            if ((($746|0) == 13) | (($746|0) == 10)) {
             $734 = HEAP32[$3>>2]|0;
             $735 = HEAP32[$734>>2]|0;
             $736 = (($735) + -1)|0;
             HEAP32[$734>>2] = $736;
             $737 = ($735|0)==(0);
             if ($737) {
              $743 = (_luaZ_fill($734)|0);
              $744 = $743;
             } else {
              $738 = ((($734)) + 4|0);
              $739 = HEAP32[$738>>2]|0;
              $740 = ((($739)) + 1|0);
              HEAP32[$738>>2] = $740;
              $741 = HEAP8[$739>>0]|0;
              $742 = $741&255;
              $744 = $742;
             }
             HEAP32[$ls>>2] = $744;
             if ((($744|0) == 13) | (($744|0) == 10)) {
              $745 = ($744|0)==($746|0);
              if ($745) {
               $$pr40$i = $746;
              } else {
               $747 = HEAP32[$3>>2]|0;
               $748 = HEAP32[$747>>2]|0;
               $749 = (($748) + -1)|0;
               HEAP32[$747>>2] = $749;
               $750 = ($748|0)==(0);
               if ($750) {
                $756 = (_luaZ_fill($747)|0);
                $757 = $756;
               } else {
                $751 = ((($747)) + 4|0);
                $752 = HEAP32[$751>>2]|0;
                $753 = ((($752)) + 1|0);
                HEAP32[$751>>2] = $753;
                $754 = HEAP8[$752>>0]|0;
                $755 = $754&255;
                $757 = $755;
               }
               HEAP32[$ls>>2] = $757;
               $$pr40$i = $757;
              }
             } else {
              $$pr40$i = $744;
             }
             $758 = HEAP32[$4>>2]|0;
             $759 = (($758) + 1)|0;
             HEAP32[$4>>2] = $759;
             $760 = ($759|0)==(2147483647);
             if ($760) {
              label = 276;
              break L99;
             } else {
              $$be$i = $$pr40$i;
             }
            } else {
             $761 = HEAP32[$3>>2]|0;
             $762 = HEAP32[$761>>2]|0;
             $763 = (($762) + -1)|0;
             HEAP32[$761>>2] = $763;
             $764 = ($762|0)==(0);
             if ($764) {
              $770 = (_luaZ_fill($761)|0);
              $771 = $770;
             } else {
              $765 = ((($761)) + 4|0);
              $766 = HEAP32[$765>>2]|0;
              $767 = ((($766)) + 1|0);
              HEAP32[$765>>2] = $767;
              $768 = HEAP8[$766>>0]|0;
              $769 = $768&255;
              $771 = $769;
             }
             HEAP32[$ls>>2] = $771;
             $$be$i = $771;
            }
            $772 = (($$be$i) + 1)|0;
            $773 = (4864 + ($772)|0);
            $774 = HEAP8[$773>>0]|0;
            $775 = $774 & 8;
            $776 = ($775<<24>>24)==(0);
            if ($776) {
             break;
            } else {
             $746 = $$be$i;
            }
           }
          }
          break;
         }
         case 97:  {
          $c$0$i = 7;
          label = 317;
          break;
         }
         default: {
          $777 = (($302) + 1)|0;
          $778 = (4864 + ($777)|0);
          $779 = HEAP8[$778>>0]|0;
          $780 = $779 & 2;
          $781 = ($780<<24>>24)==(0);
          if ($781) {
           $$lcssa376 = $302;
           label = 283;
           break L99;
          } else {
           $812 = $302;$i$08$i$i = 0;$r$09$i$i = 0;
          }
          while(1) {
           $811 = (($812) + 1)|0;
           $813 = (4864 + ($811)|0);
           $814 = HEAP8[$813>>0]|0;
           $815 = $814 & 2;
           $816 = ($815<<24>>24)==(0);
           if ($816) {
            $1153 = $812;$i$0$lcssa$i$i = $i$08$i$i;$r$0$lcssa$i$i = $r$09$i$i;
            break;
           }
           $817 = ($r$09$i$i*10)|0;
           $818 = (($812) + -48)|0;
           $819 = (($818) + ($817))|0;
           $820 = HEAP32[$0>>2]|0;
           $821 = ((($820)) + 4|0);
           $822 = HEAP32[$821>>2]|0;
           $823 = (($822) + 1)|0;
           $824 = ((($820)) + 8|0);
           $825 = HEAP32[$824>>2]|0;
           $826 = ($823>>>0)>($825>>>0);
           if ($826) {
            $827 = ($825>>>0)>(2147483646);
            if ($827) {
             label = 298;
             break L99;
            }
            $828 = $825 << 1;
            $829 = HEAP32[$275>>2]|0;
            $830 = HEAP32[$820>>2]|0;
            $831 = (_luaM_realloc_($829,$830,$825,$828)|0);
            HEAP32[$820>>2] = $831;
            HEAP32[$824>>2] = $828;
            $$pre$i$i17$i = HEAP32[$821>>2]|0;
            $834 = $$pre$i$i17$i;$836 = $831;
           } else {
            $$pre1$i$i15$i = HEAP32[$820>>2]|0;
            $834 = $822;$836 = $$pre1$i$i15$i;
           }
           $832 = $812&255;
           $833 = (($834) + 1)|0;
           HEAP32[$821>>2] = $833;
           $835 = (($836) + ($834)|0);
           HEAP8[$835>>0] = $832;
           $837 = HEAP32[$3>>2]|0;
           $838 = HEAP32[$837>>2]|0;
           $839 = (($838) + -1)|0;
           HEAP32[$837>>2] = $839;
           $840 = ($838|0)==(0);
           if ($840) {
            $846 = (_luaZ_fill($837)|0);
            $847 = $846;
           } else {
            $841 = ((($837)) + 4|0);
            $842 = HEAP32[$841>>2]|0;
            $843 = ((($842)) + 1|0);
            HEAP32[$841>>2] = $843;
            $844 = HEAP8[$842>>0]|0;
            $845 = $844&255;
            $847 = $845;
           }
           HEAP32[$ls>>2] = $847;
           $848 = (($i$08$i$i) + 1)|0;
           $849 = ($848|0)<(3);
           if ($849) {
            $812 = $847;$i$08$i$i = $848;$r$09$i$i = $819;
           } else {
            $1153 = $847;$i$0$lcssa$i$i = $848;$r$0$lcssa$i$i = $819;
            break;
           }
          }
          $850 = ($r$0$lcssa$i$i|0)<(256);
          if (!($850)) {
           $$lcssa399 = $1153;
           label = 305;
           break L99;
          }
          $880 = HEAP32[$0>>2]|0;
          $881 = ((($880)) + 4|0);
          $882 = HEAP32[$881>>2]|0;
          $883 = (($882) - ($i$0$lcssa$i$i))|0;
          HEAP32[$881>>2] = $883;
          $c$1$i = $r$0$lcssa$i$i;
          label = 321;
         }
         }
        } while(0);
        if ((label|0) == 317) {
         label = 0;
         $884 = HEAP32[$3>>2]|0;
         $885 = HEAP32[$884>>2]|0;
         $886 = (($885) + -1)|0;
         HEAP32[$884>>2] = $886;
         $887 = ($885|0)==(0);
         if ($887) {
          $893 = (_luaZ_fill($884)|0);
          $894 = $893;
         } else {
          $888 = ((($884)) + 4|0);
          $889 = HEAP32[$888>>2]|0;
          $890 = ((($889)) + 1|0);
          HEAP32[$888>>2] = $890;
          $891 = HEAP8[$889>>0]|0;
          $892 = $891&255;
          $894 = $892;
         }
         HEAP32[$ls>>2] = $894;
         $c$1$i = $c$0$i;
         label = 321;
        }
        if ((label|0) == 321) {
         label = 0;
         $895 = HEAP32[$0>>2]|0;
         $896 = ((($895)) + 4|0);
         $897 = HEAP32[$896>>2]|0;
         $898 = (($897) + -1)|0;
         HEAP32[$896>>2] = $898;
         $899 = ((($895)) + 8|0);
         $900 = HEAP32[$899>>2]|0;
         $901 = ($897>>>0)>($900>>>0);
         if ($901) {
          $902 = ($900>>>0)>(2147483646);
          if ($902) {
           label = 324;
           break L99;
          }
          $903 = $900 << 1;
          $904 = HEAP32[$275>>2]|0;
          $905 = HEAP32[$895>>2]|0;
          $906 = (_luaM_realloc_($904,$905,$900,$903)|0);
          HEAP32[$895>>2] = $906;
          HEAP32[$899>>2] = $903;
          $$pre$i23$i = HEAP32[$896>>2]|0;
          $909 = $$pre$i23$i;$911 = $906;
         } else {
          $$pre1$i21$i = HEAP32[$895>>2]|0;
          $909 = $898;$911 = $$pre1$i21$i;
         }
         $907 = $c$1$i&255;
         $908 = (($909) + 1)|0;
         HEAP32[$896>>2] = $908;
         $910 = (($911) + ($909)|0);
         HEAP8[$910>>0] = $907;
        }
        $$pr$i = HEAP32[$ls>>2]|0;
        $$be43$i = $$pr$i;
       } else {
        $912 = HEAP32[$0>>2]|0;
        $913 = ((($912)) + 4|0);
        $914 = HEAP32[$913>>2]|0;
        $915 = (($914) + 1)|0;
        $916 = ((($912)) + 8|0);
        $917 = HEAP32[$916>>2]|0;
        $918 = ($915>>>0)>($917>>>0);
        if ($918) {
         $919 = ($917>>>0)>(2147483646);
         if ($919) {
          label = 330;
          break L99;
         }
         $920 = $917 << 1;
         $921 = HEAP32[$275>>2]|0;
         $922 = HEAP32[$912>>2]|0;
         $923 = (_luaM_realloc_($921,$922,$917,$920)|0);
         HEAP32[$912>>2] = $923;
         HEAP32[$916>>2] = $920;
         $$pre$i28$i = HEAP32[$913>>2]|0;
         $927 = $$pre$i28$i;$929 = $923;
        } else {
         $$pre1$i26$i = HEAP32[$912>>2]|0;
         $927 = $914;$929 = $$pre1$i26$i;
        }
        $924 = $925&255;
        $926 = (($927) + 1)|0;
        HEAP32[$913>>2] = $926;
        $928 = (($929) + ($927)|0);
        HEAP8[$928>>0] = $924;
        $930 = HEAP32[$3>>2]|0;
        $931 = HEAP32[$930>>2]|0;
        $932 = (($931) + -1)|0;
        HEAP32[$930>>2] = $932;
        $933 = ($931|0)==(0);
        if ($933) {
         $939 = (_luaZ_fill($930)|0);
         $940 = $939;
        } else {
         $934 = ((($930)) + 4|0);
         $935 = HEAP32[$934>>2]|0;
         $936 = ((($935)) + 1|0);
         HEAP32[$934>>2] = $936;
         $937 = HEAP8[$935>>0]|0;
         $938 = $937&255;
         $940 = $938;
        }
        HEAP32[$ls>>2] = $940;
        $$be43$i = $940;
       }
      } while(0);
      $303 = ($$be43$i|0)==($$lcssa410|0);
      if ($303) {
       break L97;
      } else {
       $925 = $$be43$i;
      }
     }
     switch (label|0) {
      case 107: {
       _lexerror($ls,5400,289);
       // unreachable;
       break;
      }
      case 108: {
       _lexerror($ls,5400,293);
       // unreachable;
       break;
      }
      case 112: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 128: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 134: {
       $336 = ($$lcssa395|0)==(-1);
       if ($336) {
        _lexerror($ls,5424,293);
        // unreachable;
       }
       $337 = HEAP32[$0>>2]|0;
       $338 = ((($337)) + 4|0);
       $339 = HEAP32[$338>>2]|0;
       $340 = (($339) + 1)|0;
       $341 = ((($337)) + 8|0);
       $342 = HEAP32[$341>>2]|0;
       $343 = ($340>>>0)>($342>>>0);
       do {
        if ($343) {
         $344 = ($342>>>0)>(2147483646);
         if ($344) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $345 = $342 << 1;
          $346 = HEAP32[$275>>2]|0;
          $347 = HEAP32[$337>>2]|0;
          $348 = (_luaM_realloc_($346,$347,$342,$345)|0);
          HEAP32[$337>>2] = $348;
          HEAP32[$341>>2] = $345;
          $$pre$i11$i$i = HEAP32[$338>>2]|0;
          $351 = $$pre$i11$i$i;$353 = $348;
          break;
         }
        } else {
         $$pre1$i9$i$i = HEAP32[$337>>2]|0;
         $351 = $339;$353 = $$pre1$i9$i$i;
        }
       } while(0);
       $349 = $$lcssa395&255;
       $350 = (($351) + 1)|0;
       HEAP32[$338>>2] = $350;
       $352 = (($353) + ($351)|0);
       HEAP8[$352>>0] = $349;
       $354 = HEAP32[$3>>2]|0;
       $355 = HEAP32[$354>>2]|0;
       $356 = (($355) + -1)|0;
       HEAP32[$354>>2] = $356;
       $357 = ($355|0)==(0);
       if ($357) {
        $363 = (_luaZ_fill($354)|0);
        $364 = $363;
       } else {
        $358 = ((($354)) + 4|0);
        $359 = HEAP32[$358>>2]|0;
        $360 = ((($359)) + 1|0);
        HEAP32[$358>>2] = $360;
        $361 = HEAP8[$359>>0]|0;
        $362 = $361&255;
        $364 = $362;
       }
       HEAP32[$ls>>2] = $364;
       _lexerror($ls,5424,293);
       // unreachable;
       break;
      }
      case 148: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 154: {
       $401 = ($$lcssa398|0)==(-1);
       if ($401) {
        _lexerror($ls,5424,293);
        // unreachable;
       }
       $402 = HEAP32[$0>>2]|0;
       $403 = ((($402)) + 4|0);
       $404 = HEAP32[$403>>2]|0;
       $405 = (($404) + 1)|0;
       $406 = ((($402)) + 8|0);
       $407 = HEAP32[$406>>2]|0;
       $408 = ($405>>>0)>($407>>>0);
       do {
        if ($408) {
         $409 = ($407>>>0)>(2147483646);
         if ($409) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $410 = $407 << 1;
          $411 = HEAP32[$275>>2]|0;
          $412 = HEAP32[$402>>2]|0;
          $413 = (_luaM_realloc_($411,$412,$407,$410)|0);
          HEAP32[$402>>2] = $413;
          HEAP32[$406>>2] = $410;
          $$pre$i16$i$i = HEAP32[$403>>2]|0;
          $416 = $$pre$i16$i$i;$418 = $413;
          break;
         }
        } else {
         $$pre1$i14$i$i = HEAP32[$402>>2]|0;
         $416 = $404;$418 = $$pre1$i14$i$i;
        }
       } while(0);
       $414 = $$lcssa398&255;
       $415 = (($416) + 1)|0;
       HEAP32[$403>>2] = $415;
       $417 = (($418) + ($416)|0);
       HEAP8[$417>>0] = $414;
       $419 = HEAP32[$3>>2]|0;
       $420 = HEAP32[$419>>2]|0;
       $421 = (($420) + -1)|0;
       HEAP32[$419>>2] = $421;
       $422 = ($420|0)==(0);
       if ($422) {
        $428 = (_luaZ_fill($419)|0);
        $429 = $428;
       } else {
        $423 = ((($419)) + 4|0);
        $424 = HEAP32[$423>>2]|0;
        $425 = ((($424)) + 1|0);
        HEAP32[$423>>2] = $425;
        $426 = HEAP8[$424>>0]|0;
        $427 = $426&255;
        $429 = $427;
       }
       HEAP32[$ls>>2] = $429;
       _lexerror($ls,5424,293);
       // unreachable;
       break;
      }
      case 169: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 175: {
       $463 = HEAP32[$0>>2]|0;
       $464 = ((($463)) + 4|0);
       $465 = HEAP32[$464>>2]|0;
       $466 = (($465) + 1)|0;
       $467 = ((($463)) + 8|0);
       $468 = HEAP32[$467>>2]|0;
       $469 = ($466>>>0)>($468>>>0);
       do {
        if ($469) {
         $470 = ($468>>>0)>(2147483646);
         if ($470) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $471 = $468 << 1;
          $472 = HEAP32[$275>>2]|0;
          $473 = HEAP32[$463>>2]|0;
          $474 = (_luaM_realloc_($472,$473,$468,$471)|0);
          HEAP32[$463>>2] = $474;
          HEAP32[$467>>2] = $471;
          $$pre$i11$i$i$i = HEAP32[$464>>2]|0;
          $477 = $$pre$i11$i$i$i;$479 = $474;
          break;
         }
        } else {
         $$pre1$i9$i$i$i = HEAP32[$463>>2]|0;
         $477 = $465;$479 = $$pre1$i9$i$i$i;
        }
       } while(0);
       $475 = $$lcssa380&255;
       $476 = (($477) + 1)|0;
       HEAP32[$464>>2] = $476;
       $478 = (($479) + ($477)|0);
       HEAP8[$478>>0] = $475;
       $480 = HEAP32[$3>>2]|0;
       $481 = HEAP32[$480>>2]|0;
       $482 = (($481) + -1)|0;
       HEAP32[$480>>2] = $482;
       $483 = ($481|0)==(0);
       if ($483) {
        $489 = (_luaZ_fill($480)|0);
        $490 = $489;
       } else {
        $484 = ((($480)) + 4|0);
        $485 = HEAP32[$484>>2]|0;
        $486 = ((($485)) + 1|0);
        HEAP32[$484>>2] = $486;
        $487 = HEAP8[$485>>0]|0;
        $488 = $487&255;
        $490 = $488;
       }
       HEAP32[$ls>>2] = $490;
       _lexerror($ls,5456,293);
       // unreachable;
       break;
      }
      case 184: {
       _lexerror($ls,5456,293);
       // unreachable;
       break;
      }
      case 188: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 194: {
       $523 = ($$lcssa389|0)==(-1);
       if ($523) {
        _lexerror($ls,5424,293);
        // unreachable;
       }
       $524 = HEAP32[$0>>2]|0;
       $525 = ((($524)) + 4|0);
       $526 = HEAP32[$525>>2]|0;
       $527 = (($526) + 1)|0;
       $528 = ((($524)) + 8|0);
       $529 = HEAP32[$528>>2]|0;
       $530 = ($527>>>0)>($529>>>0);
       do {
        if ($530) {
         $531 = ($529>>>0)>(2147483646);
         if ($531) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $532 = $529 << 1;
          $533 = HEAP32[$275>>2]|0;
          $534 = HEAP32[$524>>2]|0;
          $535 = (_luaM_realloc_($533,$534,$529,$532)|0);
          HEAP32[$524>>2] = $535;
          HEAP32[$528>>2] = $532;
          $$pre$i32$i$i$i = HEAP32[$525>>2]|0;
          $538 = $$pre$i32$i$i$i;$540 = $535;
          break;
         }
        } else {
         $$pre1$i30$i$i$i = HEAP32[$524>>2]|0;
         $538 = $526;$540 = $$pre1$i30$i$i$i;
        }
       } while(0);
       $536 = $$lcssa389&255;
       $537 = (($538) + 1)|0;
       HEAP32[$525>>2] = $537;
       $539 = (($540) + ($538)|0);
       HEAP8[$539>>0] = $536;
       $541 = HEAP32[$3>>2]|0;
       $542 = HEAP32[$541>>2]|0;
       $543 = (($542) + -1)|0;
       HEAP32[$541>>2] = $543;
       $544 = ($542|0)==(0);
       if ($544) {
        $550 = (_luaZ_fill($541)|0);
        $551 = $550;
       } else {
        $545 = ((($541)) + 4|0);
        $546 = HEAP32[$545>>2]|0;
        $547 = ((($546)) + 1|0);
        HEAP32[$545>>2] = $547;
        $548 = HEAP8[$546>>0]|0;
        $549 = $548&255;
        $551 = $549;
       }
       HEAP32[$ls>>2] = $551;
       _lexerror($ls,5424,293);
       // unreachable;
       break;
      }
      case 209: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 216: {
       $592 = HEAP32[$ls>>2]|0;
       $593 = ($592|0)==(-1);
       if ($593) {
        _lexerror($ls,5472,293);
        // unreachable;
       }
       $594 = HEAP32[$0>>2]|0;
       $595 = ((($594)) + 4|0);
       $596 = HEAP32[$595>>2]|0;
       $597 = (($596) + 1)|0;
       $598 = ((($594)) + 8|0);
       $599 = HEAP32[$598>>2]|0;
       $600 = ($597>>>0)>($599>>>0);
       do {
        if ($600) {
         $601 = ($599>>>0)>(2147483646);
         if ($601) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $602 = $599 << 1;
          $603 = HEAP32[$275>>2]|0;
          $604 = HEAP32[$594>>2]|0;
          $605 = (_luaM_realloc_($603,$604,$599,$602)|0);
          HEAP32[$594>>2] = $605;
          HEAP32[$598>>2] = $602;
          $$pre$i22$i$i$i = HEAP32[$595>>2]|0;
          $608 = $$pre$i22$i$i$i;$610 = $605;
          break;
         }
        } else {
         $$pre1$i20$i$i$i = HEAP32[$594>>2]|0;
         $608 = $596;$610 = $$pre1$i20$i$i$i;
        }
       } while(0);
       $606 = $592&255;
       $607 = (($608) + 1)|0;
       HEAP32[$595>>2] = $607;
       $609 = (($610) + ($608)|0);
       HEAP8[$609>>0] = $606;
       $611 = HEAP32[$3>>2]|0;
       $612 = HEAP32[$611>>2]|0;
       $613 = (($612) + -1)|0;
       HEAP32[$611>>2] = $613;
       $614 = ($612|0)==(0);
       if ($614) {
        $620 = (_luaZ_fill($611)|0);
        $621 = $620;
       } else {
        $615 = ((($611)) + 4|0);
        $616 = HEAP32[$615>>2]|0;
        $617 = ((($616)) + 1|0);
        HEAP32[$615>>2] = $617;
        $618 = HEAP8[$616>>0]|0;
        $619 = $618&255;
        $621 = $619;
       }
       HEAP32[$ls>>2] = $621;
       _lexerror($ls,5472,293);
       // unreachable;
       break;
      }
      case 228: {
       $622 = HEAP32[$0>>2]|0;
       $623 = ((($622)) + 4|0);
       $624 = HEAP32[$623>>2]|0;
       $625 = (($624) + 1)|0;
       $626 = ((($622)) + 8|0);
       $627 = HEAP32[$626>>2]|0;
       $628 = ($625>>>0)>($627>>>0);
       do {
        if ($628) {
         $629 = ($627>>>0)>(2147483646);
         if ($629) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $630 = $627 << 1;
          $631 = HEAP32[$275>>2]|0;
          $632 = HEAP32[$622>>2]|0;
          $633 = (_luaM_realloc_($631,$632,$627,$630)|0);
          HEAP32[$622>>2] = $633;
          HEAP32[$626>>2] = $630;
          $$pre$i27$i$i$i = HEAP32[$623>>2]|0;
          $636 = $$pre$i27$i$i$i;$638 = $633;
          break;
         }
        } else {
         $$pre1$i25$i$i$i = HEAP32[$622>>2]|0;
         $636 = $624;$638 = $$pre1$i25$i$i$i;
        }
       } while(0);
       $634 = $$lcssa$lcssa&255;
       $635 = (($636) + 1)|0;
       HEAP32[$623>>2] = $635;
       $637 = (($638) + ($636)|0);
       HEAP8[$637>>0] = $634;
       $639 = HEAP32[$3>>2]|0;
       $640 = HEAP32[$639>>2]|0;
       $641 = (($640) + -1)|0;
       HEAP32[$639>>2] = $641;
       $642 = ($640|0)==(0);
       if ($642) {
        $648 = (_luaZ_fill($639)|0);
        $649 = $648;
       } else {
        $643 = ((($639)) + 4|0);
        $644 = HEAP32[$643>>2]|0;
        $645 = ((($644)) + 1|0);
        HEAP32[$643>>2] = $645;
        $646 = HEAP8[$644>>0]|0;
        $647 = $646&255;
        $649 = $647;
       }
       HEAP32[$ls>>2] = $649;
       _lexerror($ls,5496,293);
       // unreachable;
       break;
      }
      case 237: {
       _lexerror($ls,5496,293);
       // unreachable;
       break;
      }
      case 245: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 259: {
       _lexerror($ls,5304,0);
       // unreachable;
       break;
      }
      case 276: {
       _lexerror($ls,5304,0);
       // unreachable;
       break;
      }
      case 283: {
       $782 = ($$lcssa376|0)==(-1);
       if ($782) {
        _lexerror($ls,5512,293);
        // unreachable;
       }
       $783 = HEAP32[$0>>2]|0;
       $784 = ((($783)) + 4|0);
       $785 = HEAP32[$784>>2]|0;
       $786 = (($785) + 1)|0;
       $787 = ((($783)) + 8|0);
       $788 = HEAP32[$787>>2]|0;
       $789 = ($786>>>0)>($788>>>0);
       do {
        if ($789) {
         $790 = ($788>>>0)>(2147483646);
         if ($790) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $791 = $788 << 1;
          $792 = HEAP32[$275>>2]|0;
          $793 = HEAP32[$783>>2]|0;
          $794 = (_luaM_realloc_($792,$793,$788,$791)|0);
          HEAP32[$783>>2] = $794;
          HEAP32[$787>>2] = $791;
          $$pre$i38$i = HEAP32[$784>>2]|0;
          $797 = $$pre$i38$i;$799 = $794;
          break;
         }
        } else {
         $$pre1$i36$i = HEAP32[$783>>2]|0;
         $797 = $785;$799 = $$pre1$i36$i;
        }
       } while(0);
       $795 = $$lcssa376&255;
       $796 = (($797) + 1)|0;
       HEAP32[$784>>2] = $796;
       $798 = (($799) + ($797)|0);
       HEAP8[$798>>0] = $795;
       $800 = HEAP32[$3>>2]|0;
       $801 = HEAP32[$800>>2]|0;
       $802 = (($801) + -1)|0;
       HEAP32[$800>>2] = $802;
       $803 = ($801|0)==(0);
       if ($803) {
        $809 = (_luaZ_fill($800)|0);
        $810 = $809;
       } else {
        $804 = ((($800)) + 4|0);
        $805 = HEAP32[$804>>2]|0;
        $806 = ((($805)) + 1|0);
        HEAP32[$804>>2] = $806;
        $807 = HEAP8[$805>>0]|0;
        $808 = $807&255;
        $810 = $808;
       }
       HEAP32[$ls>>2] = $810;
       _lexerror($ls,5512,293);
       // unreachable;
       break;
      }
      case 298: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 305: {
       $851 = ($$lcssa399|0)==(-1);
       if ($851) {
        _lexerror($ls,5536,293);
        // unreachable;
       }
       $852 = HEAP32[$0>>2]|0;
       $853 = ((($852)) + 4|0);
       $854 = HEAP32[$853>>2]|0;
       $855 = (($854) + 1)|0;
       $856 = ((($852)) + 8|0);
       $857 = HEAP32[$856>>2]|0;
       $858 = ($855>>>0)>($857>>>0);
       do {
        if ($858) {
         $859 = ($857>>>0)>(2147483646);
         if ($859) {
          _lexerror($ls,5368,0);
          // unreachable;
         } else {
          $860 = $857 << 1;
          $861 = HEAP32[$275>>2]|0;
          $862 = HEAP32[$852>>2]|0;
          $863 = (_luaM_realloc_($861,$862,$857,$860)|0);
          HEAP32[$852>>2] = $863;
          HEAP32[$856>>2] = $860;
          $$pre$i4$i$i = HEAP32[$853>>2]|0;
          $866 = $$pre$i4$i$i;$868 = $863;
          break;
         }
        } else {
         $$pre1$i2$i$i = HEAP32[$852>>2]|0;
         $866 = $854;$868 = $$pre1$i2$i$i;
        }
       } while(0);
       $864 = $$lcssa399&255;
       $865 = (($866) + 1)|0;
       HEAP32[$853>>2] = $865;
       $867 = (($868) + ($866)|0);
       HEAP8[$867>>0] = $864;
       $869 = HEAP32[$3>>2]|0;
       $870 = HEAP32[$869>>2]|0;
       $871 = (($870) + -1)|0;
       HEAP32[$869>>2] = $871;
       $872 = ($870|0)==(0);
       if ($872) {
        $878 = (_luaZ_fill($869)|0);
        $879 = $878;
       } else {
        $873 = ((($869)) + 4|0);
        $874 = HEAP32[$873>>2]|0;
        $875 = ((($874)) + 1|0);
        HEAP32[$873>>2] = $875;
        $876 = HEAP8[$874>>0]|0;
        $877 = $876&255;
        $879 = $877;
       }
       HEAP32[$ls>>2] = $879;
       _lexerror($ls,5536,293);
       // unreachable;
       break;
      }
      case 324: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
      case 330: {
       _lexerror($ls,5368,0);
       // unreachable;
       break;
      }
     }
    }
   } while(0);
   $941 = HEAP32[$0>>2]|0;
   $942 = ((($941)) + 4|0);
   $943 = HEAP32[$942>>2]|0;
   $944 = (($943) + 1)|0;
   $945 = ((($941)) + 8|0);
   $946 = HEAP32[$945>>2]|0;
   $947 = ($944>>>0)>($946>>>0);
   do {
    if ($947) {
     $948 = ($946>>>0)>(2147483646);
     if ($948) {
      _lexerror($ls,5368,0);
      // unreachable;
     } else {
      $949 = $946 << 1;
      $950 = ((($ls)) + 52|0);
      $951 = HEAP32[$950>>2]|0;
      $952 = HEAP32[$941>>2]|0;
      $953 = (_luaM_realloc_($951,$952,$946,$949)|0);
      HEAP32[$941>>2] = $953;
      HEAP32[$945>>2] = $949;
      $$pre$i33$i = HEAP32[$942>>2]|0;
      $955 = $$pre$i33$i;$957 = $953;
      break;
     }
    } else {
     $$pre1$i31$i = HEAP32[$941>>2]|0;
     $955 = $943;$957 = $$pre1$i31$i;
    }
   } while(0);
   $954 = (($955) + 1)|0;
   HEAP32[$942>>2] = $954;
   $956 = (($957) + ($955)|0);
   HEAP8[$956>>0] = $258;
   $958 = HEAP32[$3>>2]|0;
   $959 = HEAP32[$958>>2]|0;
   $960 = (($959) + -1)|0;
   HEAP32[$958>>2] = $960;
   $961 = ($959|0)==(0);
   if ($961) {
    $967 = (_luaZ_fill($958)|0);
    $968 = $967;
   } else {
    $962 = ((($958)) + 4|0);
    $963 = HEAP32[$962>>2]|0;
    $964 = ((($963)) + 1|0);
    HEAP32[$962>>2] = $964;
    $965 = HEAP8[$963>>0]|0;
    $966 = $965&255;
    $968 = $966;
   }
   HEAP32[$ls>>2] = $968;
   $969 = HEAP32[$0>>2]|0;
   $970 = HEAP32[$969>>2]|0;
   $971 = ((($970)) + 1|0);
   $972 = ((($969)) + 4|0);
   $973 = HEAP32[$972>>2]|0;
   $974 = (($973) + -2)|0;
   $975 = ((($ls)) + 52|0);
   $976 = HEAP32[$975>>2]|0;
   $977 = (_luaS_newlstr($976,$971,$974)|0);
   $978 = ((($976)) + 8|0);
   $979 = HEAP32[$978>>2]|0;
   $980 = ((($979)) + 16|0);
   HEAP32[$978>>2] = $980;
   HEAP32[$979>>2] = $977;
   $981 = ((($977)) + 4|0);
   $982 = HEAP8[$981>>0]|0;
   $983 = $982&255;
   $984 = $983 | 64;
   $985 = ((($979)) + 8|0);
   HEAP32[$985>>2] = $984;
   $986 = ((($ls)) + 64|0);
   $987 = HEAP32[$986>>2]|0;
   $988 = HEAP32[$978>>2]|0;
   $989 = ((($988)) + -16|0);
   $990 = (_luaH_set($976,$987,$989)|0);
   $991 = ((($990)) + 8|0);
   $992 = HEAP32[$991>>2]|0;
   $993 = ($992|0)==(0);
   if ($993) {
    HEAP32[$990>>2] = 1;
    HEAP32[$991>>2] = 1;
    $994 = ((($976)) + 12|0);
    $995 = HEAP32[$994>>2]|0;
    $996 = ((($995)) + 12|0);
    $997 = HEAP32[$996>>2]|0;
    $998 = ($997|0)>(0);
    if ($998) {
     _luaC_step($976);
     $ts$0$i$i = $977;
    } else {
     $ts$0$i$i = $977;
    }
   } else {
    $999 = ((($990)) + 16|0);
    $1000 = HEAP32[$999>>2]|0;
    $ts$0$i$i = $1000;
   }
   $1001 = HEAP32[$978>>2]|0;
   $1002 = ((($1001)) + -16|0);
   HEAP32[$978>>2] = $1002;
   HEAP32[$seminfo>>2] = $ts$0$i$i;
   $$0 = 293;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 349: {
   $1003 = HEAP32[$0>>2]|0;
   $1004 = ((($1003)) + 4|0);
   $1005 = HEAP32[$1004>>2]|0;
   $1006 = (($1005) + 1)|0;
   $1007 = ((($1003)) + 8|0);
   $1008 = HEAP32[$1007>>2]|0;
   $1009 = ($1006>>>0)>($1008>>>0);
   do {
    if ($1009) {
     $1010 = ($1008>>>0)>(2147483646);
     if ($1010) {
      _lexerror($ls,5368,0);
      // unreachable;
     } else {
      $1011 = $1008 << 1;
      $1012 = ((($ls)) + 52|0);
      $1013 = HEAP32[$1012>>2]|0;
      $1014 = HEAP32[$1003>>2]|0;
      $1015 = (_luaM_realloc_($1013,$1014,$1008,$1011)|0);
      HEAP32[$1003>>2] = $1015;
      HEAP32[$1007>>2] = $1011;
      $$pre$i = HEAP32[$1004>>2]|0;
      $1017 = $$pre$i;$1019 = $1015;
      break;
     }
    } else {
     $$pre1$i = HEAP32[$1003>>2]|0;
     $1017 = $1005;$1019 = $$pre1$i;
    }
   } while(0);
   $1016 = (($1017) + 1)|0;
   HEAP32[$1004>>2] = $1016;
   $1018 = (($1019) + ($1017)|0);
   HEAP8[$1018>>0] = 46;
   $1020 = HEAP32[$3>>2]|0;
   $1021 = HEAP32[$1020>>2]|0;
   $1022 = (($1021) + -1)|0;
   HEAP32[$1020>>2] = $1022;
   $1023 = ($1021|0)==(0);
   if ($1023) {
    $1029 = (_luaZ_fill($1020)|0);
    $1030 = $1029;
   } else {
    $1024 = ((($1020)) + 4|0);
    $1025 = HEAP32[$1024>>2]|0;
    $1026 = ((($1025)) + 1|0);
    HEAP32[$1024>>2] = $1026;
    $1027 = HEAP8[$1025>>0]|0;
    $1028 = $1027&255;
    $1030 = $1028;
   }
   HEAP32[$ls>>2] = $1030;
   $1031 = ($1030|0)==(46);
   if (!($1031)) {
    $1055 = (($1030) + 1)|0;
    $1056 = (4864 + ($1055)|0);
    $1057 = HEAP8[$1056>>0]|0;
    $1058 = $1057 & 2;
    $1059 = ($1058<<24>>24)==(0);
    if ($1059) {
     $$0 = 46;
     STACKTOP = sp;return ($$0|0);
    }
    $1060 = (_read_numeral($ls,$seminfo)|0);
    $$0 = $1060;
    STACKTOP = sp;return ($$0|0);
   }
   $1032 = HEAP32[$3>>2]|0;
   $1033 = HEAP32[$1032>>2]|0;
   $1034 = (($1033) + -1)|0;
   HEAP32[$1032>>2] = $1034;
   $1035 = ($1033|0)==(0);
   if ($1035) {
    $1041 = (_luaZ_fill($1032)|0);
    $1042 = $1041;
   } else {
    $1036 = ((($1032)) + 4|0);
    $1037 = HEAP32[$1036>>2]|0;
    $1038 = ((($1037)) + 1|0);
    HEAP32[$1036>>2] = $1038;
    $1039 = HEAP8[$1037>>0]|0;
    $1040 = $1039&255;
    $1042 = $1040;
   }
   HEAP32[$ls>>2] = $1042;
   $1043 = ($1042|0)==(46);
   if (!($1043)) {
    $$0 = 280;
    STACKTOP = sp;return ($$0|0);
   }
   $1044 = HEAP32[$3>>2]|0;
   $1045 = HEAP32[$1044>>2]|0;
   $1046 = (($1045) + -1)|0;
   HEAP32[$1044>>2] = $1046;
   $1047 = ($1045|0)==(0);
   if ($1047) {
    $1053 = (_luaZ_fill($1044)|0);
    $1054 = $1053;
   } else {
    $1048 = ((($1044)) + 4|0);
    $1049 = HEAP32[$1048>>2]|0;
    $1050 = ((($1049)) + 1|0);
    HEAP32[$1048>>2] = $1050;
    $1051 = HEAP8[$1049>>0]|0;
    $1052 = $1051&255;
    $1054 = $1052;
   }
   HEAP32[$ls>>2] = $1054;
   $$0 = 281;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 368: {
   $1061 = (_read_numeral($ls,$seminfo)|0);
   $$0 = $1061;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 369: {
   $1062 = (($$lcssa400) + 1)|0;
   $1063 = (4864 + ($1062)|0);
   $1064 = HEAP8[$1063>>0]|0;
   $1065 = $1064 & 1;
   $1066 = ($1065<<24>>24)==(0);
   if ($1066) {
    $1141 = HEAP32[$3>>2]|0;
    $1142 = HEAP32[$1141>>2]|0;
    $1143 = (($1142) + -1)|0;
    HEAP32[$1141>>2] = $1143;
    $1144 = ($1142|0)==(0);
    if ($1144) {
     $1150 = (_luaZ_fill($1141)|0);
     $1151 = $1150;
    } else {
     $1145 = ((($1141)) + 4|0);
     $1146 = HEAP32[$1145>>2]|0;
     $1147 = ((($1146)) + 1|0);
     HEAP32[$1145>>2] = $1147;
     $1148 = HEAP8[$1146>>0]|0;
     $1149 = $1148&255;
     $1151 = $1149;
    }
    HEAP32[$ls>>2] = $1151;
    $$0 = $$lcssa400;
    STACKTOP = sp;return ($$0|0);
   }
   $1067 = ((($ls)) + 52|0);
   $1081 = $$lcssa400;
   while(1) {
    $1068 = HEAP32[$0>>2]|0;
    $1069 = ((($1068)) + 4|0);
    $1070 = HEAP32[$1069>>2]|0;
    $1071 = (($1070) + 1)|0;
    $1072 = ((($1068)) + 8|0);
    $1073 = HEAP32[$1072>>2]|0;
    $1074 = ($1071>>>0)>($1073>>>0);
    if ($1074) {
     $1075 = ($1073>>>0)>(2147483646);
     if ($1075) {
      label = 374;
      break;
     }
     $1076 = $1073 << 1;
     $1077 = HEAP32[$1067>>2]|0;
     $1078 = HEAP32[$1068>>2]|0;
     $1079 = (_luaM_realloc_($1077,$1078,$1073,$1076)|0);
     HEAP32[$1068>>2] = $1079;
     HEAP32[$1072>>2] = $1076;
     $$pre$i30 = HEAP32[$1069>>2]|0;
     $1083 = $$pre$i30;$1085 = $1079;
    } else {
     $$pre1$i28 = HEAP32[$1068>>2]|0;
     $1083 = $1070;$1085 = $$pre1$i28;
    }
    $1080 = $1081&255;
    $1082 = (($1083) + 1)|0;
    HEAP32[$1069>>2] = $1082;
    $1084 = (($1085) + ($1083)|0);
    HEAP8[$1084>>0] = $1080;
    $1086 = HEAP32[$3>>2]|0;
    $1087 = HEAP32[$1086>>2]|0;
    $1088 = (($1087) + -1)|0;
    HEAP32[$1086>>2] = $1088;
    $1089 = ($1087|0)==(0);
    if ($1089) {
     $1095 = (_luaZ_fill($1086)|0);
     $1096 = $1095;
    } else {
     $1090 = ((($1086)) + 4|0);
     $1091 = HEAP32[$1090>>2]|0;
     $1092 = ((($1091)) + 1|0);
     HEAP32[$1090>>2] = $1092;
     $1093 = HEAP8[$1091>>0]|0;
     $1094 = $1093&255;
     $1096 = $1094;
    }
    HEAP32[$ls>>2] = $1096;
    $1097 = (($1096) + 1)|0;
    $1098 = (4864 + ($1097)|0);
    $1099 = HEAP8[$1098>>0]|0;
    $1100 = $1099 & 3;
    $1101 = ($1100<<24>>24)==(0);
    if ($1101) {
     break;
    } else {
     $1081 = $1096;
    }
   }
   if ((label|0) == 374) {
    _lexerror($ls,5368,0);
    // unreachable;
   }
   $1102 = HEAP32[$0>>2]|0;
   $1103 = HEAP32[$1102>>2]|0;
   $1104 = ((($1102)) + 4|0);
   $1105 = HEAP32[$1104>>2]|0;
   $1106 = HEAP32[$1067>>2]|0;
   $1107 = (_luaS_newlstr($1106,$1103,$1105)|0);
   $1108 = ((($1106)) + 8|0);
   $1109 = HEAP32[$1108>>2]|0;
   $1110 = ((($1109)) + 16|0);
   HEAP32[$1108>>2] = $1110;
   HEAP32[$1109>>2] = $1107;
   $1111 = ((($1107)) + 4|0);
   $1112 = HEAP8[$1111>>0]|0;
   $1113 = $1112&255;
   $1114 = $1113 | 64;
   $1115 = ((($1109)) + 8|0);
   HEAP32[$1115>>2] = $1114;
   $1116 = ((($ls)) + 64|0);
   $1117 = HEAP32[$1116>>2]|0;
   $1118 = HEAP32[$1108>>2]|0;
   $1119 = ((($1118)) + -16|0);
   $1120 = (_luaH_set($1106,$1117,$1119)|0);
   $1121 = ((($1120)) + 8|0);
   $1122 = HEAP32[$1121>>2]|0;
   $1123 = ($1122|0)==(0);
   if ($1123) {
    HEAP32[$1120>>2] = 1;
    HEAP32[$1121>>2] = 1;
    $1124 = ((($1106)) + 12|0);
    $1125 = HEAP32[$1124>>2]|0;
    $1126 = ((($1125)) + 12|0);
    $1127 = HEAP32[$1126>>2]|0;
    $1128 = ($1127|0)>(0);
    if ($1128) {
     _luaC_step($1106);
     $ts$0$i = $1107;
    } else {
     $ts$0$i = $1107;
    }
   } else {
    $1129 = ((($1120)) + 16|0);
    $1130 = HEAP32[$1129>>2]|0;
    $ts$0$i = $1130;
   }
   $1131 = HEAP32[$1108>>2]|0;
   $1132 = ((($1131)) + -16|0);
   HEAP32[$1108>>2] = $1132;
   HEAP32[$seminfo>>2] = $ts$0$i;
   $1133 = ((($ts$0$i)) + 4|0);
   $1134 = HEAP8[$1133>>0]|0;
   $1135 = ($1134<<24>>24)==(4);
   if (!($1135)) {
    $$0 = 292;
    STACKTOP = sp;return ($$0|0);
   }
   $1136 = ((($ts$0$i)) + 6|0);
   $1137 = HEAP8[$1136>>0]|0;
   $1138 = ($1137<<24>>24)==(0);
   if ($1138) {
    $$0 = 292;
    STACKTOP = sp;return ($$0|0);
   }
   $1139 = $1137&255;
   $1140 = $1139 | 256;
   $$0 = $1140;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 391: {
   STACKTOP = sp;return ($$0|0);
   break;
  }
 }
 return (0)|0;
}
function _skip_sep($ls) {
 $ls = $ls|0;
 var $$lcssa = 0, $$pre$i = 0, $$pre$i4 = 0, $$pre1$i = 0, $$pre1$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0$lcssa = 0, $count$08 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$ls>>2]|0;
 $1 = ((($ls)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 $6 = ((($2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 do {
  if ($8) {
   $9 = ($7>>>0)>(2147483646);
   if ($9) {
    _lexerror($ls,5368,0);
    // unreachable;
   } else {
    $10 = $7 << 1;
    $11 = ((($ls)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$2>>2]|0;
    $14 = (_luaM_realloc_($12,$13,$7,$10)|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$6>>2] = $10;
    $$pre$i = HEAP32[$3>>2]|0;
    $17 = $$pre$i;$19 = $14;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$2>>2]|0;
   $17 = $4;$19 = $$pre1$i;
  }
 } while(0);
 $15 = $0&255;
 $16 = (($17) + 1)|0;
 HEAP32[$3>>2] = $16;
 $18 = (($19) + ($17)|0);
 HEAP8[$18>>0] = $15;
 $20 = ((($ls)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + -1)|0;
 HEAP32[$21>>2] = $23;
 $24 = ($22|0)==(0);
 if ($24) {
  $30 = (_luaZ_fill($21)|0);
  $31 = $30;
 } else {
  $25 = ((($21)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 1|0);
  HEAP32[$25>>2] = $27;
  $28 = HEAP8[$26>>0]|0;
  $29 = $28&255;
  $31 = $29;
 }
 HEAP32[$ls>>2] = $31;
 $32 = ($31|0)==(61);
 if (!($32)) {
  $$lcssa = $31;$count$0$lcssa = 0;
  $not$ = ($$lcssa|0)!=($0|0);
  $63 = $not$ << 31 >> 31;
  $64 = $63 ^ $count$0$lcssa;
  return ($64|0);
 }
 $33 = ((($ls)) + 52|0);
 $count$08 = 0;
 while(1) {
  $34 = HEAP32[$1>>2]|0;
  $35 = ((($34)) + 4|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1)|0;
  $38 = ((($34)) + 8|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($37>>>0)>($39>>>0);
  if ($40) {
   $41 = ($39>>>0)>(2147483646);
   if ($41) {
    label = 14;
    break;
   }
   $42 = $39 << 1;
   $43 = HEAP32[$33>>2]|0;
   $44 = HEAP32[$34>>2]|0;
   $45 = (_luaM_realloc_($43,$44,$39,$42)|0);
   HEAP32[$34>>2] = $45;
   HEAP32[$38>>2] = $42;
   $$pre$i4 = HEAP32[$35>>2]|0;
   $47 = $$pre$i4;$49 = $45;
  } else {
   $$pre1$i2 = HEAP32[$34>>2]|0;
   $47 = $36;$49 = $$pre1$i2;
  }
  $46 = (($47) + 1)|0;
  HEAP32[$35>>2] = $46;
  $48 = (($49) + ($47)|0);
  HEAP8[$48>>0] = 61;
  $50 = HEAP32[$20>>2]|0;
  $51 = HEAP32[$50>>2]|0;
  $52 = (($51) + -1)|0;
  HEAP32[$50>>2] = $52;
  $53 = ($51|0)==(0);
  if ($53) {
   $59 = (_luaZ_fill($50)|0);
   $60 = $59;
  } else {
   $54 = ((($50)) + 4|0);
   $55 = HEAP32[$54>>2]|0;
   $56 = ((($55)) + 1|0);
   HEAP32[$54>>2] = $56;
   $57 = HEAP8[$55>>0]|0;
   $58 = $57&255;
   $60 = $58;
  }
  HEAP32[$ls>>2] = $60;
  $61 = (($count$08) + 1)|0;
  $62 = ($60|0)==(61);
  if ($62) {
   $count$08 = $61;
  } else {
   $$lcssa = $60;$count$0$lcssa = $61;
   label = 20;
   break;
  }
 }
 if ((label|0) == 14) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 20) {
  $not$ = ($$lcssa|0)!=($0|0);
  $63 = $not$ << 31 >> 31;
  $64 = $63 ^ $count$0$lcssa;
  return ($64|0);
 }
 return (0)|0;
}
function _read_long_string($ls,$seminfo,$sep) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 $sep = $sep|0;
 var $$lcssa = 0, $$ph = 0, $$ph$ph = 0, $$pr21 = 0, $$pr22 = 0, $$pre$i = 0, $$pre$i15 = 0, $$pre$i4 = 0, $$pre$i9 = 0, $$pre1$i = 0, $$pre1$i13 = 0, $$pre1$i2 = 0, $$pre1$i7 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0;
 var $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ts$0$i = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($ls)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$ls>>2]|0;
 $3 = ((($ls)) + 60|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ((($4)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + 1)|0;
 $8 = ((($4)) + 8|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 do {
  if ($10) {
   $11 = ($9>>>0)>(2147483646);
   if ($11) {
    _lexerror($ls,5368,0);
    // unreachable;
   } else {
    $12 = $9 << 1;
    $13 = ((($ls)) + 52|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = HEAP32[$4>>2]|0;
    $16 = (_luaM_realloc_($14,$15,$9,$12)|0);
    HEAP32[$4>>2] = $16;
    HEAP32[$8>>2] = $12;
    $$pre$i = HEAP32[$5>>2]|0;
    $19 = $$pre$i;$21 = $16;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$4>>2]|0;
   $19 = $6;$21 = $$pre1$i;
  }
 } while(0);
 $17 = $2&255;
 $18 = (($19) + 1)|0;
 HEAP32[$5>>2] = $18;
 $20 = (($21) + ($19)|0);
 HEAP8[$20>>0] = $17;
 $22 = ((($ls)) + 56|0);
 $23 = HEAP32[$22>>2]|0;
 $24 = HEAP32[$23>>2]|0;
 $25 = (($24) + -1)|0;
 HEAP32[$23>>2] = $25;
 $26 = ($24|0)==(0);
 if ($26) {
  $32 = (_luaZ_fill($23)|0);
  $33 = $32;
 } else {
  $27 = ((($23)) + 4|0);
  $28 = HEAP32[$27>>2]|0;
  $29 = ((($28)) + 1|0);
  HEAP32[$27>>2] = $29;
  $30 = HEAP8[$28>>0]|0;
  $31 = $30&255;
  $33 = $31;
 }
 HEAP32[$ls>>2] = $33;
 if ((($33|0) == 13) | (($33|0) == 10)) {
  $34 = HEAP32[$22>>2]|0;
  $35 = HEAP32[$34>>2]|0;
  $36 = (($35) + -1)|0;
  HEAP32[$34>>2] = $36;
  $37 = ($35|0)==(0);
  if ($37) {
   $43 = (_luaZ_fill($34)|0);
   $44 = $43;
  } else {
   $38 = ((($34)) + 4|0);
   $39 = HEAP32[$38>>2]|0;
   $40 = ((($39)) + 1|0);
   HEAP32[$38>>2] = $40;
   $41 = HEAP8[$39>>0]|0;
   $42 = $41&255;
   $44 = $42;
  }
  HEAP32[$ls>>2] = $44;
  if ((($44|0) == 13) | (($44|0) == 10)) {
   $45 = ($44|0)==($33|0);
   if ($45) {
    $$pr21 = $33;
   } else {
    $46 = HEAP32[$22>>2]|0;
    $47 = HEAP32[$46>>2]|0;
    $48 = (($47) + -1)|0;
    HEAP32[$46>>2] = $48;
    $49 = ($47|0)==(0);
    if ($49) {
     $55 = (_luaZ_fill($46)|0);
     $56 = $55;
    } else {
     $50 = ((($46)) + 4|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ((($51)) + 1|0);
     HEAP32[$50>>2] = $52;
     $53 = HEAP8[$51>>0]|0;
     $54 = $53&255;
     $56 = $54;
    }
    HEAP32[$ls>>2] = $56;
    $$pr21 = $56;
   }
  } else {
   $$pr21 = $44;
  }
  $57 = HEAP32[$0>>2]|0;
  $58 = (($57) + 1)|0;
  HEAP32[$0>>2] = $58;
  $59 = ($58|0)==(2147483647);
  if ($59) {
   _lexerror($ls,5304,0);
   // unreachable;
  } else {
   $$ph$ph = $$pr21;
  }
 } else {
  $$ph$ph = $33;
 }
 $60 = ($seminfo|0)==(0|0);
 $61 = ((($ls)) + 52|0);
 $$ph = $$ph$ph;
 L28: while(1) {
  L30: do {
   if ($60) {
    $217 = $$ph;
    while(1) {
     if ((($217|0) == 13) | (($217|0) == 10)) {
      break L30;
     } else if ((($217|0) == 93)) {
      label = 30;
      break L30;
     } else if ((($217|0) == -1)) {
      label = 29;
      break L28;
     }
     $62 = HEAP32[$22>>2]|0;
     $63 = HEAP32[$62>>2]|0;
     $64 = (($63) + -1)|0;
     HEAP32[$62>>2] = $64;
     $65 = ($63|0)==(0);
     if ($65) {
      $71 = (_luaZ_fill($62)|0);
      $72 = $71;
     } else {
      $66 = ((($62)) + 4|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ((($67)) + 1|0);
      HEAP32[$66>>2] = $68;
      $69 = HEAP8[$67>>0]|0;
      $70 = $69&255;
      $72 = $70;
     }
     HEAP32[$ls>>2] = $72;
     $217 = $72;
    }
   } else {
    $166 = $$ph;
    while(1) {
     if ((($166|0) == 13) | (($166|0) == 10)) {
      break L30;
     } else if ((($166|0) == 93)) {
      label = 30;
      break L30;
     } else if ((($166|0) == -1)) {
      label = 29;
      break L28;
     }
     $153 = HEAP32[$3>>2]|0;
     $154 = ((($153)) + 4|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = (($155) + 1)|0;
     $157 = ((($153)) + 8|0);
     $158 = HEAP32[$157>>2]|0;
     $159 = ($156>>>0)>($158>>>0);
     if ($159) {
      $160 = ($158>>>0)>(2147483646);
      if ($160) {
       label = 61;
       break L28;
      }
      $161 = $158 << 1;
      $162 = HEAP32[$61>>2]|0;
      $163 = HEAP32[$153>>2]|0;
      $164 = (_luaM_realloc_($162,$163,$158,$161)|0);
      HEAP32[$153>>2] = $164;
      HEAP32[$157>>2] = $161;
      $$pre$i15 = HEAP32[$154>>2]|0;
      $168 = $$pre$i15;$170 = $164;
     } else {
      $$pre1$i13 = HEAP32[$153>>2]|0;
      $168 = $155;$170 = $$pre1$i13;
     }
     $165 = $166&255;
     $167 = (($168) + 1)|0;
     HEAP32[$154>>2] = $167;
     $169 = (($170) + ($168)|0);
     HEAP8[$169>>0] = $165;
     $171 = HEAP32[$22>>2]|0;
     $172 = HEAP32[$171>>2]|0;
     $173 = (($172) + -1)|0;
     HEAP32[$171>>2] = $173;
     $174 = ($172|0)==(0);
     if ($174) {
      $180 = (_luaZ_fill($171)|0);
      $181 = $180;
     } else {
      $175 = ((($171)) + 4|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ((($176)) + 1|0);
      HEAP32[$175>>2] = $177;
      $178 = HEAP8[$176>>0]|0;
      $179 = $178&255;
      $181 = $179;
     }
     HEAP32[$ls>>2] = $181;
     $166 = $181;
    }
   }
  } while(0);
  if ((label|0) == 30) {
   label = 0;
   $77 = (_skip_sep($ls)|0);
   $78 = ($77|0)==($sep|0);
   $79 = HEAP32[$ls>>2]|0;
   if ($78) {
    $$lcssa = $79;
    label = 31;
    break;
   } else {
    $$ph = $79;
    continue;
   }
  }
  $108 = HEAP32[$3>>2]|0;
  $109 = ((($108)) + 4|0);
  $110 = HEAP32[$109>>2]|0;
  $111 = (($110) + 1)|0;
  $112 = ((($108)) + 8|0);
  $113 = HEAP32[$112>>2]|0;
  $114 = ($111>>>0)>($113>>>0);
  if ($114) {
   $115 = ($113>>>0)>(2147483646);
   if ($115) {
    label = 43;
    break;
   }
   $116 = $113 << 1;
   $117 = HEAP32[$61>>2]|0;
   $118 = HEAP32[$108>>2]|0;
   $119 = (_luaM_realloc_($117,$118,$113,$116)|0);
   HEAP32[$108>>2] = $119;
   HEAP32[$112>>2] = $116;
   $$pre$i9 = HEAP32[$109>>2]|0;
   $121 = $$pre$i9;$123 = $119;
  } else {
   $$pre1$i7 = HEAP32[$108>>2]|0;
   $121 = $110;$123 = $$pre1$i7;
  }
  $120 = (($121) + 1)|0;
  HEAP32[$109>>2] = $120;
  $122 = (($123) + ($121)|0);
  HEAP8[$122>>0] = 10;
  $124 = HEAP32[$ls>>2]|0;
  $125 = HEAP32[$22>>2]|0;
  $126 = HEAP32[$125>>2]|0;
  $127 = (($126) + -1)|0;
  HEAP32[$125>>2] = $127;
  $128 = ($126|0)==(0);
  if ($128) {
   $134 = (_luaZ_fill($125)|0);
   $135 = $134;
  } else {
   $129 = ((($125)) + 4|0);
   $130 = HEAP32[$129>>2]|0;
   $131 = ((($130)) + 1|0);
   HEAP32[$129>>2] = $131;
   $132 = HEAP8[$130>>0]|0;
   $133 = $132&255;
   $135 = $133;
  }
  HEAP32[$ls>>2] = $135;
  if ((($135|0) == 13) | (($135|0) == 10)) {
   $136 = ($135|0)==($124|0);
   if ($136) {
    $$pr22 = $124;
   } else {
    $137 = HEAP32[$22>>2]|0;
    $138 = HEAP32[$137>>2]|0;
    $139 = (($138) + -1)|0;
    HEAP32[$137>>2] = $139;
    $140 = ($138|0)==(0);
    if ($140) {
     $146 = (_luaZ_fill($137)|0);
     $147 = $146;
    } else {
     $141 = ((($137)) + 4|0);
     $142 = HEAP32[$141>>2]|0;
     $143 = ((($142)) + 1|0);
     HEAP32[$141>>2] = $143;
     $144 = HEAP8[$142>>0]|0;
     $145 = $144&255;
     $147 = $145;
    }
    HEAP32[$ls>>2] = $147;
    $$pr22 = $147;
   }
  } else {
   $$pr22 = $135;
  }
  $148 = HEAP32[$0>>2]|0;
  $149 = (($148) + 1)|0;
  HEAP32[$0>>2] = $149;
  $150 = ($149|0)==(2147483647);
  if ($150) {
   label = 55;
   break;
  }
  if (!($60)) {
   $$ph = $$pr22;
   continue;
  }
  $151 = HEAP32[$3>>2]|0;
  $152 = ((($151)) + 4|0);
  HEAP32[$152>>2] = 0;
  $$ph = $$pr22;
 }
 if ((label|0) == 29) {
  $73 = ($seminfo|0)!=(0|0);
  $74 = $73 ? 5608 : 5616;
  $75 = HEAP32[$61>>2]|0;
  HEAP32[$vararg_buffer>>2] = $74;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $1;
  $76 = (_luaO_pushfstring($75,5624,$vararg_buffer)|0);
  _lexerror($ls,$76,289);
  // unreachable;
 }
 else if ((label|0) == 31) {
  $80 = HEAP32[$3>>2]|0;
  $81 = ((($80)) + 4|0);
  $82 = HEAP32[$81>>2]|0;
  $83 = (($82) + 1)|0;
  $84 = ((($80)) + 8|0);
  $85 = HEAP32[$84>>2]|0;
  $86 = ($83>>>0)>($85>>>0);
  do {
   if ($86) {
    $87 = ($85>>>0)>(2147483646);
    if ($87) {
     _lexerror($ls,5368,0);
     // unreachable;
    } else {
     $88 = $85 << 1;
     $89 = HEAP32[$61>>2]|0;
     $90 = HEAP32[$80>>2]|0;
     $91 = (_luaM_realloc_($89,$90,$85,$88)|0);
     HEAP32[$80>>2] = $91;
     HEAP32[$84>>2] = $88;
     $$pre$i4 = HEAP32[$81>>2]|0;
     $94 = $$pre$i4;$96 = $91;
     break;
    }
   } else {
    $$pre1$i2 = HEAP32[$80>>2]|0;
    $94 = $82;$96 = $$pre1$i2;
   }
  } while(0);
  $92 = $$lcssa&255;
  $93 = (($94) + 1)|0;
  HEAP32[$81>>2] = $93;
  $95 = (($96) + ($94)|0);
  HEAP8[$95>>0] = $92;
  $97 = HEAP32[$22>>2]|0;
  $98 = HEAP32[$97>>2]|0;
  $99 = (($98) + -1)|0;
  HEAP32[$97>>2] = $99;
  $100 = ($98|0)==(0);
  if ($100) {
   $106 = (_luaZ_fill($97)|0);
   $107 = $106;
  } else {
   $101 = ((($97)) + 4|0);
   $102 = HEAP32[$101>>2]|0;
   $103 = ((($102)) + 1|0);
   HEAP32[$101>>2] = $103;
   $104 = HEAP8[$102>>0]|0;
   $105 = $104&255;
   $107 = $105;
  }
  HEAP32[$ls>>2] = $107;
  if ($60) {
   STACKTOP = sp;return;
  }
  $182 = HEAP32[$3>>2]|0;
  $183 = HEAP32[$182>>2]|0;
  $184 = (($sep) + 2)|0;
  $185 = (($183) + ($184)|0);
  $186 = ((($182)) + 4|0);
  $187 = HEAP32[$186>>2]|0;
  $188 = $184 << 1;
  $189 = (($187) - ($188))|0;
  $190 = HEAP32[$61>>2]|0;
  $191 = (_luaS_newlstr($190,$185,$189)|0);
  $192 = ((($190)) + 8|0);
  $193 = HEAP32[$192>>2]|0;
  $194 = ((($193)) + 16|0);
  HEAP32[$192>>2] = $194;
  HEAP32[$193>>2] = $191;
  $195 = ((($191)) + 4|0);
  $196 = HEAP8[$195>>0]|0;
  $197 = $196&255;
  $198 = $197 | 64;
  $199 = ((($193)) + 8|0);
  HEAP32[$199>>2] = $198;
  $200 = ((($ls)) + 64|0);
  $201 = HEAP32[$200>>2]|0;
  $202 = HEAP32[$192>>2]|0;
  $203 = ((($202)) + -16|0);
  $204 = (_luaH_set($190,$201,$203)|0);
  $205 = ((($204)) + 8|0);
  $206 = HEAP32[$205>>2]|0;
  $207 = ($206|0)==(0);
  if ($207) {
   HEAP32[$204>>2] = 1;
   HEAP32[$205>>2] = 1;
   $208 = ((($190)) + 12|0);
   $209 = HEAP32[$208>>2]|0;
   $210 = ((($209)) + 12|0);
   $211 = HEAP32[$210>>2]|0;
   $212 = ($211|0)>(0);
   if ($212) {
    _luaC_step($190);
    $ts$0$i = $191;
   } else {
    $ts$0$i = $191;
   }
  } else {
   $213 = ((($204)) + 16|0);
   $214 = HEAP32[$213>>2]|0;
   $ts$0$i = $214;
  }
  $215 = HEAP32[$192>>2]|0;
  $216 = ((($215)) + -16|0);
  HEAP32[$192>>2] = $216;
  HEAP32[$seminfo>>2] = $ts$0$i;
  STACKTOP = sp;return;
 }
 else if ((label|0) == 43) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 55) {
  _lexerror($ls,5304,0);
  // unreachable;
 }
 else if ((label|0) == 61) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
}
function _read_numeral($ls,$seminfo) {
 $ls = $ls|0;
 $seminfo = $seminfo|0;
 var $$0 = 0, $$in$i = 0, $$in$i$i = 0, $$in$i1$i = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre$i18 = 0, $$pre$i24 = 0, $$pre$i29 = 0, $$pre$i34 = 0, $$pre$i8 = 0, $$pre1$i = 0, $$pre1$i11 = 0, $$pre1$i16 = 0, $$pre1$i22 = 0, $$pre1$i27 = 0, $$pre1$i32 = 0, $$pre1$i6 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0.0, $258 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $expo$0$ph = 0, $obj = 0, $storemerge = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $obj = sp;
 $0 = HEAP32[$ls>>2]|0;
 $1 = ((($ls)) + 60|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (($4) + 1)|0;
 $6 = ((($2)) + 8|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($5>>>0)>($7>>>0);
 do {
  if ($8) {
   $9 = ($7>>>0)>(2147483646);
   if ($9) {
    _lexerror($ls,5368,0);
    // unreachable;
   } else {
    $10 = $7 << 1;
    $11 = ((($ls)) + 52|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = HEAP32[$2>>2]|0;
    $14 = (_luaM_realloc_($12,$13,$7,$10)|0);
    HEAP32[$2>>2] = $14;
    HEAP32[$6>>2] = $10;
    $$pre$i = HEAP32[$3>>2]|0;
    $17 = $$pre$i;$19 = $14;
    break;
   }
  } else {
   $$pre1$i = HEAP32[$2>>2]|0;
   $17 = $4;$19 = $$pre1$i;
  }
 } while(0);
 $15 = $0&255;
 $16 = (($17) + 1)|0;
 HEAP32[$3>>2] = $16;
 $18 = (($19) + ($17)|0);
 HEAP8[$18>>0] = $15;
 $20 = ((($ls)) + 56|0);
 $21 = HEAP32[$20>>2]|0;
 $22 = HEAP32[$21>>2]|0;
 $23 = (($22) + -1)|0;
 HEAP32[$21>>2] = $23;
 $24 = ($22|0)==(0);
 if ($24) {
  $30 = (_luaZ_fill($21)|0);
  $31 = $30;
 } else {
  $25 = ((($21)) + 4|0);
  $26 = HEAP32[$25>>2]|0;
  $27 = ((($26)) + 1|0);
  HEAP32[$25>>2] = $27;
  $28 = HEAP8[$26>>0]|0;
  $29 = $28&255;
  $31 = $29;
 }
 HEAP32[$ls>>2] = $31;
 $32 = ($0|0)==(48);
 if ($32) {
  if ((($31|0) == 88) | (($31|0) == 120)) {
   $33 = HEAP32[$1>>2]|0;
   $34 = ((($33)) + 4|0);
   $35 = HEAP32[$34>>2]|0;
   $36 = (($35) + 1)|0;
   $37 = ((($33)) + 8|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($36>>>0)>($38>>>0);
   do {
    if ($39) {
     $40 = ($38>>>0)>(2147483646);
     if ($40) {
      _lexerror($ls,5368,0);
      // unreachable;
     } else {
      $41 = $38 << 1;
      $42 = ((($ls)) + 52|0);
      $43 = HEAP32[$42>>2]|0;
      $44 = HEAP32[$33>>2]|0;
      $45 = (_luaM_realloc_($43,$44,$38,$41)|0);
      HEAP32[$33>>2] = $45;
      HEAP32[$37>>2] = $41;
      $$pre$i24 = HEAP32[$34>>2]|0;
      $48 = $$pre$i24;$50 = $45;
      break;
     }
    } else {
     $$pre1$i22 = HEAP32[$33>>2]|0;
     $48 = $35;$50 = $$pre1$i22;
    }
   } while(0);
   $46 = $31&255;
   $47 = (($48) + 1)|0;
   HEAP32[$34>>2] = $47;
   $49 = (($50) + ($48)|0);
   HEAP8[$49>>0] = $46;
   $51 = HEAP32[$20>>2]|0;
   $52 = HEAP32[$51>>2]|0;
   $53 = (($52) + -1)|0;
   HEAP32[$51>>2] = $53;
   $54 = ($52|0)==(0);
   if ($54) {
    $60 = (_luaZ_fill($51)|0);
    $61 = $60;
   } else {
    $55 = ((($51)) + 4|0);
    $56 = HEAP32[$55>>2]|0;
    $57 = ((($56)) + 1|0);
    HEAP32[$55>>2] = $57;
    $58 = HEAP8[$56>>0]|0;
    $59 = $58&255;
    $61 = $59;
   }
   HEAP32[$ls>>2] = $61;
   $258 = $61;$expo$0$ph = 5576;
  } else {
   $258 = $31;$expo$0$ph = 5568;
  }
 } else {
  $258 = $31;$expo$0$ph = 5568;
 }
 $62 = ((($ls)) + 52|0);
 $63 = ((($expo$0$ph)) + 1|0);
 $67 = $258;
 L27: while(1) {
  $64 = HEAP8[$expo$0$ph>>0]|0;
  $65 = $64 << 24 >> 24;
  $66 = ($67|0)==($65|0);
  if ($66) {
   label = 23;
  } else {
   $68 = HEAP8[$63>>0]|0;
   $69 = $68 << 24 >> 24;
   $70 = ($67|0)==($69|0);
   if ($70) {
    label = 23;
   } else {
    $128 = $67;
   }
  }
  if ((label|0) == 23) {
   label = 0;
   $71 = HEAP32[$1>>2]|0;
   $72 = ((($71)) + 4|0);
   $73 = HEAP32[$72>>2]|0;
   $74 = (($73) + 1)|0;
   $75 = ((($71)) + 8|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = ($74>>>0)>($76>>>0);
   if ($77) {
    $78 = ($76>>>0)>(2147483646);
    if ($78) {
     label = 26;
     break;
    }
    $79 = $76 << 1;
    $80 = HEAP32[$62>>2]|0;
    $81 = HEAP32[$71>>2]|0;
    $82 = (_luaM_realloc_($80,$81,$76,$79)|0);
    HEAP32[$71>>2] = $82;
    HEAP32[$75>>2] = $79;
    $$pre$i29 = HEAP32[$72>>2]|0;
    $85 = $$pre$i29;$87 = $82;
   } else {
    $$pre1$i27 = HEAP32[$71>>2]|0;
    $85 = $73;$87 = $$pre1$i27;
   }
   $83 = $67&255;
   $84 = (($85) + 1)|0;
   HEAP32[$72>>2] = $84;
   $86 = (($87) + ($85)|0);
   HEAP8[$86>>0] = $83;
   $88 = HEAP32[$20>>2]|0;
   $89 = HEAP32[$88>>2]|0;
   $90 = (($89) + -1)|0;
   HEAP32[$88>>2] = $90;
   $91 = ($89|0)==(0);
   if ($91) {
    $97 = (_luaZ_fill($88)|0);
    $98 = $97;
   } else {
    $92 = ((($88)) + 4|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ((($93)) + 1|0);
    HEAP32[$92>>2] = $94;
    $95 = HEAP8[$93>>0]|0;
    $96 = $95&255;
    $98 = $96;
   }
   HEAP32[$ls>>2] = $98;
   if ((($98|0) == 43) | (($98|0) == 45)) {
    $99 = HEAP32[$1>>2]|0;
    $100 = ((($99)) + 4|0);
    $101 = HEAP32[$100>>2]|0;
    $102 = (($101) + 1)|0;
    $103 = ((($99)) + 8|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = ($102>>>0)>($104>>>0);
    if ($105) {
     $106 = ($104>>>0)>(2147483646);
     if ($106) {
      label = 35;
      break;
     }
     $107 = $104 << 1;
     $108 = HEAP32[$62>>2]|0;
     $109 = HEAP32[$99>>2]|0;
     $110 = (_luaM_realloc_($108,$109,$104,$107)|0);
     HEAP32[$99>>2] = $110;
     HEAP32[$103>>2] = $107;
     $$pre$i34 = HEAP32[$100>>2]|0;
     $113 = $$pre$i34;$115 = $110;
    } else {
     $$pre1$i32 = HEAP32[$99>>2]|0;
     $113 = $101;$115 = $$pre1$i32;
    }
    $111 = $98&255;
    $112 = (($113) + 1)|0;
    HEAP32[$100>>2] = $112;
    $114 = (($115) + ($113)|0);
    HEAP8[$114>>0] = $111;
    $116 = HEAP32[$20>>2]|0;
    $117 = HEAP32[$116>>2]|0;
    $118 = (($117) + -1)|0;
    HEAP32[$116>>2] = $118;
    $119 = ($117|0)==(0);
    if ($119) {
     $125 = (_luaZ_fill($116)|0);
     $126 = $125;
    } else {
     $120 = ((($116)) + 4|0);
     $121 = HEAP32[$120>>2]|0;
     $122 = ((($121)) + 1|0);
     HEAP32[$120>>2] = $122;
     $123 = HEAP8[$121>>0]|0;
     $124 = $123&255;
     $126 = $124;
    }
    HEAP32[$ls>>2] = $126;
    $128 = $126;
   } else {
    $128 = $98;
   }
  }
  $127 = (($128) + 1)|0;
  $129 = (4864 + ($127)|0);
  $130 = HEAP8[$129>>0]|0;
  $131 = $130 & 16;
  $132 = ($131<<24>>24)==(0);
  do {
   if ($132) {
    $160 = ($128|0)==(46);
    $161 = HEAP32[$1>>2]|0;
    $162 = ((($161)) + 4|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = (($163) + 1)|0;
    $165 = ((($161)) + 8|0);
    $166 = HEAP32[$165>>2]|0;
    $167 = ($164>>>0)>($166>>>0);
    if (!($160)) {
     label = 60;
     break L27;
    }
    if ($167) {
     $168 = ($166>>>0)>(2147483646);
     if ($168) {
      label = 54;
      break L27;
     }
     $169 = $166 << 1;
     $170 = HEAP32[$62>>2]|0;
     $171 = HEAP32[$161>>2]|0;
     $172 = (_luaM_realloc_($170,$171,$166,$169)|0);
     HEAP32[$161>>2] = $172;
     HEAP32[$165>>2] = $169;
     $$pre$i13 = HEAP32[$162>>2]|0;
     $174 = $$pre$i13;$176 = $172;
    } else {
     $$pre1$i11 = HEAP32[$161>>2]|0;
     $174 = $163;$176 = $$pre1$i11;
    }
    $173 = (($174) + 1)|0;
    HEAP32[$162>>2] = $173;
    $175 = (($176) + ($174)|0);
    HEAP8[$175>>0] = 46;
    $177 = HEAP32[$20>>2]|0;
    $178 = HEAP32[$177>>2]|0;
    $179 = (($178) + -1)|0;
    HEAP32[$177>>2] = $179;
    $180 = ($178|0)==(0);
    if ($180) {
     $186 = (_luaZ_fill($177)|0);
     $storemerge = $186;
     break;
    } else {
     $181 = ((($177)) + 4|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = ((($182)) + 1|0);
     HEAP32[$181>>2] = $183;
     $184 = HEAP8[$182>>0]|0;
     $185 = $184&255;
     $storemerge = $185;
     break;
    }
   } else {
    $133 = HEAP32[$1>>2]|0;
    $134 = ((($133)) + 4|0);
    $135 = HEAP32[$134>>2]|0;
    $136 = (($135) + 1)|0;
    $137 = ((($133)) + 8|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($136>>>0)>($138>>>0);
    if ($139) {
     $140 = ($138>>>0)>(2147483646);
     if ($140) {
      label = 45;
      break L27;
     }
     $141 = $138 << 1;
     $142 = HEAP32[$62>>2]|0;
     $143 = HEAP32[$133>>2]|0;
     $144 = (_luaM_realloc_($142,$143,$138,$141)|0);
     HEAP32[$133>>2] = $144;
     HEAP32[$137>>2] = $141;
     $$pre$i8 = HEAP32[$134>>2]|0;
     $147 = $$pre$i8;$149 = $144;
    } else {
     $$pre1$i6 = HEAP32[$133>>2]|0;
     $147 = $135;$149 = $$pre1$i6;
    }
    $145 = $128&255;
    $146 = (($147) + 1)|0;
    HEAP32[$134>>2] = $146;
    $148 = (($149) + ($147)|0);
    HEAP8[$148>>0] = $145;
    $150 = HEAP32[$20>>2]|0;
    $151 = HEAP32[$150>>2]|0;
    $152 = (($151) + -1)|0;
    HEAP32[$150>>2] = $152;
    $153 = ($151|0)==(0);
    if ($153) {
     $159 = (_luaZ_fill($150)|0);
     $storemerge = $159;
     break;
    } else {
     $154 = ((($150)) + 4|0);
     $155 = HEAP32[$154>>2]|0;
     $156 = ((($155)) + 1|0);
     HEAP32[$154>>2] = $156;
     $157 = HEAP8[$155>>0]|0;
     $158 = $157&255;
     $storemerge = $158;
     break;
    }
   }
  } while(0);
  HEAP32[$ls>>2] = $storemerge;
  $67 = $storemerge;
 }
 if ((label|0) == 26) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 35) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 45) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 54) {
  _lexerror($ls,5368,0);
  // unreachable;
 }
 else if ((label|0) == 60) {
  do {
   if ($167) {
    $187 = ($166>>>0)>(2147483646);
    if ($187) {
     _lexerror($ls,5368,0);
     // unreachable;
    } else {
     $188 = $166 << 1;
     $189 = HEAP32[$62>>2]|0;
     $190 = HEAP32[$161>>2]|0;
     $191 = (_luaM_realloc_($189,$190,$166,$188)|0);
     HEAP32[$161>>2] = $191;
     HEAP32[$165>>2] = $188;
     $$pre$i18 = HEAP32[$162>>2]|0;
     $193 = $$pre$i18;$195 = $191;
     break;
    }
   } else {
    $$pre1$i16 = HEAP32[$161>>2]|0;
    $193 = $163;$195 = $$pre1$i16;
   }
  } while(0);
  $192 = (($193) + 1)|0;
  HEAP32[$162>>2] = $192;
  $194 = (($195) + ($193)|0);
  HEAP8[$194>>0] = 0;
  $196 = ((($ls)) + 80|0);
  $197 = HEAP8[$196>>0]|0;
  $198 = ($197<<24>>24)==(46);
  if (!($198)) {
   $199 = HEAP32[$1>>2]|0;
   $200 = ((($199)) + 4|0);
   $201 = HEAP32[$200>>2]|0;
   $202 = HEAP32[$199>>2]|0;
   $203 = ($201|0)==(0);
   if (!($203)) {
    $$in$i = $201;
    while(1) {
     $204 = (($$in$i) + -1)|0;
     $205 = (($202) + ($204)|0);
     $206 = HEAP8[$205>>0]|0;
     $207 = ($206<<24>>24)==(46);
     if ($207) {
      HEAP8[$205>>0] = $197;
     }
     $208 = ($204|0)==(0);
     if ($208) {
      break;
     } else {
      $$in$i = $204;
     }
    }
   }
  }
  $209 = HEAP32[$1>>2]|0;
  $210 = HEAP32[$209>>2]|0;
  $211 = (_luaO_str2num($210,$obj)|0);
  $212 = ($211|0)==(0);
  if ($212) {
   $213 = HEAP8[$196>>0]|0;
   $214 = (_localeconv()|0);
   $215 = HEAP32[$214>>2]|0;
   $216 = HEAP8[$215>>0]|0;
   HEAP8[$196>>0] = $216;
   $217 = ($213<<24>>24)==($216<<24>>24);
   if (!($217)) {
    $218 = HEAP32[$1>>2]|0;
    $219 = ((($218)) + 4|0);
    $220 = HEAP32[$219>>2]|0;
    $221 = HEAP32[$218>>2]|0;
    $222 = ($220|0)==(0);
    if (!($222)) {
     $$in$i$i = $220;
     while(1) {
      $223 = (($$in$i$i) + -1)|0;
      $224 = (($221) + ($223)|0);
      $225 = HEAP8[$224>>0]|0;
      $226 = ($225<<24>>24)==($213<<24>>24);
      if ($226) {
       HEAP8[$224>>0] = $216;
      }
      $227 = ($223|0)==(0);
      if ($227) {
       break;
      } else {
       $$in$i$i = $223;
      }
     }
    }
   }
   $228 = HEAP32[$1>>2]|0;
   $229 = HEAP32[$228>>2]|0;
   $230 = (_luaO_str2num($229,$obj)|0);
   $231 = ($230|0)==(0);
   if ($231) {
    $232 = HEAP8[$196>>0]|0;
    $233 = ($232<<24>>24)==(46);
    if ($233) {
     _lexerror($ls,5584,290);
     // unreachable;
    }
    $234 = HEAP32[$1>>2]|0;
    $235 = ((($234)) + 4|0);
    $236 = HEAP32[$235>>2]|0;
    $237 = HEAP32[$234>>2]|0;
    $238 = ($236|0)==(0);
    if ($238) {
     _lexerror($ls,5584,290);
     // unreachable;
    } else {
     $$in$i1$i = $236;
    }
    while(1) {
     $239 = (($$in$i1$i) + -1)|0;
     $240 = (($237) + ($239)|0);
     $241 = HEAP8[$240>>0]|0;
     $242 = ($241<<24>>24)==($232<<24>>24);
     if ($242) {
      HEAP8[$240>>0] = 46;
     }
     $243 = ($239|0)==(0);
     if ($243) {
      break;
     } else {
      $$in$i1$i = $239;
     }
    }
    _lexerror($ls,5584,290);
    // unreachable;
   }
  }
  $244 = ((($obj)) + 8|0);
  $245 = HEAP32[$244>>2]|0;
  $246 = ($245|0)==(19);
  if ($246) {
   $247 = $obj;
   $248 = $247;
   $249 = HEAP32[$248>>2]|0;
   $250 = (($247) + 4)|0;
   $251 = $250;
   $252 = HEAP32[$251>>2]|0;
   $253 = $seminfo;
   $254 = $253;
   HEAP32[$254>>2] = $249;
   $255 = (($253) + 4)|0;
   $256 = $255;
   HEAP32[$256>>2] = $252;
   $$0 = 291;
   STACKTOP = sp;return ($$0|0);
  } else {
   $257 = +HEAPF64[$obj>>3];
   HEAPF64[$seminfo>>3] = $257;
   $$0 = 290;
   STACKTOP = sp;return ($$0|0);
  }
 }
 return (0)|0;
}
function _luaopen_base($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_lua_rawgeti($L,-1001000,2,0)|0);
 _luaL_setfuncs($L,5976,0);
 _lua_pushvalue($L,-1);
 _lua_setfield($L,-2,6176);
 (_lua_pushlstring($L,6184,7)|0);
 _lua_setfield($L,-2,6192);
 $0 = (_lua_typename($L,0)|0);
 (_lua_pushstring($L,$0)|0);
 $1 = (_lua_typename($L,1)|0);
 (_lua_pushstring($L,$1)|0);
 $2 = (_lua_typename($L,2)|0);
 (_lua_pushstring($L,$2)|0);
 $3 = (_lua_typename($L,3)|0);
 (_lua_pushstring($L,$3)|0);
 $4 = (_lua_typename($L,4)|0);
 (_lua_pushstring($L,$4)|0);
 $5 = (_lua_typename($L,5)|0);
 (_lua_pushstring($L,$5)|0);
 $6 = (_lua_typename($L,6)|0);
 (_lua_pushstring($L,$6)|0);
 $7 = (_lua_typename($L,7)|0);
 (_lua_pushstring($L,$7)|0);
 $8 = (_lua_typename($L,8)|0);
 (_lua_pushstring($L,$8)|0);
 _lua_pushcclosure($L,331,9);
 _lua_setfield($L,-2,9600);
 return 1;
}
function _luaB_type($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 $0 = (_lua_type($L,1)|0);
 $1 = (-1001001 - ($0))|0;
 _lua_pushvalue($L,$1);
 return 1;
}
function _luaB_assert($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_toboolean($L,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  _luaL_checkany($L,1);
  _lua_rotate($L,1,-1);
  _lua_settop($L,-2);
  (_lua_pushlstring($L,6856,17)|0);
  _lua_settop($L,1);
  $3 = (_luaB_error($L)|0);
  $$0 = $3;
  return ($$0|0);
 } else {
  $2 = (_lua_gettop($L)|0);
  $$0 = $2;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaB_collectgarbage($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, $8 = 0.0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkoption($L,1,6704,6712)|0);
 $1 = (6752 + ($0<<2)|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (_luaL_optinteger($L,2,0,0)|0);
 $4 = tempRet0;
 $5 = (_lua_gc($L,$2,$3)|0);
 if ((($2|0) == 9) | (($2|0) == 5)) {
  _lua_pushboolean($L,$5);
  return 1;
 } else if ((($2|0) == 3)) {
  $6 = (_lua_gc($L,4,0)|0);
  $7 = (+($5|0));
  $8 = (+($6|0));
  $9 = $8 * 9.765625E-4;
  $10 = $7 + $9;
  _lua_pushnumber($L,$10);
  return 1;
 } else {
  $11 = ($5|0)<(0);
  $12 = $11 << 31 >> 31;
  _lua_pushinteger($L,$5,$12);
  return 1;
 }
 return (0)|0;
}
function _luaB_dofile($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_optlstring($L,1,0,0)|0);
 _lua_settop($L,1);
 $1 = (_luaL_loadfilex($L,$0,0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  _lua_callk($L,0,-1,0,332);
  $3 = (_lua_gettop($L)|0);
  $4 = (($3) + -1)|0;
  return ($4|0);
 } else {
  (_lua_error($L)|0);
  // unreachable;
 }
 return (0)|0;
}
function _luaB_error($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_optinteger($L,2,1,0)|0);
 $1 = tempRet0;
 _lua_settop($L,1);
 $2 = (_lua_isstring($L,1)|0);
 $3 = ($2|0)!=(0);
 $4 = ($0|0)>(0);
 $or$cond = $4 & $3;
 if (!($or$cond)) {
  (_lua_error($L)|0);
  // unreachable;
 }
 _luaL_where($L,$0);
 _lua_pushvalue($L,1);
 _lua_concat($L,2);
 (_lua_error($L)|0);
 // unreachable;
 return (0)|0;
}
function _luaB_getmetatable($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 $0 = (_lua_getmetatable($L,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  _lua_pushnil($L);
  return 1;
 } else {
  (_luaL_getmetafield($L,1,6432)|0);
  return 1;
 }
 return (0)|0;
}
function _luaB_ipairs($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_getmetafield($L,1,11928)|0);
 $1 = ($0|0)!=(0);
 $2 = $1 ? 333 : 334;
 _pairsmeta($L,6688,1,$2);
 return 3;
}
function _luaB_loadfile($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_optlstring($L,1,0,0)|0);
 $1 = (_luaL_optlstring($L,2,0,0)|0);
 $2 = (_lua_type($L,3)|0);
 $3 = ($2|0)!=(-1);
 $4 = $3 ? 3 : 0;
 $5 = (_luaL_loadfilex($L,$0,$1)|0);
 $6 = ($5|0)==(0);
 if (!($6)) {
  _lua_pushnil($L);
  _lua_rotate($L,-2,1);
  $$0$i = 2;
  return ($$0$i|0);
 }
 if (!($3)) {
  $$0$i = 1;
  return ($$0$i|0);
 }
 _lua_pushvalue($L,$4);
 $7 = (_lua_setupvalue($L,-2,1)|0);
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $$0$i = 1;
  return ($$0$i|0);
 }
 _lua_settop($L,-2);
 $$0$i = 1;
 return ($$0$i|0);
}
function _luaB_load($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l = 0, $status$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp;
 $0 = (_lua_tolstring($L,1,$l)|0);
 $1 = (_luaL_optlstring($L,3,6600,0)|0);
 $2 = (_lua_type($L,4)|0);
 $3 = ($2|0)!=(-1);
 $4 = $3 ? 4 : 0;
 $5 = ($0|0)==(0|0);
 if ($5) {
  $9 = (_luaL_optlstring($L,2,6608,0)|0);
  _luaL_checktype($L,1,6);
  _lua_settop($L,5);
  $10 = (_lua_load($L,335,0,$9,$1)|0);
  $status$0 = $10;
 } else {
  $6 = (_luaL_optlstring($L,2,$0,0)|0);
  $7 = HEAP32[$l>>2]|0;
  $8 = (_luaL_loadbufferx($L,$0,$7,$6,$1)|0);
  $status$0 = $8;
 }
 $11 = ($status$0|0)==(0);
 if (!($11)) {
  _lua_pushnil($L);
  _lua_rotate($L,-2,1);
  $$0$i = 2;
  STACKTOP = sp;return ($$0$i|0);
 }
 if (!($3)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 _lua_pushvalue($L,$4);
 $12 = (_lua_setupvalue($L,-2,1)|0);
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $$0$i = 1;
  STACKTOP = sp;return ($$0$i|0);
 }
 _lua_settop($L,-2);
 $$0$i = 1;
 STACKTOP = sp;return ($$0$i|0);
}
function _luaB_next($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,5);
 _lua_settop($L,2);
 $0 = (_lua_next($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 2;
  return ($$0|0);
 }
 _lua_pushnil($L);
 $$0 = 1;
 return ($$0|0);
}
function _luaB_pairs($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _pairsmeta($L,6592,0,9);
 return 3;
}
function _luaB_pcall($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $status$cmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 _lua_pushboolean($L,1);
 _lua_rotate($L,1,1);
 $0 = (_lua_gettop($L)|0);
 $1 = (($0) + -2)|0;
 $2 = (_lua_pcallk($L,$1,-1,0,0,336)|0);
 $status$cmp$i = ($2>>>0)>(1);
 if ($status$cmp$i) {
  _lua_pushboolean($L,0);
  _lua_pushvalue($L,-2);
  $$0$i = 2;
  return ($$0$i|0);
 } else {
  $3 = (_lua_gettop($L)|0);
  $$0$i = $3;
  return ($$0$i|0);
 }
 return (0)|0;
}
function _luaB_print($L) {
 $L = $L|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i$04 = 0, $l = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $l = sp + 4|0;
 $0 = (_lua_gettop($L)|0);
 (_lua_getglobal($L,6376)|0);
 $1 = ($0|0)<(1);
 $$pre = HEAP32[_stdout>>2]|0;
 L1: do {
  if (!($1)) {
   $i$04 = 1;
   while(1) {
    _lua_pushvalue($L,-1);
    _lua_pushvalue($L,$i$04);
    _lua_callk($L,1,1,0,0);
    $2 = (_lua_tolstring($L,-1,$l)|0);
    $3 = ($2|0)==(0|0);
    if ($3) {
     break;
    }
    $5 = ($i$04|0)>(1);
    if ($5) {
     (_fputc(9,($$pre|0))|0);
    }
    $6 = HEAP32[$l>>2]|0;
    (_fwrite(($2|0),1,($6|0),($$pre|0))|0);
    _lua_settop($L,-2);
    $7 = (($i$04) + 1)|0;
    $8 = ($i$04|0)<($0|0);
    if ($8) {
     $i$04 = $7;
    } else {
     break L1;
    }
   }
   $4 = (_luaL_error($L,6544,$vararg_buffer)|0);
   $$0 = $4;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 (_fputc(10,($$pre|0))|0);
 (_fflush(($$pre|0))|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _luaB_rawequal($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 _luaL_checkany($L,2);
 $0 = (_lua_rawequal($L,1,2)|0);
 _lua_pushboolean($L,$0);
 return 1;
}
function _luaB_rawlen($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = $0 & -2;
 $2 = ($1|0)==(4);
 if (!($2)) {
  (_luaL_argerror($L,1,6512)|0);
 }
 $3 = (_lua_rawlen($L,1)|0);
 _lua_pushinteger($L,$3,0);
 return 1;
}
function _luaB_rawget($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,5);
 _luaL_checkany($L,2);
 _lua_settop($L,2);
 (_lua_rawget($L,1)|0);
 return 1;
}
function _luaB_rawset($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,5);
 _luaL_checkany($L,2);
 _luaL_checkany($L,3);
 _lua_settop($L,3);
 _lua_rawset($L,1);
 return 1;
}
function _luaB_select($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = (_lua_type($L,1)|0);
 $2 = ($1|0)==(4);
 if ($2) {
  $3 = (_lua_tolstring($L,1,0)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==(35);
  if ($5) {
   $6 = (($0) + -1)|0;
   $7 = ($6|0)<(0);
   $8 = $7 << 31 >> 31;
   _lua_pushinteger($L,$6,$8);
   $$0 = 1;
   return ($$0|0);
  }
 }
 $9 = (_luaL_checkinteger($L,1)|0);
 $10 = tempRet0;
 $11 = ($10|0)<(0);
 $12 = ($0|0)<(0);
 $13 = $12 << 31 >> 31;
 $14 = (_i64Add(($9|0),($10|0),($0|0),($13|0))|0);
 $15 = tempRet0;
 $16 = ($10|0)>($13|0);
 $17 = ($9>>>0)>($0>>>0);
 $18 = ($10|0)==($13|0);
 $19 = $18 & $17;
 $20 = $16 | $19;
 $21 = $20 ? $0 : $9;
 $22 = $20 ? $13 : $10;
 $23 = $11 ? $14 : $21;
 $24 = $11 ? $15 : $22;
 $25 = ($24|0)>(0);
 $26 = ($23>>>0)>(0);
 $27 = ($24|0)==(0);
 $28 = $27 & $26;
 $29 = $25 | $28;
 if (!($29)) {
  (_luaL_argerror($L,1,6488)|0);
 }
 $30 = (($0) - ($23))|0;
 $$0 = $30;
 return ($$0|0);
}
function _luaB_setmetatable($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_lua_type($L,2)|0);
 _luaL_checktype($L,1,5);
 if (!((($0|0) == 0) | (($0|0) == 5))) {
  (_luaL_argerror($L,2,7808)|0);
 }
 $1 = (_luaL_getmetafield($L,1,6432)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  _lua_settop($L,2);
  (_lua_setmetatable($L,1)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (_luaL_error($L,6448,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaB_tonumber($L) {
 $L = $L|0;
 var $$0$i = 0, $$01$i = 0, $$1$i = 0, $$1$i$lcssa12 = 0, $$lcssa13 = 0, $$sum$i = 0, $$sum2$i = 0, $$sum3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $isdigit$i = 0, $isdigittmp$i = 0, $l = 0, $l1 = 0, $neg$0$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp + 4|0;
 $l1 = sp;
 $0 = (_lua_type($L,2)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  _luaL_checkany($L,1);
  $2 = (_lua_type($L,1)|0);
  $3 = ($2|0)==(3);
  if ($3) {
   _lua_settop($L,1);
   STACKTOP = sp;return 1;
  }
  $4 = (_lua_tolstring($L,1,$l)|0);
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = (_lua_stringtonumber($L,$4)|0);
   $7 = HEAP32[$l>>2]|0;
   $8 = (($7) + 1)|0;
   $9 = ($6|0)==($8|0);
   if ($9) {
    STACKTOP = sp;return 1;
   }
  }
 } else {
  $10 = (_luaL_checkinteger($L,2)|0);
  $11 = tempRet0;
  _luaL_checktype($L,1,4);
  $12 = (_luaL_checklstring($L,1,$l1)|0);
  $13 = (_i64Add(($10|0),($11|0),-2,-1)|0);
  $14 = tempRet0;
  $15 = ($14>>>0)<(0);
  $16 = ($13>>>0)<(35);
  $17 = ($14|0)==(0);
  $18 = $17 & $16;
  $19 = $15 | $18;
  if (!($19)) {
   (_luaL_argerror($L,2,6400)|0);
  }
  $20 = (_strspn($12,6424)|0);
  $21 = (($12) + ($20)|0);
  $22 = HEAP8[$21>>0]|0;
  if ((($22<<24>>24) == 45)) {
   $$sum3$i = (($20) + 1)|0;
   $23 = (($12) + ($$sum3$i)|0);
   $$01$i = $23;$neg$0$i = 1;
  } else if ((($22<<24>>24) == 43)) {
   $$sum2$i = (($20) + 1)|0;
   $24 = (($12) + ($$sum2$i)|0);
   $$01$i = $24;$neg$0$i = 0;
  } else {
   $$01$i = $21;$neg$0$i = 0;
  }
  $25 = HEAP8[$$01$i>>0]|0;
  $26 = $25&255;
  $27 = (_isalnum($26)|0);
  $28 = ($27|0)==(0);
  L10: do {
   if ($28) {
    $$0$i = 0;$64 = 0;$65 = 0;
   } else {
    $29 = ($10|0)<(0);
    $30 = $29 << 31 >> 31;
    $$1$i = $$01$i;$39 = 0;$40 = 0;
    while(1) {
     $31 = HEAP8[$$1$i>>0]|0;
     $32 = $31&255;
     $isdigittmp$i = (($32) + -48)|0;
     $isdigit$i = ($isdigittmp$i>>>0)<(10);
     if ($isdigit$i) {
      $33 = $31 << 24 >> 24;
      $34 = (($33) + -48)|0;
      $38 = $34;
     } else {
      $35 = (_toupper($32)|0);
      $36 = (($35) + -55)|0;
      $38 = $36;
     }
     $37 = ($38|0)<($10|0);
     if (!($37)) {
      $$0$i = 0;$64 = 0;$65 = 0;
      break L10;
     }
     $41 = (___muldi3(($39|0),($40|0),($10|0),($30|0))|0);
     $42 = tempRet0;
     $43 = ($38|0)<(0);
     $44 = $43 << 31 >> 31;
     $45 = (_i64Add(($38|0),($44|0),($41|0),($42|0))|0);
     $46 = tempRet0;
     $47 = ((($$1$i)) + 1|0);
     $48 = HEAP8[$47>>0]|0;
     $49 = $48&255;
     $50 = (_isalnum($49)|0);
     $51 = ($50|0)==(0);
     if ($51) {
      $$1$i$lcssa12 = $$1$i;$$lcssa13 = $47;$55 = $45;$56 = $46;
      break;
     } else {
      $$1$i = $47;$39 = $45;$40 = $46;
     }
    }
    $52 = (_strspn($$lcssa13,6424)|0);
    $$sum$i = (($52) + 1)|0;
    $53 = (($$1$i$lcssa12) + ($$sum$i)|0);
    $54 = ($neg$0$i|0)!=(0);
    $57 = (_i64Subtract(0,0,($55|0),($56|0))|0);
    $58 = tempRet0;
    $59 = $54 ? $57 : $55;
    $60 = $54 ? $58 : $56;
    $$0$i = $53;$64 = $59;$65 = $60;
   }
  } while(0);
  $61 = HEAP32[$l1>>2]|0;
  $62 = (($12) + ($61)|0);
  $63 = ($$0$i|0)==($62|0);
  if ($63) {
   _lua_pushinteger($L,$64,$65);
   STACKTOP = sp;return 1;
  }
 }
 _lua_pushnil($L);
 STACKTOP = sp;return 1;
}
function _luaB_tostring($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 (_luaL_tolstring($L,1,0)|0);
 return 1;
}
function _luaB_xpcall($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $status$cmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 _luaL_checktype($L,2,6);
 _lua_pushboolean($L,1);
 _lua_pushvalue($L,1);
 _lua_rotate($L,3,2);
 $1 = (($0) + -2)|0;
 $2 = (_lua_pcallk($L,$1,-1,2,2,336)|0);
 $status$cmp$i = ($2>>>0)>(1);
 if ($status$cmp$i) {
  _lua_pushboolean($L,0);
  _lua_pushvalue($L,-2);
  $$0$i = 2;
  return ($$0$i|0);
 } else {
  $3 = (_lua_gettop($L)|0);
  $4 = (($3) + -2)|0;
  $$0$i = $4;
  return ($$0$i|0);
 }
 return (0)|0;
}
function _finishpcall($L,$status,$extra) {
 $L = $L|0;
 $status = $status|0;
 $extra = $extra|0;
 var $$0 = 0, $0 = 0, $1 = 0, $status$cmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $status$cmp = ($status>>>0)>(1);
 if ($status$cmp) {
  _lua_pushboolean($L,0);
  _lua_pushvalue($L,-2);
  $$0 = 2;
  return ($$0|0);
 } else {
  $0 = (_lua_gettop($L)|0);
  $1 = (($0) - ($extra))|0;
  $$0 = $1;
  return ($$0|0);
 }
 return (0)|0;
}
function _pairsmeta($L,$method,$iszero,$iter) {
 $L = $L|0;
 $method = $method|0;
 $iszero = $iszero|0;
 $iter = $iter|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_getmetafield($L,1,$method)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  _lua_pushvalue($L,1);
  _lua_callk($L,1,3,0,0);
  return;
 }
 _luaL_checktype($L,1,5);
 _lua_pushcclosure($L,$iter,0);
 _lua_pushvalue($L,1);
 $2 = ($iszero|0)==(0);
 if ($2) {
  _lua_pushnil($L);
  return;
 } else {
  _lua_pushinteger($L,0,0);
  return;
 }
}
function _generic_reader($L,$ud,$size) {
 $L = $L|0;
 $ud = $ud|0;
 $size = $size|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 _luaL_checkstack($L,2,6616);
 _lua_pushvalue($L,1);
 _lua_callk($L,0,1,0,0);
 $0 = (_lua_type($L,-1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  _lua_settop($L,-2);
  HEAP32[$size>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (_lua_isstring($L,-1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  (_luaL_error($L,6648,$vararg_buffer)|0);
 }
 _lua_copy($L,-1,5);
 _lua_settop($L,-2);
 $4 = (_lua_tolstring($L,5,$size)|0);
 $$0 = $4;
 STACKTOP = sp;return ($$0|0);
}
function _ipairsaux($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 $2 = (_i64Add(($0|0),($1|0),1,0)|0);
 $3 = tempRet0;
 _lua_pushinteger($L,$2,$3);
 $4 = (_lua_geti($L,1,$2,$3)|0);
 $5 = ($4|0)==(0);
 $6 = $5 ? 1 : 2;
 return ($6|0);
}
function _ipairsaux_raw($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 $2 = (_i64Add(($0|0),($1|0),1,0)|0);
 $3 = tempRet0;
 _luaL_checktype($L,1,5);
 _lua_pushinteger($L,$2,$3);
 $4 = (_lua_rawgeti($L,1,$2,$3)|0);
 $5 = ($4|0)==(0);
 $6 = $5 ? 1 : 2;
 return ($6|0);
}
function _dofilecont($L,$d1,$d2) {
 $L = $L|0;
 $d1 = $d1|0;
 $d2 = $d2|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = (($0) + -1)|0;
 return ($1|0);
}
function _luaopen_bit32($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,12);
 _luaL_setfuncs($L,6880,0);
 return 1;
}
function _b_arshift($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = ($3|0)<(0);
 $5 = $0 & -2147483648;
 $6 = ($5|0)==(0);
 $7 = (0)==(0);
 $8 = $6 & $7;
 $or$cond = $4 | $8;
 if (!($or$cond)) {
  $34 = ($3|0)>(0);
  $35 = ($2>>>0)>(31);
  $36 = ($3|0)==(0);
  $37 = $36 & $35;
  $38 = $34 | $37;
  if ($38) {
   $45 = -1;$46 = 0;
  } else {
   $39 = (_bitshift64Lshr(($0|0),($1|0),($2|0))|0);
   $40 = tempRet0;
   $41 = (_bitshift64Lshr(-1,0,($2|0))|0);
   $42 = tempRet0;
   $43 = $41 ^ -1;
   $44 = $43 | $39;
   $42 | $40;
   $45 = $44;$46 = 0;
  }
  _lua_pushinteger($L,$45,$46);
  return 1;
 }
 $9 = ($3|0)>(0);
 $10 = ($2>>>0)>(0);
 $11 = ($3|0)==(0);
 $12 = $11 & $10;
 $13 = $9 | $12;
 if ($13) {
  $14 = ($3|0)>(0);
  $15 = ($2>>>0)>(31);
  $16 = ($3|0)==(0);
  $17 = $16 & $15;
  $18 = $14 | $17;
  if ($18) {
   $32 = 0;$33 = 0;
  } else {
   $19 = (_bitshift64Lshr(($0|0),0,($2|0))|0);
   $20 = tempRet0;
   $32 = $19;$33 = $20;
  }
 } else {
  $21 = (_i64Subtract(0,0,($2|0),($3|0))|0);
  $22 = tempRet0;
  $23 = ($3|0)<(-1);
  $24 = ($2>>>0)<(4294967265);
  $25 = ($3|0)==(-1);
  $26 = $25 & $24;
  $27 = $23 | $26;
  $28 = (_bitshift64Shl(($0|0),($1|0),($21|0))|0);
  $29 = tempRet0;
  $30 = $27 ? 0 : $28;
  $31 = $27 ? 0 : 0;
  $32 = $30;$33 = $31;
 }
 _lua_pushinteger($L,$32,$33);
 return 1;
}
function _b_and($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $10 = 0;$9 = -1;
  _lua_pushinteger($L,$9,$10);
  return 1;
 } else {
  $5 = -1;$7 = -1;$i$01$i = 1;
 }
 while(1) {
  $2 = (_luaL_checkinteger($L,$i$01$i)|0);
  $3 = tempRet0;
  $4 = $2 & $5;
  $6 = $3 & $7;
  $8 = (($i$01$i) + 1)|0;
  $exitcond$i = ($i$01$i|0)==($0|0);
  if ($exitcond$i) {
   $11 = $4;$12 = $6;
   break;
  } else {
   $5 = $4;$7 = $6;$i$01$i = $8;
  }
 }
 $10 = 0;$9 = $11;
 _lua_pushinteger($L,$9,$10);
 return 1;
}
function _b_not($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = $0 ^ -1;
 _lua_pushinteger($L,$2,0);
 return 1;
}
function _b_or($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $10 = 0;$9 = 0;
  _lua_pushinteger($L,$9,$10);
  return 1;
 } else {
  $5 = 0;$7 = 0;$i$01 = 1;
 }
 while(1) {
  $2 = (_luaL_checkinteger($L,$i$01)|0);
  $3 = tempRet0;
  $4 = $2 | $5;
  $6 = $3 | $7;
  $8 = (($i$01) + 1)|0;
  $exitcond = ($i$01|0)==($0|0);
  if ($exitcond) {
   $11 = $4;$12 = $6;
   break;
  } else {
   $5 = $4;$7 = $6;$i$01 = $8;
  }
 }
 $10 = 0;$9 = $11;
 _lua_pushinteger($L,$9,$10);
 return 1;
}
function _b_xor($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $10 = 0;$9 = 0;
  _lua_pushinteger($L,$9,$10);
  return 1;
 } else {
  $5 = 0;$7 = 0;$i$01 = 1;
 }
 while(1) {
  $2 = (_luaL_checkinteger($L,$i$01)|0);
  $3 = tempRet0;
  $4 = $2 ^ $5;
  $6 = $3 ^ $7;
  $8 = (($i$01) + 1)|0;
  $exitcond = ($i$01|0)==($0|0);
  if ($exitcond) {
   $11 = $4;$12 = $6;
   break;
  } else {
   $5 = $4;$7 = $6;$i$01 = $8;
  }
 }
 $10 = 0;$9 = $11;
 _lua_pushinteger($L,$9,$10);
 return 1;
}
function _b_test($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$01$i = 0, $r$0$lcssa$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $r$0$lcssa$i = 1;
  $13 = $r$0$lcssa$i&1;
  _lua_pushboolean($L,$13);
  return 1;
 } else {
  $5 = -1;$7 = -1;$i$01$i = 1;
 }
 while(1) {
  $2 = (_luaL_checkinteger($L,$i$01$i)|0);
  $3 = tempRet0;
  $4 = $2 & $5;
  $6 = $3 & $7;
  $8 = (($i$01$i) + 1)|0;
  $exitcond$i = ($i$01$i|0)==($0|0);
  if ($exitcond$i) {
   $10 = $4;$14 = $6;
   break;
  } else {
   $5 = $4;$7 = $6;$i$01$i = $8;
  }
 }
 $9 = ($10|0)!=(0);
 $11 = (0)!=(0);
 $12 = $9 | $11;
 $r$0$lcssa$i = $12;
 $13 = $r$0$lcssa$i&1;
 _lua_pushboolean($L,$13);
 return 1;
}
function _b_extract($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = (_luaL_optinteger($L,3,1,0)|0);
 $5 = tempRet0;
 $6 = ($3|0)>(-1);
 $7 = ($2>>>0)>(4294967295);
 $8 = ($3|0)==(-1);
 $9 = $8 & $7;
 $10 = $6 | $9;
 if (!($10)) {
  (_luaL_argerror($L,2,7080)|0);
 }
 $11 = ($5|0)>(0);
 $12 = ($4>>>0)>(0);
 $13 = ($5|0)==(0);
 $14 = $13 & $12;
 $15 = $11 | $14;
 if (!($15)) {
  (_luaL_argerror($L,3,7112)|0);
 }
 $16 = (_i64Add(($4|0),($5|0),($2|0),($3|0))|0);
 $17 = tempRet0;
 $18 = ($17|0)>(0);
 $19 = ($16>>>0)>(32);
 $20 = ($17|0)==(0);
 $21 = $20 & $19;
 $22 = $18 | $21;
 if ($22) {
  (_luaL_error($L,7136,$vararg_buffer)|0);
 }
 $23 = (_bitshift64Lshr(($0|0),0,($2|0))|0);
 $24 = tempRet0;
 $25 = (($4) + -1)|0;
 $26 = (_bitshift64Shl(-2,1,($25|0))|0);
 $27 = tempRet0;
 $28 = $26 ^ -1;
 $29 = $27 ^ -1;
 $30 = $23 & $28;
 $31 = $24 & $29;
 _lua_pushinteger($L,$30,$31);
 STACKTOP = sp;return 1;
}
function _b_lrot($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,1)|0);
 $3 = tempRet0;
 $4 = $0 & 31;
 $5 = ($4|0)==(0);
 if ($5) {
  $13 = $2;$14 = 0;
  _lua_pushinteger($L,$13,0);
  return 1;
 }
 $6 = (_bitshift64Shl(($2|0),0,($4|0))|0);
 $7 = tempRet0;
 $8 = (32 - ($4))|0;
 $9 = (_bitshift64Lshr(($2|0),0,($8|0))|0);
 $10 = tempRet0;
 $11 = $9 | $6;
 $12 = $10 | $7;
 $13 = $11;$14 = $12;
 _lua_pushinteger($L,$13,0);
 return 1;
}
function _b_lshift($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = ($3|0)<(0);
 if (!($4)) {
  $14 = ($3|0)>(0);
  $15 = ($2>>>0)>(31);
  $16 = ($3|0)==(0);
  $17 = $16 & $15;
  $18 = $14 | $17;
  $19 = (_bitshift64Shl(($0|0),($1|0),($2|0))|0);
  $20 = tempRet0;
  $21 = $18 ? 0 : $19;
  $22 = $18 ? 0 : 0;
  $23 = $21;$24 = $22;
  _lua_pushinteger($L,$23,$24);
  return 1;
 }
 $5 = ($3|0)<(-1);
 $6 = ($2>>>0)<(4294967265);
 $7 = ($3|0)==(-1);
 $8 = $7 & $6;
 $9 = $5 | $8;
 if ($9) {
  $23 = 0;$24 = 0;
  _lua_pushinteger($L,$23,$24);
  return 1;
 }
 $10 = (_i64Subtract(0,0,($2|0),($3|0))|0);
 $11 = tempRet0;
 $12 = (_bitshift64Lshr(($0|0),0,($10|0))|0);
 $13 = tempRet0;
 $23 = $12;$24 = $13;
 _lua_pushinteger($L,$23,$24);
 return 1;
}
function _b_replace($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = (_luaL_checkinteger($L,3)|0);
 $5 = tempRet0;
 $6 = (_luaL_optinteger($L,4,1,0)|0);
 $7 = tempRet0;
 $8 = ($5|0)>(-1);
 $9 = ($4>>>0)>(4294967295);
 $10 = ($5|0)==(-1);
 $11 = $10 & $9;
 $12 = $8 | $11;
 if (!($12)) {
  (_luaL_argerror($L,3,7080)|0);
 }
 $13 = ($7|0)>(0);
 $14 = ($6>>>0)>(0);
 $15 = ($7|0)==(0);
 $16 = $15 & $14;
 $17 = $13 | $16;
 if (!($17)) {
  (_luaL_argerror($L,4,7112)|0);
 }
 $18 = (_i64Add(($6|0),($7|0),($4|0),($5|0))|0);
 $19 = tempRet0;
 $20 = ($19|0)>(0);
 $21 = ($18>>>0)>(32);
 $22 = ($19|0)==(0);
 $23 = $22 & $21;
 $24 = $20 | $23;
 if ($24) {
  (_luaL_error($L,7136,$vararg_buffer)|0);
 }
 $25 = (($6) + -1)|0;
 $26 = (_bitshift64Shl(-2,1,($25|0))|0);
 $27 = tempRet0;
 $28 = $26 ^ -1;
 $29 = ($28|0)<(0);
 $30 = $29 << 31 >> 31;
 $31 = $28 & $2;
 $32 = $30 & $3;
 $33 = $28 << $4;
 $34 = $33 ^ -1;
 $35 = ($34|0)<(0);
 $35 << 31 >> 31;
 $36 = $0 & $34;
 $37 = (_bitshift64Shl(($31|0),($32|0),($4|0))|0);
 $38 = tempRet0;
 $39 = $36 | $37;
 _lua_pushinteger($L,$39,$38);
 STACKTOP = sp;return 1;
}
function _b_rrot($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 $2 = (_i64Subtract(0,0,($0|0),($1|0))|0);
 $3 = tempRet0;
 $4 = (_luaL_checkinteger($L,1)|0);
 $5 = tempRet0;
 $6 = $2 & 31;
 $7 = ($6|0)==(0);
 if ($7) {
  $15 = $4;$16 = 0;
  _lua_pushinteger($L,$15,0);
  return 1;
 }
 $8 = (_bitshift64Shl(($4|0),0,($6|0))|0);
 $9 = tempRet0;
 $10 = (32 - ($6))|0;
 $11 = (_bitshift64Lshr(($4|0),0,($10|0))|0);
 $12 = tempRet0;
 $13 = $11 | $8;
 $14 = $12 | $9;
 $15 = $13;$16 = $14;
 _lua_pushinteger($L,$15,0);
 return 1;
}
function _b_rshift($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = ($3|0)>(0);
 $5 = ($2>>>0)>(0);
 $6 = ($3|0)==(0);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if (!($8)) {
  $16 = (_i64Subtract(0,0,($2|0),($3|0))|0);
  $17 = tempRet0;
  $18 = ($3|0)<(-1);
  $19 = ($2>>>0)<(4294967265);
  $20 = ($3|0)==(-1);
  $21 = $20 & $19;
  $22 = $18 | $21;
  $23 = (_bitshift64Shl(($0|0),($1|0),($16|0))|0);
  $24 = tempRet0;
  $25 = $22 ? 0 : $23;
  $26 = $22 ? 0 : 0;
  $27 = $25;$28 = $26;
  _lua_pushinteger($L,$27,$28);
  return 1;
 }
 $9 = ($3|0)>(0);
 $10 = ($2>>>0)>(31);
 $11 = ($3|0)==(0);
 $12 = $11 & $10;
 $13 = $9 | $12;
 if ($13) {
  $27 = 0;$28 = 0;
  _lua_pushinteger($L,$27,$28);
  return 1;
 }
 $14 = (_bitshift64Lshr(($0|0),0,($2|0))|0);
 $15 = tempRet0;
 $27 = $14;$28 = $15;
 _lua_pushinteger($L,$27,$28);
 return 1;
}
function _luaopen_coroutine($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,7);
 _luaL_setfuncs($L,7176,0);
 return 1;
}
function _luaB_cocreate($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,6);
 $0 = (_lua_newthread($L)|0);
 _lua_pushvalue($L,1);
 _lua_xmove($L,$0,1);
 return 1;
}
function _luaB_coresume($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_tothread($L,1)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_luaL_argerror($L,1,7400)|0);
 }
 $2 = (_lua_gettop($L)|0);
 $3 = (($2) + -1)|0;
 $4 = (_auxresume($L,$0,$3)|0);
 $5 = ($4|0)<(0);
 if ($5) {
  _lua_pushboolean($L,0);
  _lua_rotate($L,-2,1);
  $$0 = 2;
  return ($$0|0);
 } else {
  _lua_pushboolean($L,1);
  $6 = (($4) + 1)|0;
  $7 = $4 ^ -1;
  _lua_rotate($L,$7,1);
  $$0 = $6;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaB_corunning($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_pushthread($L)|0);
 _lua_pushboolean($L,$0);
 return 2;
}
function _luaB_costatus($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $ar = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ar = sp;
 $0 = (_lua_tothread($L,1)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_luaL_argerror($L,1,7400)|0);
 }
 $2 = ($0|0)==($L|0);
 if ($2) {
  (_lua_pushlstring($L,7256,7)|0);
  STACKTOP = sp;return 1;
 }
 $3 = (_lua_status($0)|0);
 if ((($3|0) == 0)) {
  $4 = (_lua_getstack($0,0,$ar)|0);
  $5 = ($4|0)>(0);
  do {
   if ($5) {
    (_lua_pushlstring($L,7432,6)|0);
   } else {
    $6 = (_lua_gettop($0)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     (_lua_pushlstring($L,7440,4)|0);
     break;
    } else {
     (_lua_pushlstring($L,7416,9)|0);
     break;
    }
   }
  } while(0);
  STACKTOP = sp;return 1;
 } else if ((($3|0) == 1)) {
  (_lua_pushlstring($L,7416,9)|0);
  STACKTOP = sp;return 1;
 } else {
  (_lua_pushlstring($L,7440,4)|0);
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function _luaB_cowrap($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,6);
 $0 = (_lua_newthread($L)|0);
 _lua_pushvalue($L,1);
 _lua_xmove($L,$0,1);
 _lua_pushcclosure($L,337,1);
 return 1;
}
function _luaB_yield($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = (_lua_yieldk($L,$0,0,0)|0);
 return ($1|0);
}
function _luaB_yieldable($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isyieldable($L)|0);
 _lua_pushboolean($L,$0);
 return 1;
}
function _luaB_auxwrap($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_tothread($L,-1001001)|0);
 $1 = (_lua_gettop($L)|0);
 $2 = (_auxresume($L,$0,$1)|0);
 $3 = ($2|0)<(0);
 if (!($3)) {
  return ($2|0);
 }
 $4 = (_lua_isstring($L,-1)|0);
 $5 = ($4|0)==(0);
 if ($5) {
  (_lua_error($L)|0);
  // unreachable;
 }
 _luaL_where($L,1);
 _lua_rotate($L,-2,1);
 _lua_concat($L,2);
 (_lua_error($L)|0);
 // unreachable;
 return (0)|0;
}
function _auxresume($L,$co,$narg) {
 $L = $L|0;
 $co = $co|0;
 $narg = $narg|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_checkstack($co,$narg)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  (_lua_pushlstring($L,7304,28)|0);
  $$0 = -1;
  return ($$0|0);
 }
 $2 = (_lua_status($co)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = (_lua_gettop($co)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   (_lua_pushlstring($L,7336,28)|0);
   $$0 = -1;
   return ($$0|0);
  }
 }
 _lua_xmove($L,$co,$narg);
 $6 = (_lua_resume($co,$L,$narg)|0);
 $7 = ($6>>>0)<(2);
 if (!($7)) {
  _lua_xmove($co,$L,1);
  $$0 = -1;
  return ($$0|0);
 }
 $8 = (_lua_gettop($co)|0);
 $9 = (($8) + 1)|0;
 $10 = (_lua_checkstack($L,$9)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = $8 ^ -1;
  _lua_settop($co,$12);
  (_lua_pushlstring($L,7368,26)|0);
  $$0 = -1;
  return ($$0|0);
 } else {
  _lua_xmove($co,$L,$8);
  $$0 = $8;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaopen_debug($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,16);
 _luaL_setfuncs($L,7448,0);
 return 1;
}
function _db_debug($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $buffer = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 256|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $buffer = sp + 4|0;
 $0 = HEAP32[_stderr>>2]|0;
 (_fwrite((8216|0),11,1,($0|0))|0);
 (_fflush(($0|0))|0);
 $1 = HEAP32[_stdin>>2]|0;
 $2 = (_fgets(($buffer|0),250,($1|0))|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 while(1) {
  $4 = (_strcmp($buffer,8232)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   label = 7;
   break;
  }
  $6 = (_strlen(($buffer|0))|0);
  $7 = (_luaL_loadbufferx($L,$buffer,$6,8240,0)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $9 = (_lua_pcallk($L,0,0,0,0,0)|0);
   $10 = ($9|0)==(0);
   if (!($10)) {
    label = 5;
   }
  } else {
   label = 5;
  }
  if ((label|0) == 5) {
   label = 0;
   $11 = (_lua_tolstring($L,-1,0)|0);
   HEAP32[$vararg_buffer>>2] = $11;
   (_fprintf(($0|0),(8264|0),($vararg_buffer|0))|0);
   (_fflush(($0|0))|0);
  }
  _lua_settop($L,0);
  (_fwrite((8216|0),11,1,($0|0))|0);
  (_fflush(($0|0))|0);
  $12 = (_fgets(($buffer|0),250,($1|0))|0);
  $13 = ($12|0)==(0|0);
  if ($13) {
   label = 7;
   break;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function _db_getuservalue($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(7);
 if ($1) {
  (_lua_getuservalue($L,1)|0);
  return 1;
 } else {
  _lua_pushnil($L);
  return 1;
 }
 return (0)|0;
}
function _db_gethook($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $buff = 0, $i$0$i = 0, $i$1$i = 0, $i$2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buff = sp;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;
 } else {
  $$0$i = $L;
 }
 $3 = (_lua_gethookmask($$0$i)|0);
 $4 = (_lua_gethook($$0$i)|0);
 $5 = ($4|0)==(0|0);
 do {
  if ($5) {
   _lua_pushnil($L);
  } else {
   $6 = ($4|0)==(338|0);
   if ($6) {
    (_lua_rawgetp($L,-1001000,7856)|0);
    (_lua_pushthread($$0$i)|0);
    _lua_xmove($$0$i,$L,1);
    (_lua_rawget($L,-2)|0);
    _lua_rotate($L,-2,-1);
    _lua_settop($L,-2);
    break;
   } else {
    (_lua_pushlstring($L,8200,13)|0);
    break;
   }
  }
 } while(0);
 $7 = $3 & 1;
 $8 = ($7|0)==(0);
 if ($8) {
  $i$0$i = 0;
 } else {
  HEAP8[$buff>>0] = 99;
  $i$0$i = 1;
 }
 $9 = $3 & 2;
 $10 = ($9|0)==(0);
 if ($10) {
  $i$1$i = $i$0$i;
 } else {
  $11 = (($i$0$i) + 1)|0;
  $12 = (($buff) + ($i$0$i)|0);
  HEAP8[$12>>0] = 114;
  $i$1$i = $11;
 }
 $13 = $3 & 4;
 $14 = ($13|0)==(0);
 if ($14) {
  $i$2$i = $i$1$i;
 } else {
  $15 = (($i$1$i) + 1)|0;
  $16 = (($buff) + ($i$1$i)|0);
  HEAP8[$16>>0] = 108;
  $i$2$i = $15;
 }
 $17 = (($buff) + ($i$2$i)|0);
 HEAP8[$17>>0] = 0;
 (_lua_pushstring($L,$buff)|0);
 $18 = (_lua_gethookcount($$0$i)|0);
 $19 = ($18|0)<(0);
 $20 = $19 << 31 >> 31;
 _lua_pushinteger($L,$18,$20);
 STACKTOP = sp;return 3;
}
function _db_getinfo($L) {
 $L = $L|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $ar = 0, $options$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ar = sp + 4|0;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;$4 = 1;
 } else {
  $$0$i = $L;$4 = 0;
 }
 $3 = $4 | 2;
 $5 = (_luaL_optlstring($L,$3,7992,0)|0);
 $6 = (($4) + 1)|0;
 $7 = (_lua_type($L,$6)|0);
 $8 = ($7|0)==(6);
 if ($8) {
  HEAP32[$vararg_buffer>>2] = $5;
  $9 = (_lua_pushfstring($L,8000,$vararg_buffer)|0);
  _lua_pushvalue($L,$6);
  _lua_xmove($L,$$0$i,1);
  $options$0 = $9;
 } else {
  $10 = (_luaL_checkinteger($L,$6)|0);
  $11 = tempRet0;
  $12 = (_lua_getstack($$0$i,$10,$ar)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   _lua_pushnil($L);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $options$0 = $5;
  }
 }
 $14 = (_lua_getinfo($$0$i,$options$0,$ar)|0);
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = (_luaL_argerror($L,$3,8008)|0);
  $$0 = $16;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_createtable($L,0,0);
 $17 = (_strchr($options$0,83)|0);
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $19 = ((($ar)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  (_lua_pushstring($L,$20)|0);
  _lua_setfield($L,-2,8024);
  $21 = ((($ar)) + 36|0);
  (_lua_pushstring($L,$21)|0);
  _lua_setfield($L,-2,8032);
  $22 = ((($ar)) + 24|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)<(0);
  $25 = $24 << 31 >> 31;
  _lua_pushinteger($L,$23,$25);
  _lua_setfield($L,-2,8048);
  $26 = ((($ar)) + 28|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)<(0);
  $29 = $28 << 31 >> 31;
  _lua_pushinteger($L,$27,$29);
  _lua_setfield($L,-2,8064);
  $30 = ((($ar)) + 12|0);
  $31 = HEAP32[$30>>2]|0;
  (_lua_pushstring($L,$31)|0);
  _lua_setfield($L,-2,8080);
 }
 $32 = (_strchr($options$0,108)|0);
 $33 = ($32|0)==(0|0);
 if (!($33)) {
  $34 = ((($ar)) + 20|0);
  $35 = HEAP32[$34>>2]|0;
  $36 = ($35|0)<(0);
  $37 = $36 << 31 >> 31;
  _lua_pushinteger($L,$35,$37);
  _lua_setfield($L,-2,8088);
 }
 $38 = (_strchr($options$0,117)|0);
 $39 = ($38|0)==(0|0);
 if (!($39)) {
  $40 = ((($ar)) + 32|0);
  $41 = HEAP8[$40>>0]|0;
  $42 = $41&255;
  _lua_pushinteger($L,$42,0);
  _lua_setfield($L,-2,8104);
  $43 = ((($ar)) + 33|0);
  $44 = HEAP8[$43>>0]|0;
  $45 = $44&255;
  _lua_pushinteger($L,$45,0);
  _lua_setfield($L,-2,8112);
  $46 = ((($ar)) + 34|0);
  $47 = HEAP8[$46>>0]|0;
  $48 = $47 << 24 >> 24;
  _lua_pushboolean($L,$48);
  _lua_setfield($L,-2,8120);
 }
 $49 = (_strchr($options$0,110)|0);
 $50 = ($49|0)==(0|0);
 if (!($50)) {
  $51 = ((($ar)) + 4|0);
  $52 = HEAP32[$51>>2]|0;
  (_lua_pushstring($L,$52)|0);
  _lua_setfield($L,-2,8136);
  $53 = ((($ar)) + 8|0);
  $54 = HEAP32[$53>>2]|0;
  (_lua_pushstring($L,$54)|0);
  _lua_setfield($L,-2,8144);
 }
 $55 = (_strchr($options$0,116)|0);
 $56 = ($55|0)==(0|0);
 if (!($56)) {
  $57 = ((($ar)) + 35|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58 << 24 >> 24;
  _lua_pushboolean($L,$59);
  _lua_setfield($L,-2,8160);
 }
 $60 = (_strchr($options$0,76)|0);
 $61 = ($60|0)==(0|0);
 if (!($61)) {
  $62 = ($$0$i|0)==($L|0);
  if ($62) {
   _lua_rotate($L,-2,1);
  } else {
   _lua_xmove($$0$i,$L,1);
  }
  _lua_setfield($L,-2,8176);
 }
 $63 = (_strchr($options$0,102)|0);
 $64 = ($63|0)==(0|0);
 if ($64) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $65 = ($$0$i|0)==($L|0);
 if ($65) {
  _lua_rotate($L,-2,1);
 } else {
  _lua_xmove($$0$i,$L,1);
 }
 _lua_setfield($L,-2,8192);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _db_getlocal($L) {
 $L = $L|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ar = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ar = sp;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;$4 = 1;
 } else {
  $$0$i = $L;$4 = 0;
 }
 $3 = $4 | 2;
 $5 = (_luaL_checkinteger($L,$3)|0);
 $6 = tempRet0;
 $7 = (($4) + 1)|0;
 $8 = (_lua_type($L,$7)|0);
 $9 = ($8|0)==(6);
 if ($9) {
  _lua_pushvalue($L,$7);
  $10 = (_lua_getlocal($L,0,$5)|0);
  (_lua_pushstring($L,$10)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (_luaL_checkinteger($L,$7)|0);
 $12 = tempRet0;
 $13 = (_lua_getstack($$0$i,$11,$ar)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  $15 = (_luaL_argerror($L,$7,7832)|0);
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 $16 = (_lua_getlocal($$0$i,$ar,$5)|0);
 $17 = ($16|0)==(0|0);
 if ($17) {
  _lua_pushnil($L);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  _lua_xmove($$0$i,$L,1);
  (_lua_pushstring($L,$16)|0);
  _lua_rotate($L,-2,1);
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _db_getregistry($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _lua_pushvalue($L,-1001000);
 return 1;
}
function _db_getmetatable($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 $0 = (_lua_getmetatable($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  return 1;
 }
 _lua_pushnil($L);
 return 1;
}
function _db_getupvalue($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 _luaL_checktype($L,1,6);
 $2 = (_lua_getupvalue($L,1,$0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 (_lua_pushstring($L,$2)|0);
 _lua_rotate($L,-2,1);
 $$0$i = 2;
 return ($$0$i|0);
}
function _db_upvaluejoin($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 _luaL_checktype($L,1,6);
 $2 = (_lua_getupvalue($L,1,$0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_argerror($L,2,7944)|0);
 }
 $4 = (_luaL_checkinteger($L,4)|0);
 $5 = tempRet0;
 _luaL_checktype($L,3,6);
 $6 = (_lua_getupvalue($L,3,$4)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  (_luaL_argerror($L,4,7944)|0);
 }
 $8 = (_lua_iscfunction($L,1)|0);
 $9 = ($8|0)==(0);
 if (!($9)) {
  (_luaL_argerror($L,1,7968)|0);
 }
 $10 = (_lua_iscfunction($L,3)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  _lua_upvaluejoin($L,1,$0,3,$4);
  return 0;
 }
 (_luaL_argerror($L,3,7968)|0);
 _lua_upvaluejoin($L,1,$0,3,$4);
 return 0;
}
function _db_upvalueid($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 _luaL_checktype($L,1,6);
 $2 = (_lua_getupvalue($L,1,$0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_argerror($L,2,7944)|0);
 }
 $4 = (_lua_upvalueid($L,1,$0)|0);
 _lua_pushlightuserdata($L,$4);
 return 1;
}
function _db_setuservalue($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checktype($L,1,7);
 _luaL_checkany($L,2);
 _lua_settop($L,2);
 _lua_setuservalue($L,1);
 return 1;
}
function _db_sethook($L) {
 $L = $L|0;
 var $$$i = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $count$0 = 0, $func$0 = 0, $mask$0 = 0, $mask$1$$i = 0, $mask$1$i = 0, $mask$3$i = 0, $not$$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;$4 = 1;
 } else {
  $$0$i = $L;$4 = 0;
 }
 $3 = (($4) + 1)|0;
 $5 = (_lua_type($L,$3)|0);
 $6 = ($5|0)<(1);
 if ($6) {
  _lua_settop($L,$3);
  $count$0 = 0;$func$0 = 0;$mask$0 = 0;
 } else {
  $7 = $4 | 2;
  $8 = (_luaL_checklstring($L,$7,0)|0);
  _luaL_checktype($L,$3,6);
  $9 = (($4) + 3)|0;
  $10 = (_luaL_optinteger($L,$9,0,0)|0);
  $11 = tempRet0;
  $12 = (_strchr($8,99)|0);
  $not$$i = ($12|0)!=(0|0);
  $$$i = $not$$i&1;
  $13 = (_strchr($8,114)|0);
  $14 = ($13|0)==(0|0);
  $15 = $$$i | 2;
  $mask$1$i = $14 ? $$$i : $15;
  $16 = (_strchr($8,108)|0);
  $17 = ($16|0)==(0|0);
  $18 = $mask$1$i | 4;
  $mask$1$$i = $17 ? $mask$1$i : $18;
  $19 = ($10|0)>(0);
  $20 = $mask$1$$i | 8;
  $mask$3$i = $19 ? $20 : $mask$1$$i;
  $count$0 = $10;$func$0 = 338;$mask$0 = $mask$3$i;
 }
 $21 = (_lua_rawgetp($L,-1001000,7856)|0);
 $22 = ($21|0)==(0);
 if (!($22)) {
  (_lua_pushthread($$0$i)|0);
  _lua_xmove($$0$i,$L,1);
  _lua_pushvalue($L,$3);
  _lua_rawset($L,-3);
  _lua_sethook($$0$i,$func$0,$mask$0,$count$0);
  return 0;
 }
 _lua_createtable($L,0,2);
 _lua_pushvalue($L,-1);
 _lua_rawsetp($L,-1001000,7856);
 (_lua_pushstring($L,7864)|0);
 _lua_setfield($L,-2,7872);
 _lua_pushvalue($L,-1);
 (_lua_setmetatable($L,-2)|0);
 (_lua_pushthread($$0$i)|0);
 _lua_xmove($$0$i,$L,1);
 _lua_pushvalue($L,$3);
 _lua_rawset($L,-3);
 _lua_sethook($$0$i,$func$0,$mask$0,$count$0);
 return 0;
}
function _db_setlocal($L) {
 $L = $L|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ar = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ar = sp;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;$4 = 1;
 } else {
  $$0$i = $L;$4 = 0;
 }
 $3 = (($4) + 1)|0;
 $5 = (_luaL_checkinteger($L,$3)|0);
 $6 = tempRet0;
 $7 = $4 | 2;
 $8 = (_luaL_checkinteger($L,$7)|0);
 $9 = tempRet0;
 $10 = (_lua_getstack($$0$i,$5,$ar)|0);
 $11 = ($10|0)==(0);
 if ($11) {
  $12 = (_luaL_argerror($L,$3,7832)|0);
  $$0 = $12;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($4) + 3)|0;
 _luaL_checkany($L,$13);
 _lua_settop($L,$13);
 _lua_xmove($L,$$0$i,1);
 $14 = (_lua_setlocal($$0$i,$ar,$8)|0);
 $15 = ($14|0)==(0|0);
 if ($15) {
  _lua_settop($$0$i,-2);
 }
 (_lua_pushstring($L,$14)|0);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _db_setmetatable($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,2)|0);
 if (!((($0|0) == 0) | (($0|0) == 5))) {
  (_luaL_argerror($L,2,7808)|0);
 }
 _lua_settop($L,2);
 (_lua_setmetatable($L,1)|0);
 return 1;
}
function _db_setupvalue($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,3);
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 _luaL_checktype($L,1,6);
 $2 = (_lua_setupvalue($L,1,$0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0$i = 0;
  return ($$0$i|0);
 }
 (_lua_pushstring($L,$2)|0);
 _lua_rotate($L,-1,1);
 $$0$i = 1;
 return ($$0$i|0);
}
function _db_traceback($L) {
 $L = $L|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(8);
 if ($1) {
  $2 = (_lua_tothread($L,1)|0);
  $$0$i = $2;$4 = 1;
 } else {
  $$0$i = $L;$4 = 0;
 }
 $3 = (($4) + 1)|0;
 $5 = (_lua_tolstring($L,$3,0)|0);
 $6 = ($5|0)==(0|0);
 if ($6) {
  $7 = (_lua_type($L,$3)|0);
  $8 = ($7|0)<(1);
  if (!($8)) {
   _lua_pushvalue($L,$3);
   return 1;
  }
 }
 $9 = $4 | 2;
 $10 = ($$0$i|0)==($L|0);
 $11 = $10&1;
 $12 = (_luaL_optinteger($L,$9,$11,0)|0);
 $13 = tempRet0;
 _luaL_traceback($L,$$0$i,$5,$12);
 return 1;
}
function _hookf($L,$ar) {
 $L = $L|0;
 $ar = $ar|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_lua_rawgetp($L,-1001000,7856)|0);
 (_lua_pushthread($L)|0);
 $0 = (_lua_rawget($L,-2)|0);
 $1 = ($0|0)==(6);
 if (!($1)) {
  return;
 }
 $2 = HEAP32[$ar>>2]|0;
 $3 = (7880 + ($2<<2)|0);
 $4 = HEAP32[$3>>2]|0;
 (_lua_pushstring($L,$4)|0);
 $5 = ((($ar)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  $8 = ($6|0)<(0);
  $9 = $8 << 31 >> 31;
  _lua_pushinteger($L,$6,$9);
 } else {
  _lua_pushnil($L);
 }
 _lua_callk($L,2,0,0,0);
 return;
}
function _luaopen_io($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,11);
 _luaL_setfuncs($L,8272,0);
 (_luaL_newmetatable($L,8368)|0);
 _lua_pushvalue($L,-1);
 _lua_setfield($L,-2,11928);
 _luaL_setfuncs($L,8376,0);
 _lua_settop($L,-2);
 $0 = HEAP32[_stdin>>2]|0;
 $1 = (_lua_newuserdata($L,8)|0);
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 _luaL_setmetatable($L,8368);
 HEAP32[$1>>2] = $0;
 HEAP32[$2>>2] = 339;
 _lua_pushvalue($L,-1);
 _lua_setfield($L,-1001000,8456);
 _lua_setfield($L,-2,8472);
 $3 = HEAP32[_stdout>>2]|0;
 $4 = (_lua_newuserdata($L,8)|0);
 $5 = ((($4)) + 4|0);
 HEAP32[$5>>2] = 0;
 _luaL_setmetatable($L,8368);
 HEAP32[$4>>2] = $3;
 HEAP32[$5>>2] = 339;
 _lua_pushvalue($L,-1);
 _lua_setfield($L,-1001000,8480);
 _lua_setfield($L,-2,8496);
 $6 = HEAP32[_stderr>>2]|0;
 $7 = (_lua_newuserdata($L,8)|0);
 $8 = ((($7)) + 4|0);
 HEAP32[$8>>2] = 0;
 _luaL_setmetatable($L,8368);
 HEAP32[$7>>2] = $6;
 HEAP32[$8>>2] = 339;
 _lua_setfield($L,-2,8504);
 return 1;
}
function _io_noclose($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 339;
 _lua_pushnil($L);
 (_lua_pushlstring($L,8512,26)|0);
 return 2;
}
function _io_close($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cf$sroa$0$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $cf$sroa$0$i = sp + 4|0;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(-1);
 if ($1) {
  (_lua_getfield($L,-1001000,8480)|0);
 }
 $2 = (_luaL_checkudata($L,1,8368)|0);
 $3 = ((($2)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $6 = (_luaL_checkudata($L,1,8368)|0);
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$cf$sroa$0$i>>2] = $8;
 HEAP32[$7>>2] = 0;
 $9 = HEAP32[$cf$sroa$0$i>>2]|0;
 $10 = $9;
 $11 = (FUNCTION_TABLE_ii[$10 & 511]($L)|0);
 STACKTOP = sp;return ($11|0);
}
function _f_flush($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_fflush(($4|0))|0);
 $6 = ($5|0)==(0);
 $7 = $6&1;
 $8 = (_luaL_fileresult($L,$7,0)|0);
 STACKTOP = sp;return ($8|0);
}
function _f_lines($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = (_lua_gettop($L)|0);
 $5 = (($4) + -1)|0;
 $6 = ($5|0)<(0);
 $7 = $6 << 31 >> 31;
 _lua_pushinteger($L,$5,$7);
 _lua_pushboolean($L,0);
 _lua_rotate($L,2,2);
 $8 = (($4) + 2)|0;
 _lua_pushcclosure($L,340,$8);
 STACKTOP = sp;return 1;
}
function _f_read($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_g_read($L,$4,2)|0);
 STACKTOP = sp;return ($5|0);
}
function _f_seek($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_luaL_checkoption($L,2,8744,8752)|0);
 $6 = (_luaL_optinteger($L,3,0,0)|0);
 $7 = tempRet0;
 $8 = ($6|0)<(0);
 $9 = $8 << 31 >> 31;
 $10 = ($6|0)==($6|0);
 $11 = ($9|0)==($7|0);
 $12 = $10 & $11;
 if (!($12)) {
  (_luaL_argerror($L,3,8768)|0);
 }
 $13 = (8800 + ($5<<2)|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (_fseek(($4|0),($6|0),($14|0))|0);
 $16 = ($15|0)==(0);
 if ($16) {
  $18 = (_ftell(($4|0))|0);
  $19 = ($18|0)<(0);
  $20 = $19 << 31 >> 31;
  _lua_pushinteger($L,$18,$20);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $17 = (_luaL_fileresult($L,0,0)|0);
  $$0 = $17;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _f_setvbuf($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_luaL_checkoption($L,2,0,8696)|0);
 $6 = (_luaL_optinteger($L,3,4096,0)|0);
 $7 = tempRet0;
 $8 = (8712 + ($5<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = (_setvbuf(($4|0),(0|0),($9|0),($6|0))|0);
 $11 = ($10|0)==(0);
 $12 = $11&1;
 $13 = (_luaL_fileresult($L,$12,0)|0);
 STACKTOP = sp;return ($13|0);
}
function _f_write($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_luaL_error($L,8648,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 _lua_pushvalue($L,1);
 $5 = (_g_write($L,$4,2)|0);
 STACKTOP = sp;return ($5|0);
}
function _f_gc($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cf$sroa$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $cf$sroa$0$i = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  STACKTOP = sp;return 0;
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  STACKTOP = sp;return 0;
 }
 $6 = (_luaL_checkudata($L,1,8368)|0);
 $7 = ((($6)) + 4|0);
 $8 = HEAP32[$7>>2]|0;
 HEAP32[$cf$sroa$0$i>>2] = $8;
 HEAP32[$7>>2] = 0;
 $9 = HEAP32[$cf$sroa$0$i>>2]|0;
 $10 = $9;
 (FUNCTION_TABLE_ii[$10 & 511]($L)|0);
 STACKTOP = sp;return 0;
}
function _f_tostring($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  (_lua_pushlstring($L,8616,13)|0);
  STACKTOP = sp;return 1;
 } else {
  $4 = HEAP32[$0>>2]|0;
  HEAP32[$vararg_buffer>>2] = $4;
  (_lua_pushfstring($L,8632,$vararg_buffer)|0);
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function _g_write($L,$f,$arg) {
 $L = $L|0;
 $f = $f|0;
 $arg = $arg|0;
 var $$0 = 0, $$013 = 0, $$in = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0.0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l = 0, $status$02 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $l = sp + 16|0;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)==($arg|0);
 if ($1) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = (($0) - ($arg))|0;
 $$013 = $arg;$$in = $2;$status$02 = 1;
 while(1) {
  $3 = (($$in) + -1)|0;
  $4 = (_lua_type($L,$$013)|0);
  $5 = ($4|0)==(3);
  if ($5) {
   $6 = (_lua_isinteger($L,$$013)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    $15 = (+_lua_tonumberx($L,$$013,0));
    HEAPF64[$vararg_buffer1>>3] = $15;
    $16 = (_fprintf(($f|0),(8688|0),($vararg_buffer1|0))|0);
    $19 = $16;
   } else {
    $8 = (_lua_tointegerx($L,$$013,0)|0);
    $9 = tempRet0;
    $10 = $vararg_buffer;
    $11 = $10;
    HEAP32[$11>>2] = $8;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP32[$13>>2] = $9;
    $14 = (_fprintf(($f|0),(8680|0),($vararg_buffer|0))|0);
    $19 = $14;
   }
   $17 = ($status$02|0)!=(0);
   $18 = ($19|0)>(0);
   $20 = $17 & $18;
   $$sink = $20;
  } else {
   $21 = (_luaL_checklstring($L,$$013,$l)|0);
   $22 = ($status$02|0)==(0);
   if ($22) {
    $$sink = 0;
   } else {
    $23 = HEAP32[$l>>2]|0;
    $24 = (_fwrite(($21|0),1,($23|0),($f|0))|0);
    $25 = HEAP32[$l>>2]|0;
    $26 = ($24|0)==($25|0);
    $$sink = $26;
   }
  }
  $27 = $$sink&1;
  $28 = (($$013) + 1)|0;
  $29 = ($3|0)==(0);
  if ($29) {
   break;
  } else {
   $$013 = $28;$$in = $3;$status$02 = $27;
  }
 }
 if ($$sink) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $30 = (_luaL_fileresult($L,0,0)|0);
 $$0 = $30;
 STACKTOP = sp;return ($$0|0);
}
function _g_read($L,$f,$first) {
 $L = $L|0;
 $f = $f|0;
 $first = $first|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $$lcssa = 0, $$lcssa242 = 0, $$lcssa243 = 0, $$lcssa244 = 0, $$lcssa273 = 0, $$lcssa275 = 0, $$pre$i = 0, $$pre$i13 = 0, $$pre83$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $b$i = 0, $b$i1 = 0, $b$i15 = 0, $b$i2 = 0, $b$i8 = 0, $c$0$i = 0, $c$0$i$lcssa = 0, $c$0$i3 = 0, $c$0$i3$lcssa = 0, $c$0$i9 = 0, $count$0$i1663$i = 0, $count$0$i71$i63 = 0, $count$0$lcssa2$i$i = 0, $count$0$lcssa2$i18$i = 0, $count$0$ph$i = 0, $count$0$us$i1261$i = 0, $count$0$us$i68$i66 = 0, $count$03$i$i = 0, $count$03$i20$i = 0, $count$038$i = 0;
 var $count$039$i = 0, $count$1$i = 0, $hex$041$i = 0, $hex$042$i = 0, $i$0$lcssa$i = 0, $i$0$lcssa$i11 = 0, $i$0$lcssa$i5 = 0, $i$05$i = 0, $i$05$i10 = 0, $i$05$i4 = 0, $isdigit$us$i$i = 0, $isdigit$us$i14$i = 0, $isdigit$us$i1460$i = 0, $isdigit$us$i32$i = 0, $isdigit$us$i3258$i = 0, $isdigit$us$i67$i = 0, $isdigittmp$us$i$i = 0, $isdigittmp$us$i13$i = 0, $isdigittmp$us$i1359$i = 0, $isdigittmp$us$i31$i = 0;
 var $isdigittmp$us$i3157$i = 0, $isdigittmp$us$i66$i = 0, $n$070 = 0, $n$070$lcssa = 0, $n$1 = 0, $or$cond$i22$i = 0, $rn$i = 0, $success$1 = 0, $success$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 20784|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $b$i15 = sp + 16664|0;
 $b$i8 = sp + 12552|0;
 $b$i2 = sp + 8440|0;
 $rn$i = sp + 8224|0;
 $b$i1 = sp + 4112|0;
 $b$i = sp;
 $0 = (_lua_gettop($L)|0);
 _clearerr(($f|0));
 $1 = ($0|0)==(1);
 L1: do {
  if ($1) {
   _luaL_buffinit($L,$b$i);
   $2 = ((($b$i)) + 8|0);
   $c$0$i = 0;
   while(1) {
    if ((($c$0$i|0) == 10) | (($c$0$i|0) == -1)) {
     $c$0$i$lcssa = $c$0$i;
     break;
    }
    $3 = (_luaL_prepbuffsize($b$i,4096)|0);
    $i$05$i = 0;
    while(1) {
     $4 = (_getc(($f|0))|0);
     if ((($4|0) == 10) | (($4|0) == -1)) {
      $$lcssa = $4;$i$0$lcssa$i = $i$05$i;
      break;
     }
     $5 = $4&255;
     $6 = (($i$05$i) + 1)|0;
     $7 = (($3) + ($i$05$i)|0);
     HEAP8[$7>>0] = $5;
     $8 = ($6|0)<(4096);
     if ($8) {
      $i$05$i = $6;
     } else {
      $$lcssa = $4;$i$0$lcssa$i = $6;
      break;
     }
    }
    $9 = HEAP32[$2>>2]|0;
    $10 = (($9) + ($i$0$lcssa$i))|0;
    HEAP32[$2>>2] = $10;
    $c$0$i = $$lcssa;
   }
   $11 = ($c$0$i$lcssa|0)==(10);
   _luaL_pushresult($b$i);
   if ($11) {
    $15 = 1;
   } else {
    $12 = (_lua_rawlen($L,-1)|0);
    $13 = ($12|0)!=(0);
    $15 = $13;
   }
   $14 = $15&1;
   $16 = (($first) + 1)|0;
   $n$1 = $16;$success$2 = $14;
  } else {
   $17 = (($0) + 19)|0;
   _luaL_checkstack($L,$17,8824);
   $18 = (($0) + -2)|0;
   $19 = ((($b$i1)) + 8|0);
   $20 = ((($rn$i)) + 8|0);
   $21 = ((($rn$i)) + 4|0);
   $22 = ((($rn$i)) + 12|0);
   $23 = ((($b$i2)) + 8|0);
   $24 = ((($b$i8)) + 8|0);
   $25 = ((($b$i8)) + 4|0);
   $26 = ((($b$i15)) + 8|0);
   $205 = $18;$n$070 = $first;
   L3: while(1) {
    $27 = (_lua_type($L,$n$070)|0);
    $28 = ($27|0)==(3);
    do {
     if ($28) {
      $29 = (_luaL_checkinteger($L,$n$070)|0);
      $30 = tempRet0;
      $31 = ($29|0)==(0);
      if ($31) {
       $32 = (_getc(($f|0))|0);
       (_ungetc(($32|0),($f|0))|0);
       (_lua_pushlstring($L,0,0)|0);
       $33 = ($32|0)!=(-1);
       $34 = $33&1;
       $success$1 = $34;
       break;
      } else {
       _luaL_buffinit($L,$b$i1);
       $35 = (_luaL_prepbuffsize($b$i1,$29)|0);
       $36 = (_fread(($35|0),1,($29|0),($f|0))|0);
       $37 = HEAP32[$19>>2]|0;
       $38 = (($37) + ($36))|0;
       HEAP32[$19>>2] = $38;
       _luaL_pushresult($b$i1);
       $39 = ($36|0)!=(0);
       $40 = $39&1;
       $success$1 = $40;
       break;
      }
     } else {
      $41 = (_luaL_checklstring($L,$n$070,0)|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = ($42<<24>>24)==(42);
      $44 = ((($41)) + 1|0);
      $$ = $43 ? $44 : $41;
      $45 = HEAP8[$$>>0]|0;
      $46 = $45 << 24 >> 24;
      if ((($46|0) == 110)) {
       HEAP32[$rn$i>>2] = $f;
       HEAP32[$20>>2] = 0;
       $47 = (_localeconv()|0);
       $48 = HEAP32[$47>>2]|0;
       $49 = HEAP8[$48>>0]|0;
       while(1) {
        $50 = (_getc(($f|0))|0);
        $51 = (_isspace($50)|0);
        $52 = ($51|0)==(0);
        if ($52) {
         $$lcssa244 = $50;
         break;
        }
       }
       HEAP32[$21>>2] = $$lcssa244;
       if ((($$lcssa244|0) == 43) | (($$lcssa244|0) == 45)) {
        $53 = $$lcssa244&255;
        HEAP32[$20>>2] = 1;
        HEAP8[$22>>0] = $53;
        $54 = (_getc(($f|0))|0);
        HEAP32[$21>>2] = $54;
        $56 = $54;$58 = 1;
       } else {
        $56 = $$lcssa244;$58 = 0;
       }
       $55 = ($56|0)==(48);
       L19: do {
        if ($55) {
         $57 = (($58) + 1)|0;
         HEAP32[$20>>2] = $57;
         $59 = (((($rn$i)) + 12|0) + ($58)|0);
         HEAP8[$59>>0] = 48;
         $60 = (_getc(($f|0))|0);
         HEAP32[$21>>2] = $60;
         if ((($60|0) == 88) | (($60|0) == 120)) {
          $61 = $60&255;
          $62 = $58 | 2;
          HEAP32[$20>>2] = $62;
          $63 = (((($rn$i)) + 12|0) + ($57)|0);
          HEAP8[$63>>0] = $61;
          $64 = (_getc(($f|0))|0);
          HEAP32[$21>>2] = $64;
          $65 = (_isxdigit($64)|0);
          $66 = ($65|0)==(0);
          if ($66) {
           $214 = $f;$215 = 0;$93 = $64;$count$03$i$i = 0;$count$039$i = 0;$hex$042$i = 1;
          } else {
           $80 = $64;$82 = $62;$count$0$i71$i63 = 0;
           while(1) {
            $79 = $80&255;
            $81 = (($82) + 1)|0;
            HEAP32[$20>>2] = $81;
            $83 = (((($rn$i)) + 12|0) + ($82)|0);
            HEAP8[$83>>0] = $79;
            $84 = HEAP32[$rn$i>>2]|0;
            $85 = (_getc(($84|0))|0);
            HEAP32[$21>>2] = $85;
            $86 = (($count$0$i71$i63) + 1)|0;
            $87 = (_isxdigit($85)|0);
            $88 = ($87|0)==(0);
            if ($88) {
             $214 = $84;$215 = 0;$93 = $85;$count$03$i$i = $86;$count$039$i = 0;$hex$042$i = 1;
             break L19;
            }
            $$pre$i = HEAP32[$20>>2]|0;
            $89 = ($$pre$i|0)>(199);
            if ($89) {
             $216 = $84;$217 = $85;$218 = 0;$count$0$lcssa2$i$i = $86;$count$038$i = 0;$hex$041$i = 1;
             label = 28;
             break;
            } else {
             $80 = $85;$82 = $$pre$i;$count$0$i71$i63 = $86;
            }
           }
          }
         } else {
          $67 = $60;$69 = $57;$count$0$ph$i = 1;
          label = 24;
         }
        } else {
         $67 = $56;$69 = $58;$count$0$ph$i = 0;
         label = 24;
        }
       } while(0);
       L25: do {
        if ((label|0) == 24) {
         label = 0;
         $isdigittmp$us$i66$i = (($67) + -48)|0;
         $isdigit$us$i67$i = ($isdigittmp$us$i66$i>>>0)<(10);
         if ($isdigit$us$i67$i) {
          $68 = ($69|0)>(199);
          if ($68) {
           $216 = $f;$217 = $67;$218 = 1;$count$0$lcssa2$i$i = 0;$count$038$i = $count$0$ph$i;$hex$041$i = 0;
           label = 28;
          } else {
           $71 = $67;$73 = $69;$count$0$us$i68$i66 = 0;
           while(1) {
            $70 = $71&255;
            $72 = (($73) + 1)|0;
            HEAP32[$20>>2] = $72;
            $74 = (((($rn$i)) + 12|0) + ($73)|0);
            HEAP8[$74>>0] = $70;
            $75 = HEAP32[$rn$i>>2]|0;
            $76 = (_getc(($75|0))|0);
            HEAP32[$21>>2] = $76;
            $77 = (($count$0$us$i68$i66) + 1)|0;
            $isdigittmp$us$i$i = (($76) + -48)|0;
            $isdigit$us$i$i = ($isdigittmp$us$i$i>>>0)<(10);
            if (!($isdigit$us$i$i)) {
             $214 = $75;$215 = 1;$93 = $76;$count$03$i$i = $77;$count$039$i = $count$0$ph$i;$hex$042$i = 0;
             break L25;
            }
            $$pre83$i = HEAP32[$20>>2]|0;
            $78 = ($$pre83$i|0)>(199);
            if ($78) {
             $216 = $75;$217 = $76;$218 = 1;$count$0$lcssa2$i$i = $77;$count$038$i = $count$0$ph$i;$hex$041$i = 0;
             label = 28;
             break;
            } else {
             $71 = $76;$73 = $$pre83$i;$count$0$us$i68$i66 = $77;
            }
           }
          }
         } else {
          $214 = $f;$215 = 1;$93 = $67;$count$03$i$i = 0;$count$039$i = $count$0$ph$i;$hex$042$i = 0;
         }
        }
       } while(0);
       if ((label|0) == 28) {
        label = 0;
        HEAP8[$22>>0] = 0;
        $214 = $216;$215 = $218;$93 = $217;$count$03$i$i = $count$0$lcssa2$i$i;$count$039$i = $count$038$i;$hex$042$i = $hex$041$i;
       }
       $90 = (($count$03$i$i) + ($count$039$i))|0;
       $91 = $49 << 24 >> 24;
       $92 = ($93|0)==($91|0);
       do {
        if ($92) {
         $94 = HEAP32[$20>>2]|0;
         $95 = ($94|0)>(199);
         if ($95) {
          HEAP8[$22>>0] = 0;
          $130 = $93;$219 = $214;$count$1$i = $90;
          break;
         }
         $96 = $93&255;
         $97 = (($94) + 1)|0;
         HEAP32[$20>>2] = $97;
         $98 = (((($rn$i)) + 12|0) + ($94)|0);
         HEAP8[$98>>0] = $96;
         $99 = HEAP32[$rn$i>>2]|0;
         $100 = (_getc(($99|0))|0);
         HEAP32[$21>>2] = $100;
         L39: do {
          if ($215) {
           $isdigittmp$us$i1359$i = (($100) + -48)|0;
           $isdigit$us$i1460$i = ($isdigittmp$us$i1359$i>>>0)<(10);
           if ($isdigit$us$i1460$i) {
            $106 = $100;$223 = $99;$count$0$us$i1261$i = 0;
            while(1) {
             $103 = HEAP32[$20>>2]|0;
             $104 = ($103|0)>(199);
             if ($104) {
              $224 = $223;$225 = $106;$count$0$lcssa2$i18$i = $count$0$us$i1261$i;
              label = 40;
              break L39;
             }
             $105 = $106&255;
             $107 = (($103) + 1)|0;
             HEAP32[$20>>2] = $107;
             $108 = (((($rn$i)) + 12|0) + ($103)|0);
             HEAP8[$108>>0] = $105;
             $109 = HEAP32[$rn$i>>2]|0;
             $110 = (_getc(($109|0))|0);
             HEAP32[$21>>2] = $110;
             $111 = (($count$0$us$i1261$i) + 1)|0;
             $isdigittmp$us$i13$i = (($110) + -48)|0;
             $isdigit$us$i14$i = ($isdigittmp$us$i13$i>>>0)<(10);
             if ($isdigit$us$i14$i) {
              $106 = $110;$223 = $109;$count$0$us$i1261$i = $111;
             } else {
              $220 = $109;$221 = $110;$count$03$i20$i = $111;
              break;
             }
            }
           } else {
            $220 = $99;$221 = $100;$count$03$i20$i = 0;
           }
          } else {
           $101 = (_isxdigit($100)|0);
           $102 = ($101|0)==(0);
           if ($102) {
            $220 = $99;$221 = $100;$count$03$i20$i = 0;
           } else {
            $115 = $100;$222 = $99;$count$0$i1663$i = 0;
            while(1) {
             $112 = HEAP32[$20>>2]|0;
             $113 = ($112|0)>(199);
             if ($113) {
              $224 = $222;$225 = $115;$count$0$lcssa2$i18$i = $count$0$i1663$i;
              label = 40;
              break L39;
             }
             $114 = $115&255;
             $116 = (($112) + 1)|0;
             HEAP32[$20>>2] = $116;
             $117 = (((($rn$i)) + 12|0) + ($112)|0);
             HEAP8[$117>>0] = $114;
             $118 = HEAP32[$rn$i>>2]|0;
             $119 = (_getc(($118|0))|0);
             HEAP32[$21>>2] = $119;
             $120 = (($count$0$i1663$i) + 1)|0;
             $121 = (_isxdigit($119)|0);
             $122 = ($121|0)==(0);
             if ($122) {
              $220 = $118;$221 = $119;$count$03$i20$i = $120;
              break;
             } else {
              $115 = $119;$222 = $118;$count$0$i1663$i = $120;
             }
            }
           }
          }
         } while(0);
         if ((label|0) == 40) {
          label = 0;
          HEAP8[$22>>0] = 0;
          $220 = $224;$221 = $225;$count$03$i20$i = $count$0$lcssa2$i18$i;
         }
         $123 = (($count$03$i20$i) + ($90))|0;
         $130 = $221;$219 = $220;$count$1$i = $123;
        } else {
         $130 = $93;$219 = $214;$count$1$i = $90;
        }
       } while(0);
       $124 = ($count$1$i|0)>(0);
       L52: do {
        if ($124) {
         $125 = ($hex$042$i|0)!=(0);
         $126 = $125 ? 8848 : 8856;
         $127 = HEAP8[$126>>0]|0;
         $128 = $127 << 24 >> 24;
         $129 = ($130|0)==($128|0);
         if (!($129)) {
          $131 = ((($126)) + 1|0);
          $132 = HEAP8[$131>>0]|0;
          $133 = $132 << 24 >> 24;
          $134 = ($130|0)!=($133|0);
          $135 = ($130|0)==(0);
          $or$cond$i22$i = $135 | $134;
          if ($or$cond$i22$i) {
           $159 = $130;$160 = $219;
           break;
          }
         }
         $136 = HEAP32[$20>>2]|0;
         $137 = ($136|0)>(199);
         if ($137) {
          HEAP8[$22>>0] = 0;
          $159 = $130;$160 = $219;
          break;
         }
         $138 = $130&255;
         $139 = (($136) + 1)|0;
         HEAP32[$20>>2] = $139;
         $140 = (((($rn$i)) + 12|0) + ($136)|0);
         HEAP8[$140>>0] = $138;
         $141 = HEAP32[$rn$i>>2]|0;
         $142 = (_getc(($141|0))|0);
         HEAP32[$21>>2] = $142;
         do {
          if ((($142|0) == 43) | (($142|0) == 45)) {
           $143 = HEAP32[$20>>2]|0;
           $144 = ($143|0)>(199);
           if ($144) {
            HEAP8[$22>>0] = 0;
            $150 = $142;$226 = $141;
            break;
           } else {
            $145 = $142&255;
            $146 = (($143) + 1)|0;
            HEAP32[$20>>2] = $146;
            $147 = (((($rn$i)) + 12|0) + ($143)|0);
            HEAP8[$147>>0] = $145;
            $148 = HEAP32[$rn$i>>2]|0;
            $149 = (_getc(($148|0))|0);
            HEAP32[$21>>2] = $149;
            $150 = $149;$226 = $148;
            break;
           }
          } else {
           $150 = $142;$226 = $141;
          }
         } while(0);
         $isdigittmp$us$i3157$i = (($150) + -48)|0;
         $isdigit$us$i3258$i = ($isdigittmp$us$i3157$i>>>0)<(10);
         if ($isdigit$us$i3258$i) {
          $154 = $150;$227 = $226;
          while(1) {
           $151 = HEAP32[$20>>2]|0;
           $152 = ($151|0)>(199);
           if ($152) {
            $$lcssa273 = $227;$$lcssa275 = $154;
            break;
           }
           $153 = $154&255;
           $155 = (($151) + 1)|0;
           HEAP32[$20>>2] = $155;
           $156 = (((($rn$i)) + 12|0) + ($151)|0);
           HEAP8[$156>>0] = $153;
           $157 = HEAP32[$rn$i>>2]|0;
           $158 = (_getc(($157|0))|0);
           HEAP32[$21>>2] = $158;
           $isdigittmp$us$i31$i = (($158) + -48)|0;
           $isdigit$us$i32$i = ($isdigittmp$us$i31$i>>>0)<(10);
           if ($isdigit$us$i32$i) {
            $154 = $158;$227 = $157;
           } else {
            $159 = $158;$160 = $157;
            break L52;
           }
          }
          HEAP8[$22>>0] = 0;
          $159 = $$lcssa275;$160 = $$lcssa273;
         } else {
          $159 = $150;$160 = $226;
         }
        } else {
         $159 = $130;$160 = $219;
        }
       } while(0);
       (_ungetc(($159|0),($160|0))|0);
       $161 = HEAP32[$20>>2]|0;
       $162 = (((($rn$i)) + 12|0) + ($161)|0);
       HEAP8[$162>>0] = 0;
       $163 = (_lua_stringtonumber($L,$22)|0);
       $164 = ($163|0)==(0);
       if ($164) {
        _lua_pushnil($L);
        $$0$i = 0;
       } else {
        $$0$i = 1;
       }
       $success$1 = $$0$i;
       break;
      } else if ((($46|0) == 97)) {
       _luaL_buffinit($L,$b$i15);
       while(1) {
        $197 = (_luaL_prepbuffsize($b$i15,4096)|0);
        $198 = (_fread(($197|0),1,4096,($f|0))|0);
        $199 = HEAP32[$26>>2]|0;
        $200 = (($199) + ($198))|0;
        HEAP32[$26>>2] = $200;
        $201 = ($198|0)==(4096);
        if (!($201)) {
         break;
        }
       }
       _luaL_pushresult($b$i15);
       $success$1 = 1;
       break;
      } else if ((($46|0) == 108)) {
       _luaL_buffinit($L,$b$i2);
       $c$0$i3 = 0;
       while(1) {
        if ((($c$0$i3|0) == 10) | (($c$0$i3|0) == -1)) {
         $c$0$i3$lcssa = $c$0$i3;
         break;
        }
        $165 = (_luaL_prepbuffsize($b$i2,4096)|0);
        $i$05$i4 = 0;
        while(1) {
         $166 = (_getc(($f|0))|0);
         if ((($166|0) == 10) | (($166|0) == -1)) {
          $$lcssa243 = $166;$i$0$lcssa$i5 = $i$05$i4;
          break;
         }
         $167 = $166&255;
         $168 = (($i$05$i4) + 1)|0;
         $169 = (($165) + ($i$05$i4)|0);
         HEAP8[$169>>0] = $167;
         $170 = ($168|0)<(4096);
         if ($170) {
          $i$05$i4 = $168;
         } else {
          $$lcssa243 = $166;$i$0$lcssa$i5 = $168;
          break;
         }
        }
        $171 = HEAP32[$23>>2]|0;
        $172 = (($171) + ($i$0$lcssa$i5))|0;
        HEAP32[$23>>2] = $172;
        $c$0$i3 = $$lcssa243;
       }
       $173 = ($c$0$i3$lcssa|0)==(10);
       _luaL_pushresult($b$i2);
       if ($173) {
        $177 = 1;
       } else {
        $174 = (_lua_rawlen($L,-1)|0);
        $175 = ($174|0)!=(0);
        $177 = $175;
       }
       $176 = $177&1;
       $success$1 = $176;
       break;
      } else if ((($46|0) == 76)) {
       _luaL_buffinit($L,$b$i8);
       $c$0$i9 = 0;
       while(1) {
        if ((($c$0$i9|0) == -1)) {
         label = 77;
         break;
        } else if ((($c$0$i9|0) == 10)) {
         label = 74;
         break;
        }
        $178 = (_luaL_prepbuffsize($b$i8,4096)|0);
        $i$05$i10 = 0;
        while(1) {
         $179 = (_getc(($f|0))|0);
         if ((($179|0) == 10) | (($179|0) == -1)) {
          $$lcssa242 = $179;$i$0$lcssa$i11 = $i$05$i10;
          break;
         }
         $180 = $179&255;
         $181 = (($i$05$i10) + 1)|0;
         $182 = (($178) + ($i$05$i10)|0);
         HEAP8[$182>>0] = $180;
         $183 = ($181|0)<(4096);
         if ($183) {
          $i$05$i10 = $181;
         } else {
          $$lcssa242 = $179;$i$0$lcssa$i11 = $181;
          break;
         }
        }
        $184 = HEAP32[$24>>2]|0;
        $185 = (($184) + ($i$0$lcssa$i11))|0;
        HEAP32[$24>>2] = $185;
        $c$0$i9 = $$lcssa242;
       }
       if ((label|0) == 74) {
        label = 0;
        $186 = HEAP32[$24>>2]|0;
        $187 = HEAP32[$25>>2]|0;
        $188 = ($186>>>0)<($187>>>0);
        if ($188) {
         $190 = $186;
        } else {
         (_luaL_prepbuffsize($b$i8,1)|0);
         $$pre$i13 = HEAP32[$24>>2]|0;
         $190 = $$pre$i13;
        }
        $189 = (($190) + 1)|0;
        HEAP32[$24>>2] = $189;
        $191 = HEAP32[$b$i8>>2]|0;
        $192 = (($191) + ($190)|0);
        HEAP8[$192>>0] = 10;
        _luaL_pushresult($b$i8);
        $196 = 1;
       }
       else if ((label|0) == 77) {
        label = 0;
        _luaL_pushresult($b$i8);
        $193 = (_lua_rawlen($L,-1)|0);
        $194 = ($193|0)!=(0);
        $196 = $194;
       }
       $195 = $196&1;
       $success$1 = $195;
       break;
      } else {
       $n$070$lcssa = $n$070;
       break L3;
      }
     }
    } while(0);
    $203 = (($n$070) + 1)|0;
    $204 = (($205) + -1)|0;
    $206 = ($205|0)!=(0);
    $207 = ($success$1|0)!=(0);
    $208 = $206 & $207;
    if ($208) {
     $205 = $204;$n$070 = $203;
    } else {
     $n$1 = $203;$success$2 = $success$1;
     break L1;
    }
   }
   $202 = (_luaL_argerror($L,$n$070$lcssa,8864)|0);
   $$0 = $202;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $209 = (_ferror(($f|0))|0);
 $210 = ($209|0)==(0);
 if (!($210)) {
  $211 = (_luaL_fileresult($L,0,0)|0);
  $$0 = $211;
  STACKTOP = sp;return ($$0|0);
 }
 $212 = ($success$2|0)==(0);
 if ($212) {
  _lua_settop($L,-2);
  _lua_pushnil($L);
 }
 $213 = (($n$1) - ($first))|0;
 $$0 = $213;
 STACKTOP = sp;return ($$0|0);
}
function _io_readline($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cf$sroa$0$i = 0, $exitcond = 0, $i$01 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $cf$sroa$0$i = sp + 12|0;
 $0 = (_lua_touserdata($L,-1001001)|0);
 $1 = (_lua_tointegerx($L,-1001002,0)|0);
 $2 = tempRet0;
 $3 = ((($0)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = (_luaL_error($L,8880,$vararg_buffer)|0);
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_settop($L,1);
 _luaL_checkstack($L,$1,8824);
 $7 = ($1|0)<(1);
 if (!($7)) {
  $i$01 = 1;
  while(1) {
   $8 = (-1001003 - ($i$01))|0;
   _lua_pushvalue($L,$8);
   $9 = (($i$01) + 1)|0;
   $exitcond = ($i$01|0)==($1|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $9;
   }
  }
 }
 $10 = HEAP32[$0>>2]|0;
 $11 = (_g_read($L,$10,2)|0);
 $12 = (0 - ($11))|0;
 $13 = (_lua_toboolean($L,$12)|0);
 $14 = ($13|0)==(0);
 if (!($14)) {
  $$0 = $11;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = ($11|0)>(1);
 if ($15) {
  $16 = (1 - ($11))|0;
  $17 = (_lua_tolstring($L,$16,0)|0);
  HEAP32[$vararg_buffer1>>2] = $17;
  $18 = (_luaL_error($L,34480,$vararg_buffer1)|0);
  $$0 = $18;
  STACKTOP = sp;return ($$0|0);
 }
 $19 = (_lua_toboolean($L,-1001003)|0);
 $20 = ($19|0)==(0);
 if ($20) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _lua_settop($L,0);
 _lua_pushvalue($L,-1001001);
 $21 = (_luaL_checkudata($L,1,8368)|0);
 $22 = ((($21)) + 4|0);
 $23 = HEAP32[$22>>2]|0;
 HEAP32[$cf$sroa$0$i>>2] = $23;
 HEAP32[$22>>2] = 0;
 $24 = HEAP32[$cf$sroa$0$i>>2]|0;
 $25 = $24;
 (FUNCTION_TABLE_ii[$25 & 511]($L)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _io_flush($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 (_lua_getfield($L,-1001000,8480)|0);
 $0 = (_lua_touserdata($L,-1)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = (8484);
  (_luaL_error($L,8944,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_fflush(($4|0))|0);
 $6 = ($5|0)==(0);
 $7 = $6&1;
 $8 = (_luaL_fileresult($L,$7,0)|0);
 STACKTOP = sp;return ($8|0);
}
function _io_input($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _g_iofile($L,8456,13328);
 return 1;
}
function _io_lines($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $toclose$0 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(-1);
 if ($1) {
  _lua_pushnil($L);
 }
 $2 = (_lua_type($L,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  (_lua_getfield($L,-1001000,8456)|0);
  _lua_copy($L,-1,1);
  _lua_settop($L,-2);
  $4 = (_luaL_checkudata($L,1,8368)|0);
  $5 = ((($4)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  if ($7) {
   (_luaL_error($L,8648,$vararg_buffer)|0);
   $toclose$0 = 0;
  } else {
   $toclose$0 = 0;
  }
 } else {
  $8 = (_luaL_checklstring($L,1,0)|0);
  $9 = (_lua_newuserdata($L,8)|0);
  $10 = ((($9)) + 4|0);
  HEAP32[$10>>2] = 0;
  _luaL_setmetatable($L,8368);
  HEAP32[$9>>2] = 0;
  HEAP32[$10>>2] = 341;
  $11 = (_fopen(($8|0),(13328|0))|0);
  HEAP32[$9>>2] = $11;
  $12 = ($11|0)==(0|0);
  if ($12) {
   $13 = (___errno_location()|0);
   $14 = HEAP32[$13>>2]|0;
   $15 = (_strerror(($14|0))|0);
   HEAP32[$vararg_buffer1>>2] = $8;
   $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr3>>2] = $15;
   (_luaL_error($L,9032,$vararg_buffer1)|0);
  }
  _lua_copy($L,-1,1);
  _lua_settop($L,-2);
  $toclose$0 = 1;
 }
 $16 = (_lua_gettop($L)|0);
 $17 = (($16) + -1)|0;
 $18 = ($17|0)<(0);
 $19 = $18 << 31 >> 31;
 _lua_pushinteger($L,$17,$19);
 _lua_pushboolean($L,$toclose$0);
 _lua_rotate($L,2,2);
 $20 = (($16) + 2)|0;
 _lua_pushcclosure($L,340,$20);
 STACKTOP = sp;return 1;
}
function _io_open($L) {
 $L = $L|0;
 var $$ = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $md$1 = 0, $memchr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_luaL_optlstring($L,2,13328,0)|0);
 $2 = (_lua_newuserdata($L,8)|0);
 $3 = ((($2)) + 4|0);
 HEAP32[$3>>2] = 0;
 _luaL_setmetatable($L,8368);
 HEAP32[$2>>2] = 0;
 HEAP32[$3>>2] = 341;
 $4 = HEAP8[$1>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  label = 4;
 } else {
  $6 = $4 << 24 >> 24;
  $7 = ((($1)) + 1|0);
  $memchr = (_memchr(9064,$6,4)|0);
  $8 = ($memchr|0)==(0|0);
  if ($8) {
   label = 4;
  } else {
   $9 = HEAP8[$7>>0]|0;
   $10 = ($9<<24>>24)==(43);
   $11 = ((($1)) + 2|0);
   $$ = $10 ? 3 : 2;
   $$1 = $10 ? $11 : $7;
   $12 = HEAP8[$$1>>0]|0;
   $13 = ($12<<24>>24)==(98);
   $14 = (($1) + ($$)|0);
   $md$1 = $13 ? $14 : $$1;
   $15 = HEAP8[$md$1>>0]|0;
   $16 = ($15<<24>>24)==(0);
   if (!($16)) {
    label = 4;
   }
  }
 }
 if ((label|0) == 4) {
  (_luaL_argerror($L,2,9072)|0);
 }
 $17 = (_fopen(($0|0),($1|0))|0);
 HEAP32[$2>>2] = $17;
 $18 = ($17|0)==(0|0);
 if (!($18)) {
  $20 = 1;
  return ($20|0);
 }
 $19 = (_luaL_fileresult($L,0,$0)|0);
 $20 = $19;
 return ($20|0);
}
function _io_output($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _g_iofile($L,8480,9024);
 return 1;
}
function _io_popen($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 (_luaL_optlstring($L,2,13328,0)|0);
 $1 = (_lua_newuserdata($L,8)|0);
 $2 = ((($1)) + 4|0);
 HEAP32[$2>>2] = 0;
 _luaL_setmetatable($L,8368);
 (_luaL_error($L,9000,$vararg_buffer)|0);
 HEAP32[$1>>2] = 0;
 HEAP32[$2>>2] = 342;
 $3 = (_luaL_fileresult($L,0,$0)|0);
 STACKTOP = sp;return ($3|0);
}
function _io_read($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 (_lua_getfield($L,-1001000,8456)|0);
 $0 = (_lua_touserdata($L,-1)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = (8460);
  (_luaL_error($L,8944,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_g_read($L,$4,1)|0);
 STACKTOP = sp;return ($5|0);
}
function _io_tmpfile($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_newuserdata($L,8)|0);
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 0;
 _luaL_setmetatable($L,8368);
 HEAP32[$0>>2] = 0;
 HEAP32[$1>>2] = 341;
 $2 = (_tmpfile()|0);
 HEAP32[$0>>2] = $2;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $5 = 1;
  return ($5|0);
 }
 $4 = (_luaL_fileresult($L,0,0)|0);
 $5 = $4;
 return ($5|0);
}
function _io_type($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkany($L,1);
 $0 = (_luaL_testudata($L,1,8368)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  _lua_pushnil($L);
  return 1;
 }
 $2 = ((($0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_lua_pushlstring($L,8976,11)|0);
  return 1;
 } else {
  (_lua_pushlstring($L,8992,4)|0);
  return 1;
 }
 return (0)|0;
}
function _io_write($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 (_lua_getfield($L,-1001000,8480)|0);
 $0 = (_lua_touserdata($L,-1)|0);
 $1 = ((($0)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[$vararg_buffer>>2] = (8484);
  (_luaL_error($L,8944,$vararg_buffer)|0);
 }
 $4 = HEAP32[$0>>2]|0;
 $5 = (_g_write($L,$4,1)|0);
 STACKTOP = sp;return ($5|0);
}
function _io_fclose($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkudata($L,1,8368)|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = (_fclose(($1|0))|0);
 $3 = ($2|0)==(0);
 $4 = $3&1;
 $5 = (_luaL_fileresult($L,$4,0)|0);
 return ($5|0);
}
function _io_pclose($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_luaL_checkudata($L,1,8368)|0);
 $0 = (_luaL_execresult($L,-1)|0);
 return ($0|0);
}
function _g_iofile($L,$f,$mode) {
 $L = $L|0;
 $f = $f|0;
 $mode = $mode|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  (_lua_getfield($L,-1001000,$f)|0);
  STACKTOP = sp;return;
 }
 $2 = (_lua_tolstring($L,1,0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $11 = (_luaL_checkudata($L,1,8368)|0);
  $12 = ((($11)) + 4|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   (_luaL_error($L,8648,$vararg_buffer2)|0);
  }
  _lua_pushvalue($L,1);
 } else {
  $4 = (_lua_newuserdata($L,8)|0);
  $5 = ((($4)) + 4|0);
  HEAP32[$5>>2] = 0;
  _luaL_setmetatable($L,8368);
  HEAP32[$4>>2] = 0;
  HEAP32[$5>>2] = 341;
  $6 = (_fopen(($2|0),($mode|0))|0);
  HEAP32[$4>>2] = $6;
  $7 = ($6|0)==(0|0);
  if ($7) {
   $8 = (___errno_location()|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (_strerror(($9|0))|0);
   HEAP32[$vararg_buffer>>2] = $2;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $10;
   (_luaL_error($L,9032,$vararg_buffer)|0);
  }
 }
 _lua_setfield($L,-1001000,$f);
 (_lua_getfield($L,-1001000,$f)|0);
 STACKTOP = sp;return;
}
function _luaopen_math($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,35);
 _luaL_setfuncs($L,9088,0);
 _lua_pushnumber($L,3.1415926535897931);
 _lua_setfield($L,-2,37016);
 _lua_pushnumber($L,inf);
 _lua_setfield($L,-2,9376);
 _lua_pushinteger($L,-1,2147483647);
 _lua_setfield($L,-2,9384);
 _lua_pushinteger($L,0,-2147483648);
 _lua_setfield($L,-2,9400);
 return 1;
}
function _math_abs($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isinteger($L,1)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $9 = (+_luaL_checknumber($L,1));
  $10 = (+Math_abs((+$9)));
  _lua_pushnumber($L,$10);
  return 1;
 } else {
  $2 = (_lua_tointegerx($L,1,0)|0);
  $3 = tempRet0;
  $4 = ($3|0)<(0);
  $5 = (_i64Subtract(0,0,($2|0),($3|0))|0);
  $6 = tempRet0;
  $7 = $4 ? $5 : $2;
  $8 = $4 ? $6 : $3;
  _lua_pushinteger($L,$7,$8);
  return 1;
 }
 return (0)|0;
}
function _math_acos($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_acos((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_asin($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_asin((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_atan($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_luaL_optnumber($L,2,1.0));
 $2 = (+Math_atan2((+$0),(+$1)));
 _lua_pushnumber($L,$2);
 return 1;
}
function _math_ceil($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isinteger($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  _lua_settop($L,1);
  return 1;
 }
 $2 = (+_luaL_checknumber($L,1));
 $3 = (+Math_ceil((+$2)));
 $4 = $3 >= -9.2233720368547758E+18;
 $5 = $3 < 9.2233720368547758E+18;
 $or$cond$i = $4 & $5;
 if ($or$cond$i) {
  $6 = (~~$3)>>>0;
  $7 = +Math_abs($3) >= 1.0 ? $3 > 0.0 ? (~~+Math_min(+Math_floor($3 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($3 - +(~~$3 >>> 0)) / 4294967296.0) >>> 0 : 0;
  _lua_pushinteger($L,$6,$7);
  return 1;
 } else {
  _lua_pushnumber($L,$3);
  return 1;
 }
 return (0)|0;
}
function _math_cos($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_cos((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_deg($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = $0 * 57.295779513082323;
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_exp($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_exp((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_toint($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $valid = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $valid = sp;
 $0 = (_lua_tointegerx($L,1,$valid)|0);
 $1 = tempRet0;
 $2 = HEAP32[$valid>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  _luaL_checkany($L,1);
  _lua_pushnil($L);
  STACKTOP = sp;return 1;
 } else {
  _lua_pushinteger($L,$0,$1);
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function _math_floor($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isinteger($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  _lua_settop($L,1);
  return 1;
 }
 $2 = (+_luaL_checknumber($L,1));
 $3 = (+Math_floor((+$2)));
 $4 = $3 >= -9.2233720368547758E+18;
 $5 = $3 < 9.2233720368547758E+18;
 $or$cond$i = $4 & $5;
 if ($or$cond$i) {
  $6 = (~~$3)>>>0;
  $7 = +Math_abs($3) >= 1.0 ? $3 > 0.0 ? (~~+Math_min(+Math_floor($3 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($3 - +(~~$3 >>> 0)) / 4294967296.0) >>> 0 : 0;
  _lua_pushinteger($L,$6,$7);
  return 1;
 } else {
  _lua_pushnumber($L,$3);
  return 1;
 }
 return (0)|0;
}
function _math_fmod($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isinteger($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (_lua_isinteger($L,2)|0);
  $3 = ($2|0)==(0);
  if (!($3)) {
   $4 = (_lua_tointegerx($L,2,0)|0);
   $5 = tempRet0;
   $6 = (_i64Add(($4|0),($5|0),1,0)|0);
   $7 = tempRet0;
   $8 = ($7>>>0)<(0);
   $9 = ($6>>>0)<(2);
   $10 = ($7|0)==(0);
   $11 = $10 & $9;
   $12 = $8 | $11;
   if (!($12)) {
    $16 = (_lua_tointegerx($L,1,0)|0);
    $17 = tempRet0;
    $18 = (___remdi3(($16|0),($17|0),($4|0),($5|0))|0);
    $19 = tempRet0;
    _lua_pushinteger($L,$18,$19);
    return 1;
   }
   $13 = ($4|0)==(0);
   $14 = ($5|0)==(0);
   $15 = $13 & $14;
   if ($15) {
    (_luaL_argerror($L,2,9784)|0);
   }
   _lua_pushinteger($L,0,0);
   return 1;
  }
 }
 $20 = (+_luaL_checknumber($L,1));
 $21 = (+_luaL_checknumber($L,2));
 $22 = (+_fmod($20,$21));
 _lua_pushnumber($L,$22);
 return 1;
}
function _math_ult($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = ($1>>>0)<($3>>>0);
 $5 = ($0>>>0)<($2>>>0);
 $6 = ($1|0)==($3|0);
 $7 = $6 & $5;
 $8 = $4 | $7;
 $9 = $8&1;
 _lua_pushboolean($L,$9);
 return 1;
}
function _math_log($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0.0, $4 = 0.0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $res$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (_lua_type($L,2)|0);
 $2 = ($1|0)<(1);
 do {
  if ($2) {
   $3 = (+Math_log((+$0)));
   $res$0 = $3;
  } else {
   $4 = (+_luaL_checknumber($L,2));
   $5 = $4 == 10.0;
   if ($5) {
    $6 = (+_log10($0));
    $res$0 = $6;
    break;
   } else {
    $7 = (+Math_log((+$0)));
    $8 = (+Math_log((+$4)));
    $9 = $7 / $8;
    $res$0 = $9;
    break;
   }
  }
 } while(0);
 _lua_pushnumber($L,$res$0);
 return 1;
}
function _math_max($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $exitcond = 0, $i$02 = 0, $imax$0$i$0 = 0, $imax$0$lcssa = 0, $imax$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)>(0);
 if ($1) {
  $2 = ($0|0)<(2);
  if ($2) {
   $imax$0$lcssa = 1;
  } else {
   $i$02 = 2;$imax$01 = 1;
   while(1) {
    $3 = (_lua_compare($L,$imax$01,$i$02,1)|0);
    $4 = ($3|0)==(0);
    $imax$0$i$0 = $4 ? $imax$01 : $i$02;
    $5 = (($i$02) + 1)|0;
    $exitcond = ($i$02|0)==($0|0);
    if ($exitcond) {
     $imax$0$lcssa = $imax$0$i$0;
     break;
    } else {
     $i$02 = $5;$imax$01 = $imax$0$i$0;
    }
   }
  }
 } else {
  (_luaL_argerror($L,1,9768)|0);
  $imax$0$lcssa = 1;
 }
 _lua_pushvalue($L,$imax$0$lcssa);
 return 1;
}
function _math_min($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $exitcond = 0, $i$02 = 0, $imin$0$i$0 = 0, $imin$0$lcssa = 0, $imin$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)>(0);
 if ($1) {
  $2 = ($0|0)<(2);
  if ($2) {
   $imin$0$lcssa = 1;
  } else {
   $i$02 = 2;$imin$01 = 1;
   while(1) {
    $3 = (_lua_compare($L,$i$02,$imin$01,1)|0);
    $4 = ($3|0)==(0);
    $imin$0$i$0 = $4 ? $imin$01 : $i$02;
    $5 = (($i$02) + 1)|0;
    $exitcond = ($i$02|0)==($0|0);
    if ($exitcond) {
     $imin$0$lcssa = $imin$0$i$0;
     break;
    } else {
     $i$02 = $5;$imin$01 = $imin$0$i$0;
    }
   }
  }
 } else {
  (_luaL_argerror($L,1,9768)|0);
  $imin$0$lcssa = 1;
 }
 _lua_pushvalue($L,$imin$0$lcssa);
 return 1;
}
function _math_modf($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0.0, $13 = 0.0, $2 = 0.0, $3 = 0, $4 = 0.0, $5 = 0.0, $6 = 0, $7 = 0.0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_isinteger($L,1)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  _lua_settop($L,1);
  _lua_pushnumber($L,0.0);
  return 2;
 }
 $2 = (+_luaL_checknumber($L,1));
 $3 = $2 < 0.0;
 if ($3) {
  $4 = (+Math_ceil((+$2)));
  $7 = $4;
 } else {
  $5 = (+Math_floor((+$2)));
  $7 = $5;
 }
 $6 = $7 >= -9.2233720368547758E+18;
 $8 = $7 < 9.2233720368547758E+18;
 $or$cond$i = $6 & $8;
 if ($or$cond$i) {
  $9 = (~~$7)>>>0;
  $10 = +Math_abs($7) >= 1.0 ? $7 > 0.0 ? (~~+Math_min(+Math_floor($7 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($7 - +(~~$7 >>> 0)) / 4294967296.0) >>> 0 : 0;
  _lua_pushinteger($L,$9,$10);
 } else {
  _lua_pushnumber($L,$7);
 }
 $11 = $2 == $7;
 $12 = $2 - $7;
 $13 = $11 ? 0.0 : $12;
 _lua_pushnumber($L,$13);
 return 2;
}
function _math_rad($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = $0 * 0.017453292519943295;
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_random($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0.0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_rand()|0);
 $1 = (+($0|0));
 $2 = $1 * 4.6566128730773926E-10;
 $3 = (_lua_gettop($L)|0);
 if ((($3|0) == 1)) {
  $4 = (_luaL_checkinteger($L,1)|0);
  $5 = tempRet0;
  $12 = $5;$13 = 0;$15 = $4;$16 = 1;
 } else if ((($3|0) == 0)) {
  _lua_pushnumber($L,$2);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($3|0) == 2)) {
  $6 = (_luaL_checkinteger($L,1)|0);
  $7 = tempRet0;
  $8 = (_luaL_checkinteger($L,2)|0);
  $9 = tempRet0;
  $12 = $9;$13 = $7;$15 = $8;$16 = $6;
 } else {
  $10 = (_luaL_error($L,9688,$vararg_buffer)|0);
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ($12|0)<($13|0);
 $14 = ($15>>>0)<($16>>>0);
 $17 = ($12|0)==($13|0);
 $18 = $17 & $14;
 $19 = $11 | $18;
 if ($19) {
  (_luaL_argerror($L,1,9720)|0);
 }
 $20 = ($13|0)<(0);
 $21 = (_i64Add(($16|0),($13|0),-1,2147483647)|0);
 $22 = tempRet0;
 $23 = ($12|0)>($22|0);
 $24 = ($15>>>0)>($21>>>0);
 $25 = ($12|0)==($22|0);
 $26 = $25 & $24;
 $27 = $23 | $26;
 $or$cond = $20 & $27;
 if ($or$cond) {
  (_luaL_argerror($L,1,9744)|0);
 }
 $28 = (_i64Subtract(($15|0),($12|0),($16|0),($13|0))|0);
 $29 = tempRet0;
 $30 = (+($28>>>0)) + (4294967296.0*(+($29|0)));
 $31 = $30 + 1.0;
 $32 = $2 * $31;
 $33 = (~~$32)>>>0;
 $34 = +Math_abs($32) >= 1.0 ? $32 > 0.0 ? (~~+Math_min(+Math_floor($32 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($32 - +(~~$32 >>> 0)) / 4294967296.0) >>> 0 : 0;
 $35 = (_i64Add(($33|0),($34|0),($16|0),($13|0))|0);
 $36 = tempRet0;
 _lua_pushinteger($L,$35,$36);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _math_randomseed($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (~~$0)>>>0;
 $2 = +Math_abs($0) >= 1.0 ? $0 > 0.0 ? (~~+Math_min(+Math_floor($0 / 4294967296.0), 4294967295.0)) >>> 0 : ~~+Math_ceil(($0 - +(~~$0 >>> 0)) / 4294967296.0) >>> 0 : 0;
 _srand($1);
 (_rand()|0);
 return 0;
}
function _math_sin($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_sin((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_sqrt($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_sqrt((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_tan($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+Math_tan((+$0)));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_type($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(3);
 if (!($1)) {
  _luaL_checkany($L,1);
  _lua_pushnil($L);
  return 1;
 }
 $2 = (_lua_isinteger($L,1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  (_lua_pushlstring($L,9680,5)|0);
  return 1;
 } else {
  (_lua_pushlstring($L,9672,7)|0);
  return 1;
 }
 return (0)|0;
}
function _math_cosh($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_cosh($0));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_sinh($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_sinh($0));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_tanh($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_tanh($0));
 _lua_pushnumber($L,$1);
 return 1;
}
function _math_pow($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_luaL_checknumber($L,2));
 $2 = (+Math_pow((+$0),(+$1)));
 _lua_pushnumber($L,$2);
 return 1;
}
function _math_frexp($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, $2 = 0, $3 = 0, $4 = 0, $e = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $e = sp;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_frexp($0,$e));
 _lua_pushnumber($L,$1);
 $2 = HEAP32[$e>>2]|0;
 $3 = ($2|0)<(0);
 $4 = $3 << 31 >> 31;
 _lua_pushinteger($L,$2,$4);
 STACKTOP = sp;return 2;
}
function _math_ldexp($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0, $2 = 0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (_luaL_checkinteger($L,2)|0);
 $2 = tempRet0;
 $3 = (+_ldexp($0,$1));
 _lua_pushnumber($L,$3);
 return 1;
}
function _math_log10($L) {
 $L = $L|0;
 var $0 = 0.0, $1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_luaL_checknumber($L,1));
 $1 = (+_log10($0));
 _lua_pushnumber($L,$1);
 return 1;
}
function _luaopen_os($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,11);
 _luaL_setfuncs($L,9792,0);
 return 1;
}
function _os_clock($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0.0, $2 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_clock()|0);
 $1 = (+($0|0));
 $2 = $1 / 1.0E+6;
 _lua_pushnumber($L,$2);
 return 1;
}
function _os_date($L) {
 $L = $L|0;
 var $$0$i = 0, $$lcssa$i = 0, $$pr10$pr$i = 0, $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $b = 0, $buff = 0, $cc = 0, $memchr$i = 0, $memchr6$i = 0, $memchr7$i = 0;
 var $memchr8$i = 0, $memchr9$i = 0, $s$0 = 0, $s$1 = 0, $stm$0 = 0, $t = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4336|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $t = sp + 4120|0;
 $cc = sp + 4328|0;
 $b = sp + 8|0;
 $buff = sp + 4128|0;
 $0 = (_luaL_optlstring($L,1,10224,0)|0);
 $1 = (_lua_type($L,2)|0);
 $2 = ($1|0)<(1);
 if ($2) {
  $3 = (_time((0|0))|0);
  $6 = $3;
 } else {
  $4 = (_luaL_checkinteger($L,2)|0);
  $5 = tempRet0;
  $6 = $4;
 }
 HEAP32[$t>>2] = $6;
 $7 = HEAP8[$0>>0]|0;
 $8 = ($7<<24>>24)==(33);
 if ($8) {
  $9 = (_gmtime(($t|0))|0);
  $10 = ((($0)) + 1|0);
  $s$0 = $10;$stm$0 = $9;
 } else {
  $11 = (_localtime(($t|0))|0);
  $s$0 = $0;$stm$0 = $11;
 }
 $12 = ($stm$0|0)==(0|0);
 if ($12) {
  _lua_pushnil($L);
  STACKTOP = sp;return 1;
 }
 $13 = (_strcmp($s$0,10232)|0);
 $14 = ($13|0)==(0);
 if ($14) {
  _lua_createtable($L,0,9);
  $15 = HEAP32[$stm$0>>2]|0;
  $16 = ($15|0)<(0);
  $17 = $16 << 31 >> 31;
  _lua_pushinteger($L,$15,$17);
  _lua_setfield($L,-2,10024);
  $18 = ((($stm$0)) + 4|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)<(0);
  $21 = $20 << 31 >> 31;
  _lua_pushinteger($L,$19,$21);
  _lua_setfield($L,-2,10032);
  $22 = ((($stm$0)) + 8|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ($23|0)<(0);
  $25 = $24 << 31 >> 31;
  _lua_pushinteger($L,$23,$25);
  _lua_setfield($L,-2,10040);
  $26 = ((($stm$0)) + 12|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = ($27|0)<(0);
  $29 = $28 << 31 >> 31;
  _lua_pushinteger($L,$27,$29);
  _lua_setfield($L,-2,10048);
  $30 = ((($stm$0)) + 16|0);
  $31 = HEAP32[$30>>2]|0;
  $32 = (($31) + 1)|0;
  $33 = ($32|0)<(0);
  $34 = $33 << 31 >> 31;
  _lua_pushinteger($L,$32,$34);
  _lua_setfield($L,-2,10096);
  $35 = ((($stm$0)) + 20|0);
  $36 = HEAP32[$35>>2]|0;
  $37 = (($36) + 1900)|0;
  $38 = ($37|0)<(0);
  $39 = $38 << 31 >> 31;
  _lua_pushinteger($L,$37,$39);
  _lua_setfield($L,-2,10104);
  $40 = ((($stm$0)) + 24|0);
  $41 = HEAP32[$40>>2]|0;
  $42 = (($41) + 1)|0;
  $43 = ($42|0)<(0);
  $44 = $43 << 31 >> 31;
  _lua_pushinteger($L,$42,$44);
  _lua_setfield($L,-2,10240);
  $45 = ((($stm$0)) + 28|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = (($46) + 1)|0;
  $48 = ($47|0)<(0);
  $49 = $48 << 31 >> 31;
  _lua_pushinteger($L,$47,$49);
  _lua_setfield($L,-2,10248);
  $50 = ((($stm$0)) + 32|0);
  $51 = HEAP32[$50>>2]|0;
  $52 = ($51|0)<(0);
  if ($52) {
   STACKTOP = sp;return 1;
  }
  _lua_pushboolean($L,$51);
  _lua_setfield($L,-2,10112);
  STACKTOP = sp;return 1;
 }
 HEAP8[$cc>>0] = 37;
 _luaL_buffinit($L,$b);
 $53 = ((($b)) + 8|0);
 $54 = ((($b)) + 4|0);
 $55 = ((($cc)) + 1|0);
 $56 = ((($cc)) + 2|0);
 $57 = ((($cc)) + 3|0);
 $s$1 = $s$0;
 while(1) {
  $58 = HEAP8[$s$1>>0]|0;
  if ((($58<<24>>24) == 0)) {
   break;
  } else if (!((($58<<24>>24) == 37))) {
   $59 = HEAP32[$53>>2]|0;
   $60 = HEAP32[$54>>2]|0;
   $61 = ($59>>>0)<($60>>>0);
   if ($61) {
    $64 = $59;$67 = $58;
   } else {
    (_luaL_prepbuffsize($b,1)|0);
    $$pre = HEAP8[$s$1>>0]|0;
    $$pre1 = HEAP32[$53>>2]|0;
    $64 = $$pre1;$67 = $$pre;
   }
   $62 = ((($s$1)) + 1|0);
   $63 = (($64) + 1)|0;
   HEAP32[$53>>2] = $63;
   $65 = HEAP32[$b>>2]|0;
   $66 = (($65) + ($64)|0);
   HEAP8[$66>>0] = $67;
   $s$1 = $62;
   continue;
  }
  $68 = ((($s$1)) + 1|0);
  $69 = ((($s$1)) + 2|0);
  $70 = HEAP8[$68>>0]|0;
  $71 = ($70<<24>>24)==(0);
  do {
   if ($71) {
    label = 28;
   } else {
    $72 = $70 << 24 >> 24;
    $memchr$i = (_memchr(10256,$72,38)|0);
    $73 = ($memchr$i|0)==(0|0);
    if (!($73)) {
     HEAP8[$55>>0] = $70;
     HEAP8[$56>>0] = 0;
     $$0$i = $69;
     break;
    }
    $memchr6$i = (_memchr(10296,$72,2)|0);
    $75 = ($memchr6$i|0)==(0|0);
    if ($75) {
     label = 24;
    } else {
     HEAP8[$55>>0] = $70;
     $76 = HEAP8[$69>>0]|0;
     $77 = ($76<<24>>24)==(0);
     if ($77) {
      label = 24;
     } else {
      $78 = $76 << 24 >> 24;
      $memchr7$i = (_memchr(10304,$78,7)|0);
      $79 = ($memchr7$i|0)==(0|0);
      if ($79) {
       label = 24;
      } else {
       $$lcssa$i = $76;
      }
     }
    }
    if ((label|0) == 24) {
     label = 0;
     $$pr10$pr$i = HEAP8[$68>>0]|0;
     $80 = ($$pr10$pr$i<<24>>24)==(0);
     if ($80) {
      label = 28;
      break;
     }
     $81 = $$pr10$pr$i << 24 >> 24;
     $memchr8$i = (_memchr(10312,$81,2)|0);
     $82 = ($memchr8$i|0)==(0|0);
     if ($82) {
      label = 28;
      break;
     }
     HEAP8[$55>>0] = $$pr10$pr$i;
     $83 = HEAP8[$69>>0]|0;
     $84 = ($83<<24>>24)==(0);
     if ($84) {
      label = 28;
      break;
     }
     $85 = $83 << 24 >> 24;
     $memchr9$i = (_memchr(10320,$85,14)|0);
     $86 = ($memchr9$i|0)==(0|0);
     if ($86) {
      label = 28;
      break;
     } else {
      $$lcssa$i = $83;
     }
    }
    HEAP8[$56>>0] = $$lcssa$i;
    HEAP8[$57>>0] = 0;
    $74 = ((($s$1)) + 3|0);
    $$0$i = $74;
   }
  } while(0);
  if ((label|0) == 28) {
   label = 0;
   HEAP32[$vararg_buffer>>2] = $68;
   $87 = (_lua_pushfstring($L,10336,$vararg_buffer)|0);
   (_luaL_argerror($L,1,$87)|0);
   $$0$i = $68;
  }
  $88 = (_strftime(($buff|0),200,($cc|0),($stm$0|0))|0);
  _luaL_addlstring($b,$buff,$88);
  $s$1 = $$0$i;
 }
 _luaL_pushresult($b);
 STACKTOP = sp;return 1;
}
function _os_difftime($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,2)|0);
 $3 = tempRet0;
 $4 = (+_difftime(($0|0),($2|0)));
 _lua_pushnumber($L,$4);
 return 1;
}
function _os_execute($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_optlstring($L,1,0,0)|0);
 $1 = (_system(($0|0))|0);
 $2 = ($0|0)==(0|0);
 if ($2) {
  _lua_pushboolean($L,$1);
  $$0 = 1;
  return ($$0|0);
 } else {
  $3 = (_luaL_execresult($L,$1)|0);
  $$0 = $3;
  return ($$0|0);
 }
 return (0)|0;
}
function _os_exit($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $not$ = 0, $status$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)==(1);
 if ($1) {
  $2 = (_lua_toboolean($L,1)|0);
  $not$ = ($2|0)==(0);
  $3 = $not$&1;
  $status$0 = $3;
 } else {
  $4 = (_luaL_optinteger($L,1,0,0)|0);
  $5 = tempRet0;
  $status$0 = $4;
 }
 $6 = (_lua_toboolean($L,2)|0);
 $7 = ($6|0)==(0);
 if (!($7)) {
  _lua_close($L);
 }
 $8 = ($L|0)==(0|0);
 if ($8) {
  return 0;
 } else {
  _exit(($status$0|0));
  // unreachable;
 }
 return (0)|0;
}
function _os_getenv($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_getenv(($0|0))|0);
 (_lua_pushstring($L,$1)|0);
 return 1;
}
function _os_remove($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_remove(($0|0))|0);
 $2 = ($1|0)==(0);
 $3 = $2&1;
 $4 = (_luaL_fileresult($L,$3,$0)|0);
 return ($4|0);
}
function _os_rename($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_luaL_checklstring($L,2,0)|0);
 $2 = (_rename(($0|0),($1|0))|0);
 $3 = ($2|0)==(0);
 $4 = $3&1;
 $5 = (_luaL_fileresult($L,$4,0)|0);
 return ($5|0);
}
function _os_setlocale($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_optlstring($L,1,0,0)|0);
 $1 = (_luaL_checkoption($L,2,10120,10128)|0);
 $2 = (10160 + ($1<<2)|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = (_setlocale(($3|0),($0|0))|0);
 (_lua_pushstring($L,$4)|0);
 return 1;
}
function _os_time($L) {
 $L = $L|0;
 var $$ = 0, $$0$i = 0, $$0$i12 = 0, $$0$i16 = 0, $$18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $isnum$i = 0, $isnum$i1 = 0, $isnum$i10 = 0, $isnum$i14 = 0, $isnum$i4 = 0, $isnum$i7 = 0, $res$0$i2 = 0, $t$0 = 0, $ts = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $isnum$i14 = sp + 84|0;
 $isnum$i10 = sp + 80|0;
 $isnum$i7 = sp + 76|0;
 $isnum$i4 = sp + 72|0;
 $isnum$i1 = sp + 68|0;
 $isnum$i = sp + 64|0;
 $ts = sp + 20|0;
 $0 = (_lua_type($L,1)|0);
 $1 = ($0|0)<(1);
 if ($1) {
  $2 = (_time((0|0))|0);
  $t$0 = $2;
 } else {
  _luaL_checktype($L,1,5);
  _lua_settop($L,1);
  (_lua_getfield($L,-1,10024)|0);
  $3 = (_lua_tointegerx($L,-1,$isnum$i)|0);
  $4 = tempRet0;
  $5 = HEAP32[$isnum$i>>2]|0;
  $6 = ($5|0)==(0);
  $$ = $6 ? 0 : $3;
  _lua_settop($L,-2);
  HEAP32[$ts>>2] = $$;
  (_lua_getfield($L,-1,10032)|0);
  $7 = (_lua_tointegerx($L,-1,$isnum$i1)|0);
  $8 = tempRet0;
  $9 = HEAP32[$isnum$i1>>2]|0;
  $10 = ($9|0)==(0);
  $res$0$i2 = $10 ? 0 : $7;
  _lua_settop($L,-2);
  $11 = ((($ts)) + 4|0);
  HEAP32[$11>>2] = $res$0$i2;
  (_lua_getfield($L,-1,10040)|0);
  $12 = (_lua_tointegerx($L,-1,$isnum$i4)|0);
  $13 = tempRet0;
  $14 = HEAP32[$isnum$i4>>2]|0;
  $15 = ($14|0)==(0);
  $$18 = $15 ? 12 : $12;
  _lua_settop($L,-2);
  $16 = ((($ts)) + 8|0);
  HEAP32[$16>>2] = $$18;
  (_lua_getfield($L,-1,10048)|0);
  $17 = (_lua_tointegerx($L,-1,$isnum$i7)|0);
  $18 = tempRet0;
  $19 = HEAP32[$isnum$i7>>2]|0;
  $20 = ($19|0)==(0);
  if ($20) {
   HEAP32[$vararg_buffer>>2] = 10048;
   $21 = (_luaL_error($L,10056,$vararg_buffer)|0);
   $$0$i = $21;
  } else {
   _lua_settop($L,-2);
   $$0$i = $17;
  }
  $22 = ((($ts)) + 12|0);
  HEAP32[$22>>2] = $$0$i;
  (_lua_getfield($L,-1,10096)|0);
  $23 = (_lua_tointegerx($L,-1,$isnum$i10)|0);
  $24 = tempRet0;
  $25 = HEAP32[$isnum$i10>>2]|0;
  $26 = ($25|0)==(0);
  if ($26) {
   HEAP32[$vararg_buffer1>>2] = 10096;
   $27 = (_luaL_error($L,10056,$vararg_buffer1)|0);
   $$0$i12 = $27;
  } else {
   _lua_settop($L,-2);
   $$0$i12 = $23;
  }
  $28 = (($$0$i12) + -1)|0;
  $29 = ((($ts)) + 16|0);
  HEAP32[$29>>2] = $28;
  (_lua_getfield($L,-1,10104)|0);
  $30 = (_lua_tointegerx($L,-1,$isnum$i14)|0);
  $31 = tempRet0;
  $32 = HEAP32[$isnum$i14>>2]|0;
  $33 = ($32|0)==(0);
  if ($33) {
   HEAP32[$vararg_buffer4>>2] = 10104;
   $34 = (_luaL_error($L,10056,$vararg_buffer4)|0);
   $$0$i16 = $34;
  } else {
   _lua_settop($L,-2);
   $$0$i16 = $30;
  }
  $35 = (($$0$i16) + -1900)|0;
  $36 = ((($ts)) + 20|0);
  HEAP32[$36>>2] = $35;
  $37 = (_lua_getfield($L,-1,10112)|0);
  $38 = ($37|0)==(0);
  if ($38) {
   $41 = -1;
  } else {
   $39 = (_lua_toboolean($L,-1)|0);
   $41 = $39;
  }
  _lua_settop($L,-2);
  $40 = ((($ts)) + 32|0);
  HEAP32[$40>>2] = $41;
  $42 = (_mktime(($ts|0))|0);
  $t$0 = $42;
 }
 $43 = ($t$0|0)==(-1);
 if ($43) {
  _lua_pushnil($L);
  STACKTOP = sp;return 1;
 } else {
  $44 = ($t$0|0)<(0);
  $45 = $44 << 31 >> 31;
  _lua_pushinteger($L,$t$0,$45);
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function _os_tmpname($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $buff = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $buff = sp + 4|0;
 $0 = (_tmpnam(($buff|0))|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_luaL_error($L,9984,$vararg_buffer)|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 } else {
  (_lua_pushstring($L,$buff)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _luaopen_string($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,17);
 _luaL_setfuncs($L,10376,0);
 _lua_createtable($L,0,1);
 (_lua_pushlstring($L,37352,0)|0);
 _lua_pushvalue($L,-2);
 (_lua_setmetatable($L,-2)|0);
 _lua_settop($L,-2);
 _lua_pushvalue($L,-2);
 _lua_setfield($L,-2,11928);
 _lua_settop($L,-2);
 return 1;
}
function _str_byte($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $exitcond = 0, $i$03 = 0, $l = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $l = sp + 4|0;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = (_luaL_optinteger($L,2,1,0)|0);
 $2 = tempRet0;
 $3 = HEAP32[$l>>2]|0;
 $4 = ($2|0)>(-1);
 $5 = ($1>>>0)>(4294967295);
 $6 = ($2|0)==(-1);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  $15 = $1;$16 = $2;
 } else {
  $9 = (0 - ($1))|0;
  $10 = ($3>>>0)<($9>>>0);
  if ($10) {
   $15 = 0;$16 = 0;
  } else {
   $11 = (_i64Add(($1|0),($2|0),1,0)|0);
   $12 = tempRet0;
   $13 = (_i64Add(($11|0),($12|0),($3|0),0)|0);
   $14 = tempRet0;
   $15 = $13;$16 = $14;
  }
 }
 $17 = (_luaL_optinteger($L,3,$15,$16)|0);
 $18 = tempRet0;
 $19 = HEAP32[$l>>2]|0;
 $20 = ($18|0)>(-1);
 $21 = ($17>>>0)>(4294967295);
 $22 = ($18|0)==(-1);
 $23 = $22 & $21;
 $24 = $20 | $23;
 if ($24) {
  $39 = $18;$41 = $17;
 } else {
  $25 = (0 - ($17))|0;
  $26 = ($19>>>0)<($25>>>0);
  if ($26) {
   $39 = 0;$41 = 0;
  } else {
   $27 = (_i64Add(($17|0),($18|0),1,0)|0);
   $28 = tempRet0;
   $29 = (_i64Add(($27|0),($28|0),($19|0),0)|0);
   $30 = tempRet0;
   $39 = $30;$41 = $29;
  }
 }
 $31 = ($16|0)<(0);
 $32 = ($15>>>0)<(1);
 $33 = ($16|0)==(0);
 $34 = $33 & $32;
 $35 = $31 | $34;
 $36 = $35 ? 1 : $15;
 $37 = $35 ? 0 : $16;
 $38 = ($39|0)>(0);
 $40 = ($41>>>0)>($19>>>0);
 $42 = ($39|0)==(0);
 $43 = $42 & $40;
 $44 = $38 | $43;
 $45 = $44 ? $19 : $41;
 $46 = $44 ? 0 : $39;
 $47 = ($46|0)<($37|0);
 $48 = ($45>>>0)<($36>>>0);
 $49 = ($46|0)==($37|0);
 $50 = $49 & $48;
 $51 = $47 | $50;
 if ($51) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $52 = (_i64Subtract(1,0,($36|0),($37|0))|0);
 $53 = tempRet0;
 $54 = (_i64Add(($52|0),($53|0),($45|0),($46|0))|0);
 $55 = tempRet0;
 $56 = ($54|0)<(0);
 $57 = $56 << 31 >> 31;
 $58 = (_i64Add(($54|0),($57|0),($36|0),($37|0))|0);
 $59 = tempRet0;
 $60 = ($59|0)>($46|0);
 $61 = ($58>>>0)>($45>>>0);
 $62 = ($59|0)==($46|0);
 $63 = $62 & $61;
 $64 = $60 | $63;
 if (!($64)) {
  $65 = (_luaL_error($L,12440,$vararg_buffer)|0);
  $$0 = $65;
  STACKTOP = sp;return ($$0|0);
 }
 _luaL_checkstack($L,$54,12440);
 $66 = ($54|0)>(0);
 if (!($66)) {
  $$0 = $54;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (_i64Add(($36|0),($37|0),-1,0)|0);
 $68 = tempRet0;
 $69 = (0)>($39|0);
 $70 = ($19>>>0)>($41>>>0);
 $71 = (0)==($39|0);
 $72 = $71 & $70;
 $73 = $69 | $72;
 $74 = $73 ? $41 : $19;
 $75 = $73 ? $39 : 0;
 $76 = (_i64Add(($74|0),($75|0),1,0)|0);
 $77 = tempRet0;
 $78 = ($16|0)>(0);
 $79 = ($15>>>0)>(1);
 $80 = ($16|0)==(0);
 $81 = $80 & $79;
 $82 = $78 | $81;
 $83 = $82 ? $15 : 1;
 $84 = $82 ? $16 : 0;
 $85 = (_i64Subtract(($76|0),($77|0),($83|0),($84|0))|0);
 $86 = tempRet0;
 $i$03 = 0;
 while(1) {
  $87 = (_i64Add(($67|0),($68|0),($i$03|0),0)|0);
  $88 = tempRet0;
  $89 = (($0) + ($87)|0);
  $90 = HEAP8[$89>>0]|0;
  $91 = $90&255;
  _lua_pushinteger($L,$91,0);
  $92 = (($i$03) + 1)|0;
  $exitcond = ($92|0)==($85|0);
  if ($exitcond) {
   $$0 = $54;
   break;
  } else {
   $i$03 = $92;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _str_char($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $b = sp;
 $0 = (_lua_gettop($L)|0);
 $1 = (_luaL_buffinitsize($L,$b,$0)|0);
 $2 = ($0|0)<(1);
 if ($2) {
  _luaL_pushresultsize($b,$0);
  STACKTOP = sp;return 1;
 } else {
  $i$01 = 1;
 }
 while(1) {
  $3 = (_luaL_checkinteger($L,$i$01)|0);
  $4 = tempRet0;
  $5 = $3&255;
  $6 = $3 & 255;
  $7 = ($6|0)==($3|0);
  $8 = (0)==($4|0);
  $9 = $7 & $8;
  if (!($9)) {
   (_luaL_argerror($L,$i$01,12392)|0);
  }
  $10 = (($i$01) + -1)|0;
  $11 = (($1) + ($10)|0);
  HEAP8[$11>>0] = $5;
  $12 = (($i$01) + 1)|0;
  $exitcond = ($i$01|0)==($0|0);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $12;
  }
 }
 _luaL_pushresultsize($b,$0);
 STACKTOP = sp;return 1;
}
function _str_dump($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $b = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $b = sp + 8|0;
 $0 = (_lua_toboolean($L,2)|0);
 _luaL_checktype($L,1,6);
 _lua_settop($L,1);
 _luaL_buffinit($L,$b);
 $1 = (_lua_dump($L,343,$b,$0)|0);
 $2 = ($1|0)==(0);
 if ($2) {
  _luaL_pushresult($b);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else {
  $3 = (_luaL_error($L,11736,$vararg_buffer)|0);
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _str_find($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_str_find_aux($L,1)|0);
 return ($0|0);
}
function _str_format($L) {
 $L = $L|0;
 var $$$i = 0, $$0 = 0, $$lcssa = 0, $$lcssa24 = 0, $$p$0$i = 0, $$p$2$i = 0, $$pre = 0, $$pre$i = 0, $$pre$i2 = 0, $$pre12 = 0, $$pre13 = 0, $$pre13$i = 0, $$pre14 = 0, $$pre3$i = 0, $$pre4$i = 0, $$pre6$i = 0, $$pre7$i = 0, $$pre8$i = 0, $$sum$i = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0;
 var $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0;
 var $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0;
 var $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0;
 var $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0.0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arg$0$ph9 = 0, $b = 0, $buff$i = 0;
 var $form = 0, $isdigit$i = 0, $isdigit$i5 = 0, $isdigit2$i = 0, $isdigit4$i = 0, $isdigit6$i = 0, $isdigit8$i = 0, $isdigittmp$i = 0, $isdigittmp$i4 = 0, $isdigittmp1$i = 0, $isdigittmp3$i = 0, $isdigittmp5$i = 0, $isdigittmp7$i = 0, $l = 0, $l$i = 0, $memchr$i = 0, $nb$0 = 0, $or$cond = 0, $p$0$lcssa$i = 0, $p$09$i = 0;
 var $p$2$i = 0, $p$4$i = 0, $s$01$i = 0, $sfl = 0, $strfrmt$0$be = 0, $strfrmt$0$ph8 = 0, $strfrmt$07 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer14 = 0, $vararg_buffer17 = 0, $vararg_buffer20 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer20 = sp + 64|0;
 $vararg_buffer17 = sp + 56|0;
 $vararg_buffer14 = sp + 48|0;
 $vararg_buffer11 = sp + 40|0;
 $vararg_buffer8 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $l$i = sp + 4188|0;
 $buff$i = sp + 4210|0;
 $sfl = sp + 4184|0;
 $b = sp + 72|0;
 $form = sp + 4192|0;
 $l = sp + 68|0;
 $0 = (_lua_gettop($L)|0);
 $1 = (_luaL_checklstring($L,1,$sfl)|0);
 $2 = HEAP32[$sfl>>2]|0;
 $3 = (($1) + ($2)|0);
 _luaL_buffinit($L,$b);
 $4 = ($2|0)>(0);
 L1: do {
  if ($4) {
   $5 = ((($b)) + 8|0);
   $6 = ((($b)) + 4|0);
   $7 = ((($form)) + 1|0);
   $arg$0$ph9 = 1;$strfrmt$0$ph8 = $1;
   L3: while(1) {
    $strfrmt$07 = $strfrmt$0$ph8;
    while(1) {
     $8 = HEAP8[$strfrmt$07>>0]|0;
     $9 = ($8<<24>>24)==(37);
     if ($9) {
      $19 = ((($strfrmt$07)) + 1|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = ($20<<24>>24)==(37);
      if (!($21)) {
       $$lcssa = $19;
       break;
      }
      $22 = HEAP32[$5>>2]|0;
      $23 = HEAP32[$6>>2]|0;
      $24 = ($22>>>0)<($23>>>0);
      if ($24) {
       $27 = $22;$30 = 37;
      } else {
       (_luaL_prepbuffsize($b,1)|0);
       $$pre13 = HEAP8[$19>>0]|0;
       $$pre14 = HEAP32[$5>>2]|0;
       $27 = $$pre14;$30 = $$pre13;
      }
      $25 = ((($strfrmt$07)) + 2|0);
      $26 = (($27) + 1)|0;
      HEAP32[$5>>2] = $26;
      $28 = HEAP32[$b>>2]|0;
      $29 = (($28) + ($27)|0);
      HEAP8[$29>>0] = $30;
      $strfrmt$0$be = $25;
     } else {
      $10 = HEAP32[$5>>2]|0;
      $11 = HEAP32[$6>>2]|0;
      $12 = ($10>>>0)<($11>>>0);
      if ($12) {
       $15 = $10;$18 = $8;
      } else {
       (_luaL_prepbuffsize($b,1)|0);
       $$pre = HEAP8[$strfrmt$07>>0]|0;
       $$pre12 = HEAP32[$5>>2]|0;
       $15 = $$pre12;$18 = $$pre;
      }
      $13 = ((($strfrmt$07)) + 1|0);
      $14 = (($15) + 1)|0;
      HEAP32[$5>>2] = $14;
      $16 = HEAP32[$b>>2]|0;
      $17 = (($16) + ($15)|0);
      HEAP8[$17>>0] = $18;
      $strfrmt$0$be = $13;
     }
     $31 = ($strfrmt$0$be>>>0)<($3>>>0);
     if ($31) {
      $strfrmt$07 = $strfrmt$0$be;
     } else {
      break L1;
     }
    }
    $32 = (_luaL_prepbuffsize($b,512)|0);
    $33 = (($arg$0$ph9) + 1)|0;
    $34 = ($arg$0$ph9|0)<($0|0);
    if (!($34)) {
     (_luaL_argerror($L,$33,11568)|0);
    }
    $35 = HEAP8[$$lcssa>>0]|0;
    $36 = ($35<<24>>24)==(0);
    L22: do {
     if ($36) {
      $157 = 0;$p$0$lcssa$i = $$lcssa;
     } else {
      $38 = $35;$p$09$i = $$lcssa;
      while(1) {
       $37 = $38 << 24 >> 24;
       $memchr$i = (_memchr(11584,$37,6)|0);
       $39 = ($memchr$i|0)==(0|0);
       if ($39) {
        $157 = $38;$p$0$lcssa$i = $p$09$i;
        break L22;
       }
       $40 = ((($p$09$i)) + 1|0);
       $41 = HEAP8[$40>>0]|0;
       $42 = ($41<<24>>24)==(0);
       if ($42) {
        $157 = 0;$p$0$lcssa$i = $40;
        break;
       } else {
        $38 = $41;$p$09$i = $40;
       }
      }
     }
    } while(0);
    $43 = $p$0$lcssa$i;
    $44 = $$lcssa;
    $45 = (($43) - ($44))|0;
    $46 = ($45>>>0)>(5);
    if ($46) {
     (_luaL_error($L,11592,$vararg_buffer)|0);
     $$pre$i = HEAP8[$p$0$lcssa$i>>0]|0;
     $48 = $$pre$i;
    } else {
     $48 = $157;
    }
    $47 = $48&255;
    $isdigittmp$i = (($47) + -48)|0;
    $isdigit$i = ($isdigittmp$i>>>0)<(10);
    $49 = ((($p$0$lcssa$i)) + 1|0);
    $$p$0$i = $isdigit$i ? $49 : $p$0$lcssa$i;
    $50 = HEAP8[$$p$0$i>>0]|0;
    $51 = $50&255;
    $isdigittmp1$i = (($51) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    $52 = ((($$p$0$i)) + 1|0);
    $p$2$i = $isdigit2$i ? $52 : $$p$0$i;
    $53 = HEAP8[$p$2$i>>0]|0;
    $54 = ($53<<24>>24)==(46);
    if ($54) {
     $55 = ((($p$2$i)) + 1|0);
     $56 = HEAP8[$55>>0]|0;
     $57 = $56&255;
     $isdigittmp5$i = (($57) + -48)|0;
     $isdigit6$i = ($isdigittmp5$i>>>0)<(10);
     $58 = ((($p$2$i)) + 2|0);
     $$$i = $isdigit6$i ? $58 : $55;
     $59 = HEAP8[$$$i>>0]|0;
     $60 = $59&255;
     $isdigittmp7$i = (($60) + -48)|0;
     $isdigit8$i = ($isdigittmp7$i>>>0)<(10);
     if ($isdigit8$i) {
      $$p$2$i = $isdigit6$i ? $55 : $p$2$i;
      $61 = ((($$p$2$i)) + 2|0);
      $$pre13$i = HEAP8[$61>>0]|0;
      $63 = $$pre13$i;$p$4$i = $61;
     } else {
      $63 = $59;$p$4$i = $$$i;
     }
    } else {
     $63 = $53;$p$4$i = $p$2$i;
    }
    $62 = $63&255;
    $isdigittmp3$i = (($62) + -48)|0;
    $isdigit4$i = ($isdigittmp3$i>>>0)<(10);
    if ($isdigit4$i) {
     (_luaL_error($L,11624,$vararg_buffer1)|0);
    }
    HEAP8[$form>>0] = 37;
    $64 = $p$4$i;
    $65 = (($64) - ($44))|0;
    $66 = (($65) + 1)|0;
    _memcpy(($7|0),($$lcssa|0),($66|0))|0;
    $$sum$i = (($65) + 2)|0;
    $67 = (($form) + ($$sum$i)|0);
    HEAP8[$67>>0] = 0;
    $68 = ((($p$4$i)) + 1|0);
    $69 = HEAP8[$p$4$i>>0]|0;
    $70 = $69 << 24 >> 24;
    L37: do {
     switch ($70|0) {
     case 88: case 120: case 117: case 111: case 105: case 100:  {
      $74 = (_luaL_checkinteger($L,$33)|0);
      $75 = tempRet0;
      $76 = (_strlen(($form|0))|0);
      $77 = (($76) + -1)|0;
      $78 = (($form) + ($77)|0);
      $79 = HEAP8[$78>>0]|0;
      ;HEAP8[$78>>0]=HEAP8[11672>>0]|0;HEAP8[$78+1>>0]=HEAP8[11672+1>>0]|0;HEAP8[$78+2>>0]=HEAP8[11672+2>>0]|0;
      $80 = (($76) + 2)|0;
      $81 = (($76) + 1)|0;
      $82 = (($form) + ($81)|0);
      HEAP8[$82>>0] = $79;
      $83 = (($form) + ($80)|0);
      HEAP8[$83>>0] = 0;
      $84 = $vararg_buffer5;
      $85 = $84;
      HEAP32[$85>>2] = $74;
      $86 = (($84) + 4)|0;
      $87 = $86;
      HEAP32[$87>>2] = $75;
      $88 = (_sprintf($32,$form,$vararg_buffer5)|0);
      $nb$0 = $88;
      break;
     }
     case 71: case 103: case 102: case 69: case 101: case 65: case 97:  {
      $89 = (_strlen(($form|0))|0);
      $90 = (($form) + ($89)|0);
      HEAP8[$90>>0] = 0;
      $91 = (+_luaL_checknumber($L,$33));
      HEAPF64[$vararg_buffer8>>3] = $91;
      $92 = (_sprintf($32,$form,$vararg_buffer8)|0);
      $nb$0 = $92;
      break;
     }
     case 115:  {
      $147 = (_luaL_tolstring($L,$33,$l)|0);
      $148 = (_strchr($form,46)|0);
      $149 = ($148|0)==(0|0);
      $150 = HEAP32[$l>>2]|0;
      $151 = ($150>>>0)>(99);
      $or$cond = $149 & $151;
      if ($or$cond) {
       _luaL_addvalue($b);
       $nb$0 = 0;
       break L37;
      } else {
       HEAP32[$vararg_buffer17>>2] = $147;
       $152 = (_sprintf($32,$form,$vararg_buffer17)|0);
       _lua_settop($L,-2);
       $nb$0 = $152;
       break L37;
      }
      break;
     }
     case 99:  {
      $71 = (_luaL_checkinteger($L,$33)|0);
      $72 = tempRet0;
      HEAP32[$vararg_buffer3>>2] = $71;
      $73 = (_sprintf($32,$form,$vararg_buffer3)|0);
      $nb$0 = $73;
      break;
     }
     case 113:  {
      $93 = (_luaL_checklstring($L,$33,$l$i)|0);
      $94 = HEAP32[$5>>2]|0;
      $95 = HEAP32[$6>>2]|0;
      $96 = ($94>>>0)<($95>>>0);
      if ($96) {
       $98 = $94;
      } else {
       (_luaL_prepbuffsize($b,1)|0);
       $$pre$i2 = HEAP32[$5>>2]|0;
       $98 = $$pre$i2;
      }
      $97 = (($98) + 1)|0;
      HEAP32[$5>>2] = $97;
      $99 = HEAP32[$b>>2]|0;
      $100 = (($99) + ($98)|0);
      HEAP8[$100>>0] = 34;
      $101 = HEAP32[$l$i>>2]|0;
      $102 = (($101) + -1)|0;
      HEAP32[$l$i>>2] = $102;
      $103 = ($101|0)==(0);
      if (!($103)) {
       $s$01$i = $93;
       while(1) {
        $104 = HEAP8[$s$01$i>>0]|0;
        do {
         if ((($104<<24>>24) == 0)) {
          $127 = 0;
          label = 40;
         } else if ((($104<<24>>24) == 10) | (($104<<24>>24) == 92) | (($104<<24>>24) == 34)) {
          $105 = HEAP32[$5>>2]|0;
          $106 = HEAP32[$6>>2]|0;
          $107 = ($105>>>0)<($106>>>0);
          if ($107) {
           $109 = $105;
          } else {
           (_luaL_prepbuffsize($b,1)|0);
           $$pre3$i = HEAP32[$5>>2]|0;
           $109 = $$pre3$i;
          }
          $108 = (($109) + 1)|0;
          HEAP32[$5>>2] = $108;
          $110 = HEAP32[$b>>2]|0;
          $111 = (($110) + ($109)|0);
          HEAP8[$111>>0] = 92;
          $112 = HEAP32[$5>>2]|0;
          $113 = HEAP32[$6>>2]|0;
          $114 = ($112>>>0)<($113>>>0);
          if ($114) {
           $117 = $112;
          } else {
           (_luaL_prepbuffsize($b,1)|0);
           $$pre4$i = HEAP32[$5>>2]|0;
           $117 = $$pre4$i;
          }
          $115 = HEAP8[$s$01$i>>0]|0;
          $116 = (($117) + 1)|0;
          HEAP32[$5>>2] = $116;
          $118 = HEAP32[$b>>2]|0;
          $119 = (($118) + ($117)|0);
          HEAP8[$119>>0] = $115;
         } else {
          $120 = $104&255;
          $121 = (_iscntrl($120)|0);
          $122 = ($121|0)==(0);
          if (!($122)) {
           $$pre6$i = HEAP8[$s$01$i>>0]|0;
           $127 = $$pre6$i;
           label = 40;
           break;
          }
          $128 = HEAP32[$5>>2]|0;
          $129 = HEAP32[$6>>2]|0;
          $130 = ($128>>>0)<($129>>>0);
          if ($130) {
           $133 = $128;
          } else {
           (_luaL_prepbuffsize($b,1)|0);
           $$pre7$i = HEAP32[$5>>2]|0;
           $133 = $$pre7$i;
          }
          $131 = HEAP8[$s$01$i>>0]|0;
          $132 = (($133) + 1)|0;
          HEAP32[$5>>2] = $132;
          $134 = HEAP32[$b>>2]|0;
          $135 = (($134) + ($133)|0);
          HEAP8[$135>>0] = $131;
         }
        } while(0);
        if ((label|0) == 40) {
         label = 0;
         $123 = ((($s$01$i)) + 1|0);
         $124 = HEAP8[$123>>0]|0;
         $125 = $124&255;
         $isdigittmp$i4 = (($125) + -48)|0;
         $isdigit$i5 = ($isdigittmp$i4>>>0)<(10);
         $126 = $127&255;
         if ($isdigit$i5) {
          HEAP32[$vararg_buffer14>>2] = $126;
          (_sprintf($buff$i,11688,$vararg_buffer14)|0);
         } else {
          HEAP32[$vararg_buffer11>>2] = $126;
          (_sprintf($buff$i,11680,$vararg_buffer11)|0);
         }
         _luaL_addstring($b,$buff$i);
        }
        $136 = ((($s$01$i)) + 1|0);
        $137 = HEAP32[$l$i>>2]|0;
        $138 = (($137) + -1)|0;
        HEAP32[$l$i>>2] = $138;
        $139 = ($137|0)==(0);
        if ($139) {
         break;
        } else {
         $s$01$i = $136;
        }
       }
      }
      $140 = HEAP32[$5>>2]|0;
      $141 = HEAP32[$6>>2]|0;
      $142 = ($140>>>0)<($141>>>0);
      if ($142) {
       $144 = $140;
      } else {
       (_luaL_prepbuffsize($b,1)|0);
       $$pre8$i = HEAP32[$5>>2]|0;
       $144 = $$pre8$i;
      }
      $143 = (($144) + 1)|0;
      HEAP32[$5>>2] = $143;
      $145 = HEAP32[$b>>2]|0;
      $146 = (($145) + ($144)|0);
      HEAP8[$146>>0] = 34;
      $nb$0 = 0;
      break;
     }
     default: {
      $$lcssa24 = $70;
      break L3;
     }
     }
    } while(0);
    $154 = HEAP32[$5>>2]|0;
    $155 = (($154) + ($nb$0))|0;
    HEAP32[$5>>2] = $155;
    $156 = ($68>>>0)<($3>>>0);
    if ($156) {
     $arg$0$ph9 = $33;$strfrmt$0$ph8 = $68;
    } else {
     break L1;
    }
   }
   HEAP32[$vararg_buffer20>>2] = $$lcssa24;
   $153 = (_luaL_error($L,11696,$vararg_buffer20)|0);
   $$0 = $153;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 _luaL_pushresult($b);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _gmatch($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_luaL_checklstring($L,1,0)|0);
 (_luaL_checklstring($L,2,0)|0);
 _lua_settop($L,2);
 _lua_pushinteger($L,0,0);
 _lua_pushcclosure($L,344,3);
 return 1;
}
function _str_gsub($L) {
 $L = $L|0;
 var $$$i$i = 0, $$off = 0, $$pre = 0, $$pre$i$i = 0, $$pre2$i$i = 0, $$pre3$i$i = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0;
 var $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0;
 var $128 = 0, $129 = 0, $13 = 0, $130 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $b = 0, $exitcond$i$i = 0;
 var $i$01$i$i = 0, $i$02$i$i = 0, $i$1$i$i = 0, $isdigit$i$i = 0, $isdigittmp$i$i = 0, $l$i$i = 0, $lp = 0, $ms = 0, $or$cond$i$i = 0, $p$0 = 0, $src$0 = 0, $src$1 = 0, $src$2 = 0, $srcl = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4432|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $l$i$i = sp + 4424|0;
 $srcl = sp + 4420|0;
 $lp = sp + 4416|0;
 $ms = sp + 4136|0;
 $b = sp + 24|0;
 $0 = (_luaL_checklstring($L,1,$srcl)|0);
 $1 = (_luaL_checklstring($L,2,$lp)|0);
 $2 = (_lua_type($L,3)|0);
 $3 = HEAP32[$srcl>>2]|0;
 $4 = (($3) + 1)|0;
 $5 = (_luaL_optinteger($L,4,$4,0)|0);
 $6 = tempRet0;
 $7 = HEAP8[$1>>0]|0;
 $8 = ($7<<24>>24)==(94);
 $$off = (($2) + -3)|0;
 $9 = ($$off>>>0)<(4);
 if (!($9)) {
  (_luaL_argerror($L,3,11448)|0);
 }
 _luaL_buffinit($L,$b);
 if ($8) {
  $10 = ((($1)) + 1|0);
  $11 = HEAP32[$lp>>2]|0;
  $12 = (($11) + -1)|0;
  HEAP32[$lp>>2] = $12;
  $19 = $12;$p$0 = $10;
 } else {
  $$pre = HEAP32[$lp>>2]|0;
  $19 = $$pre;$p$0 = $1;
 }
 $13 = ((($ms)) + 16|0);
 HEAP32[$13>>2] = $L;
 HEAP32[$ms>>2] = 200;
 $14 = ((($ms)) + 4|0);
 HEAP32[$14>>2] = $0;
 $15 = HEAP32[$srcl>>2]|0;
 $16 = (($0) + ($15)|0);
 $17 = ((($ms)) + 8|0);
 HEAP32[$17>>2] = $16;
 $18 = (($p$0) + ($19)|0);
 $20 = ((($ms)) + 12|0);
 HEAP32[$20>>2] = $18;
 $21 = ((($ms)) + 20|0);
 $22 = ((($b)) + 8|0);
 $23 = ((($b)) + 4|0);
 $24 = ((($ms)) + 28|0);
 $25 = ((($ms)) + 24|0);
 $27 = 0;$29 = 0;$src$0 = $0;
 while(1) {
  $26 = ($27|0)<($6|0);
  $28 = ($29>>>0)<($5>>>0);
  $30 = ($27|0)==($6|0);
  $31 = $30 & $28;
  $32 = $26 | $31;
  if (!($32)) {
   $125 = $29;$126 = $27;$src$2 = $src$0;
   label = 49;
   break;
  }
  HEAP32[$21>>2] = 0;
  $33 = (_match($ms,$src$0,$p$0)|0);
  $34 = ($33|0)==(0|0);
  if ($34) {
   $127 = $29;$128 = $27;
   label = 44;
  } else {
   $35 = (_i64Add(($29|0),($27|0),1,0)|0);
   $36 = tempRet0;
   $37 = HEAP32[$13>>2]|0;
   if ((($2|0) == 5)) {
    $44 = HEAP32[$21>>2]|0;
    $45 = ($44|0)>(0);
    do {
     if ($45) {
      $49 = HEAP32[$24>>2]|0;
      $50 = ($49|0)==(-1);
      if ($50) {
       (_luaL_error($37,11216,$vararg_buffer)|0);
       $51 = HEAP32[$13>>2]|0;
       $52 = HEAP32[$25>>2]|0;
       $62 = $51;$63 = $52;
      } else {
       $53 = ($49|0)==(-2);
       $54 = HEAP32[$25>>2]|0;
       if ($53) {
        $55 = HEAP32[$14>>2]|0;
        $56 = $54;
        $57 = $55;
        $58 = (($56) + 1)|0;
        $59 = (($58) - ($57))|0;
        $60 = ($59|0)<(0);
        $61 = $60 << 31 >> 31;
        _lua_pushinteger($37,$59,$61);
        break;
       } else {
        $62 = $37;$63 = $54;
       }
      }
      (_lua_pushlstring($62,$63,$49)|0);
     } else {
      $46 = $33;
      $47 = $src$0;
      $48 = (($46) - ($47))|0;
      (_lua_pushlstring($37,$src$0,$48)|0);
     }
    } while(0);
    (_lua_gettable($37,3)|0);
    label = 38;
   } else if ((($2|0) == 6)) {
    _lua_pushvalue($37,3);
    $38 = HEAP32[$21>>2]|0;
    $39 = ($38|0)==(0);
    $40 = ($src$0|0)!=(0|0);
    $or$cond$i$i = $40 & $39;
    $$$i$i = $or$cond$i$i ? 1 : $38;
    $41 = HEAP32[$13>>2]|0;
    _luaL_checkstack($41,$$$i$i,11160);
    $42 = ($$$i$i|0)>(0);
    if ($42) {
     $i$02$i$i = 0;
     while(1) {
      _push_onecapture($ms,$i$02$i$i,$src$0,$33);
      $43 = (($i$02$i$i) + 1)|0;
      $exitcond$i$i = ($43|0)==($$$i$i|0);
      if ($exitcond$i$i) {
       break;
      } else {
       $i$02$i$i = $43;
      }
     }
    }
    _lua_callk($37,$$$i$i,1,0,0);
    label = 38;
   } else {
    $64 = (_lua_tolstring($37,3,$l$i$i)|0);
    $65 = HEAP32[$l$i$i>>2]|0;
    $66 = ($65|0)==(0);
    if (!($66)) {
     $67 = $33;
     $68 = $src$0;
     $69 = (($67) - ($68))|0;
     $i$01$i$i = 0;
     while(1) {
      $70 = (($64) + ($i$01$i$i)|0);
      $71 = HEAP8[$70>>0]|0;
      $72 = ($71<<24>>24)==(37);
      do {
       if ($72) {
        $81 = (($i$01$i$i) + 1)|0;
        $82 = (($64) + ($81)|0);
        $83 = HEAP8[$82>>0]|0;
        $84 = $83&255;
        $isdigittmp$i$i = (($84) + -48)|0;
        $isdigit$i$i = ($isdigittmp$i$i>>>0)<(10);
        $85 = $83 << 24 >> 24;
        if ($isdigit$i$i) {
         $95 = ($83<<24>>24)==(48);
         if ($95) {
          _luaL_addlstring($b,$src$0,$69);
          $i$1$i$i = $81;
          break;
         } else {
          $96 = (($85) + -49)|0;
          _push_onecapture($ms,$96,$src$0,$33);
          (_luaL_tolstring($37,-1,0)|0);
          _lua_rotate($37,-2,-1);
          _lua_settop($37,-2);
          _luaL_addvalue($b);
          $i$1$i$i = $81;
          break;
         }
        }
        $86 = ($83<<24>>24)==(37);
        if (!($86)) {
         HEAP32[$vararg_buffer1>>2] = 37;
         (_luaL_error($37,11480,$vararg_buffer1)|0);
        }
        $87 = HEAP32[$22>>2]|0;
        $88 = HEAP32[$23>>2]|0;
        $89 = ($87>>>0)<($88>>>0);
        if ($89) {
         $92 = $87;
        } else {
         (_luaL_prepbuffsize($b,1)|0);
         $$pre3$i$i = HEAP32[$22>>2]|0;
         $92 = $$pre3$i$i;
        }
        $90 = HEAP8[$82>>0]|0;
        $91 = (($92) + 1)|0;
        HEAP32[$22>>2] = $91;
        $93 = HEAP32[$b>>2]|0;
        $94 = (($93) + ($92)|0);
        HEAP8[$94>>0] = $90;
        $i$1$i$i = $81;
       } else {
        $73 = HEAP32[$22>>2]|0;
        $74 = HEAP32[$23>>2]|0;
        $75 = ($73>>>0)<($74>>>0);
        if ($75) {
         $77 = $73;$80 = $71;
        } else {
         (_luaL_prepbuffsize($b,1)|0);
         $$pre$i$i = HEAP8[$70>>0]|0;
         $$pre2$i$i = HEAP32[$22>>2]|0;
         $77 = $$pre2$i$i;$80 = $$pre$i$i;
        }
        $76 = (($77) + 1)|0;
        HEAP32[$22>>2] = $76;
        $78 = HEAP32[$b>>2]|0;
        $79 = (($78) + ($77)|0);
        HEAP8[$79>>0] = $80;
        $i$1$i$i = $i$01$i$i;
       }
      } while(0);
      $97 = (($i$1$i$i) + 1)|0;
      $98 = HEAP32[$l$i$i>>2]|0;
      $99 = ($97>>>0)<($98>>>0);
      if ($99) {
       $i$01$i$i = $97;
      } else {
       break;
      }
     }
    }
   }
   if ((label|0) == 38) {
    label = 0;
    $100 = (_lua_toboolean($37,-1)|0);
    $101 = ($100|0)==(0);
    if ($101) {
     _lua_settop($37,-2);
     $102 = $33;
     $103 = $src$0;
     $104 = (($102) - ($103))|0;
     (_lua_pushlstring($37,$src$0,$104)|0);
    } else {
     $105 = (_lua_isstring($37,-1)|0);
     $106 = ($105|0)==(0);
     if ($106) {
      $107 = (_lua_type($37,-1)|0);
      $108 = (_lua_typename($37,$107)|0);
      HEAP32[$vararg_buffer3>>2] = $108;
      (_luaL_error($37,11528,$vararg_buffer3)|0);
     }
    }
    _luaL_addvalue($b);
   }
   $109 = ($33>>>0)>($src$0>>>0);
   if ($109) {
    $129 = $35;$130 = $36;$src$1 = $33;
   } else {
    $127 = $35;$128 = $36;
    label = 44;
   }
  }
  if ((label|0) == 44) {
   label = 0;
   $110 = HEAP32[$17>>2]|0;
   $111 = ($src$0>>>0)<($110>>>0);
   if (!($111)) {
    $125 = $127;$126 = $128;$src$2 = $src$0;
    label = 49;
    break;
   }
   $112 = HEAP32[$22>>2]|0;
   $113 = HEAP32[$23>>2]|0;
   $114 = ($112>>>0)<($113>>>0);
   if ($114) {
    $118 = $112;
   } else {
    (_luaL_prepbuffsize($b,1)|0);
    $$pre9 = HEAP32[$22>>2]|0;
    $118 = $$pre9;
   }
   $115 = ((($src$0)) + 1|0);
   $116 = HEAP8[$src$0>>0]|0;
   $117 = (($118) + 1)|0;
   HEAP32[$22>>2] = $117;
   $119 = HEAP32[$b>>2]|0;
   $120 = (($119) + ($118)|0);
   HEAP8[$120>>0] = $116;
   $129 = $127;$130 = $128;$src$1 = $115;
  }
  if ($8) {
   $125 = $129;$126 = $130;$src$2 = $src$1;
   label = 49;
   break;
  } else {
   $27 = $130;$29 = $129;$src$0 = $src$1;
  }
 }
 if ((label|0) == 49) {
  $121 = HEAP32[$17>>2]|0;
  $122 = $121;
  $123 = $src$2;
  $124 = (($122) - ($123))|0;
  _luaL_addlstring($b,$src$2,$124);
  _luaL_pushresult($b);
  _lua_pushinteger($L,$125,$126);
  STACKTOP = sp;return 2;
 }
 return (0)|0;
}
function _str_len($L) {
 $L = $L|0;
 var $0 = 0, $l = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp;
 (_luaL_checklstring($L,1,$l)|0);
 $0 = HEAP32[$l>>2]|0;
 _lua_pushinteger($L,$0,0);
 STACKTOP = sp;return 1;
}
function _str_lower($L) {
 $L = $L|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $i$01 = 0, $l = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp + 4112|0;
 $b = sp;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = HEAP32[$l>>2]|0;
 $2 = (_luaL_buffinitsize($L,$b,$1)|0);
 $3 = HEAP32[$l>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$lcssa = 0;
  _luaL_pushresultsize($b,$$lcssa);
  STACKTOP = sp;return 1;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $5 = (($0) + ($i$01)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = (_tolower($7)|0);
  $9 = $8&255;
  $10 = (($2) + ($i$01)|0);
  HEAP8[$10>>0] = $9;
  $11 = (($i$01) + 1)|0;
  $12 = HEAP32[$l>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $i$01 = $11;
  } else {
   $$lcssa = $12;
   break;
  }
 }
 _luaL_pushresultsize($b,$$lcssa);
 STACKTOP = sp;return 1;
}
function _str_match($L) {
 $L = $L|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_str_find_aux($L,0)|0);
 return ($0|0);
}
function _str_rep($L) {
 $L = $L|0;
 var $$0 = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $l = 0, $lsep = 0, $p$0$be = 0, $p$01 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $l = sp + 4124|0;
 $lsep = sp + 4120|0;
 $b = sp + 8|0;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = (_luaL_checkinteger($L,2)|0);
 $2 = tempRet0;
 $3 = (_luaL_optlstring($L,3,37352,$lsep)|0);
 $4 = ($2|0)<(0);
 $5 = ($1>>>0)<(1);
 $6 = ($2|0)==(0);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  (_lua_pushlstring($L,37352,0)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP32[$l>>2]|0;
 $10 = HEAP32[$lsep>>2]|0;
 $11 = (($10) + ($9))|0;
 $12 = ($11>>>0)<($9>>>0);
 if (!($12)) {
  $13 = (___divdi3(2147483647,0,($1|0),($2|0))|0);
  $14 = tempRet0;
  $15 = (0)>($14|0);
  $16 = ($11>>>0)>($13>>>0);
  $17 = (0)==($14|0);
  $18 = $17 & $16;
  $19 = $15 | $18;
  if (!($19)) {
   $21 = Math_imul($9, $1)|0;
   $22 = (_i64Add(($1|0),($2|0),-1,0)|0);
   $23 = tempRet0;
   $24 = Math_imul($10, $22)|0;
   $25 = (($24) + ($21))|0;
   $26 = (_luaL_buffinitsize($L,$b,$25)|0);
   $27 = ($2|0)>(0);
   $28 = ($1>>>0)>(1);
   $29 = ($2|0)==(0);
   $30 = $29 & $28;
   $31 = $27 | $30;
   $32 = HEAP32[$l>>2]|0;
   _memcpy(($26|0),($0|0),($32|0))|0;
   if ($31) {
    $33 = $1;$34 = $2;$p$01 = $26;
    while(1) {
     $35 = (_i64Add(($33|0),($34|0),-1,-1)|0);
     $36 = tempRet0;
     $37 = HEAP32[$l>>2]|0;
     $38 = (($p$01) + ($37)|0);
     $39 = HEAP32[$lsep>>2]|0;
     $40 = ($39|0)==(0);
     if ($40) {
      $48 = $37;$p$0$be = $38;
     } else {
      _memcpy(($38|0),($3|0),($39|0))|0;
      $41 = HEAP32[$lsep>>2]|0;
      $$sum = (($41) + ($37))|0;
      $42 = (($p$01) + ($$sum)|0);
      $$pre = HEAP32[$l>>2]|0;
      $48 = $$pre;$p$0$be = $42;
     }
     $43 = ($36|0)>(0);
     $44 = ($35>>>0)>(1);
     $45 = ($36|0)==(0);
     $46 = $45 & $44;
     $47 = $43 | $46;
     _memcpy(($p$0$be|0),($0|0),($48|0))|0;
     if ($47) {
      $33 = $35;$34 = $36;$p$01 = $p$0$be;
     } else {
      break;
     }
    }
   }
   _luaL_pushresultsize($b,$25);
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $20 = (_luaL_error($L,11112,$vararg_buffer)|0);
 $$0 = $20;
 STACKTOP = sp;return ($$0|0);
}
function _str_reverse($L) {
 $L = $L|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $i$01 = 0, $l = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp + 4112|0;
 $b = sp;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = HEAP32[$l>>2]|0;
 $2 = (_luaL_buffinitsize($L,$b,$1)|0);
 $3 = HEAP32[$l>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$lcssa = 0;
  _luaL_pushresultsize($b,$$lcssa);
  STACKTOP = sp;return 1;
 } else {
  $7 = $3;$i$01 = 0;
 }
 while(1) {
  $5 = $i$01 ^ -1;
  $6 = (($7) + ($5))|0;
  $8 = (($0) + ($6)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = (($2) + ($i$01)|0);
  HEAP8[$10>>0] = $9;
  $11 = (($i$01) + 1)|0;
  $12 = HEAP32[$l>>2]|0;
  $13 = ($12>>>0)>($11>>>0);
  if ($13) {
   $7 = $12;$i$01 = $11;
  } else {
   $$lcssa = $12;
   break;
  }
 }
 _luaL_pushresultsize($b,$$lcssa);
 STACKTOP = sp;return 1;
}
function _str_sub($L) {
 $L = $L|0;
 var $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = (_luaL_checkinteger($L,2)|0);
 $2 = tempRet0;
 $3 = HEAP32[$l>>2]|0;
 $4 = ($2|0)>(-1);
 $5 = ($1>>>0)>(4294967295);
 $6 = ($2|0)==(-1);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  $30 = $2;$32 = $1;
 } else {
  $9 = (0 - ($1))|0;
  $10 = ($3>>>0)<($9>>>0);
  if ($10) {
   $30 = 0;$32 = 0;
  } else {
   $11 = (_i64Add(($1|0),($2|0),1,0)|0);
   $12 = tempRet0;
   $13 = (_i64Add(($11|0),($12|0),($3|0),0)|0);
   $14 = tempRet0;
   $30 = $14;$32 = $13;
  }
 }
 $15 = (_luaL_optinteger($L,3,-1,-1)|0);
 $16 = tempRet0;
 $17 = HEAP32[$l>>2]|0;
 $18 = ($16|0)>(-1);
 $19 = ($15>>>0)>(4294967295);
 $20 = ($16|0)==(-1);
 $21 = $20 & $19;
 $22 = $18 | $21;
 if ($22) {
  $39 = $16;$41 = $15;
 } else {
  $23 = (0 - ($15))|0;
  $24 = ($17>>>0)<($23>>>0);
  if ($24) {
   $39 = 0;$41 = 0;
  } else {
   $25 = (_i64Add(($15|0),($16|0),1,0)|0);
   $26 = tempRet0;
   $27 = (_i64Add(($25|0),($26|0),($17|0),0)|0);
   $28 = tempRet0;
   $39 = $28;$41 = $27;
  }
 }
 $29 = ($30|0)<(0);
 $31 = ($32>>>0)<(1);
 $33 = ($30|0)==(0);
 $34 = $33 & $31;
 $35 = $29 | $34;
 $36 = $35 ? 1 : $32;
 $37 = $35 ? 0 : $30;
 $38 = ($39|0)>(0);
 $40 = ($41>>>0)>($17>>>0);
 $42 = ($39|0)==(0);
 $43 = $42 & $40;
 $44 = $38 | $43;
 $45 = $44 ? $17 : $41;
 $46 = $44 ? 0 : $39;
 $47 = ($46|0)<($37|0);
 $48 = ($45>>>0)<($36>>>0);
 $49 = ($46|0)==($37|0);
 $50 = $49 & $48;
 $51 = $47 | $50;
 if ($51) {
  (_lua_pushlstring($L,37352,0)|0);
  STACKTOP = sp;return 1;
 } else {
  $$sum = (($36) + -1)|0;
  $52 = (($0) + ($$sum)|0);
  $53 = (_i64Subtract(1,0,($36|0),($37|0))|0);
  $54 = tempRet0;
  $55 = (_i64Add(($53|0),($54|0),($45|0),($46|0))|0);
  $56 = tempRet0;
  (_lua_pushlstring($L,$52,$55)|0);
  STACKTOP = sp;return 1;
 }
 return (0)|0;
}
function _str_upper($L) {
 $L = $L|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $i$01 = 0, $l = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $l = sp + 4112|0;
 $b = sp;
 $0 = (_luaL_checklstring($L,1,$l)|0);
 $1 = HEAP32[$l>>2]|0;
 $2 = (_luaL_buffinitsize($L,$b,$1)|0);
 $3 = HEAP32[$l>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $$lcssa = 0;
  _luaL_pushresultsize($b,$$lcssa);
  STACKTOP = sp;return 1;
 } else {
  $i$01 = 0;
 }
 while(1) {
  $5 = (($0) + ($i$01)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = $6&255;
  $8 = (_toupper($7)|0);
  $9 = $8&255;
  $10 = (($2) + ($i$01)|0);
  HEAP8[$10>>0] = $9;
  $11 = (($i$01) + 1)|0;
  $12 = HEAP32[$l>>2]|0;
  $13 = ($11>>>0)<($12>>>0);
  if ($13) {
   $i$01 = $11;
  } else {
   $$lcssa = $12;
   break;
  }
 }
 _luaL_pushresultsize($b,$$lcssa);
 STACKTOP = sp;return 1;
}
function _str_pack($L) {
 $L = $L|0;
 var $$017$i = 0, $$036$i = 0, $$08$i = 0, $$111$i = 0, $$1210$i = 0, $$149$i = 0, $$op = 0, $$pr33 = 0, $$pre = 0, $$pre39 = 0, $$pre40 = 0, $$pre41 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0.0, $118 = 0, $119 = 0.0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $arg$0$be = 0, $arg$035 = 0, $b = 0, $exitcond$i = 0, $exitcond6$i = 0, $exitcond6$i19 = 0, $exitcond6$i8 = 0, $exitcond8$i = 0, $exitcond8$i15 = 0;
 var $exitcond8$i4 = 0, $fmt = 0, $h = 0, $i$04$i = 0, $i$04$i17 = 0, $i$04$i6 = 0, $i$04$us$i = 0, $i$04$us$i13 = 0, $i$04$us$i2 = 0, $i$12$i = 0, $len = 0, $len3 = 0, $len5 = 0, $ntoalign = 0, $or$cond = 0, $or$cond$i = 0, $scevgep$i = 0, $size = 0, $totalsize$0$be = 0, $totalsize$034 = 0;
 var $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4192|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $b = sp + 80|0;
 $h = sp + 64|0;
 $fmt = sp + 60|0;
 $size = sp + 56|0;
 $ntoalign = sp + 52|0;
 $u = sp;
 $len = sp + 48|0;
 $len3 = sp + 44|0;
 $len5 = sp + 40|0;
 $0 = (_luaL_checklstring($L,1,0)|0);
 HEAP32[$fmt>>2] = $0;
 HEAP32[$h>>2] = $L;
 $1 = ((($h)) + 4|0);
 HEAP32[$1>>2] = 1;
 $2 = ((($h)) + 8|0);
 HEAP32[$2>>2] = 1;
 _lua_pushnil($L);
 _luaL_buffinit($L,$b);
 $3 = HEAP8[$0>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  _luaL_pushresult($b);
  STACKTOP = sp;return 1;
 }
 $5 = ((($b)) + 8|0);
 $6 = ((($b)) + 4|0);
 $arg$035 = 1;$totalsize$034 = 0;
 while(1) {
  $7 = (_getdetails($h,$totalsize$034,$fmt,$size,$ntoalign)|0);
  $8 = HEAP32[$ntoalign>>2]|0;
  $9 = HEAP32[$size>>2]|0;
  $10 = (($8) + ($totalsize$034))|0;
  $11 = (($10) + ($9))|0;
  $12 = (($8) + -1)|0;
  HEAP32[$ntoalign>>2] = $12;
  $13 = ($8|0)>(0);
  if ($13) {
   $14 = (0 - ($8))|0;
   $15 = ($14|0)>(-1);
   $$pr33 = $12;
   while(1) {
    $16 = HEAP32[$5>>2]|0;
    $17 = HEAP32[$6>>2]|0;
    $18 = ($16>>>0)<($17>>>0);
    if ($18) {
     $20 = $16;
    } else {
     (_luaL_prepbuffsize($b,1)|0);
     $$pre = HEAP32[$5>>2]|0;
     $20 = $$pre;
    }
    $19 = (($20) + 1)|0;
    HEAP32[$5>>2] = $19;
    $21 = HEAP32[$b>>2]|0;
    $22 = (($21) + ($20)|0);
    HEAP8[$22>>0] = 0;
    $23 = (($$pr33) + -1)|0;
    $24 = ($$pr33|0)>(0);
    if ($24) {
     $$pr33 = $23;
    } else {
     break;
    }
   }
   $$op = (($8) + -2)|0;
   $25 = $15 ? $$op : -1;
   HEAP32[$ntoalign>>2] = $25;
  }
  $26 = (($arg$035) + 1)|0;
  switch ($7|0) {
  case 5:  {
   $177 = (_luaL_checklstring($L,$26,$len5)|0);
   $178 = (_strlen(($177|0))|0);
   $179 = HEAP32[$len5>>2]|0;
   $180 = ($178|0)==($179|0);
   if ($180) {
    $181 = $178;
   } else {
    (_luaL_argerror($L,$26,11088)|0);
    $$pre40 = HEAP32[$len5>>2]|0;
    $181 = $$pre40;
   }
   _luaL_addlstring($b,$177,$181);
   $182 = HEAP32[$5>>2]|0;
   $183 = HEAP32[$6>>2]|0;
   $184 = ($182>>>0)<($183>>>0);
   if ($184) {
    $186 = $182;
   } else {
    (_luaL_prepbuffsize($b,1)|0);
    $$pre41 = HEAP32[$5>>2]|0;
    $186 = $$pre41;
   }
   $185 = (($186) + 1)|0;
   HEAP32[$5>>2] = $185;
   $187 = HEAP32[$b>>2]|0;
   $188 = (($187) + ($186)|0);
   HEAP8[$188>>0] = 0;
   $189 = HEAP32[$len5>>2]|0;
   $190 = (($11) + 1)|0;
   $191 = (($190) + ($189))|0;
   $arg$0$be = $26;$totalsize$0$be = $191;
   break;
  }
  case 4:  {
   $142 = (_luaL_checklstring($L,$26,$len3)|0);
   $143 = ($9|0)>(3);
   if (!($143)) {
    $144 = HEAP32[$len3>>2]|0;
    $145 = $9 << 3;
    $146 = 1 << $145;
    $147 = ($144>>>0)<($146>>>0);
    if (!($147)) {
     (_luaL_argerror($L,$26,11040)|0);
    }
   }
   $148 = HEAP32[$len3>>2]|0;
   $149 = HEAP32[$1>>2]|0;
   $150 = (_luaL_prepbuffsize($b,$9)|0);
   $151 = $148&255;
   $152 = ($149|0)!=(0);
   $153 = (($9) + -1)|0;
   $154 = $152 ? 0 : $153;
   $155 = (($150) + ($154)|0);
   HEAP8[$155>>0] = $151;
   $156 = ($9|0)>(1);
   if ($156) {
    if ($152) {
     $157 = $148;$158 = 0;$i$04$us$i = 1;
     while(1) {
      $159 = (_bitshift64Lshr(($157|0),($158|0),8)|0);
      $160 = tempRet0;
      $161 = $159&255;
      $162 = (($150) + ($i$04$us$i)|0);
      HEAP8[$162>>0] = $161;
      $163 = (($i$04$us$i) + 1)|0;
      $exitcond8$i = ($163|0)==($9|0);
      if ($exitcond8$i) {
       break;
      } else {
       $157 = $159;$158 = $160;$i$04$us$i = $163;
      }
     }
    } else {
     $164 = $148;$165 = 0;$i$04$i = 1;
     while(1) {
      $166 = (_bitshift64Lshr(($164|0),($165|0),8)|0);
      $167 = tempRet0;
      $168 = $166&255;
      $169 = (($153) - ($i$04$i))|0;
      $170 = (($150) + ($169)|0);
      HEAP8[$170>>0] = $168;
      $171 = (($i$04$i) + 1)|0;
      $exitcond6$i = ($171|0)==($9|0);
      if ($exitcond6$i) {
       break;
      } else {
       $164 = $166;$165 = $167;$i$04$i = $171;
      }
     }
    }
   }
   $172 = HEAP32[$5>>2]|0;
   $173 = (($172) + ($9))|0;
   HEAP32[$5>>2] = $173;
   $174 = HEAP32[$len3>>2]|0;
   _luaL_addlstring($b,$142,$174);
   $175 = HEAP32[$len3>>2]|0;
   $176 = (($175) + ($11))|0;
   $arg$0$be = $26;$totalsize$0$be = $176;
   break;
  }
  case 6:  {
   $192 = HEAP32[$5>>2]|0;
   $193 = HEAP32[$6>>2]|0;
   $194 = ($192>>>0)<($193>>>0);
   if ($194) {
    $196 = $192;
   } else {
    (_luaL_prepbuffsize($b,1)|0);
    $$pre39 = HEAP32[$5>>2]|0;
    $196 = $$pre39;
   }
   $195 = (($196) + 1)|0;
   HEAP32[$5>>2] = $195;
   $197 = HEAP32[$b>>2]|0;
   $198 = (($197) + ($196)|0);
   HEAP8[$198>>0] = 0;
   label = 60;
   break;
  }
  case 1:  {
   $80 = (_luaL_checkinteger($L,$26)|0);
   $81 = tempRet0;
   $82 = ($9|0)<(8);
   if ($82) {
    $83 = $9 << 3;
    $84 = (_bitshift64Shl(1,0,($83|0))|0);
    $85 = tempRet0;
    $86 = ($81>>>0)<($85>>>0);
    $87 = ($80>>>0)<($84>>>0);
    $88 = ($81|0)==($85|0);
    $89 = $88 & $87;
    $90 = $86 | $89;
    if (!($90)) {
     (_luaL_argerror($L,$26,11000)|0);
    }
   }
   $91 = HEAP32[$1>>2]|0;
   $92 = (_luaL_prepbuffsize($b,$9)|0);
   $93 = $80&255;
   $94 = ($91|0)!=(0);
   $95 = (($9) + -1)|0;
   $96 = $94 ? 0 : $95;
   $97 = (($92) + ($96)|0);
   HEAP8[$97>>0] = $93;
   $98 = ($9|0)>(1);
   if ($98) {
    if ($94) {
     $100 = $81;$99 = $80;$i$04$us$i13 = 1;
     while(1) {
      $101 = (_bitshift64Lshr(($99|0),($100|0),8)|0);
      $102 = tempRet0;
      $103 = $101&255;
      $104 = (($92) + ($i$04$us$i13)|0);
      HEAP8[$104>>0] = $103;
      $105 = (($i$04$us$i13) + 1)|0;
      $exitcond8$i15 = ($105|0)==($9|0);
      if ($exitcond8$i15) {
       break;
      } else {
       $100 = $102;$99 = $101;$i$04$us$i13 = $105;
      }
     }
    } else {
     $106 = $80;$107 = $81;$i$04$i17 = 1;
     while(1) {
      $108 = (_bitshift64Lshr(($106|0),($107|0),8)|0);
      $109 = tempRet0;
      $110 = $108&255;
      $111 = (($95) - ($i$04$i17))|0;
      $112 = (($92) + ($111)|0);
      HEAP8[$112>>0] = $110;
      $113 = (($i$04$i17) + 1)|0;
      $exitcond6$i19 = ($113|0)==($9|0);
      if ($exitcond6$i19) {
       break;
      } else {
       $106 = $108;$107 = $109;$i$04$i17 = $113;
      }
     }
    }
   }
   $114 = HEAP32[$5>>2]|0;
   $115 = (($114) + ($9))|0;
   HEAP32[$5>>2] = $115;
   $arg$0$be = $26;$totalsize$0$be = $11;
   break;
  }
  case 8: case 7:  {
   label = 60;
   break;
  }
  case 2:  {
   $116 = (_luaL_prepbuffsize($b,$9)|0);
   $117 = (+_luaL_checknumber($L,$26));
   $118 = ($9|0)==(4);
   if ($118) {
    $119 = $117;
    HEAPF32[$u>>2] = $119;
   } else {
    HEAPF64[$u>>3] = $117;
   }
   $120 = HEAP32[$size>>2]|0;
   $121 = HEAP32[$1>>2]|0;
   $122 = ($121|0)==(1);
   $123 = ($120|0)==(0);
   if ($122) {
    if (!($123)) {
     $$017$i = $120;$$036$i = $u;$$08$i = $116;
     while(1) {
      $124 = (($$017$i) + -1)|0;
      $125 = ((($$036$i)) + 1|0);
      $126 = HEAP8[$$036$i>>0]|0;
      $127 = ((($$08$i)) + 1|0);
      HEAP8[$$08$i>>0] = $126;
      $128 = ($124|0)==(0);
      if ($128) {
       break;
      } else {
       $$017$i = $124;$$036$i = $125;$$08$i = $127;
      }
     }
    }
   } else {
    if (!($123)) {
     $129 = (($120) + -1)|0;
     $130 = (($116) + ($129)|0);
     $$111$i = $130;$$1210$i = $120;$$149$i = $u;
     while(1) {
      $131 = (($$1210$i) + -1)|0;
      $132 = ((($$149$i)) + 1|0);
      $133 = HEAP8[$$149$i>>0]|0;
      $134 = ((($$111$i)) + -1|0);
      HEAP8[$$111$i>>0] = $133;
      $135 = ($131|0)==(0);
      if ($135) {
       break;
      } else {
       $$111$i = $134;$$1210$i = $131;$$149$i = $132;
      }
     }
    }
   }
   $136 = HEAP32[$size>>2]|0;
   $137 = HEAP32[$5>>2]|0;
   $138 = (($137) + ($136))|0;
   HEAP32[$5>>2] = $138;
   $arg$0$be = $26;$totalsize$0$be = $11;
   break;
  }
  case 3:  {
   $139 = (_luaL_checklstring($L,$26,$len)|0);
   $140 = HEAP32[$len>>2]|0;
   $141 = ($140|0)==($9|0);
   if (!($141)) {
    (_luaL_argerror($L,$26,11024)|0);
   }
   _luaL_addlstring($b,$139,$9);
   $arg$0$be = $26;$totalsize$0$be = $11;
   break;
  }
  case 0:  {
   $30 = (_luaL_checkinteger($L,$26)|0);
   $31 = tempRet0;
   $32 = ($9|0)<(8);
   if ($32) {
    $33 = $9 << 3;
    $34 = (($33) + -1)|0;
    $35 = (_bitshift64Shl(1,0,($34|0))|0);
    $36 = tempRet0;
    $37 = (_i64Subtract(0,0,($35|0),($36|0))|0);
    $38 = tempRet0;
    $39 = ($31|0)>($38|0);
    $40 = ($30>>>0)>=($37>>>0);
    $41 = ($31|0)==($38|0);
    $42 = $41 & $40;
    $43 = $39 | $42;
    $44 = ($31|0)<($36|0);
    $45 = ($30>>>0)<($35>>>0);
    $46 = ($31|0)==($36|0);
    $47 = $46 & $45;
    $48 = $44 | $47;
    $or$cond = $43 & $48;
    if (!($or$cond)) {
     (_luaL_argerror($L,$26,10976)|0);
    }
   }
   $49 = HEAP32[$1>>2]|0;
   $50 = (_luaL_prepbuffsize($b,$9)|0);
   $51 = $30&255;
   $52 = ($49|0)!=(0);
   $53 = (($9) + -1)|0;
   $54 = $52 ? 0 : $53;
   $55 = (($50) + ($54)|0);
   HEAP8[$55>>0] = $51;
   $56 = ($9|0)>(1);
   do {
    if ($56) {
     if ($52) {
      $57 = $30;$58 = $31;$i$04$us$i2 = 1;
      while(1) {
       $59 = (_bitshift64Lshr(($57|0),($58|0),8)|0);
       $60 = tempRet0;
       $61 = $59&255;
       $62 = (($50) + ($i$04$us$i2)|0);
       HEAP8[$62>>0] = $61;
       $63 = (($i$04$us$i2) + 1)|0;
       $exitcond8$i4 = ($63|0)==($9|0);
       if ($exitcond8$i4) {
        break;
       } else {
        $57 = $59;$58 = $60;$i$04$us$i2 = $63;
       }
      }
     } else {
      $64 = $30;$65 = $31;$i$04$i6 = 1;
      while(1) {
       $66 = (_bitshift64Lshr(($64|0),($65|0),8)|0);
       $67 = tempRet0;
       $68 = $66&255;
       $69 = (($53) - ($i$04$i6))|0;
       $70 = (($50) + ($69)|0);
       HEAP8[$70>>0] = $68;
       $71 = (($i$04$i6) + 1)|0;
       $exitcond6$i8 = ($71|0)==($9|0);
       if ($exitcond6$i8) {
        break;
       } else {
        $64 = $66;$65 = $67;$i$04$i6 = $71;
       }
      }
     }
     $72 = ($31|0)<(0);
     $73 = ($9|0)>(8);
     $or$cond$i = $72 & $73;
     if ($or$cond$i) {
      if ($52) {
       $scevgep$i = ((($50)) + 8|0);
       $74 = (($9) + -8)|0;
       _memset(($scevgep$i|0),-1,($74|0))|0;
       break;
      } else {
       $i$12$i = 8;
       while(1) {
        $75 = (($53) - ($i$12$i))|0;
        $76 = (($50) + ($75)|0);
        HEAP8[$76>>0] = -1;
        $77 = (($i$12$i) + 1)|0;
        $exitcond$i = ($77|0)==($9|0);
        if ($exitcond$i) {
         break;
        } else {
         $i$12$i = $77;
        }
       }
      }
     }
    }
   } while(0);
   $78 = HEAP32[$5>>2]|0;
   $79 = (($78) + ($9))|0;
   HEAP32[$5>>2] = $79;
   $arg$0$be = $26;$totalsize$0$be = $11;
   break;
  }
  default: {
   $arg$0$be = $26;$totalsize$0$be = $11;
  }
  }
  if ((label|0) == 60) {
   label = 0;
   $arg$0$be = $arg$035;$totalsize$0$be = $11;
  }
  $27 = HEAP32[$fmt>>2]|0;
  $28 = HEAP8[$27>>0]|0;
  $29 = ($28<<24>>24)==(0);
  if ($29) {
   break;
  } else {
   $arg$035 = $arg$0$be;$totalsize$034 = $totalsize$0$be;
  }
 }
 _luaL_pushresult($b);
 STACKTOP = sp;return 1;
}
function _str_packsize($L) {
 $L = $L|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $fmt = 0;
 var $h = 0, $ntoalign = 0, $size = 0, $switch = 0, $totalsize$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $h = sp + 12|0;
 $fmt = sp + 8|0;
 $size = sp + 4|0;
 $ntoalign = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 HEAP32[$fmt>>2] = $0;
 HEAP32[$h>>2] = $L;
 $1 = ((($h)) + 4|0);
 HEAP32[$1>>2] = 1;
 $2 = ((($h)) + 8|0);
 HEAP32[$2>>2] = 1;
 $3 = HEAP8[$0>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $16 = 0;$17 = 0;
  _lua_pushinteger($L,$16,$17);
  STACKTOP = sp;return 1;
 } else {
  $totalsize$01 = 0;
 }
 while(1) {
  $5 = (_getdetails($h,$totalsize$01,$fmt,$size,$ntoalign)|0);
  $6 = HEAP32[$ntoalign>>2]|0;
  $7 = HEAP32[$size>>2]|0;
  $8 = (($7) + ($6))|0;
  HEAP32[$size>>2] = $8;
  $9 = (2147483647 - ($8))|0;
  $10 = ($totalsize$01>>>0)>($9>>>0);
  if ($10) {
   (_luaL_argerror($L,1,10928)|0);
  }
  $11 = (($8) + ($totalsize$01))|0;
  $12 = $5 & -2;
  $switch = ($12|0)==(4);
  if ($switch) {
   (_luaL_argerror($L,1,10952)|0);
  }
  $13 = HEAP32[$fmt>>2]|0;
  $14 = HEAP8[$13>>0]|0;
  $15 = ($14<<24>>24)==(0);
  if ($15) {
   $$lcssa = $11;
   break;
  } else {
   $totalsize$01 = $11;
  }
 }
 $16 = $$lcssa;$17 = 0;
 _lua_pushinteger($L,$16,$17);
 STACKTOP = sp;return 1;
}
function _str_unpack($L) {
 $L = $L|0;
 var $$0$i$off0 = 0, $$017$i = 0, $$036$i = 0, $$08$i = 0, $$111$i = 0, $$1210$i = 0, $$149$i = 0, $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $9 = 0, $fmt = 0, $h = 0, $ld = 0, $n$0$lcssa = 0, $n$03 = 0, $n$1 = 0, $ntoalign = 0, $num$0 = 0.0, $pos$0$lcssa = 0;
 var $pos$04 = 0, $pos$1 = 0, $size = 0, $u = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $h = sp + 56|0;
 $fmt = sp + 52|0;
 $ld = sp + 48|0;
 $size = sp + 44|0;
 $ntoalign = sp + 40|0;
 $u = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 HEAP32[$fmt>>2] = $0;
 $1 = (_luaL_checklstring($L,2,$ld)|0);
 $2 = (_luaL_optinteger($L,3,1,0)|0);
 $3 = tempRet0;
 $4 = HEAP32[$ld>>2]|0;
 $5 = ($3|0)>(-1);
 $6 = ($2>>>0)>(4294967295);
 $7 = ($3|0)==(-1);
 $8 = $7 & $6;
 $9 = $5 | $8;
 if ($9) {
  $$0$i$off0 = $2;
 } else {
  $10 = (0 - ($2))|0;
  $11 = ($4>>>0)<($10>>>0);
  if ($11) {
   $$0$i$off0 = 0;
  } else {
   $12 = (_i64Add(($2|0),($3|0),1,0)|0);
   $13 = tempRet0;
   $14 = (_i64Add(($12|0),($13|0),($4|0),0)|0);
   $15 = tempRet0;
   $$0$i$off0 = $14;
  }
 }
 $16 = (($$0$i$off0) + -1)|0;
 $17 = ($16>>>0)>($4>>>0);
 if ($17) {
  (_luaL_argerror($L,3,12328)|0);
 }
 HEAP32[$h>>2] = $L;
 $18 = ((($h)) + 4|0);
 HEAP32[$18>>2] = 1;
 $19 = ((($h)) + 8|0);
 HEAP32[$19>>2] = 1;
 $20 = HEAP8[$0>>0]|0;
 $21 = ($20<<24>>24)==(0);
 if ($21) {
  $n$0$lcssa = 0;$pos$0$lcssa = $16;
  $79 = (($pos$0$lcssa) + 1)|0;
  _lua_pushinteger($L,$79,0);
  $80 = (($n$0$lcssa) + 1)|0;
  STACKTOP = sp;return ($80|0);
 }
 $n$03 = 0;$pos$04 = $16;
 while(1) {
  $22 = (_getdetails($h,$pos$04,$fmt,$size,$ntoalign)|0);
  $23 = HEAP32[$ntoalign>>2]|0;
  $24 = HEAP32[$size>>2]|0;
  $25 = (($24) + ($23))|0;
  $26 = $pos$04 ^ -1;
  $27 = ($25>>>0)>($26>>>0);
  if ($27) {
   label = 10;
  } else {
   $28 = (($23) + ($pos$04))|0;
   $29 = (($28) + ($24))|0;
   $30 = HEAP32[$ld>>2]|0;
   $31 = ($29>>>0)>($30>>>0);
   if ($31) {
    label = 10;
   } else {
    $$pre$phiZ2D = $28;
   }
  }
  if ((label|0) == 10) {
   label = 0;
   (_luaL_argerror($L,2,10632)|0);
   $$pre = (($23) + ($pos$04))|0;
   $$pre$phiZ2D = $$pre;
  }
  _luaL_checkstack($L,2,10656);
  $32 = (($n$03) + 1)|0;
  switch ($22|0) {
  case 2:  {
   $39 = (($1) + ($$pre$phiZ2D)|0);
   $40 = HEAP32[$18>>2]|0;
   $41 = ($40|0)==(1);
   $42 = ($24|0)==(0);
   if ($41) {
    if (!($42)) {
     $$017$i = $24;$$036$i = $39;$$08$i = $u;
     while(1) {
      $43 = (($$017$i) + -1)|0;
      $44 = ((($$036$i)) + 1|0);
      $45 = HEAP8[$$036$i>>0]|0;
      $46 = ((($$08$i)) + 1|0);
      HEAP8[$$08$i>>0] = $45;
      $47 = ($43|0)==(0);
      if ($47) {
       break;
      } else {
       $$017$i = $43;$$036$i = $44;$$08$i = $46;
      }
     }
    }
   } else {
    if (!($42)) {
     $48 = (($24) + -1)|0;
     $49 = (($u) + ($48)|0);
     $$111$i = $49;$$1210$i = $24;$$149$i = $39;
     while(1) {
      $50 = (($$1210$i) + -1)|0;
      $51 = ((($$149$i)) + 1|0);
      $52 = HEAP8[$$149$i>>0]|0;
      $53 = ((($$111$i)) + -1|0);
      HEAP8[$$111$i>>0] = $52;
      $54 = ($50|0)==(0);
      if ($54) {
       break;
      } else {
       $$111$i = $53;$$1210$i = $50;$$149$i = $51;
      }
     }
    }
   }
   $55 = HEAP32[$size>>2]|0;
   $56 = ($55|0)==(4);
   if ($56) {
    $57 = +HEAPF32[$u>>2];
    $58 = $57;
    $num$0 = $58;
   } else {
    $59 = +HEAPF64[$u>>3];
    $num$0 = $59;
   }
   _lua_pushnumber($L,$num$0);
   $75 = $55;$n$1 = $32;$pos$1 = $$pre$phiZ2D;
   break;
  }
  case 5:  {
   $70 = (($1) + ($$pre$phiZ2D)|0);
   $71 = (_strlen(($70|0))|0);
   (_lua_pushlstring($L,$70,$71)|0);
   $72 = (($$pre$phiZ2D) + 1)|0;
   $73 = (($72) + ($71))|0;
   $75 = $24;$n$1 = $32;$pos$1 = $73;
   break;
  }
  case 8: case 6: case 7:  {
   $75 = $24;$n$1 = $n$03;$pos$1 = $$pre$phiZ2D;
   break;
  }
  case 1: case 0:  {
   $33 = (($1) + ($$pre$phiZ2D)|0);
   $34 = HEAP32[$18>>2]|0;
   $35 = ($22|0)==(0);
   $36 = $35&1;
   $37 = (_unpackint($L,$33,$34,$24,$36)|0);
   $38 = tempRet0;
   _lua_pushinteger($L,$37,$38);
   $75 = $24;$n$1 = $32;$pos$1 = $$pre$phiZ2D;
   break;
  }
  case 4:  {
   $61 = (($1) + ($$pre$phiZ2D)|0);
   $62 = HEAP32[$18>>2]|0;
   $63 = (_unpackint($L,$61,$62,$24,0)|0);
   $64 = tempRet0;
   $65 = (($63) + ($$pre$phiZ2D))|0;
   $66 = (($65) + ($24))|0;
   $67 = HEAP32[$ld>>2]|0;
   $68 = ($66>>>0)>($67>>>0);
   if ($68) {
    (_luaL_argerror($L,2,10632)|0);
   }
   $$sum = (($24) + ($$pre$phiZ2D))|0;
   $69 = (($1) + ($$sum)|0);
   (_lua_pushlstring($L,$69,$63)|0);
   $75 = $24;$n$1 = $32;$pos$1 = $65;
   break;
  }
  case 3:  {
   $60 = (($1) + ($$pre$phiZ2D)|0);
   (_lua_pushlstring($L,$60,$24)|0);
   $75 = $24;$n$1 = $32;$pos$1 = $$pre$phiZ2D;
   break;
  }
  default: {
   $75 = $24;$n$1 = $32;$pos$1 = $$pre$phiZ2D;
  }
  }
  $74 = (($75) + ($pos$1))|0;
  $76 = HEAP32[$fmt>>2]|0;
  $77 = HEAP8[$76>>0]|0;
  $78 = ($77<<24>>24)==(0);
  if ($78) {
   $n$0$lcssa = $n$1;$pos$0$lcssa = $74;
   break;
  } else {
   $n$03 = $n$1;$pos$04 = $74;
  }
 }
 $79 = (($pos$0$lcssa) + 1)|0;
 _lua_pushinteger($L,$79,0);
 $80 = (($n$0$lcssa) + 1)|0;
 STACKTOP = sp;return ($80|0);
}
function _getdetails($h,$totalsize,$fmt,$psize,$ntoalign) {
 $h = $h|0;
 $totalsize = $totalsize|0;
 $fmt = $fmt|0;
 $psize = $psize|0;
 $ntoalign = $ntoalign|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $align = 0, $or$cond = 0, $or$cond3 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $align = sp;
 $0 = (_getoption($h,$fmt,$psize)|0);
 $1 = HEAP32[$psize>>2]|0;
 HEAP32[$align>>2] = $1;
 $2 = ($0|0)==(7);
 do {
  if ($2) {
   $3 = HEAP32[$fmt>>2]|0;
   $4 = HEAP8[$3>>0]|0;
   $5 = ($4<<24>>24)==(0);
   if ($5) {
    $25 = $1;
   } else {
    $6 = (_getoption($h,$fmt,$align)|0);
    $7 = ($6|0)==(3);
    $8 = HEAP32[$align>>2]|0;
    $9 = ($8|0)==(0);
    $or$cond = $7 | $9;
    if ($or$cond) {
     $25 = $8;
    } else {
     $12 = $8;
     break;
    }
   }
   $10 = HEAP32[$h>>2]|0;
   (_luaL_argerror($10,1,10728)|0);
   $12 = $25;
  } else {
   $12 = $1;
  }
 } while(0);
 $11 = ($12|0)<(2);
 $13 = ($0|0)==(3);
 $or$cond3 = $13 | $11;
 if ($or$cond3) {
  $storemerge = 0;
  HEAP32[$ntoalign>>2] = $storemerge;
  STACKTOP = sp;return ($0|0);
 }
 $14 = ((($h)) + 8|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = ($12|0)>($15|0);
 if ($16) {
  HEAP32[$align>>2] = $15;
  $18 = $15;
 } else {
  $18 = $12;
 }
 $17 = (($18) + -1)|0;
 $19 = $17 & $18;
 $20 = ($19|0)==(0);
 if (!($20)) {
  $21 = HEAP32[$h>>2]|0;
  (_luaL_argerror($21,1,10768)|0);
 }
 $22 = $17 & $totalsize;
 $23 = (($18) - ($22))|0;
 $24 = $23 & $17;
 $storemerge = $24;
 HEAP32[$ntoalign>>2] = $storemerge;
 STACKTOP = sp;return ($0|0);
}
function _unpackint($L,$str,$islittle,$size,$issigned) {
 $L = $L|0;
 $str = $str|0;
 $islittle = $islittle|0;
 $size = $size|0;
 $issigned = $issigned|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $i$0 = 0, $i$0$us = 0, $i$02 = 0, $i$04 = 0, $i$04$us = 0, $i$11 = 0, $i$11$us = 0, $not$ = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ($size|0)>(8);
 $1 = $0 ? 8 : $size;
 $i$02 = (($1) + -1)|0;
 $2 = ($1|0)>(0);
 if ($2) {
  $3 = ($islittle|0)==(0);
  $4 = (($size) + -1)|0;
  if ($3) {
   $5 = 0;$6 = 0;$i$04$us = $i$02;
   while(1) {
    $7 = (_bitshift64Shl(($5|0),($6|0),8)|0);
    $8 = tempRet0;
    $9 = (($4) - ($i$04$us))|0;
    $10 = (($str) + ($9)|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = $11&255;
    $13 = $12 | $7;
    $i$0$us = (($i$04$us) + -1)|0;
    $14 = ($i$04$us|0)>(0);
    if ($14) {
     $5 = $13;$6 = $8;$i$04$us = $i$0$us;
    } else {
     $31 = $13;$33 = $8;
     break;
    }
   }
  } else {
   $15 = 0;$16 = 0;$i$04 = $i$02;
   while(1) {
    $17 = (_bitshift64Shl(($15|0),($16|0),8)|0);
    $18 = tempRet0;
    $19 = (($str) + ($i$04)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20&255;
    $22 = $21 | $17;
    $i$0 = (($i$04) + -1)|0;
    $23 = ($i$04|0)>(0);
    if ($23) {
     $15 = $22;$16 = $18;$i$04 = $i$0;
    } else {
     $31 = $22;$33 = $18;
     break;
    }
   }
  }
 } else {
  $31 = 0;$33 = 0;
 }
 $24 = ($size|0)<(8);
 if ($24) {
  $25 = ($issigned|0)==(0);
  if ($25) {
   $58 = $33;$59 = $31;
   tempRet0 = ($58);
   STACKTOP = sp;return ($59|0);
  }
  $26 = $size << 3;
  $27 = (($26) + -1)|0;
  $28 = (_bitshift64Shl(1,0,($27|0))|0);
  $29 = tempRet0;
  $30 = $31 ^ $28;
  $32 = $33 ^ $29;
  $34 = (_i64Subtract(($30|0),($32|0),($28|0),($29|0))|0);
  $35 = tempRet0;
  $58 = $35;$59 = $34;
  tempRet0 = ($58);
  STACKTOP = sp;return ($59|0);
 }
 if (!($0)) {
  $58 = $33;$59 = $31;
  tempRet0 = ($58);
  STACKTOP = sp;return ($59|0);
 }
 $36 = ($33|0)>(-1);
 $37 = ($31>>>0)>(4294967295);
 $38 = ($33|0)==(-1);
 $39 = $38 & $37;
 $40 = $36 | $39;
 $not$ = ($issigned|0)==(0);
 $41 = $not$ | $40;
 $42 = $41 ? 0 : 255;
 $43 = ($islittle|0)==(0);
 $44 = (($size) + -1)|0;
 if ($43) {
  $i$11$us = $1;
  while(1) {
   $45 = (($44) - ($i$11$us))|0;
   $46 = (($str) + ($45)|0);
   $47 = HEAP8[$46>>0]|0;
   $48 = $47&255;
   $49 = ($48|0)==($42|0);
   if (!($49)) {
    HEAP32[$vararg_buffer>>2] = $size;
    (_luaL_error($L,10680,$vararg_buffer)|0);
   }
   $50 = (($i$11$us) + 1)|0;
   $51 = ($50|0)<($size|0);
   if ($51) {
    $i$11$us = $50;
   } else {
    $58 = $33;$59 = $31;
    break;
   }
  }
  tempRet0 = ($58);
  STACKTOP = sp;return ($59|0);
 } else {
  $i$11 = $1;
  while(1) {
   $52 = (($str) + ($i$11)|0);
   $53 = HEAP8[$52>>0]|0;
   $54 = $53&255;
   $55 = ($54|0)==($42|0);
   if (!($55)) {
    HEAP32[$vararg_buffer1>>2] = $size;
    (_luaL_error($L,10680,$vararg_buffer1)|0);
   }
   $56 = (($i$11) + 1)|0;
   $57 = ($56|0)<($size|0);
   if ($57) {
    $i$11 = $56;
   } else {
    $58 = $33;$59 = $31;
    break;
   }
  }
  tempRet0 = ($58);
  STACKTOP = sp;return ($59|0);
 }
 return (0)|0;
}
function _getoption($h,$fmt,$size) {
 $h = $h|0;
 $fmt = $fmt|0;
 $size = $size|0;
 var $$0 = 0, $$0$i$i1330 = 0, $$0$i$i2132 = 0, $$0$i$i26 = 0, $$0$i$i528 = 0, $$lcssa = 0, $$lcssa53 = 0, $$lcssa54 = 0, $$lcssa55 = 0, $$lcssa56 = 0, $$off$i = 0, $$off$i14 = 0, $$off$i22 = 0, $$off$i6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $a$0$i = 0, $a$0$i$i = 0, $a$0$i$i10 = 0, $a$0$i$i18 = 0, $a$0$i$i2 = 0, $c$off$i$i = 0, $c$off$i$i$i = 0, $c$off$i$i$i1 = 0, $c$off$i$i$i17 = 0, $c$off$i$i$i9 = 0, $c$off$i1$i = 0, $c$off$i1$i$i = 0;
 var $c$off$i1$i$i11 = 0, $c$off$i1$i$i19 = 0, $c$off$i1$i$i3 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer12 = 0, $vararg_buffer16 = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr15 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer16 = sp + 40|0;
 $vararg_buffer12 = sp + 32|0;
 $vararg_buffer10 = sp + 24|0;
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$fmt>>2]|0;
 $1 = ((($0)) + 1|0);
 HEAP32[$fmt>>2] = $1;
 $2 = HEAP8[$0>>0]|0;
 $3 = $2 << 24 >> 24;
 HEAP32[$size>>2] = 0;
 do {
  switch ($3|0) {
  case 98:  {
   HEAP32[$size>>2] = 1;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 105:  {
   $4 = HEAP8[$1>>0]|0;
   $5 = $4 << 24 >> 24;
   $c$off$i$i$i = (($5) + -48)|0;
   $6 = ($c$off$i$i$i>>>0)<(10);
   if ($6) {
    $9 = $1;$a$0$i$i = 0;
    while(1) {
     $7 = ($a$0$i$i*10)|0;
     $8 = ((($9)) + 1|0);
     HEAP32[$fmt>>2] = $8;
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 << 24 >> 24;
     $12 = (($7) + -48)|0;
     $13 = (($12) + ($11))|0;
     $14 = HEAP8[$8>>0]|0;
     $15 = $14 << 24 >> 24;
     $c$off$i1$i$i = (($15) + -48)|0;
     $16 = ($c$off$i1$i$i>>>0)<(10);
     $17 = ($13|0)<(214748364);
     $18 = $17 & $16;
     if ($18) {
      $9 = $8;$a$0$i$i = $13;
     } else {
      $$lcssa = $13;
      break;
     }
    }
    $$off$i = (($$lcssa) + -1)|0;
    $19 = ($$off$i>>>0)>(15);
    if ($19) {
     $20 = HEAP32[$h>>2]|0;
     HEAP32[$vararg_buffer>>2] = $$lcssa;
     $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
     HEAP32[$vararg_ptr1>>2] = 16;
     (_luaL_error($20,10816,$vararg_buffer)|0);
     $$0$i$i26 = $$lcssa;
    } else {
     $$0$i$i26 = $$lcssa;
    }
   } else {
    $$0$i$i26 = 4;
   }
   HEAP32[$size>>2] = $$0$i$i26;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 72:  {
   HEAP32[$size>>2] = 2;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 88:  {
   $$0 = 7;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 60:  {
   $72 = ((($h)) + 4|0);
   HEAP32[$72>>2] = 1;
   break;
  }
  case 100:  {
   HEAP32[$size>>2] = 8;
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 76:  {
   HEAP32[$size>>2] = 4;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 115:  {
   $38 = HEAP8[$1>>0]|0;
   $39 = $38 << 24 >> 24;
   $c$off$i$i$i9 = (($39) + -48)|0;
   $40 = ($c$off$i$i$i9>>>0)<(10);
   if ($40) {
    $43 = $1;$a$0$i$i10 = 0;
    while(1) {
     $41 = ($a$0$i$i10*10)|0;
     $42 = ((($43)) + 1|0);
     HEAP32[$fmt>>2] = $42;
     $44 = HEAP8[$43>>0]|0;
     $45 = $44 << 24 >> 24;
     $46 = (($41) + -48)|0;
     $47 = (($46) + ($45))|0;
     $48 = HEAP8[$42>>0]|0;
     $49 = $48 << 24 >> 24;
     $c$off$i1$i$i11 = (($49) + -48)|0;
     $50 = ($c$off$i1$i$i11>>>0)<(10);
     $51 = ($47|0)<(214748364);
     $52 = $51 & $50;
     if ($52) {
      $43 = $42;$a$0$i$i10 = $47;
     } else {
      $$lcssa54 = $47;
      break;
     }
    }
    $$off$i14 = (($$lcssa54) + -1)|0;
    $53 = ($$off$i14>>>0)>(15);
    if ($53) {
     $54 = HEAP32[$h>>2]|0;
     HEAP32[$vararg_buffer6>>2] = $$lcssa54;
     $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
     HEAP32[$vararg_ptr9>>2] = 16;
     (_luaL_error($54,10816,$vararg_buffer6)|0);
     $$0$i$i1330 = $$lcssa54;
    } else {
     $$0$i$i1330 = $$lcssa54;
    }
   } else {
    $$0$i$i1330 = 4;
   }
   HEAP32[$size>>2] = $$0$i$i1330;
   $$0 = 4;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 62:  {
   $73 = ((($h)) + 4|0);
   HEAP32[$73>>2] = 0;
   break;
  }
  case 74:  {
   HEAP32[$size>>2] = 8;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 84:  {
   HEAP32[$size>>2] = 4;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 66:  {
   HEAP32[$size>>2] = 1;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 73:  {
   $21 = HEAP8[$1>>0]|0;
   $22 = $21 << 24 >> 24;
   $c$off$i$i$i1 = (($22) + -48)|0;
   $23 = ($c$off$i$i$i1>>>0)<(10);
   if ($23) {
    $26 = $1;$a$0$i$i2 = 0;
    while(1) {
     $24 = ($a$0$i$i2*10)|0;
     $25 = ((($26)) + 1|0);
     HEAP32[$fmt>>2] = $25;
     $27 = HEAP8[$26>>0]|0;
     $28 = $27 << 24 >> 24;
     $29 = (($24) + -48)|0;
     $30 = (($29) + ($28))|0;
     $31 = HEAP8[$25>>0]|0;
     $32 = $31 << 24 >> 24;
     $c$off$i1$i$i3 = (($32) + -48)|0;
     $33 = ($c$off$i1$i$i3>>>0)<(10);
     $34 = ($30|0)<(214748364);
     $35 = $34 & $33;
     if ($35) {
      $26 = $25;$a$0$i$i2 = $30;
     } else {
      $$lcssa53 = $30;
      break;
     }
    }
    $$off$i6 = (($$lcssa53) + -1)|0;
    $36 = ($$off$i6>>>0)>(15);
    if ($36) {
     $37 = HEAP32[$h>>2]|0;
     HEAP32[$vararg_buffer2>>2] = $$lcssa53;
     $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
     HEAP32[$vararg_ptr5>>2] = 16;
     (_luaL_error($37,10816,$vararg_buffer2)|0);
     $$0$i$i528 = $$lcssa53;
    } else {
     $$0$i$i528 = $$lcssa53;
    }
   } else {
    $$0$i$i528 = 4;
   }
   HEAP32[$size>>2] = $$0$i$i528;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 61:  {
   $74 = ((($h)) + 4|0);
   HEAP32[$74>>2] = 1;
   break;
  }
  case 104:  {
   HEAP32[$size>>2] = 2;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 102:  {
   HEAP32[$size>>2] = 4;
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 99:  {
   $55 = HEAP8[$1>>0]|0;
   $56 = $55 << 24 >> 24;
   $c$off$i$i = (($56) + -48)|0;
   $57 = ($c$off$i$i>>>0)<(10);
   if ($57) {
    $60 = $1;$a$0$i = 0;
    while(1) {
     $58 = ($a$0$i*10)|0;
     $59 = ((($60)) + 1|0);
     HEAP32[$fmt>>2] = $59;
     $61 = HEAP8[$60>>0]|0;
     $62 = $61 << 24 >> 24;
     $63 = (($58) + -48)|0;
     $64 = (($63) + ($62))|0;
     $65 = HEAP8[$59>>0]|0;
     $66 = $65 << 24 >> 24;
     $c$off$i1$i = (($66) + -48)|0;
     $67 = ($c$off$i1$i>>>0)<(10);
     $68 = ($64|0)<(214748364);
     $69 = $68 & $67;
     if ($69) {
      $60 = $59;$a$0$i = $64;
     } else {
      $$lcssa55 = $64;
      break;
     }
    }
    HEAP32[$size>>2] = $$lcssa55;
    $70 = ($$lcssa55|0)==(-1);
    if (!($70)) {
     $$0 = 3;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    HEAP32[$size>>2] = -1;
   }
   $71 = HEAP32[$h>>2]|0;
   (_luaL_error($71,10856,$vararg_buffer10)|0);
   $$0 = 3;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 32:  {
   break;
  }
  case 110:  {
   HEAP32[$size>>2] = 8;
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 122:  {
   $$0 = 5;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 33:  {
   $75 = HEAP8[$1>>0]|0;
   $76 = $75 << 24 >> 24;
   $c$off$i$i$i17 = (($76) + -48)|0;
   $77 = ($c$off$i$i$i17>>>0)<(10);
   if ($77) {
    $80 = $1;$a$0$i$i18 = 0;
    while(1) {
     $78 = ($a$0$i$i18*10)|0;
     $79 = ((($80)) + 1|0);
     HEAP32[$fmt>>2] = $79;
     $81 = HEAP8[$80>>0]|0;
     $82 = $81 << 24 >> 24;
     $83 = (($78) + -48)|0;
     $84 = (($83) + ($82))|0;
     $85 = HEAP8[$79>>0]|0;
     $86 = $85 << 24 >> 24;
     $c$off$i1$i$i19 = (($86) + -48)|0;
     $87 = ($c$off$i1$i$i19>>>0)<(10);
     $88 = ($84|0)<(214748364);
     $89 = $88 & $87;
     if ($89) {
      $80 = $79;$a$0$i$i18 = $84;
     } else {
      $$lcssa56 = $84;
      break;
     }
    }
    $$off$i22 = (($$lcssa56) + -1)|0;
    $90 = ($$off$i22>>>0)>(15);
    if ($90) {
     $91 = HEAP32[$h>>2]|0;
     HEAP32[$vararg_buffer12>>2] = $$lcssa56;
     $vararg_ptr15 = ((($vararg_buffer12)) + 4|0);
     HEAP32[$vararg_ptr15>>2] = 16;
     (_luaL_error($91,10816,$vararg_buffer12)|0);
     $$0$i$i2132 = $$lcssa56;
    } else {
     $$0$i$i2132 = $$lcssa56;
    }
   } else {
    $$0$i$i2132 = 8;
   }
   $92 = ((($h)) + 8|0);
   HEAP32[$92>>2] = $$0$i$i2132;
   break;
  }
  case 108:  {
   HEAP32[$size>>2] = 4;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 120:  {
   HEAP32[$size>>2] = 1;
   $$0 = 6;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  case 106:  {
   HEAP32[$size>>2] = 8;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
   break;
  }
  default: {
   $93 = HEAP32[$h>>2]|0;
   HEAP32[$vararg_buffer16>>2] = $3;
   (_luaL_error($93,10896,$vararg_buffer16)|0);
  }
  }
 } while(0);
 $$0 = 8;
 STACKTOP = sp;return ($$0|0);
}
function _str_find_aux($L,$find) {
 $L = $L|0;
 $find = $find|0;
 var $$$i = 0, $$0$i512 = 0, $$01$ph = 0, $$014$i = 0, $$023$i = 0, $$1 = 0, $$lcssa16 = 0, $$pre = 0, $$sum = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i7 = 0, $i$02$i = 0, $i$02$i6 = 0, $init$0$off0 = 0, $lp = 0, $ls = 0, $ms = 0, $or$cond$i = 0, $p$0 = 0, $s1$0$lcssa = 0, $s1$034 = 0, $upto$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ls = sp + 284|0;
 $lp = sp + 280|0;
 $ms = sp;
 $0 = (_luaL_checklstring($L,1,$ls)|0);
 $1 = (_luaL_checklstring($L,2,$lp)|0);
 $2 = (_luaL_optinteger($L,3,1,0)|0);
 $3 = tempRet0;
 $4 = HEAP32[$ls>>2]|0;
 $5 = ($3|0)>(-1);
 $6 = ($2>>>0)>(4294967295);
 $7 = ($3|0)==(-1);
 $8 = $7 & $6;
 $9 = $5 | $8;
 if ($9) {
  $17 = $3;$19 = $2;
  label = 4;
 } else {
  $10 = (0 - ($2))|0;
  $11 = ($4>>>0)<($10>>>0);
  if ($11) {
   $init$0$off0 = 1;
  } else {
   $12 = (_i64Add(($2|0),($3|0),1,0)|0);
   $13 = tempRet0;
   $14 = (_i64Add(($12|0),($13|0),($4|0),0)|0);
   $15 = tempRet0;
   $17 = $15;$19 = $14;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $16 = ($17|0)<(0);
  $18 = ($19>>>0)<(1);
  $20 = ($17|0)==(0);
  $21 = $20 & $18;
  $22 = $16 | $21;
  if ($22) {
   $init$0$off0 = 1;
  } else {
   $23 = (_i64Add(($4|0),0,1,0)|0);
   $24 = tempRet0;
   $25 = ($17|0)>($24|0);
   $26 = ($19>>>0)>($23>>>0);
   $27 = ($17|0)==($24|0);
   $28 = $27 & $26;
   $29 = $25 | $28;
   if ($29) {
    _lua_pushnil($L);
    $$1 = 1;
    STACKTOP = sp;return ($$1|0);
   } else {
    $init$0$off0 = $19;
   }
  }
 }
 $30 = ($find|0)!=(0);
 L10: do {
  if ($30) {
   $31 = (_lua_toboolean($L,4)|0);
   $32 = ($31|0)==(0);
   $33 = HEAP32[$lp>>2]|0;
   if ($32) {
    $upto$0$i = 0;
    while(1) {
     $34 = (($1) + ($upto$0$i)|0);
     $35 = (_strpbrk($34,11144)|0);
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      label = 20;
      break L10;
     }
     $37 = (_strlen(($34|0))|0);
     $38 = (($upto$0$i) + 1)|0;
     $39 = (($38) + ($37))|0;
     $40 = ($39>>>0)>($33>>>0);
     if ($40) {
      break;
     } else {
      $upto$0$i = $39;
     }
    }
   }
   $$sum2 = (($init$0$off0) + -1)|0;
   $41 = (($0) + ($$sum2)|0);
   $42 = HEAP32[$ls>>2]|0;
   $43 = (($42) - ($init$0$off0))|0;
   $44 = (($43) + 1)|0;
   $45 = ($33|0)==(0);
   L17: do {
    if ($45) {
     $63 = ($41|0)==(0|0);
     if ($63) {
      break L10;
     } else {
      $$0$i512 = $41;
     }
    } else {
     $46 = ($33>>>0)>($44>>>0);
     if ($46) {
      break L10;
     }
     $47 = (($33) + -1)|0;
     $48 = ($44|0)==($47|0);
     if ($48) {
      break L10;
     }
     $49 = (($44) - ($47))|0;
     $50 = HEAP8[$1>>0]|0;
     $51 = $50 << 24 >> 24;
     $52 = ((($1)) + 1|0);
     $$014$i = $49;$$023$i = $41;
     while(1) {
      $53 = (_memchr($$023$i,$51,$$014$i)|0);
      $54 = ($53|0)==(0|0);
      if ($54) {
       break L10;
      }
      $55 = ((($53)) + 1|0);
      $56 = (_memcmp($55,$52,$47)|0);
      $57 = ($56|0)==(0);
      if ($57) {
       $$0$i512 = $53;
       break L17;
      }
      $58 = $55;
      $59 = $$023$i;
      $60 = (($59) + ($$014$i))|0;
      $61 = (($60) - ($58))|0;
      $62 = ($60|0)==($58|0);
      if ($62) {
       break L10;
      } else {
       $$014$i = $61;$$023$i = $55;
      }
     }
    }
   } while(0);
   $64 = $$0$i512;
   $65 = $0;
   $66 = (($64) - ($65))|0;
   $67 = (($66) + 1)|0;
   $68 = ($67|0)<(0);
   $69 = $68 << 31 >> 31;
   _lua_pushinteger($L,$67,$69);
   $70 = HEAP32[$lp>>2]|0;
   $71 = (($66) + ($70))|0;
   _lua_pushinteger($L,$71,0);
   $$1 = 2;
   STACKTOP = sp;return ($$1|0);
  } else {
   label = 20;
  }
 } while(0);
 do {
  if ((label|0) == 20) {
   $$sum = (($init$0$off0) + -1)|0;
   $72 = (($0) + ($$sum)|0);
   $73 = HEAP8[$1>>0]|0;
   $74 = ($73<<24>>24)==(94);
   if ($74) {
    $75 = ((($1)) + 1|0);
    $76 = HEAP32[$lp>>2]|0;
    $77 = (($76) + -1)|0;
    HEAP32[$lp>>2] = $77;
    $84 = $77;$p$0 = $75;
   } else {
    $$pre = HEAP32[$lp>>2]|0;
    $84 = $$pre;$p$0 = $1;
   }
   $78 = ((($ms)) + 16|0);
   HEAP32[$78>>2] = $L;
   HEAP32[$ms>>2] = 200;
   $79 = ((($ms)) + 4|0);
   HEAP32[$79>>2] = $0;
   $80 = HEAP32[$ls>>2]|0;
   $81 = (($0) + ($80)|0);
   $82 = ((($ms)) + 8|0);
   HEAP32[$82>>2] = $81;
   $83 = (($p$0) + ($84)|0);
   $85 = ((($ms)) + 12|0);
   HEAP32[$85>>2] = $83;
   $86 = ((($ms)) + 20|0);
   HEAP32[$86>>2] = 0;
   $87 = (_match($ms,$72,$p$0)|0);
   $88 = ($87|0)==(0|0);
   L34: do {
    if ($74) {
     if ($88) {
      label = 35;
     } else {
      $$lcssa16 = $87;$s1$0$lcssa = $72;
     }
    } else {
     if ($88) {
      $s1$034 = $72;
      while(1) {
       $110 = HEAP32[$82>>2]|0;
       $111 = ($s1$034>>>0)<($110>>>0);
       if (!($111)) {
        label = 35;
        break L34;
       }
       $112 = ((($s1$034)) + 1|0);
       HEAP32[$86>>2] = 0;
       $113 = (_match($ms,$112,$p$0)|0);
       $114 = ($113|0)==(0|0);
       if ($114) {
        $s1$034 = $112;
       } else {
        $$lcssa16 = $113;$s1$0$lcssa = $112;
        break;
       }
      }
     } else {
      $$lcssa16 = $87;$s1$0$lcssa = $72;
     }
    }
   } while(0);
   if ((label|0) == 35) {
    break;
   }
   if ($30) {
    $89 = $s1$0$lcssa;
    $90 = $0;
    $91 = (1 - ($90))|0;
    $92 = (($91) + ($89))|0;
    $93 = ($92|0)<(0);
    $94 = $93 << 31 >> 31;
    _lua_pushinteger($L,$92,$94);
    $95 = $$lcssa16;
    $96 = (($95) - ($90))|0;
    $97 = ($96|0)<(0);
    $98 = $97 << 31 >> 31;
    _lua_pushinteger($L,$96,$98);
    $99 = HEAP32[$86>>2]|0;
    $100 = HEAP32[$78>>2]|0;
    _luaL_checkstack($100,$99,11160);
    $101 = ($99|0)>(0);
    if ($101) {
     $i$02$i6 = 0;
     while(1) {
      _push_onecapture($ms,$i$02$i6,0,0);
      $102 = (($i$02$i6) + 1)|0;
      $exitcond$i7 = ($102|0)==($99|0);
      if ($exitcond$i7) {
       break;
      } else {
       $i$02$i6 = $102;
      }
     }
    }
    $103 = (($99) + 2)|0;
    $$01$ph = $103;
   } else {
    $104 = HEAP32[$86>>2]|0;
    $105 = ($104|0)==(0);
    $106 = ($s1$0$lcssa|0)!=(0|0);
    $or$cond$i = $106 & $105;
    $$$i = $or$cond$i ? 1 : $104;
    $107 = HEAP32[$78>>2]|0;
    _luaL_checkstack($107,$$$i,11160);
    $108 = ($$$i|0)>(0);
    if ($108) {
     $i$02$i = 0;
     while(1) {
      _push_onecapture($ms,$i$02$i,$s1$0$lcssa,$$lcssa16);
      $109 = (($i$02$i) + 1)|0;
      $exitcond$i = ($109|0)==($$$i|0);
      if ($exitcond$i) {
       $$01$ph = $$$i;
       break;
      } else {
       $i$02$i = $109;
      }
     }
    } else {
     $$01$ph = $$$i;
    }
   }
   $$1 = $$01$ph;
   STACKTOP = sp;return ($$1|0);
  }
 } while(0);
 _lua_pushnil($L);
 $$1 = 1;
 STACKTOP = sp;return ($$1|0);
}
function _match($ms,$s,$p) {
 $ms = $ms|0;
 $s = $s|0;
 $p = $p|0;
 var $$$i = 0, $$$i14 = 0, $$$i34 = 0, $$$i4 = 0, $$$i42 = 0, $$$i50 = 0, $$$i7 = 0, $$0$i = 0, $$0$i$i = 0, $$0$i$i23 = 0, $$0$i$i25 = 0, $$0$i$i30 = 0, $$0$i12 = 0, $$0$i15 = 0, $$0$i2 = 0, $$0$i5 = 0, $$0$ph$be = 0, $$0$ph136 = 0, $$0$ph136$lcssa = 0, $$0$ph136$lcssa402 = 0;
 var $$0$ph136$lcssa406 = 0, $$0$ph136$lcssa409 = 0, $$01$be = 0, $$01$be$i = 0, $$01$be$i10 = 0, $$01$be$i37 = 0, $$01$be$i45 = 0, $$01$be$i53 = 0, $$01$i = 0, $$01$i$lcssa397 = 0, $$01$i$lcssa399 = 0, $$01$i18 = 0, $$01$i27119 = 0, $$01$i400 = 0, $$01$ph$be = 0, $$01$ph135 = 0, $$01125 = 0, $$01125$lcssa = 0, $$01125$lcssa382 = 0, $$01125$lcssa383 = 0;
 var $$01125$lcssa384 = 0, $$01125$lcssa388 = 0, $$01125$lcssa390 = 0, $$01125391 = 0, $$012$i = 0, $$012$i35 = 0, $$012$i43 = 0, $$012$i51 = 0, $$012$i8 = 0, $$013$i = 0, $$013$i$lcssa = 0, $$013$i$phi = 0, $$1 = 0, $$1$i = 0, $$1$i$lcssa = 0, $$1$i17 = 0, $$1$i17$lcssa = 0, $$2 = 0, $$2$i = 0, $$2$i16 = 0;
 var $$cont$0$i = 0, $$lcssa374 = 0, $$lcssa392 = 0, $$lcssa415 = 0, $$p$i = 0, $$p$i33 = 0, $$p$i41 = 0, $$p$i49 = 0, $$p$i6 = 0, $$phi$trans$insert$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi207$lcssa393Z2D = 0, $$pre$phi207$lcssa395Z2D = 0, $$pre$phi207396Z2D = 0, $$pre$phi207Z2D = 0, $$pre202 = 0, $$pre206 = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0;
 var $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0;
 var $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0;
 var $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0;
 var $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond = 0, $cont$0$be$i = 0, $cont$04$i = 0, $i$0$i$lcssa = 0, $i$0$i$lcssa210 = 0, $i$0$i112 = 0, $i$1$i109 = 0, $level$0$i$i = 0, $level$0$in$i$i = 0, $ms$idx = 0, $ms$idx$val = 0, $ms$idx$val$i = 0, $ms$idx$val$i$pre = 0, $ms$idx$val$i111 = 0;
 var $ms$idx$val$i203 = 0, $ms$idx$val$i29 = 0, $or$cond = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer13 = 0, $vararg_buffer15 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer3 = 0, $vararg_buffer5 = 0, $vararg_buffer7 = 0, $vararg_buffer9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer19 = sp + 80|0;
 $vararg_buffer17 = sp + 72|0;
 $vararg_buffer15 = sp + 64|0;
 $vararg_buffer13 = sp + 56|0;
 $vararg_buffer11 = sp + 48|0;
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer7 = sp + 32|0;
 $vararg_buffer5 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[$ms>>2]|0;
 $1 = (($0) + -1)|0;
 HEAP32[$ms>>2] = $1;
 $2 = ($0|0)==(0);
 if ($2) {
  $3 = ((($ms)) + 16|0);
  $4 = HEAP32[$3>>2]|0;
  (_luaL_error($4,11240,$vararg_buffer)|0);
 }
 $5 = ((($ms)) + 12|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = ($6|0)==($p|0);
 L4: do {
  if ($7) {
   $$2 = $s;
  } else {
   $ms$idx = ((($ms)) + 8|0);
   $8 = ((($ms)) + 16|0);
   $9 = ((($ms)) + 4|0);
   $10 = ((($ms)) + 20|0);
   $$0$ph136 = $s;$$01$ph135 = $p;$346 = $6;
   L6: while(1) {
    $11 = ((($$0$ph136)) + 1|0);
    $12 = ((($$0$ph136)) + -1|0);
    $$01125 = $$01$ph135;$57 = $346;
    L8: while(1) {
     $13 = HEAP8[$$01125>>0]|0;
     $14 = $13 << 24 >> 24;
     L10: do {
      if ((($14|0) == 37)) {
       $61 = ((($$01125)) + 1|0);
       $62 = HEAP8[$61>>0]|0;
       $63 = $62 << 24 >> 24;
       switch ($63|0) {
       case 98:  {
        $$01125$lcssa383 = $$01125;$$lcssa374 = $57;
        label = 25;
        break L8;
        break;
       }
       case 102:  {
        break;
       }
       case 57: case 56: case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
        $$01125$lcssa384 = $$01125;$$lcssa392 = $62;
        label = 70;
        break L8;
        break;
       }
       default: {
        $194 = ($61|0)==($57|0);
        if ($194) {
         $195 = HEAP32[$8>>2]|0;
         (_luaL_error($195,11376,$vararg_buffer17)|0);
        }
        $196 = ((($$01125)) + 2|0);
        $$01$i = $196;$$pre$phi207Z2D = $61;
        label = 89;
        break L10;
       }
       }
       $86 = ((($$01125)) + 2|0);
       $87 = HEAP8[$86>>0]|0;
       $88 = ($87<<24>>24)==(91);
       if ($88) {
        $92 = 91;
       } else {
        $89 = HEAP32[$8>>2]|0;
        (_luaL_error($89,11336,$vararg_buffer9)|0);
        $$pre = HEAP8[$86>>0]|0;
        $92 = $$pre;
       }
       $90 = ((($$01125)) + 3|0);
       $91 = $92 << 24 >> 24;
       if ((($91|0) == 91)) {
        $97 = HEAP8[$90>>0]|0;
        $98 = ($97<<24>>24)==(94);
        $99 = ((($$01125)) + 4|0);
        $$$i14 = $98 ? $99 : $90;
        $$0$i15 = $$$i14;
        while(1) {
         $100 = HEAP32[$5>>2]|0;
         $101 = ($$0$i15|0)==($100|0);
         if ($101) {
          $102 = HEAP32[$8>>2]|0;
          (_luaL_error($102,11416,$vararg_buffer13)|0);
         }
         $103 = ((($$0$i15)) + 1|0);
         $104 = HEAP8[$$0$i15>>0]|0;
         $105 = ($104<<24>>24)==(37);
         if ($105) {
          $106 = HEAP32[$5>>2]|0;
          $107 = ($103>>>0)<($106>>>0);
          $108 = ((($$0$i15)) + 2|0);
          $$2$i16 = $107 ? $108 : $103;
          $$1$i17 = $$2$i16;
         } else {
          $$1$i17 = $103;
         }
         $109 = HEAP8[$$1$i17>>0]|0;
         $110 = ($109<<24>>24)==(93);
         if ($110) {
          $$1$i17$lcssa = $$1$i17;
          break;
         } else {
          $$0$i15 = $$1$i17;
         }
        }
        $111 = ((($$1$i17$lcssa)) + 1|0);
        $$01$i18 = $111;
       } else if ((($91|0) == 37)) {
        $93 = HEAP32[$5>>2]|0;
        $94 = ($90|0)==($93|0);
        if ($94) {
         $95 = HEAP32[$8>>2]|0;
         (_luaL_error($95,11376,$vararg_buffer11)|0);
        }
        $96 = ((($$01125)) + 4|0);
        $$01$i18 = $96;
       } else {
        $$01$i18 = $90;
       }
       $112 = HEAP32[$9>>2]|0;
       $113 = ($$0$ph136|0)==($112|0);
       if ($113) {
        $117 = 0;
       } else {
        $114 = HEAP8[$12>>0]|0;
        $115 = $114 << 24 >> 24;
        $117 = $115;
       }
       $116 = $117 & 255;
       $118 = ((($$01$i18)) + -1|0);
       $119 = HEAP8[$90>>0]|0;
       $120 = ($119<<24>>24)==(94);
       $$p$i6 = $120 ? $90 : $86;
       $121 = $120&1;
       $$$i7 = $121 ^ 1;
       $122 = ((($$p$i6)) + 1|0);
       $123 = ($122>>>0)<($118>>>0);
       L40: do {
        if ($123) {
         $124 = $117&255;
         $$012$i8 = $$p$i6;$126 = $122;
         while(1) {
          $125 = HEAP8[$126>>0]|0;
          $127 = ($125<<24>>24)==(37);
          $128 = ((($$012$i8)) + 2|0);
          $129 = HEAP8[$128>>0]|0;
          do {
           if ($127) {
            $130 = $129&255;
            $131 = (_match_class($116,$130)|0);
            $132 = ($131|0)==(0);
            if ($132) {
             $$01$be$i10 = $128;
            } else {
             $$0$i12 = $$$i7;
             break L40;
            }
           } else {
            $133 = ($129<<24>>24)==(45);
            if ($133) {
             $134 = ((($$012$i8)) + 3|0);
             $135 = ($134>>>0)<($118>>>0);
             if ($135) {
              $136 = $125&255;
              $137 = ($136>>>0)>($116>>>0);
              if ($137) {
               $$01$be$i10 = $134;
               break;
              }
              $138 = HEAP8[$134>>0]|0;
              $139 = $138&255;
              $140 = ($139>>>0)<($116>>>0);
              if ($140) {
               $$01$be$i10 = $134;
               break;
              } else {
               $$0$i12 = $$$i7;
               break L40;
              }
             }
            }
            $141 = ($125<<24>>24)==($124<<24>>24);
            if ($141) {
             $$0$i12 = $$$i7;
             break L40;
            } else {
             $$01$be$i10 = $126;
            }
           }
          } while(0);
          $142 = ((($$01$be$i10)) + 1|0);
          $143 = ($142>>>0)<($118>>>0);
          if ($143) {
           $$012$i8 = $$01$be$i10;$126 = $142;
          } else {
           $$0$i12 = $121;
           break;
          }
         }
        } else {
         $$0$i12 = $121;
        }
       } while(0);
       $144 = ($$0$i12|0)==(0);
       if (!($144)) {
        $$2 = 0;
        break L4;
       }
       $145 = HEAP8[$$0$ph136>>0]|0;
       $146 = $145&255;
       $147 = HEAP8[$90>>0]|0;
       $148 = ($147<<24>>24)==(94);
       $$p$i = $148 ? $90 : $86;
       $149 = $148&1;
       $$$i4 = $149 ^ 1;
       $150 = ((($$p$i)) + 1|0);
       $151 = ($150>>>0)<($118>>>0);
       L55: do {
        if ($151) {
         $$012$i = $$p$i;$153 = $150;
         while(1) {
          $152 = HEAP8[$153>>0]|0;
          $154 = ($152<<24>>24)==(37);
          $155 = ((($$012$i)) + 2|0);
          $156 = HEAP8[$155>>0]|0;
          do {
           if ($154) {
            $157 = $156&255;
            $158 = (_match_class($146,$157)|0);
            $159 = ($158|0)==(0);
            if ($159) {
             $$01$be$i = $155;
            } else {
             $$0$i5 = $$$i4;
             break L55;
            }
           } else {
            $160 = ($156<<24>>24)==(45);
            if ($160) {
             $161 = ((($$012$i)) + 3|0);
             $162 = ($161>>>0)<($118>>>0);
             if ($162) {
              $163 = ($152&255)>($145&255);
              if ($163) {
               $$01$be$i = $161;
               break;
              }
              $164 = HEAP8[$161>>0]|0;
              $165 = ($164&255)<($145&255);
              if ($165) {
               $$01$be$i = $161;
               break;
              } else {
               $$0$i5 = $$$i4;
               break L55;
              }
             }
            }
            $166 = ($152<<24>>24)==($145<<24>>24);
            if ($166) {
             $$0$i5 = $$$i4;
             break L55;
            } else {
             $$01$be$i = $153;
            }
           }
          } while(0);
          $167 = ((($$01$be$i)) + 1|0);
          $168 = ($167>>>0)<($118>>>0);
          if ($168) {
           $$012$i = $$01$be$i;$153 = $167;
          } else {
           $$0$i5 = $149;
           break;
          }
         }
        } else {
         $$0$i5 = $149;
        }
       } while(0);
       $169 = ($$0$i5|0)==(0);
       if ($169) {
        $$2 = 0;
        break L4;
       } else {
        $$01$be = $$01$i18;
       }
      } else if ((($14|0) == 40)) {
       $$0$ph136$lcssa = $$0$ph136;$$01125$lcssa = $$01125;
       label = 7;
       break L6;
      } else if ((($14|0) == 36)) {
       $55 = ((($$01125)) + 1|0);
       $56 = ($55|0)==($57|0);
       if ($56) {
        $$0$ph136$lcssa406 = $$0$ph136;
        label = 23;
        break L6;
       } else {
        $$01$i = $55;$$pre$phi207Z2D = $55;
        label = 89;
       }
      } else if ((($14|0) == 41)) {
       $$0$ph136$lcssa402 = $$0$ph136;$$01125$lcssa382 = $$01125;
       label = 16;
       break L6;
      } else {
       $$pre206 = ((($$01125)) + 1|0);
       $cond = ($13<<24>>24)==(91);
       if ($cond) {
        $197 = HEAP8[$$pre206>>0]|0;
        $198 = ($197<<24>>24)==(94);
        $199 = ((($$01125)) + 2|0);
        $$$i = $198 ? $199 : $$pre206;
        $$0$i2 = $$$i;$201 = $57;
        while(1) {
         $200 = ($$0$i2|0)==($201|0);
         if ($200) {
          $202 = HEAP32[$8>>2]|0;
          (_luaL_error($202,11416,$vararg_buffer19)|0);
         }
         $203 = ((($$0$i2)) + 1|0);
         $204 = HEAP8[$$0$i2>>0]|0;
         $205 = ($204<<24>>24)==(37);
         if ($205) {
          $206 = HEAP32[$5>>2]|0;
          $207 = ($203>>>0)<($206>>>0);
          $208 = ((($$0$i2)) + 2|0);
          $$2$i = $207 ? $208 : $203;
          $$1$i = $$2$i;
         } else {
          $$1$i = $203;
         }
         $209 = HEAP8[$$1$i>>0]|0;
         $210 = ($209<<24>>24)==(93);
         if ($210) {
          $$1$i$lcssa = $$1$i;
          break;
         }
         $$pre202 = HEAP32[$5>>2]|0;
         $$0$i2 = $$1$i;$201 = $$pre202;
        }
        $211 = ((($$1$i$lcssa)) + 1|0);
        $$01$i = $211;$$pre$phi207Z2D = $$pre206;
        label = 89;
       } else {
        $$01$i = $$pre206;$$pre$phi207Z2D = $$pre206;
        label = 89;
       }
      }
     } while(0);
     L81: do {
      if ((label|0) == 89) {
       label = 0;
       $ms$idx$val = HEAP32[$ms$idx>>2]|0;
       $212 = ($ms$idx$val>>>0)>($$0$ph136>>>0);
       do {
        if ($212) {
         $214 = HEAP8[$$0$ph136>>0]|0;
         $215 = $214&255;
         $216 = HEAP8[$$01125>>0]|0;
         $217 = $216 << 24 >> 24;
         L86: do {
          if ((($217|0) == 91)) {
           $222 = ((($$01$i)) + -1|0);
           $223 = HEAP8[$$pre$phi207Z2D>>0]|0;
           $224 = ($223<<24>>24)==(94);
           $$p$i33 = $224 ? $$pre$phi207Z2D : $$01125;
           $225 = $224&1;
           $$$i34 = $225 ^ 1;
           $226 = ((($$p$i33)) + 1|0);
           $227 = ($226>>>0)<($222>>>0);
           if ($227) {
            $$012$i35 = $$p$i33;$229 = $226;
            while(1) {
             $228 = HEAP8[$229>>0]|0;
             $230 = ($228<<24>>24)==(37);
             $231 = ((($$012$i35)) + 2|0);
             $232 = HEAP8[$231>>0]|0;
             do {
              if ($230) {
               $233 = $232&255;
               $234 = (_match_class($215,$233)|0);
               $235 = ($234|0)==(0);
               if ($235) {
                $$01$be$i37 = $231;
               } else {
                $$0$i = $$$i34;
                label = 104;
                break L86;
               }
              } else {
               $236 = ($232<<24>>24)==(45);
               if ($236) {
                $237 = ((($$012$i35)) + 3|0);
                $238 = ($237>>>0)<($222>>>0);
                if ($238) {
                 $239 = ($228&255)>($214&255);
                 if ($239) {
                  $$01$be$i37 = $237;
                  break;
                 }
                 $240 = HEAP8[$237>>0]|0;
                 $241 = ($240&255)<($214&255);
                 if ($241) {
                  $$01$be$i37 = $237;
                  break;
                 } else {
                  $$0$i = $$$i34;
                  label = 104;
                  break L86;
                 }
                }
               }
               $242 = ($228<<24>>24)==($214<<24>>24);
               if ($242) {
                $$0$i = $$$i34;
                label = 104;
                break L86;
               } else {
                $$01$be$i37 = $229;
               }
              }
             } while(0);
             $243 = ((($$01$be$i37)) + 1|0);
             $244 = ($243>>>0)<($222>>>0);
             if ($244) {
              $$012$i35 = $$01$be$i37;$229 = $243;
             } else {
              $$0$i = $225;
              label = 104;
              break;
             }
            }
           } else {
            $$0$i = $225;
            label = 104;
           }
          } else if ((($217|0) == 46)) {
           $218 = HEAP8[$$01$i>>0]|0;
           $253 = $218;
          } else if ((($217|0) == 37)) {
           $219 = HEAP8[$$pre$phi207Z2D>>0]|0;
           $220 = $219&255;
           $221 = (_match_class($215,$220)|0);
           $$0$i = $221;
           label = 104;
          } else {
           $245 = ($216<<24>>24)==($214<<24>>24);
           $246 = $245&1;
           $$0$i = $246;
           label = 104;
          }
         } while(0);
         if ((label|0) == 104) {
          label = 0;
          $247 = ($$0$i|0)==(0);
          $248 = HEAP8[$$01$i>>0]|0;
          if ($247) {
           $347 = $248;
           break;
          } else {
           $253 = $248;
          }
         }
         $252 = $253 << 24 >> 24;
         if ((($252|0) == 45)) {
          $$0$ph136$lcssa409 = $$0$ph136;$$01$i$lcssa399 = $$01$i;$$01125$lcssa390 = $$01125;$$pre$phi207$lcssa395Z2D = $$pre$phi207Z2D;
          label = 109;
          break L6;
         } else if ((($252|0) == 43)) {
          $$01$i$lcssa397 = $$01$i;$$01125$lcssa388 = $$01125;$$lcssa415 = $11;$$pre$phi207$lcssa393Z2D = $$pre$phi207Z2D;
          label = 112;
          break L6;
         } else if ((($252|0) == 42)) {
          $$01$i400 = $$01$i;$$01125391 = $$01125;$$1 = $$0$ph136;$$pre$phi207396Z2D = $$pre$phi207Z2D;
          break L6;
         } else if (!((($252|0) == 63))) {
          $$0$ph$be = $11;$$01$ph$be = $$01$i;
          break L8;
         }
         $258 = ((($$01$i)) + 1|0);
         $259 = (_match($ms,$11,$258)|0);
         $260 = ($259|0)==(0|0);
         if ($260) {
          $$01$be = $258;
          break L81;
         } else {
          $$2 = $259;
          break L4;
         }
        } else {
         $213 = HEAP8[$$01$i>>0]|0;
         $347 = $213;
        }
       } while(0);
       if (!((($347<<24>>24) == 45) | (($347<<24>>24) == 63) | (($347<<24>>24) == 42))) {
        $$2 = 0;
        break L4;
       }
       $249 = ((($$01$i)) + 1|0);
       $$01$be = $249;
      }
     } while(0);
     $250 = HEAP32[$5>>2]|0;
     $251 = ($$01$be|0)==($250|0);
     if ($251) {
      $$2 = $$0$ph136;
      break L4;
     } else {
      $$01125 = $$01$be;$57 = $250;
     }
    }
    if ((label|0) == 25) {
     label = 0;
     $64 = ((($$01125$lcssa383)) + 2|0);
     $65 = ((($$lcssa374)) + -1|0);
     $66 = ($65>>>0)>($64>>>0);
     if (!($66)) {
      $67 = HEAP32[$8>>2]|0;
      (_luaL_error($67,11288,$vararg_buffer7)|0);
     }
     $68 = HEAP8[$$0$ph136>>0]|0;
     $69 = HEAP8[$64>>0]|0;
     $70 = ($68<<24>>24)==($69<<24>>24);
     if (!($70)) {
      $$2 = 0;
      break L4;
     }
     $71 = ((($$01125$lcssa383)) + 3|0);
     $72 = HEAP8[$71>>0]|0;
     $73 = HEAP32[$ms$idx>>2]|0;
     $74 = ($11>>>0)<($73>>>0);
     if ($74) {
      $$013$i = $$0$ph136;$76 = $11;$cont$04$i = 1;
     } else {
      $$2 = 0;
      break L4;
     }
     while(1) {
      $75 = HEAP8[$76>>0]|0;
      $77 = ($75<<24>>24)==($72<<24>>24);
      if ($77) {
       $78 = (($cont$04$i) + -1)|0;
       $79 = ($78|0)==(0);
       if ($79) {
        $$013$i$lcssa = $$013$i;
        break;
       } else {
        $cont$0$be$i = $78;
       }
      } else {
       $82 = ($75<<24>>24)==($68<<24>>24);
       $83 = $82&1;
       $$cont$0$i = (($83) + ($cont$04$i))|0;
       $cont$0$be$i = $$cont$0$i;
      }
      $80 = ((($76)) + 1|0);
      $81 = ($80>>>0)<($73>>>0);
      if ($81) {
       $$013$i$phi = $76;$76 = $80;$cont$04$i = $cont$0$be$i;$$013$i = $$013$i$phi;
      } else {
       $$2 = 0;
       break L4;
      }
     }
     $84 = ((($$013$i$lcssa)) + 2|0);
     $85 = ((($$01125$lcssa383)) + 4|0);
     $$0$ph$be = $84;$$01$ph$be = $85;
    }
    else if ((label|0) == 70) {
     label = 0;
     $170 = $$lcssa392&255;
     $171 = (($170) + -49)|0;
     $172 = ($$lcssa392&255)<(49);
     if ($172) {
      label = 73;
     } else {
      $173 = HEAP32[$10>>2]|0;
      $174 = ($171|0)<($173|0);
      if ($174) {
       $175 = (((((($ms)) + 24|0) + ($171<<3)|0)) + 4|0);
       $176 = HEAP32[$175>>2]|0;
       $177 = ($176|0)==(-1);
       if ($177) {
        label = 73;
       } else {
        $$0$i$i = $171;$186 = $176;
       }
      } else {
       label = 73;
      }
     }
     if ((label|0) == 73) {
      label = 0;
      $178 = HEAP32[$8>>2]|0;
      $179 = (($170) + -48)|0;
      HEAP32[$vararg_buffer15>>2] = $179;
      $180 = (_luaL_error($178,11184,$vararg_buffer15)|0);
      $$phi$trans$insert$i = (((((($ms)) + 24|0) + ($180<<3)|0)) + 4|0);
      $$pre$i = HEAP32[$$phi$trans$insert$i>>2]|0;
      $$0$i$i = $180;$186 = $$pre$i;
     }
     $181 = HEAP32[$ms$idx>>2]|0;
     $182 = $181;
     $183 = $$0$ph136;
     $184 = (($182) - ($183))|0;
     $185 = ($184>>>0)<($186>>>0);
     if ($185) {
      $$2 = 0;
      break L4;
     }
     $187 = (((($ms)) + 24|0) + ($$0$i$i<<3)|0);
     $188 = HEAP32[$187>>2]|0;
     $189 = (_memcmp($188,$$0$ph136,$186)|0);
     $190 = ($189|0)!=(0);
     $191 = (($$0$ph136) + ($186)|0);
     $192 = ($191|0)==(0|0);
     $or$cond = $192 | $190;
     if ($or$cond) {
      $$2 = 0;
      break L4;
     }
     $193 = ((($$01125$lcssa384)) + 2|0);
     $$0$ph$be = $191;$$01$ph$be = $193;
    }
    $342 = HEAP32[$5>>2]|0;
    $343 = ($$01$ph$be|0)==($342|0);
    if ($343) {
     $$2 = $$0$ph$be;
     break L4;
    } else {
     $$0$ph136 = $$0$ph$be;$$01$ph135 = $$01$ph$be;$346 = $342;
    }
   }
   if ((label|0) == 7) {
    $15 = ((($$01125$lcssa)) + 1|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(41);
    if ($17) {
     $18 = ((($$01125$lcssa)) + 2|0);
     $19 = HEAP32[$10>>2]|0;
     $20 = ($19|0)>(31);
     if ($20) {
      $21 = HEAP32[$8>>2]|0;
      (_luaL_error($21,11160,$vararg_buffer1)|0);
     }
     $22 = (((($ms)) + 24|0) + ($19<<3)|0);
     HEAP32[$22>>2] = $$0$ph136$lcssa;
     $23 = (((((($ms)) + 24|0) + ($19<<3)|0)) + 4|0);
     HEAP32[$23>>2] = -2;
     $24 = (($19) + 1)|0;
     HEAP32[$10>>2] = $24;
     $25 = (_match($ms,$$0$ph136$lcssa,$18)|0);
     $26 = ($25|0)==(0|0);
     if (!($26)) {
      $$2 = $25;
      break;
     }
     $27 = HEAP32[$10>>2]|0;
     $28 = (($27) + -1)|0;
     HEAP32[$10>>2] = $28;
     $$2 = 0;
     break;
    } else {
     $29 = HEAP32[$10>>2]|0;
     $30 = ($29|0)>(31);
     if ($30) {
      $31 = HEAP32[$8>>2]|0;
      (_luaL_error($31,11160,$vararg_buffer3)|0);
     }
     $32 = (((($ms)) + 24|0) + ($29<<3)|0);
     HEAP32[$32>>2] = $$0$ph136$lcssa;
     $33 = (((((($ms)) + 24|0) + ($29<<3)|0)) + 4|0);
     HEAP32[$33>>2] = -1;
     $34 = (($29) + 1)|0;
     HEAP32[$10>>2] = $34;
     $35 = (_match($ms,$$0$ph136$lcssa,$15)|0);
     $36 = ($35|0)==(0|0);
     if (!($36)) {
      $$2 = $35;
      break;
     }
     $37 = HEAP32[$10>>2]|0;
     $38 = (($37) + -1)|0;
     HEAP32[$10>>2] = $38;
     $$2 = 0;
     break;
    }
   }
   else if ((label|0) == 16) {
    $39 = ((($$01125$lcssa382)) + 1|0);
    $40 = HEAP32[$10>>2]|0;
    $level$0$in$i$i = $40;
    while(1) {
     $level$0$i$i = (($level$0$in$i$i) + -1)|0;
     $41 = ($level$0$in$i$i|0)>(0);
     if (!($41)) {
      label = 19;
      break;
     }
     $42 = (((((($ms)) + 24|0) + ($level$0$i$i<<3)|0)) + 4|0);
     $43 = HEAP32[$42>>2]|0;
     $44 = ($43|0)==(-1);
     if ($44) {
      $$0$i$i23 = $level$0$i$i;
      break;
     } else {
      $level$0$in$i$i = $level$0$i$i;
     }
    }
    if ((label|0) == 19) {
     $45 = HEAP32[$8>>2]|0;
     $46 = (_luaL_error($45,11264,$vararg_buffer5)|0);
     $$0$i$i23 = $46;
    }
    $47 = (((($ms)) + 24|0) + ($$0$i$i23<<3)|0);
    $48 = HEAP32[$47>>2]|0;
    $49 = $$0$ph136$lcssa402;
    $50 = $48;
    $51 = (($49) - ($50))|0;
    $52 = (((((($ms)) + 24|0) + ($$0$i$i23<<3)|0)) + 4|0);
    HEAP32[$52>>2] = $51;
    $53 = (_match($ms,$$0$ph136$lcssa402,$39)|0);
    $54 = ($53|0)==(0|0);
    if (!($54)) {
     $$2 = $53;
     break;
    }
    HEAP32[$52>>2] = -1;
    $$2 = 0;
    break;
   }
   else if ((label|0) == 23) {
    $58 = HEAP32[$ms$idx>>2]|0;
    $59 = ($$0$ph136$lcssa406|0)==($58|0);
    $60 = $59 ? $$0$ph136$lcssa406 : 0;
    $$2 = $60;
    break;
   }
   else if ((label|0) == 109) {
    $254 = ((($$01$i$lcssa399)) + 1|0);
    $255 = (_match($ms,$$0$ph136$lcssa409,$254)|0);
    $256 = ($255|0)==(0|0);
    if (!($256)) {
     $$2 = $255;
     break;
    }
    $257 = ((($$01$i$lcssa399)) + -1|0);
    $$01$i27119 = $$0$ph136$lcssa409;
    while(1) {
     $ms$idx$val$i29 = HEAP32[$ms$idx>>2]|0;
     $306 = ($ms$idx$val$i29>>>0)>($$01$i27119>>>0);
     if (!($306)) {
      $$2 = 0;
      break L4;
     }
     $307 = HEAP8[$$01$i27119>>0]|0;
     $308 = $307&255;
     $309 = HEAP8[$$01125$lcssa390>>0]|0;
     $310 = $309 << 24 >> 24;
     L151: do {
      if ((($310|0) == 91)) {
       $314 = HEAP8[$$pre$phi207$lcssa395Z2D>>0]|0;
       $315 = ($314<<24>>24)==(94);
       $$p$i49 = $315 ? $$pre$phi207$lcssa395Z2D : $$01125$lcssa390;
       $316 = $315&1;
       $$$i50 = $316 ^ 1;
       $317 = ((($$p$i49)) + 1|0);
       $318 = ($317>>>0)<($257>>>0);
       if ($318) {
        $$012$i51 = $$p$i49;$320 = $317;
        while(1) {
         $319 = HEAP8[$320>>0]|0;
         $321 = ($319<<24>>24)==(37);
         $322 = ((($$012$i51)) + 2|0);
         $323 = HEAP8[$322>>0]|0;
         do {
          if ($321) {
           $324 = $323&255;
           $325 = (_match_class($308,$324)|0);
           $326 = ($325|0)==(0);
           if ($326) {
            $$01$be$i53 = $322;
           } else {
            $$0$i$i30 = $$$i50;
            label = 147;
            break L151;
           }
          } else {
           $327 = ($323<<24>>24)==(45);
           if ($327) {
            $328 = ((($$012$i51)) + 3|0);
            $329 = ($328>>>0)<($257>>>0);
            if ($329) {
             $330 = ($319&255)>($307&255);
             if ($330) {
              $$01$be$i53 = $328;
              break;
             }
             $331 = HEAP8[$328>>0]|0;
             $332 = ($331&255)<($307&255);
             if ($332) {
              $$01$be$i53 = $328;
              break;
             } else {
              $$0$i$i30 = $$$i50;
              label = 147;
              break L151;
             }
            }
           }
           $333 = ($319<<24>>24)==($307<<24>>24);
           if ($333) {
            $$0$i$i30 = $$$i50;
            label = 147;
            break L151;
           } else {
            $$01$be$i53 = $320;
           }
          }
         } while(0);
         $334 = ((($$01$be$i53)) + 1|0);
         $335 = ($334>>>0)<($257>>>0);
         if ($335) {
          $$012$i51 = $$01$be$i53;$320 = $334;
         } else {
          $$0$i$i30 = $316;
          label = 147;
          break;
         }
        }
       } else {
        $$0$i$i30 = $316;
        label = 147;
       }
      } else if ((($310|0) == 37)) {
       $311 = HEAP8[$$pre$phi207$lcssa395Z2D>>0]|0;
       $312 = $311&255;
       $313 = (_match_class($308,$312)|0);
       $$0$i$i30 = $313;
       label = 147;
      } else if (!((($310|0) == 46))) {
       $336 = ($309<<24>>24)==($307<<24>>24);
       $337 = $336&1;
       $$0$i$i30 = $337;
       label = 147;
      }
     } while(0);
     if ((label|0) == 147) {
      label = 0;
      $338 = ($$0$i$i30|0)==(0);
      if ($338) {
       $$2 = 0;
       break L4;
      }
     }
     $339 = ((($$01$i27119)) + 1|0);
     $340 = (_match($ms,$339,$254)|0);
     $341 = ($340|0)==(0|0);
     if ($341) {
      $$01$i27119 = $339;
     } else {
      $$2 = $340;
      break L4;
     }
    }
   }
   else if ((label|0) == 112) {
    $$01$i400 = $$01$i$lcssa397;$$01125391 = $$01125$lcssa388;$$1 = $$lcssa415;$$pre$phi207396Z2D = $$pre$phi207$lcssa393Z2D;
   }
   $ms$idx$val$i111 = HEAP32[$ms$idx>>2]|0;
   $261 = ($ms$idx$val$i111>>>0)>($$1>>>0);
   if ($261) {
    $262 = ((($$01$i400)) + -1|0);
    $266 = $$1;$i$0$i112 = 0;$ms$idx$val$i203 = $ms$idx$val$i111;
    while(1) {
     $265 = HEAP8[$266>>0]|0;
     $267 = $265&255;
     $268 = HEAP8[$$01125391>>0]|0;
     $269 = $268 << 24 >> 24;
     L183: do {
      if ((($269|0) == 46)) {
       $ms$idx$val$i = $ms$idx$val$i203;
      } else if ((($269|0) == 37)) {
       $270 = HEAP8[$$pre$phi207396Z2D>>0]|0;
       $271 = $270&255;
       $272 = (_match_class($267,$271)|0);
       $$0$i$i25 = $272;
       label = 129;
      } else if ((($269|0) == 91)) {
       $273 = HEAP8[$$pre$phi207396Z2D>>0]|0;
       $274 = ($273<<24>>24)==(94);
       $$p$i41 = $274 ? $$pre$phi207396Z2D : $$01125391;
       $275 = $274&1;
       $$$i42 = $275 ^ 1;
       $276 = ((($$p$i41)) + 1|0);
       $277 = ($276>>>0)<($262>>>0);
       if ($277) {
        $$012$i43 = $$p$i41;$279 = $276;
        while(1) {
         $278 = HEAP8[$279>>0]|0;
         $280 = ($278<<24>>24)==(37);
         $281 = ((($$012$i43)) + 2|0);
         $282 = HEAP8[$281>>0]|0;
         do {
          if ($280) {
           $283 = $282&255;
           $284 = (_match_class($267,$283)|0);
           $285 = ($284|0)==(0);
           if ($285) {
            $$01$be$i45 = $281;
           } else {
            $$0$i$i25 = $$$i42;
            label = 129;
            break L183;
           }
          } else {
           $286 = ($282<<24>>24)==(45);
           if ($286) {
            $287 = ((($$012$i43)) + 3|0);
            $288 = ($287>>>0)<($262>>>0);
            if ($288) {
             $289 = ($278&255)>($265&255);
             if ($289) {
              $$01$be$i45 = $287;
              break;
             }
             $290 = HEAP8[$287>>0]|0;
             $291 = ($290&255)<($265&255);
             if ($291) {
              $$01$be$i45 = $287;
              break;
             } else {
              $$0$i$i25 = $$$i42;
              label = 129;
              break L183;
             }
            }
           }
           $292 = ($278<<24>>24)==($265<<24>>24);
           if ($292) {
            $$0$i$i25 = $$$i42;
            label = 129;
            break L183;
           } else {
            $$01$be$i45 = $279;
           }
          }
         } while(0);
         $293 = ((($$01$be$i45)) + 1|0);
         $294 = ($293>>>0)<($262>>>0);
         if ($294) {
          $$012$i43 = $$01$be$i45;$279 = $293;
         } else {
          $$0$i$i25 = $275;
          label = 129;
          break;
         }
        }
       } else {
        $$0$i$i25 = $275;
        label = 129;
       }
      } else {
       $295 = ($268<<24>>24)==($265<<24>>24);
       $296 = $295&1;
       $$0$i$i25 = $296;
       label = 129;
      }
     } while(0);
     if ((label|0) == 129) {
      label = 0;
      $297 = ($$0$i$i25|0)==(0);
      if ($297) {
       $i$0$i$lcssa = $i$0$i112;
       break;
      }
      $ms$idx$val$i$pre = HEAP32[$ms$idx>>2]|0;
      $ms$idx$val$i = $ms$idx$val$i$pre;
     }
     $298 = (($i$0$i112) + 1)|0;
     $299 = (($$1) + ($298)|0);
     $300 = ($ms$idx$val$i>>>0)>($299>>>0);
     if ($300) {
      $266 = $299;$i$0$i112 = $298;$ms$idx$val$i203 = $ms$idx$val$i;
     } else {
      $i$0$i$lcssa = $298;
      break;
     }
    }
    $263 = ($i$0$i$lcssa|0)>(-1);
    if ($263) {
     $i$0$i$lcssa210 = $i$0$i$lcssa;
    } else {
     $$2 = 0;
     break;
    }
   } else {
    $i$0$i$lcssa210 = 0;
   }
   $264 = ((($$01$i400)) + 1|0);
   $i$1$i109 = $i$0$i$lcssa210;
   while(1) {
    $303 = (($$1) + ($i$1$i109)|0);
    $304 = (_match($ms,$303,$264)|0);
    $305 = ($304|0)==(0|0);
    if (!($305)) {
     $$2 = $304;
     break L4;
    }
    $301 = (($i$1$i109) + -1)|0;
    $302 = ($i$1$i109|0)>(0);
    if ($302) {
     $i$1$i109 = $301;
    } else {
     $$2 = 0;
     break;
    }
   }
  }
 } while(0);
 $344 = HEAP32[$ms>>2]|0;
 $345 = (($344) + 1)|0;
 HEAP32[$ms>>2] = $345;
 STACKTOP = sp;return ($$2|0);
}
function _push_onecapture($ms,$i,$s,$e) {
 $ms = $ms|0;
 $i = $i|0;
 $s = $s|0;
 $e = $e|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ((($ms)) + 20|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)>($i|0);
 if (!($2)) {
  $3 = ($i|0)==(0);
  $4 = ((($ms)) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  if ($3) {
   $6 = $e;
   $7 = $s;
   $8 = (($6) - ($7))|0;
   (_lua_pushlstring($5,$s,$8)|0);
   STACKTOP = sp;return;
  } else {
   $9 = (($i) + 1)|0;
   HEAP32[$vararg_buffer>>2] = $9;
   (_luaL_error($5,11184,$vararg_buffer)|0);
   STACKTOP = sp;return;
  }
 }
 $10 = (((((($ms)) + 24|0) + ($i<<3)|0)) + 4|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(-1);
 if ($12) {
  $13 = ((($ms)) + 16|0);
  $14 = HEAP32[$13>>2]|0;
  (_luaL_error($14,11216,$vararg_buffer1)|0);
  $15 = HEAP32[$13>>2]|0;
  $16 = (((($ms)) + 24|0) + ($i<<3)|0);
  $17 = HEAP32[$16>>2]|0;
  $31 = $15;$32 = $17;
 } else {
  $18 = ($11|0)==(-2);
  $19 = ((($ms)) + 16|0);
  $20 = HEAP32[$19>>2]|0;
  $21 = (((($ms)) + 24|0) + ($i<<3)|0);
  $22 = HEAP32[$21>>2]|0;
  if ($18) {
   $23 = ((($ms)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $22;
   $26 = $24;
   $27 = (($25) + 1)|0;
   $28 = (($27) - ($26))|0;
   $29 = ($28|0)<(0);
   $30 = $29 << 31 >> 31;
   _lua_pushinteger($20,$28,$30);
   STACKTOP = sp;return;
  } else {
   $31 = $20;$32 = $22;
  }
 }
 (_lua_pushlstring($31,$32,$11)|0);
 STACKTOP = sp;return;
}
function _match_class($c,$cl) {
 $c = $c|0;
 $cl = $cl|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $isdigit = 0, $isdigittmp = 0, $res$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_tolower($cl)|0);
 do {
  switch ($0|0) {
  case 97:  {
   $1 = (_isalpha($c)|0);
   $res$0 = $1;
   break;
  }
  case 103:  {
   $4 = (_isgraph($c)|0);
   $res$0 = $4;
   break;
  }
  case 115:  {
   $7 = (_isspace($c)|0);
   $res$0 = $7;
   break;
  }
  case 117:  {
   $8 = (_isupper($c)|0);
   $res$0 = $8;
   break;
  }
  case 119:  {
   $9 = (_isalnum($c)|0);
   $res$0 = $9;
   break;
  }
  case 112:  {
   $6 = (_ispunct($c)|0);
   $res$0 = $6;
   break;
  }
  case 99:  {
   $2 = (_iscntrl($c)|0);
   $res$0 = $2;
   break;
  }
  case 100:  {
   $isdigittmp = (($c) + -48)|0;
   $isdigit = ($isdigittmp>>>0)<(10);
   $3 = $isdigit&1;
   $res$0 = $3;
   break;
  }
  case 120:  {
   $10 = (_isxdigit($c)|0);
   $res$0 = $10;
   break;
  }
  case 122:  {
   $11 = ($c|0)==(0);
   $12 = $11&1;
   $res$0 = $12;
   break;
  }
  case 108:  {
   $5 = (_islower($c)|0);
   $res$0 = $5;
   break;
  }
  default: {
   $13 = ($cl|0)==($c|0);
   $14 = $13&1;
   $$0 = $14;
   return ($$0|0);
  }
  }
 } while(0);
 $15 = (_islower($cl)|0);
 $16 = ($15|0)==(0);
 $17 = ($res$0|0)==(0);
 $18 = $17&1;
 $19 = $16 ? $18 : $res$0;
 $$0 = $19;
 return ($$0|0);
}
function _gmatch_aux($L) {
 $L = $L|0;
 var $$$i = 0, $$0 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$02$i = 0;
 var $lp = 0, $ls = 0, $ms = 0, $or$cond$i = 0, $src$04 = 0, $src$04$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 288|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ms = sp + 8|0;
 $ls = sp + 4|0;
 $lp = sp;
 $0 = (_lua_tolstring($L,-1001001,$ls)|0);
 $1 = (_lua_tolstring($L,-1001002,$lp)|0);
 $2 = ((($ms)) + 16|0);
 HEAP32[$2>>2] = $L;
 HEAP32[$ms>>2] = 200;
 $3 = ((($ms)) + 4|0);
 HEAP32[$3>>2] = $0;
 $4 = HEAP32[$ls>>2]|0;
 $5 = (($0) + ($4)|0);
 $6 = ((($ms)) + 8|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[$lp>>2]|0;
 $8 = (($1) + ($7)|0);
 $9 = ((($ms)) + 12|0);
 HEAP32[$9>>2] = $8;
 $10 = (_lua_tointegerx($L,-1001003,0)|0);
 $11 = tempRet0;
 $12 = ($10|0)>($4|0);
 if ($12) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $13 = (($0) + ($10)|0);
 $14 = ((($ms)) + 20|0);
 $src$04 = $13;
 while(1) {
  HEAP32[$14>>2] = 0;
  $15 = (_match($ms,$src$04,$1)|0);
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $$lcssa = $15;$src$04$lcssa = $src$04;
   break;
  }
  $32 = ((($src$04)) + 1|0);
  $33 = HEAP32[$6>>2]|0;
  $34 = ($32>>>0)>($33>>>0);
  if ($34) {
   $$0 = 0;
   label = 7;
   break;
  } else {
   $src$04 = $32;
  }
 }
 if ((label|0) == 7) {
  STACKTOP = sp;return ($$0|0);
 }
 $17 = $$lcssa;
 $18 = $0;
 $19 = (($17) - ($18))|0;
 $20 = ($19|0)<(0);
 $21 = $20 << 31 >> 31;
 $22 = ($$lcssa|0)==($src$04$lcssa|0);
 $23 = $22&1;
 $24 = (_i64Add(($19|0),($21|0),($23|0),0)|0);
 $25 = tempRet0;
 _lua_pushinteger($L,$24,$25);
 _lua_copy($L,-1,-1001003);
 _lua_settop($L,-2);
 $26 = HEAP32[$14>>2]|0;
 $27 = ($26|0)==(0);
 $28 = ($src$04$lcssa|0)!=(0|0);
 $or$cond$i = $28 & $27;
 $$$i = $or$cond$i ? 1 : $26;
 $29 = HEAP32[$2>>2]|0;
 _luaL_checkstack($29,$$$i,11160);
 $30 = ($$$i|0)>(0);
 if ($30) {
  $i$02$i = 0;
 } else {
  $$0 = $$$i;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  _push_onecapture($ms,$i$02$i,$src$04$lcssa,$$lcssa);
  $31 = (($i$02$i) + 1)|0;
  $exitcond$i = ($31|0)==($$$i|0);
  if ($exitcond$i) {
   $$0 = $$$i;
   break;
  } else {
   $i$02$i = $31;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function _writer($L,$b,$size,$B) {
 $L = $L|0;
 $b = $b|0;
 $size = $size|0;
 $B = $B|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_addlstring($B,$b,$size);
 return 0;
}
function _luaopen_table($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,7);
 _luaL_setfuncs($L,11768,0);
 return 1;
}
function _tconcat($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $lsep = 0, $ta = 0, $ta$idx$val = 0, $ta$idx1$val = 0, $vararg_buffer = 0, $vararg_buffer2 = 0, $vararg_ptr1 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer2 = sp + 16|0;
 $vararg_buffer = sp;
 $ta = sp + 4152|0;
 $b = sp + 40|0;
 $lsep = sp + 32|0;
 $0 = (_luaL_optlstring($L,2,37352,$lsep)|0);
 _checktab($L,$ta);
 $1 = (_luaL_optinteger($L,3,1,0)|0);
 $2 = tempRet0;
 $3 = (_lua_type($L,4)|0);
 $4 = ($3|0)<(1);
 if ($4) {
  $5 = (_luaL_len($L,1)|0);
  $6 = tempRet0;
  $10 = $6;$12 = $5;
 } else {
  $7 = (_luaL_checkinteger($L,4)|0);
  $8 = tempRet0;
  $10 = $8;$12 = $7;
 }
 _luaL_buffinit($L,$b);
 $9 = ($2|0)<($10|0);
 $11 = ($1>>>0)<($12>>>0);
 $13 = ($2|0)==($10|0);
 $14 = $13 & $11;
 $15 = $9 | $14;
 if ($15) {
  $ta$idx1$val = HEAP32[$ta>>2]|0;
  $16 = $1;$17 = $2;
  while(1) {
   (FUNCTION_TABLE_iiiii[$ta$idx1$val & 511]($L,1,$16,$17)|0);
   $18 = (_lua_isstring($L,-1)|0);
   $19 = ($18|0)==(0);
   if ($19) {
    $20 = (_lua_type($L,-1)|0);
    $21 = (_lua_typename($L,$20)|0);
    HEAP32[$vararg_buffer>>2] = $21;
    $vararg_ptr1 = ((($vararg_buffer)) + 8|0);
    $22 = $vararg_ptr1;
    $23 = $22;
    HEAP32[$23>>2] = $16;
    $24 = (($22) + 4)|0;
    $25 = $24;
    HEAP32[$25>>2] = $17;
    (_luaL_error($L,12096,$vararg_buffer)|0);
   }
   _luaL_addvalue($b);
   $26 = HEAP32[$lsep>>2]|0;
   _luaL_addlstring($b,$0,$26);
   $27 = (_i64Add(($16|0),($17|0),1,0)|0);
   $28 = tempRet0;
   $29 = ($28|0)<($10|0);
   $30 = ($27>>>0)<($12>>>0);
   $31 = ($28|0)==($10|0);
   $32 = $31 & $30;
   $33 = $29 | $32;
   if ($33) {
    $16 = $27;$17 = $28;
   } else {
    break;
   }
  }
 } else {
  $34 = ($1|0)==($12|0);
  $35 = ($2|0)==($10|0);
  $36 = $34 & $35;
  if (!($36)) {
   _luaL_pushresult($b);
   STACKTOP = sp;return 1;
  }
 }
 $ta$idx$val = HEAP32[$ta>>2]|0;
 (FUNCTION_TABLE_iiiii[$ta$idx$val & 511]($L,1,$12,$10)|0);
 $37 = (_lua_isstring($L,-1)|0);
 $38 = ($37|0)==(0);
 if ($38) {
  $39 = (_lua_type($L,-1)|0);
  $40 = (_lua_typename($L,$39)|0);
  HEAP32[$vararg_buffer2>>2] = $40;
  $vararg_ptr5 = ((($vararg_buffer2)) + 8|0);
  $41 = $vararg_ptr5;
  $42 = $41;
  HEAP32[$42>>2] = $12;
  $43 = (($41) + 4)|0;
  $44 = $43;
  HEAP32[$44>>2] = $10;
  (_luaL_error($L,12096,$vararg_buffer2)|0);
 }
 _luaL_addvalue($b);
 _luaL_pushresult($b);
 STACKTOP = sp;return 1;
}
function _tinsert($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $or$cond = 0, $ta = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ta = sp + 8|0;
 _checktab($L,$ta);
 $0 = (_luaL_len($L,1)|0);
 $1 = tempRet0;
 $2 = (_i64Add(($0|0),($1|0),1,0)|0);
 $3 = tempRet0;
 $4 = (_lua_gettop($L)|0);
 if ((($4|0) == 3)) {
  label = 2;
 } else if ((($4|0) == 2)) {
  $37 = $2;$38 = $3;
 } else {
  $34 = (_luaL_error($L,12056,$vararg_buffer)|0);
  $$0 = $34;
  STACKTOP = sp;return ($$0|0);
 }
 if ((label|0) == 2) {
  $5 = (_luaL_checkinteger($L,2)|0);
  $6 = tempRet0;
  $7 = ($6|0)<(0);
  $8 = ($5>>>0)<(1);
  $9 = ($6|0)==(0);
  $10 = $9 & $8;
  $11 = $7 | $10;
  $12 = ($6|0)>($3|0);
  $13 = ($5>>>0)>($2>>>0);
  $14 = ($6|0)==($3|0);
  $15 = $14 & $13;
  $16 = $12 | $15;
  $or$cond = $11 | $16;
  if ($or$cond) {
   (_luaL_argerror($L,2,11992)|0);
  }
  $17 = ($1|0)<($6|0);
  $18 = ($0>>>0)<($5>>>0);
  $19 = ($1|0)==($6|0);
  $20 = $19 & $18;
  $21 = $17 | $20;
  if ($21) {
   $37 = $5;$38 = $6;
  } else {
   $22 = HEAP32[$ta>>2]|0;
   $23 = ((($ta)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = $2;$26 = $3;
   while(1) {
    $27 = (_i64Add(($25|0),($26|0),-1,-1)|0);
    $28 = tempRet0;
    (FUNCTION_TABLE_iiiii[$22 & 511]($L,1,$27,$28)|0);
    FUNCTION_TABLE_viiii[$24 & 511]($L,1,$25,$26);
    $29 = ($28|0)>($6|0);
    $30 = ($27>>>0)>($5>>>0);
    $31 = ($28|0)==($6|0);
    $32 = $31 & $30;
    $33 = $29 | $32;
    if ($33) {
     $25 = $27;$26 = $28;
    } else {
     $37 = $5;$38 = $6;
     break;
    }
   }
  }
 }
 $35 = ((($ta)) + 4|0);
 $36 = HEAP32[$35>>2]|0;
 FUNCTION_TABLE_viiii[$36 & 511]($L,1,$37,$38);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _pack($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_gettop($L)|0);
 _lua_createtable($L,$0,1);
 _lua_rotate($L,1,1);
 $1 = ($0|0)>(0);
 if ($1) {
  $i$01 = $0;
  while(1) {
   $2 = ($i$01|0)<(0);
   $3 = $2 << 31 >> 31;
   _lua_rawseti($L,1,$i$01,$3);
   $4 = (($i$01) + -1)|0;
   $5 = ($i$01|0)>(1);
   if ($5) {
    $i$01 = $4;
   } else {
    break;
   }
  }
 }
 $6 = ($0|0)<(0);
 $7 = $6 << 31 >> 31;
 _lua_pushinteger($L,$0,$7);
 _lua_setfield($L,1,12048);
 return 1;
}
function _unpack($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ta = 0, $vararg_buffer = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ta = sp + 8|0;
 _checktab($L,$ta);
 $0 = (_luaL_optinteger($L,2,1,0)|0);
 $1 = tempRet0;
 $2 = (_lua_type($L,3)|0);
 $3 = ($2|0)<(1);
 if ($3) {
  $4 = (_luaL_len($L,1)|0);
  $5 = tempRet0;
  $11 = $4;$9 = $5;
 } else {
  $6 = (_luaL_checkinteger($L,3)|0);
  $7 = tempRet0;
  $11 = $6;$9 = $7;
 }
 $8 = ($9|0)<($1|0);
 $10 = ($11>>>0)<($0>>>0);
 $12 = ($9|0)==($1|0);
 $13 = $12 & $10;
 $14 = $8 | $13;
 if ($14) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = (_i64Subtract(($11|0),($9|0),($0|0),($1|0))|0);
 $16 = tempRet0;
 $17 = ($16>>>0)>(0);
 $18 = ($15>>>0)>(2147483646);
 $19 = ($16|0)==(0);
 $20 = $19 & $18;
 $21 = $17 | $20;
 if (!($21)) {
  $22 = (_i64Add(($15|0),($16|0),1,0)|0);
  $23 = tempRet0;
  $24 = (_lua_checkstack($L,$22)|0);
  $25 = ($24|0)==(0);
  if (!($25)) {
   $26 = HEAP32[$ta>>2]|0;
   $28 = $0;$29 = $1;
   while(1) {
    (FUNCTION_TABLE_iiiii[$26 & 511]($L,1,$28,$29)|0);
    $30 = (_i64Add(($28|0),($29|0),1,0)|0);
    $31 = tempRet0;
    $32 = ($29|0)<($9|0);
    $33 = ($28>>>0)<($11>>>0);
    $34 = ($29|0)==($9|0);
    $35 = $34 & $33;
    $36 = $32 | $35;
    if ($36) {
     $28 = $30;$29 = $31;
    } else {
     $$0 = $22;
     break;
    }
   }
   STACKTOP = sp;return ($$0|0);
  }
 }
 $27 = (_luaL_error($L,12016,$vararg_buffer)|0);
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function _tremove($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $ta = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ta = sp;
 _checktab($L,$ta);
 $0 = (_luaL_len($L,1)|0);
 $1 = tempRet0;
 $2 = (_luaL_optinteger($L,2,$0,$1)|0);
 $3 = tempRet0;
 $4 = ($2|0)==($0|0);
 $5 = ($3|0)==($1|0);
 $6 = $4 & $5;
 if (!($6)) {
  $7 = ($3|0)<(0);
  $8 = ($2>>>0)<(1);
  $9 = ($3|0)==(0);
  $10 = $9 & $8;
  $11 = $7 | $10;
  $12 = (_i64Add(($0|0),($1|0),1,0)|0);
  $13 = tempRet0;
  $14 = ($3|0)>($13|0);
  $15 = ($2>>>0)>($12>>>0);
  $16 = ($3|0)==($13|0);
  $17 = $16 & $15;
  $18 = $14 | $17;
  $or$cond = $11 | $18;
  if ($or$cond) {
   (_luaL_argerror($L,1,11992)|0);
  }
 }
 $19 = HEAP32[$ta>>2]|0;
 (FUNCTION_TABLE_iiiii[$19 & 511]($L,1,$2,$3)|0);
 $20 = ($3|0)<($1|0);
 $21 = ($2>>>0)<($0>>>0);
 $22 = ($3|0)==($1|0);
 $23 = $22 & $21;
 $24 = $20 | $23;
 $25 = ((($ta)) + 4|0);
 $26 = HEAP32[$25>>2]|0;
 if ($24) {
  $27 = $2;$28 = $3;
 } else {
  $36 = $2;$37 = $3;
  _lua_pushnil($L);
  FUNCTION_TABLE_viiii[$26 & 511]($L,1,$36,$37);
  STACKTOP = sp;return 1;
 }
 while(1) {
  $29 = (_i64Add(($27|0),($28|0),1,0)|0);
  $30 = tempRet0;
  (FUNCTION_TABLE_iiiii[$19 & 511]($L,1,$29,$30)|0);
  FUNCTION_TABLE_viiii[$26 & 511]($L,1,$27,$28);
  $31 = ($30|0)<($1|0);
  $32 = ($29>>>0)<($0>>>0);
  $33 = ($30|0)==($1|0);
  $34 = $33 & $32;
  $35 = $31 | $34;
  if ($35) {
   $27 = $29;$28 = $30;
  } else {
   $36 = $0;$37 = $1;
   break;
  }
 }
 _lua_pushnil($L);
 FUNCTION_TABLE_viiii[$26 & 511]($L,1,$36,$37);
 STACKTOP = sp;return 1;
}
function _tmove($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checkinteger($L,2)|0);
 $1 = tempRet0;
 $2 = (_luaL_checkinteger($L,3)|0);
 $3 = tempRet0;
 $4 = (_luaL_checkinteger($L,4)|0);
 $5 = tempRet0;
 $6 = (_lua_type($L,5)|0);
 $7 = ($6|0)>(0);
 $8 = $7 ? 5 : 1;
 $9 = ($1|0)>(0);
 $10 = ($0>>>0)>(0);
 $11 = ($1|0)==(0);
 $12 = $11 & $10;
 $13 = $9 | $12;
 if (!($13)) {
  (_luaL_argerror($L,2,11952)|0);
 }
 $14 = ($3|0)<($1|0);
 $15 = ($2>>>0)<($0>>>0);
 $16 = ($3|0)==($1|0);
 $17 = $16 & $15;
 $18 = $14 | $17;
 if ($18) {
  _lua_pushvalue($L,$8);
  return 1;
 }
 $19 = (_luaL_getmetafield($L,1,11928)|0);
 $20 = ($19|0)==(0);
 if ($20) {
  _luaL_checktype($L,1,5);
  $39 = 346;
 } else {
  $39 = 345;
 }
 $21 = (_luaL_getmetafield($L,$8,11936)|0);
 $22 = ($21|0)==(0);
 if ($22) {
  _luaL_checktype($L,$8,5);
  $42 = 348;
 } else {
  $42 = 347;
 }
 $23 = (_i64Subtract(($2|0),($3|0),($0|0),($1|0))|0);
 $24 = tempRet0;
 $25 = ($5|0)>($1|0);
 $26 = ($4>>>0)>($0>>>0);
 $27 = ($5|0)==($1|0);
 $28 = $27 & $26;
 $29 = $25 | $28;
 $30 = ($24|0)>(-1);
 $31 = ($23>>>0)>(4294967295);
 $32 = ($24|0)==(-1);
 $33 = $32 & $31;
 $34 = $30 | $33;
 if ($29) {
  if ($34) {
   $35 = $23;$36 = $24;
  } else {
   _lua_pushvalue($L,$8);
   return 1;
  }
  while(1) {
   $37 = (_i64Add(($35|0),($36|0),($0|0),($1|0))|0);
   $38 = tempRet0;
   (FUNCTION_TABLE_iiiii[$39 & 511]($L,1,$37,$38)|0);
   $40 = (_i64Add(($35|0),($36|0),($4|0),($5|0))|0);
   $41 = tempRet0;
   FUNCTION_TABLE_viiii[$42 & 511]($L,$8,$40,$41);
   $43 = (_i64Add(($35|0),($36|0),-1,-1)|0);
   $44 = tempRet0;
   $45 = ($36|0)>(0);
   $46 = ($35>>>0)>(0);
   $47 = ($36|0)==(0);
   $48 = $47 & $46;
   $49 = $45 | $48;
   if ($49) {
    $35 = $43;$36 = $44;
   } else {
    break;
   }
  }
  _lua_pushvalue($L,$8);
  return 1;
 } else {
  if ($34) {
   $50 = 0;$51 = 0;
  } else {
   _lua_pushvalue($L,$8);
   return 1;
  }
  while(1) {
   $52 = (_i64Add(($50|0),($51|0),($0|0),($1|0))|0);
   $53 = tempRet0;
   (FUNCTION_TABLE_iiiii[$39 & 511]($L,1,$52,$53)|0);
   $54 = (_i64Add(($50|0),($51|0),($4|0),($5|0))|0);
   $55 = tempRet0;
   FUNCTION_TABLE_viiii[$42 & 511]($L,$8,$54,$55);
   $56 = (_i64Add(($50|0),($51|0),1,0)|0);
   $57 = tempRet0;
   $58 = ($51|0)<($24|0);
   $59 = ($50>>>0)<($23>>>0);
   $60 = ($51|0)==($24|0);
   $61 = $60 & $59;
   $62 = $58 | $61;
   if ($62) {
    $50 = $56;$51 = $57;
   } else {
    break;
   }
  }
  _lua_pushvalue($L,$8);
  return 1;
 }
 return (0)|0;
}
function _sort($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $ta = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ta = sp;
 _checktab($L,$ta);
 $0 = (_luaL_len($L,1)|0);
 $1 = tempRet0;
 _luaL_checkstack($L,50,37352);
 $2 = (_lua_type($L,2)|0);
 $3 = ($2|0)<(1);
 if (!($3)) {
  _luaL_checktype($L,2,6);
 }
 _lua_settop($L,2);
 _auxsort($L,$ta,1,$0);
 STACKTOP = sp;return 0;
}
function _checktab($L,$ta) {
 $L = $L|0;
 $ta = $ta|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[$ta>>2] = 0;
 $0 = ((($ta)) + 4|0);
 HEAP32[$0>>2] = 0;
 $1 = (_lua_getmetatable($L,1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  (_lua_pushlstring($L,11928,7)|0);
  $3 = (_lua_rawget($L,-2)|0);
  $4 = ($3|0)==(0);
  if (!($4)) {
   HEAP32[$ta>>2] = 345;
  }
  (_lua_pushlstring($L,11936,10)|0);
  $5 = (_lua_rawget($L,-3)|0);
  $6 = ($5|0)==(0);
  if (!($6)) {
   HEAP32[$0>>2] = 347;
  }
  _lua_settop($L,-4);
 }
 $7 = HEAP32[$ta>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  $9 = HEAP32[$0>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   return;
  }
 }
 _luaL_checktype($L,1,5);
 $11 = HEAP32[$ta>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  HEAP32[$ta>>2] = 346;
 }
 $13 = HEAP32[$0>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  return;
 }
 HEAP32[$0>>2] = 348;
 return;
}
function _auxsort($L,$ta,$l,$u) {
 $L = $L|0;
 $ta = $ta|0;
 $l = $l|0;
 $u = $u|0;
 var $$$01 = 0, $$0$i$0 = 0, $$01$ = 0, $$0112 = 0, $$013 = 0, $$lcssa = 0, $$lcssa$lcssa = 0, $$lcssa4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $9 = 0, $i$0$$0 = 0, $i$0$lcssa = 0, $i$0$lcssa$lcssa = 0, $i$0$ph = 0, $j$0$ph = 0, $j$1$lcssa = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ($u|0)>($l|0);
 if (!($0)) {
  STACKTOP = sp;return;
 }
 $1 = ((($ta)) + 4|0);
 $$0112 = $l;$$013 = $u;
 while(1) {
  $2 = HEAP32[$ta>>2]|0;
  $3 = ($$0112|0)<(0);
  $4 = $3 << 31 >> 31;
  (FUNCTION_TABLE_iiiii[$2 & 511]($L,1,$$0112,$4)|0);
  $5 = HEAP32[$ta>>2]|0;
  $6 = ($$013|0)<(0);
  $7 = $6 << 31 >> 31;
  (FUNCTION_TABLE_iiiii[$5 & 511]($L,1,$$013,$7)|0);
  $8 = (_sort_comp($L,-1,-2)|0);
  $9 = ($8|0)==(0);
  if ($9) {
   _lua_settop($L,-3);
  } else {
   $10 = HEAP32[$1>>2]|0;
   FUNCTION_TABLE_viiii[$10 & 511]($L,1,$$0112,$4);
   $11 = HEAP32[$1>>2]|0;
   FUNCTION_TABLE_viiii[$11 & 511]($L,1,$$013,$7);
  }
  $12 = (($$013) - ($$0112))|0;
  $13 = ($12|0)==(1);
  if ($13) {
   label = 25;
   break;
  }
  $14 = (($$013) + ($$0112))|0;
  $15 = (($14|0) / 2)&-1;
  $16 = HEAP32[$ta>>2]|0;
  $17 = ($15|0)<(0);
  $18 = $17 << 31 >> 31;
  (FUNCTION_TABLE_iiiii[$16 & 511]($L,1,$15,$18)|0);
  $19 = HEAP32[$ta>>2]|0;
  (FUNCTION_TABLE_iiiii[$19 & 511]($L,1,$$0112,$4)|0);
  $20 = (_sort_comp($L,-2,-1)|0);
  $21 = ($20|0)==(0);
  do {
   if ($21) {
    _lua_settop($L,-2);
    $24 = HEAP32[$ta>>2]|0;
    (FUNCTION_TABLE_iiiii[$24 & 511]($L,1,$$013,$7)|0);
    $25 = (_sort_comp($L,-1,-2)|0);
    $26 = ($25|0)==(0);
    if ($26) {
     _lua_settop($L,-3);
     break;
    } else {
     $27 = HEAP32[$1>>2]|0;
     FUNCTION_TABLE_viiii[$27 & 511]($L,1,$15,$18);
     $28 = HEAP32[$1>>2]|0;
     FUNCTION_TABLE_viiii[$28 & 511]($L,1,$$013,$7);
     break;
    }
   } else {
    $22 = HEAP32[$1>>2]|0;
    FUNCTION_TABLE_viiii[$22 & 511]($L,1,$15,$18);
    $23 = HEAP32[$1>>2]|0;
    FUNCTION_TABLE_viiii[$23 & 511]($L,1,$$0112,$4);
   }
  } while(0);
  $29 = ($12|0)==(2);
  if ($29) {
   label = 25;
   break;
  }
  $30 = HEAP32[$ta>>2]|0;
  (FUNCTION_TABLE_iiiii[$30 & 511]($L,1,$15,$18)|0);
  _lua_pushvalue($L,-1);
  $31 = HEAP32[$ta>>2]|0;
  $32 = (($$013) + -1)|0;
  $33 = ($32|0)<(0);
  $34 = $33 << 31 >> 31;
  (FUNCTION_TABLE_iiiii[$31 & 511]($L,1,$32,$34)|0);
  $35 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viiii[$35 & 511]($L,1,$15,$18);
  $36 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viiii[$36 & 511]($L,1,$32,$34);
  $i$0$ph = $$0112;$j$0$ph = $32;
  while(1) {
   $37 = HEAP32[$ta>>2]|0;
   $38 = (($i$0$ph) + 1)|0;
   $39 = ($38|0)<(0);
   $40 = $39 << 31 >> 31;
   (FUNCTION_TABLE_iiiii[$37 & 511]($L,1,$38,$40)|0);
   $41 = (_sort_comp($L,-1,-2)|0);
   $42 = ($41|0)==(0);
   if ($42) {
    $$lcssa = $38;$78 = $38;$79 = $40;$i$0$lcssa = $i$0$ph;
   } else {
    $50 = $38;
    while(1) {
     $49 = ($$013|0)>($50|0);
     if (!($49)) {
      (_luaL_error($L,11888,$vararg_buffer)|0);
     }
     _lua_settop($L,-2);
     $51 = HEAP32[$ta>>2]|0;
     $52 = (($50) + 1)|0;
     $53 = ($52|0)<(0);
     $54 = $53 << 31 >> 31;
     (FUNCTION_TABLE_iiiii[$51 & 511]($L,1,$52,$54)|0);
     $55 = (_sort_comp($L,-1,-2)|0);
     $56 = ($55|0)==(0);
     if ($56) {
      $$lcssa = $52;$78 = $52;$79 = $54;$i$0$lcssa = $50;
      break;
     } else {
      $50 = $52;
     }
    }
   }
   $43 = HEAP32[$ta>>2]|0;
   $44 = (($j$0$ph) + -1)|0;
   $45 = ($44|0)<(0);
   $46 = $45 << 31 >> 31;
   (FUNCTION_TABLE_iiiii[$43 & 511]($L,1,$44,$46)|0);
   $47 = (_sort_comp($L,-3,-1)|0);
   $48 = ($47|0)==(0);
   if ($48) {
    $$lcssa4 = $44;$81 = $44;$82 = $46;$j$1$lcssa = $j$0$ph;
   } else {
    $58 = $44;
    while(1) {
     $57 = ($58|0)>($$0112|0);
     if (!($57)) {
      (_luaL_error($L,11888,$vararg_buffer1)|0);
     }
     _lua_settop($L,-2);
     $59 = HEAP32[$ta>>2]|0;
     $60 = (($58) + -1)|0;
     $61 = ($60|0)<(0);
     $62 = $61 << 31 >> 31;
     (FUNCTION_TABLE_iiiii[$59 & 511]($L,1,$60,$62)|0);
     $63 = (_sort_comp($L,-3,-1)|0);
     $64 = ($63|0)==(0);
     if ($64) {
      $$lcssa4 = $60;$81 = $60;$82 = $62;$j$1$lcssa = $58;
      break;
     } else {
      $58 = $60;
     }
    }
   }
   $65 = ($j$1$lcssa|0)>($$lcssa|0);
   if (!($65)) {
    $$lcssa$lcssa = $$lcssa;$68 = $78;$69 = $79;$i$0$lcssa$lcssa = $i$0$lcssa;
    break;
   }
   $77 = HEAP32[$1>>2]|0;
   FUNCTION_TABLE_viiii[$77 & 511]($L,1,$78,$79);
   $80 = HEAP32[$1>>2]|0;
   FUNCTION_TABLE_viiii[$80 & 511]($L,1,$81,$82);
   $i$0$ph = $$lcssa;$j$0$ph = $$lcssa4;
  }
  _lua_settop($L,-4);
  $66 = HEAP32[$ta>>2]|0;
  (FUNCTION_TABLE_iiiii[$66 & 511]($L,1,$32,$34)|0);
  $67 = HEAP32[$ta>>2]|0;
  (FUNCTION_TABLE_iiiii[$67 & 511]($L,1,$68,$69)|0);
  $70 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viiii[$70 & 511]($L,1,$32,$34);
  $71 = HEAP32[$1>>2]|0;
  FUNCTION_TABLE_viiii[$71 & 511]($L,1,$68,$69);
  $72 = (($$lcssa$lcssa) - ($$0112))|0;
  $73 = (($$013) - ($$lcssa$lcssa))|0;
  $74 = ($72|0)<($73|0);
  $75 = (($i$0$lcssa$lcssa) + 2)|0;
  $$$01 = $74 ? $75 : $$0112;
  $$0$i$0 = $74 ? $$013 : $i$0$lcssa$lcssa;
  $i$0$$0 = $74 ? $i$0$lcssa$lcssa : $$013;
  $$01$ = $74 ? $$0112 : $75;
  _auxsort($L,$ta,$$01$,$i$0$$0);
  $76 = ($$0$i$0|0)>($$$01|0);
  if ($76) {
   $$0112 = $$$01;$$013 = $$0$i$0;
  } else {
   label = 25;
   break;
  }
 }
 if ((label|0) == 25) {
  STACKTOP = sp;return;
 }
}
function _sort_comp($L,$a,$b) {
 $L = $L|0;
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_lua_type($L,2)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $5 = (_lua_compare($L,$a,$b,1)|0);
  $$0 = $5;
  return ($$0|0);
 } else {
  _lua_pushvalue($L,2);
  $2 = (($a) + -1)|0;
  _lua_pushvalue($L,$2);
  $3 = (($b) + -2)|0;
  _lua_pushvalue($L,$3);
  _lua_callk($L,2,1,0,0);
  $4 = (_lua_toboolean($L,-1)|0);
  _lua_settop($L,-2);
  $$0 = $4;
  return ($$0|0);
 }
 return (0)|0;
}
function _luaopen_utf8($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,6);
 _luaL_setfuncs($L,12152,0);
 (_lua_pushlstring($L,12208,14)|0);
 _lua_setfield($L,-2,12224);
 return 1;
}
function _byteoffset($L) {
 $L = $L|0;
 var $$lcssa58 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $len = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $len = sp + 4|0;
 $0 = (_luaL_checklstring($L,1,$len)|0);
 $1 = (_luaL_checkinteger($L,2)|0);
 $2 = tempRet0;
 $3 = ($2|0)>(-1);
 $4 = ($1>>>0)>(4294967295);
 $5 = ($2|0)==(-1);
 $6 = $5 & $4;
 $7 = $3 | $6;
 $8 = HEAP32[$len>>2]|0;
 $9 = (($8) + 1)|0;
 $10 = $7 ? 1 : $9;
 $11 = $7 ? 0 : 0;
 $12 = (_luaL_optinteger($L,3,$10,$11)|0);
 $13 = tempRet0;
 $14 = HEAP32[$len>>2]|0;
 $15 = ($13|0)>(-1);
 $16 = ($12>>>0)>(4294967295);
 $17 = ($13|0)==(-1);
 $18 = $17 & $16;
 $19 = $15 | $18;
 if ($19) {
  $27 = $13;$29 = $12;
  label = 4;
 } else {
  $20 = (0 - ($12))|0;
  $21 = ($14>>>0)<($20>>>0);
  if ($21) {
   $141 = 0;$142 = 0;
   label = 6;
  } else {
   $22 = (_i64Add(($12|0),($13|0),1,0)|0);
   $23 = tempRet0;
   $24 = (_i64Add(($22|0),($23|0),($14|0),0)|0);
   $25 = tempRet0;
   $27 = $25;$29 = $24;
   label = 4;
  }
 }
 if ((label|0) == 4) {
  $26 = ($27|0)>(0);
  $28 = ($29>>>0)>(0);
  $30 = ($27|0)==(0);
  $31 = $30 & $28;
  $32 = $26 | $31;
  if ($32) {
   $33 = (_i64Add(($29|0),($27|0),-1,-1)|0);
   $34 = tempRet0;
   $35 = ($34|0)>(0);
   $36 = ($33>>>0)>($14>>>0);
   $37 = ($34|0)==(0);
   $38 = $37 & $36;
   $39 = $35 | $38;
   if ($39) {
    $141 = $33;$142 = $34;
    label = 6;
   } else {
    $44 = $34;$46 = $33;
   }
  } else {
   $141 = $29;$142 = $27;
   label = 6;
  }
 }
 if ((label|0) == 6) {
  (_luaL_argerror($L,3,12464)|0);
  $44 = $142;$46 = $141;
 }
 $40 = ($1|0)==(0);
 $41 = ($2|0)==(0);
 $42 = $40 & $41;
 L10: do {
  if ($42) {
   $43 = ($44|0)>(0);
   $45 = ($46>>>0)>(0);
   $47 = ($44|0)==(0);
   $48 = $47 & $45;
   $49 = $43 | $48;
   if ($49) {
    $51 = $46;$55 = $44;
    while(1) {
     $50 = (($0) + ($51)|0);
     $52 = HEAP8[$50>>0]|0;
     $53 = $52 & -64;
     $54 = ($53<<24>>24)==(-128);
     if (!($54)) {
      $137 = $51;$138 = $55;
      break L10;
     }
     $56 = (_i64Add(($51|0),($55|0),-1,-1)|0);
     $57 = tempRet0;
     $58 = ($55|0)>(0);
     $59 = ($51>>>0)>(1);
     $60 = ($55|0)==(0);
     $61 = $60 & $59;
     $62 = $58 | $61;
     if ($62) {
      $51 = $56;$55 = $57;
     } else {
      $137 = $56;$138 = $57;
      break;
     }
    }
   } else {
    $137 = $46;$138 = $44;
   }
  } else {
   $63 = (($0) + ($46)|0);
   $64 = HEAP8[$63>>0]|0;
   $65 = $64 & -64;
   $66 = ($65<<24>>24)==(-128);
   if ($66) {
    (_luaL_error($L,12488,$vararg_buffer)|0);
   }
   $67 = ($2|0)<(0);
   L19: do {
    if ($67) {
     $76 = ($44|0)>(0);
     $77 = ($46>>>0)>(0);
     $78 = ($44|0)==(0);
     $79 = $78 & $77;
     $80 = $76 | $79;
     if ($80) {
      $145 = $46;$146 = $44;$98 = $1;$99 = $2;
      L21: while(1) {
       $81 = $145;$82 = $146;
       while(1) {
        $83 = (_i64Add(($81|0),($82|0),-1,-1)|0);
        $84 = tempRet0;
        $85 = ($82|0)>(0);
        $86 = ($81>>>0)>(1);
        $87 = ($82|0)==(0);
        $88 = $87 & $86;
        $89 = $85 | $88;
        if (!($89)) {
         $147 = $83;$148 = $84;$90 = $98;$91 = $99;
         break L21;
        }
        $94 = (($0) + ($83)|0);
        $95 = HEAP8[$94>>0]|0;
        $96 = $95 & -64;
        $97 = ($96<<24>>24)==(-128);
        if ($97) {
         $81 = $83;$82 = $84;
        } else {
         $$lcssa58 = $89;$149 = $83;$150 = $84;
         break;
        }
       }
       $100 = (_i64Add(($98|0),($99|0),1,0)|0);
       $101 = tempRet0;
       $102 = ($99|0)<(-1);
       $103 = ($98>>>0)<(4294967295);
       $104 = ($99|0)==(-1);
       $105 = $104 & $103;
       $106 = $102 | $105;
       $107 = $106 & $$lcssa58;
       if ($107) {
        $145 = $149;$146 = $150;$98 = $100;$99 = $101;
       } else {
        $133 = $100;$135 = $101;$143 = $149;$144 = $150;
        label = 25;
        break L19;
       }
      }
      $92 = (_i64Add(($90|0),($91|0),1,0)|0);
      $93 = tempRet0;
      $133 = $92;$135 = $93;$143 = $147;$144 = $148;
      label = 25;
     }
    } else {
     $68 = (_i64Add(($1|0),($2|0),-1,-1)|0);
     $69 = tempRet0;
     $70 = ($2|0)>(0);
     $71 = ($1>>>0)>(1);
     $72 = ($2|0)==(0);
     $73 = $72 & $71;
     $74 = $70 | $73;
     if ($74) {
      $75 = HEAP32[$len>>2]|0;
      $108 = $68;$109 = $69;$118 = $44;$120 = $46;
      while(1) {
       $117 = ($118|0)<(0);
       $119 = ($120>>>0)<($75>>>0);
       $121 = ($118|0)==(0);
       $122 = $121 & $119;
       $123 = $117 | $122;
       if ($123) {
        $124 = $120;$125 = $118;
       } else {
        $133 = $108;$135 = $109;$143 = $120;$144 = $118;
        label = 25;
        break L19;
       }
       while(1) {
        $126 = (_i64Add(($124|0),($125|0),1,0)|0);
        $127 = tempRet0;
        $128 = (($0) + ($126)|0);
        $129 = HEAP8[$128>>0]|0;
        $130 = $129 & -64;
        $131 = ($130<<24>>24)==(-128);
        if ($131) {
         $124 = $126;$125 = $127;
        } else {
         $151 = $126;$152 = $127;
         break;
        }
       }
       $110 = (_i64Add(($108|0),($109|0),-1,-1)|0);
       $111 = tempRet0;
       $112 = ($109|0)>(0);
       $113 = ($108>>>0)>(1);
       $114 = ($109|0)==(0);
       $115 = $114 & $113;
       $116 = $112 | $115;
       if ($116) {
        $108 = $110;$109 = $111;$118 = $152;$120 = $151;
       } else {
        $133 = $110;$135 = $111;$143 = $151;$144 = $152;
        label = 25;
        break;
       }
      }
     } else {
      $133 = $68;$135 = $69;$143 = $46;$144 = $44;
      label = 25;
     }
    }
   } while(0);
   if ((label|0) == 25) {
    $132 = ($133|0)==(0);
    $134 = ($135|0)==(0);
    $136 = $132 & $134;
    if ($136) {
     $137 = $143;$138 = $144;
     break;
    }
   }
   _lua_pushnil($L);
   STACKTOP = sp;return 1;
  }
 } while(0);
 $139 = (_i64Add(($137|0),($138|0),1,0)|0);
 $140 = tempRet0;
 _lua_pushinteger($L,$139,$140);
 STACKTOP = sp;return 1;
}
function _codepoint($L) {
 $L = $L|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $c$0$lcssa$i = 0, $c$05$i = 0, $count$0$lcssa$i = 0, $count$07$i = 0, $len = 0, $n$010 = 0, $or$cond$i = 0, $res$0$lcssa$i = 0, $res$06$i = 0, $res$1$i = 0, $s$0$i = 0, $s$09 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $len = sp + 12|0;
 $0 = (_luaL_checklstring($L,1,$len)|0);
 $1 = (_luaL_optinteger($L,2,1,0)|0);
 $2 = tempRet0;
 $3 = HEAP32[$len>>2]|0;
 $4 = ($2|0)>(-1);
 $5 = ($1>>>0)>(4294967295);
 $6 = ($2|0)==(-1);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  $15 = $1;$16 = $2;
 } else {
  $9 = (0 - ($1))|0;
  $10 = ($3>>>0)<($9>>>0);
  if ($10) {
   $15 = 0;$16 = 0;
  } else {
   $11 = (_i64Add(($1|0),($2|0),1,0)|0);
   $12 = tempRet0;
   $13 = (_i64Add(($11|0),($12|0),($3|0),0)|0);
   $14 = tempRet0;
   $15 = $13;$16 = $14;
  }
 }
 $17 = (_luaL_optinteger($L,3,$15,$16)|0);
 $18 = tempRet0;
 $19 = HEAP32[$len>>2]|0;
 $20 = ($18|0)>(-1);
 $21 = ($17>>>0)>(4294967295);
 $22 = ($18|0)==(-1);
 $23 = $22 & $21;
 $24 = $20 | $23;
 if ($24) {
  $37 = $18;$39 = $17;
 } else {
  $25 = (0 - ($17))|0;
  $26 = ($19>>>0)<($25>>>0);
  if ($26) {
   $37 = 0;$39 = 0;
  } else {
   $27 = (_i64Add(($17|0),($18|0),1,0)|0);
   $28 = tempRet0;
   $29 = (_i64Add(($27|0),($28|0),($19|0),0)|0);
   $30 = tempRet0;
   $37 = $30;$39 = $29;
  }
 }
 $31 = ($16|0)>(0);
 $32 = ($15>>>0)>(0);
 $33 = ($16|0)==(0);
 $34 = $33 & $32;
 $35 = $31 | $34;
 if ($35) {
  $40 = $19;
 } else {
  (_luaL_argerror($L,2,12424)|0);
  $$pre = HEAP32[$len>>2]|0;
  $40 = $$pre;
 }
 $36 = ($37|0)>(0);
 $38 = ($39>>>0)>($40>>>0);
 $41 = ($37|0)==(0);
 $42 = $41 & $38;
 $43 = $36 | $42;
 if ($43) {
  (_luaL_argerror($L,3,12424)|0);
 }
 $44 = ($37|0)<($16|0);
 $45 = ($39>>>0)<($15>>>0);
 $46 = ($37|0)==($16|0);
 $47 = $46 & $45;
 $48 = $44 | $47;
 if ($48) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $49 = (_i64Subtract(1,0,($15|0),($16|0))|0);
 $50 = tempRet0;
 $51 = (_i64Add(($49|0),($50|0),($39|0),($37|0))|0);
 $52 = tempRet0;
 $53 = ($51|0)<(0);
 $54 = $53 << 31 >> 31;
 $55 = (_i64Add(($51|0),($54|0),($15|0),($16|0))|0);
 $56 = tempRet0;
 $57 = ($56|0)>($37|0);
 $58 = ($55>>>0)>($39>>>0);
 $59 = ($56|0)==($37|0);
 $60 = $59 & $58;
 $61 = $57 | $60;
 if (!($61)) {
  $62 = (_luaL_error($L,12440,$vararg_buffer)|0);
  $$0 = $62;
  STACKTOP = sp;return ($$0|0);
 }
 _luaL_checkstack($L,$51,12440);
 $63 = (($0) + ($39)|0);
 $64 = (_i64Add(($15|0),($16|0),-1,0)|0);
 $65 = tempRet0;
 $66 = ($64|0)<($39|0);
 if (!($66)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $67 = (($0) + ($64)|0);
 $n$010 = 0;$s$09 = $67;
 L25: while(1) {
  $68 = HEAP8[$s$09>>0]|0;
  $69 = $68&255;
  $70 = ($68<<24>>24)>(-1);
  if ($70) {
   $res$1$i = $69;$s$0$i = $s$09;
  } else {
   $71 = $69 & 64;
   $72 = ($71|0)==(0);
   if ($72) {
    $c$0$lcssa$i = $69;$count$0$lcssa$i = 0;$res$0$lcssa$i = 0;
   } else {
    $c$05$i = $69;$count$07$i = 0;$res$06$i = 0;
    while(1) {
     $73 = (($count$07$i) + 1)|0;
     $74 = (($s$09) + ($73)|0);
     $75 = HEAP8[$74>>0]|0;
     $76 = $75&255;
     $77 = $76 & 192;
     $78 = ($77|0)==(128);
     if (!($78)) {
      break L25;
     }
     $79 = $res$06$i << 6;
     $80 = $76 & 63;
     $81 = $80 | $79;
     $82 = $c$05$i << 1;
     $83 = $82 & 64;
     $84 = ($83|0)==(0);
     if ($84) {
      $c$0$lcssa$i = $82;$count$0$lcssa$i = $73;$res$0$lcssa$i = $81;
      break;
     } else {
      $c$05$i = $82;$count$07$i = $73;$res$06$i = $81;
     }
    }
   }
   $85 = $c$0$lcssa$i & 127;
   $86 = ($count$0$lcssa$i*5)|0;
   $87 = $85 << $86;
   $88 = $87 | $res$0$lcssa$i;
   $89 = ($count$0$lcssa$i|0)>(3);
   $90 = ($88>>>0)>(1114111);
   $or$cond$i = $89 | $90;
   if ($or$cond$i) {
    break;
   }
   $91 = (12288 + ($count$0$lcssa$i<<2)|0);
   $92 = HEAP32[$91>>2]|0;
   $93 = ($88>>>0)>($92>>>0);
   if (!($93)) {
    break;
   }
   $94 = (($s$09) + ($count$0$lcssa$i)|0);
   $res$1$i = $88;$s$0$i = $94;
  }
  $96 = ((($s$0$i)) + 1|0);
  $97 = ($res$1$i|0)<(0);
  $98 = $97 << 31 >> 31;
  _lua_pushinteger($L,$res$1$i,$98);
  $99 = (($n$010) + 1)|0;
  $100 = ($96>>>0)<($63>>>0);
  if ($100) {
   $n$010 = $99;$s$09 = $96;
  } else {
   $$0 = $99;
   label = 25;
   break;
  }
 }
 if ((label|0) == 25) {
  STACKTOP = sp;return ($$0|0);
 }
 $95 = (_luaL_error($L,12304,$vararg_buffer1)|0);
 $$0 = $95;
 STACKTOP = sp;return ($$0|0);
}
function _utfchar($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $exitcond = 0;
 var $i$02 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $b = sp + 16|0;
 $0 = (_lua_gettop($L)|0);
 $1 = ($0|0)==(1);
 if ($1) {
  $2 = (_luaL_checkinteger($L,1)|0);
  $3 = tempRet0;
  $4 = ($3>>>0)<(0);
  $5 = ($2>>>0)<(1114112);
  $6 = ($3|0)==(0);
  $7 = $6 & $5;
  $8 = $4 | $7;
  if (!($8)) {
   (_luaL_argerror($L,1,12392)|0);
  }
  HEAP32[$vararg_buffer>>2] = $2;
  (_lua_pushfstring($L,12416,$vararg_buffer)|0);
  STACKTOP = sp;return 1;
 }
 _luaL_buffinit($L,$b);
 $9 = ($0|0)<(1);
 if (!($9)) {
  $i$02 = 1;
  while(1) {
   $10 = (_luaL_checkinteger($L,$i$02)|0);
   $11 = tempRet0;
   $12 = ($11>>>0)<(0);
   $13 = ($10>>>0)<(1114112);
   $14 = ($11|0)==(0);
   $15 = $14 & $13;
   $16 = $12 | $15;
   if (!($16)) {
    (_luaL_argerror($L,$i$02,12392)|0);
   }
   HEAP32[$vararg_buffer1>>2] = $10;
   (_lua_pushfstring($L,12416,$vararg_buffer1)|0);
   _luaL_addvalue($b);
   $17 = (($i$02) + 1)|0;
   $exitcond = ($i$02|0)==($0|0);
   if ($exitcond) {
    break;
   } else {
    $i$02 = $17;
   }
  }
 }
 _luaL_pushresult($b);
 STACKTOP = sp;return 1;
}
function _utflen($L) {
 $L = $L|0;
 var $$0 = 0, $$lcssa49 = 0, $$pre = 0, $$sum = 0, $$sum4 = 0, $$sum5 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0;
 var $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0;
 var $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0;
 var $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0;
 var $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$0$lcssa$i = 0, $c$05$i = 0, $count$0$lcssa$i = 0, $count$07$i = 0;
 var $len = 0, $n$014 = 0, $or$cond$i = 0, $res$0$lcssa$i = 0, $res$06$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $len = sp;
 $0 = (_luaL_checklstring($L,1,$len)|0);
 $1 = (_luaL_optinteger($L,2,1,0)|0);
 $2 = tempRet0;
 $3 = HEAP32[$len>>2]|0;
 $4 = ($2|0)>(-1);
 $5 = ($1>>>0)>(4294967295);
 $6 = ($2|0)==(-1);
 $7 = $6 & $5;
 $8 = $4 | $7;
 if ($8) {
  $30 = $2;$32 = $1;
 } else {
  $9 = (0 - ($1))|0;
  $10 = ($3>>>0)<($9>>>0);
  if ($10) {
   $30 = 0;$32 = 0;
  } else {
   $11 = (_i64Add(($1|0),($2|0),1,0)|0);
   $12 = tempRet0;
   $13 = (_i64Add(($11|0),($12|0),($3|0),0)|0);
   $14 = tempRet0;
   $30 = $14;$32 = $13;
  }
 }
 $15 = (_luaL_optinteger($L,3,-1,-1)|0);
 $16 = tempRet0;
 $17 = HEAP32[$len>>2]|0;
 $18 = ($16|0)>(-1);
 $19 = ($15>>>0)>(4294967295);
 $20 = ($16|0)==(-1);
 $21 = $20 & $19;
 $22 = $18 | $21;
 if ($22) {
  $43 = $15;$44 = $16;
 } else {
  $23 = (0 - ($15))|0;
  $24 = ($17>>>0)<($23>>>0);
  if ($24) {
   $43 = 0;$44 = 0;
  } else {
   $25 = (_i64Add(($15|0),($16|0),1,0)|0);
   $26 = tempRet0;
   $27 = (_i64Add(($25|0),($26|0),($17|0),0)|0);
   $28 = tempRet0;
   $43 = $27;$44 = $28;
  }
 }
 $29 = ($30|0)>(0);
 $31 = ($32>>>0)>(0);
 $33 = ($30|0)==(0);
 $34 = $33 & $31;
 $35 = $29 | $34;
 if ($35) {
  $36 = (_i64Add(($32|0),($30|0),-1,-1)|0);
  $37 = tempRet0;
  $38 = ($37|0)>(0);
  $39 = ($36>>>0)>($17>>>0);
  $40 = ($37|0)==(0);
  $41 = $40 & $39;
  $42 = $38 | $41;
  if ($42) {
   $107 = $36;$108 = $37;
   label = 9;
  } else {
   $49 = $17;$54 = $37;$56 = $36;
  }
 } else {
  $107 = $32;$108 = $30;
  label = 9;
 }
 if ((label|0) == 9) {
  (_luaL_argerror($L,2,12328)|0);
  $$pre = HEAP32[$len>>2]|0;
  $49 = $$pre;$54 = $108;$56 = $107;
 }
 $45 = (_i64Add(($43|0),($44|0),-1,-1)|0);
 $46 = tempRet0;
 $47 = ($44|0)>(0);
 $48 = ($43>>>0)>($49>>>0);
 $50 = ($44|0)==(0);
 $51 = $50 & $48;
 $52 = $47 | $51;
 if ($52) {
  (_luaL_argerror($L,3,12360)|0);
 }
 $53 = ($54|0)>($46|0);
 $55 = ($56>>>0)>($45>>>0);
 $57 = ($54|0)==($46|0);
 $58 = $57 & $55;
 $59 = $53 | $58;
 do {
  if ($59) {
   $105 = 0;$106 = 0;
  } else {
   $109 = $54;$61 = $56;$n$014 = 0;
   L18: while(1) {
    $60 = (($0) + ($61)|0);
    $62 = HEAP8[$60>>0]|0;
    $63 = $62&255;
    $64 = ($62<<24>>24)>(-1);
    if ($64) {
     $88 = $61;
    } else {
     $65 = $63 & 64;
     $66 = ($65|0)==(0);
     if ($66) {
      $c$0$lcssa$i = $63;$count$0$lcssa$i = 0;$res$0$lcssa$i = 0;
     } else {
      $c$05$i = $63;$count$07$i = 0;$res$06$i = 0;
      while(1) {
       $67 = (($count$07$i) + 1)|0;
       $$sum = (($67) + ($61))|0;
       $68 = (($0) + ($$sum)|0);
       $69 = HEAP8[$68>>0]|0;
       $70 = $69&255;
       $71 = $70 & 192;
       $72 = ($71|0)==(128);
       if (!($72)) {
        $91 = $61;$92 = $109;
        break L18;
       }
       $73 = $res$06$i << 6;
       $74 = $70 & 63;
       $75 = $74 | $73;
       $76 = $c$05$i << 1;
       $77 = $76 & 64;
       $78 = ($77|0)==(0);
       if ($78) {
        $c$0$lcssa$i = $76;$count$0$lcssa$i = $67;$res$0$lcssa$i = $75;
        break;
       } else {
        $c$05$i = $76;$count$07$i = $67;$res$06$i = $75;
       }
      }
     }
     $79 = $c$0$lcssa$i & 127;
     $80 = ($count$0$lcssa$i*5)|0;
     $81 = $79 << $80;
     $82 = $81 | $res$0$lcssa$i;
     $83 = ($count$0$lcssa$i|0)>(3);
     $84 = ($82>>>0)>(1114111);
     $or$cond$i = $83 | $84;
     if ($or$cond$i) {
      $91 = $61;$92 = $109;
      break;
     }
     $85 = (12288 + ($count$0$lcssa$i<<2)|0);
     $86 = HEAP32[$85>>2]|0;
     $87 = ($82>>>0)>($86>>>0);
     if (!($87)) {
      $91 = $61;$92 = $109;
      break;
     }
     $$sum4 = (($count$0$lcssa$i) + ($61))|0;
     $88 = $$sum4;
    }
    $$sum5 = (($88) + 1)|0;
    $89 = (($0) + ($$sum5)|0);
    $90 = ($89|0)==(0|0);
    if ($90) {
     $91 = $61;$92 = $109;
     break;
    }
    $95 = ($$sum5|0)<(0);
    $96 = $95 << 31 >> 31;
    $97 = (($n$014) + 1)|0;
    $98 = ($96|0)>($46|0);
    $99 = ($$sum5>>>0)>($45>>>0);
    $100 = ($96|0)==($46|0);
    $101 = $100 & $99;
    $102 = $98 | $101;
    if ($102) {
     $$lcssa49 = $97;
     label = 23;
     break;
    } else {
     $109 = $96;$61 = $$sum5;$n$014 = $97;
    }
   }
   if ((label|0) == 23) {
    $103 = ($$lcssa49|0)<(0);
    $104 = $103 << 31 >> 31;
    $105 = $$lcssa49;$106 = $104;
    break;
   }
   _lua_pushnil($L);
   $93 = (_i64Add(($91|0),($92|0),1,0)|0);
   $94 = tempRet0;
   _lua_pushinteger($L,$93,$94);
   $$0 = 2;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 _lua_pushinteger($L,$105,$106);
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _iter_codes($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_luaL_checklstring($L,1,0)|0);
 _lua_pushcclosure($L,349,0);
 _lua_pushvalue($L,1);
 _lua_pushinteger($L,0,0);
 return 3;
}
function _iter_aux($L) {
 $L = $L|0;
 var $$0 = 0, $$pre = 0, $$sum = 0, $$sum1 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0$lcssa$i = 0, $c$05$i = 0, $count$0$lcssa$i = 0, $count$07$i = 0, $len = 0;
 var $or$cond$i = 0, $res$0$lcssa$i = 0, $res$06$i = 0, $res$1$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $len = sp + 4|0;
 $0 = (_luaL_checklstring($L,1,$len)|0);
 $1 = (_lua_tointegerx($L,2,0)|0);
 $2 = tempRet0;
 $3 = ($2|0)<(0);
 $4 = ($1>>>0)<(1);
 $5 = ($2|0)==(0);
 $6 = $5 & $4;
 $7 = $3 | $6;
 if ($7) {
  $$pre = HEAP32[$len>>2]|0;
  $25 = 0;$27 = 0;$28 = $$pre;
 } else {
  $8 = (_i64Add(($1|0),($2|0),-1,-1)|0);
  $9 = tempRet0;
  $10 = HEAP32[$len>>2]|0;
  $11 = ($2|0)>(0);
  $12 = ($1>>>0)>($10>>>0);
  $13 = ($2|0)==(0);
  $14 = $13 & $12;
  $15 = $11 | $14;
  if ($15) {
   $25 = $9;$27 = $8;$28 = $10;
  } else {
   $17 = $1;$21 = $2;
   while(1) {
    $16 = (($0) + ($17)|0);
    $18 = HEAP8[$16>>0]|0;
    $19 = $18 & -64;
    $20 = ($19<<24>>24)==(-128);
    $22 = (_i64Add(($17|0),($21|0),1,0)|0);
    $23 = tempRet0;
    if ($20) {
     $17 = $22;$21 = $23;
    } else {
     $25 = $21;$27 = $17;$28 = $10;
     break;
    }
   }
  }
 }
 $24 = ($25|0)<(0);
 $26 = ($27>>>0)<($28>>>0);
 $29 = ($25|0)==(0);
 $30 = $29 & $26;
 $31 = $24 | $30;
 if (!($31)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $32 = (($0) + ($27)|0);
 $33 = HEAP8[$32>>0]|0;
 $34 = $33&255;
 $35 = ($33<<24>>24)>(-1);
 L10: do {
  if ($35) {
   $59 = $27;$res$1$i = $34;
   label = 13;
  } else {
   $36 = $34 & 64;
   $37 = ($36|0)==(0);
   if ($37) {
    $c$0$lcssa$i = $34;$count$0$lcssa$i = 0;$res$0$lcssa$i = 0;
   } else {
    $c$05$i = $34;$count$07$i = 0;$res$06$i = 0;
    while(1) {
     $38 = (($count$07$i) + 1)|0;
     $$sum = (($38) + ($27))|0;
     $39 = (($0) + ($$sum)|0);
     $40 = HEAP8[$39>>0]|0;
     $41 = $40&255;
     $42 = $41 & 192;
     $43 = ($42|0)==(128);
     if (!($43)) {
      break L10;
     }
     $44 = $res$06$i << 6;
     $45 = $41 & 63;
     $46 = $45 | $44;
     $47 = $c$05$i << 1;
     $48 = $47 & 64;
     $49 = ($48|0)==(0);
     if ($49) {
      $c$0$lcssa$i = $47;$count$0$lcssa$i = $38;$res$0$lcssa$i = $46;
      break;
     } else {
      $c$05$i = $47;$count$07$i = $38;$res$06$i = $46;
     }
    }
   }
   $50 = $c$0$lcssa$i & 127;
   $51 = ($count$0$lcssa$i*5)|0;
   $52 = $50 << $51;
   $53 = $52 | $res$0$lcssa$i;
   $54 = ($count$0$lcssa$i|0)>(3);
   $55 = ($53>>>0)>(1114111);
   $or$cond$i = $54 | $55;
   if (!($or$cond$i)) {
    $56 = (12288 + ($count$0$lcssa$i<<2)|0);
    $57 = HEAP32[$56>>2]|0;
    $58 = ($53>>>0)>($57>>>0);
    if ($58) {
     $$sum1 = (($count$0$lcssa$i) + ($27))|0;
     $59 = $$sum1;$res$1$i = $53;
     label = 13;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $$sum2 = (($59) + 1)|0;
  $60 = (($0) + ($$sum2)|0);
  $61 = ($60|0)==(0|0);
  if (!($61)) {
   $62 = HEAP8[$60>>0]|0;
   $63 = $62 & -64;
   $64 = ($63<<24>>24)==(-128);
   if (!($64)) {
    $66 = (_i64Add(($27|0),($25|0),1,0)|0);
    $67 = tempRet0;
    _lua_pushinteger($L,$66,$67);
    $68 = ($res$1$i|0)<(0);
    $69 = $68 << 31 >> 31;
    _lua_pushinteger($L,$res$1$i,$69);
    $$0 = 2;
    STACKTOP = sp;return ($$0|0);
   }
  }
 }
 $65 = (_luaL_error($L,12304,$vararg_buffer)|0);
 $$0 = $65;
 STACKTOP = sp;return ($$0|0);
}
function _luaopen_package($L) {
 $L = $L|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _lua_createtable($L,0,0);
 _lua_createtable($L,0,1);
 _lua_pushcclosure($L,350,0);
 _lua_setfield($L,-2,12528);
 (_lua_setmetatable($L,-2)|0);
 _lua_rawsetp($L,-1001000,12536);
 _luaL_checkversion_($L,503.0,136);
 _lua_createtable($L,0,7);
 _luaL_setfuncs($L,12544,0);
 _lua_createtable($L,4,0);
 _lua_pushvalue($L,-2);
 _lua_pushcclosure($L,351,1);
 _lua_rawseti($L,-2,1,0);
 _lua_pushvalue($L,-2);
 _lua_pushcclosure($L,352,1);
 _lua_rawseti($L,-2,2,0);
 _lua_pushvalue($L,-2);
 _lua_pushcclosure($L,353,1);
 _lua_rawseti($L,-2,3,0);
 _lua_pushvalue($L,-2);
 _lua_pushcclosure($L,354,1);
 _lua_rawseti($L,-2,4,0);
 _lua_setfield($L,-2,12608);
 _setpath($L,12624,12632,12648,12664);
 _setpath($L,12816,12824,12840,12856);
 (_lua_pushlstring($L,12928,10)|0);
 _lua_setfield($L,-2,12944);
 (_luaL_getsubtable($L,-1001000,12952)|0);
 _lua_setfield($L,-2,12960);
 (_luaL_getsubtable($L,-1001000,12968)|0);
 _lua_setfield($L,-2,12984);
 (_lua_rawgeti($L,-1001000,2,0)|0);
 _lua_pushvalue($L,-2);
 _luaL_setfuncs($L,12992,1);
 _lua_settop($L,-2);
 return 1;
}
function _gctm($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_len($L,1)|0);
 $1 = tempRet0;
 $2 = ($1|0)>(0);
 $3 = ($0>>>0)>(0);
 $4 = ($1|0)==(0);
 $5 = $4 & $3;
 $6 = $2 | $5;
 if ($6) {
  $7 = $0;$8 = $1;
 } else {
  return 0;
 }
 while(1) {
  (_lua_rawgeti($L,1,$7,$8)|0);
  _lua_settop($L,-2);
  $9 = (_i64Add(($7|0),($8|0),-1,-1)|0);
  $10 = tempRet0;
  $11 = ($8|0)>(0);
  $12 = ($7>>>0)>(1);
  $13 = ($8|0)==(0);
  $14 = $13 & $12;
  $15 = $11 | $14;
  if ($15) {
   $7 = $9;$8 = $10;
  } else {
   break;
  }
 }
 return 0;
}
function _searcher_preload($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $2 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 (_lua_getfield($L,-1001000,12968)|0);
 $1 = (_lua_getfield($L,-1,$0)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return 1;
 }
 HEAP32[$vararg_buffer>>2] = $0;
 (_lua_pushfstring($L,13352,$vararg_buffer)|0);
 STACKTOP = sp;return 1;
}
function _searcher_Lua($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 (_lua_getfield($L,-1001001,12624)|0);
 $1 = (_lua_tolstring($L,-1,0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 12624;
  (_luaL_error($L,13128,$vararg_buffer)|0);
 }
 $3 = (_searchpath($L,$0,$1,73176,29576)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_luaL_loadfilex($L,$3,0)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  (_lua_pushstring($L,$3)|0);
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = (_lua_tolstring($L,1,0)|0);
  $8 = (_lua_tolstring($L,-1,0)|0);
  HEAP32[$vararg_buffer1>>2] = $7;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $3;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $8;
  $9 = (_luaL_error($L,13160,$vararg_buffer1)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _searcher_C($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 (_lua_getfield($L,-1001001,12816)|0);
 $1 = (_lua_tolstring($L,-1,0)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  HEAP32[$vararg_buffer>>2] = 12816;
  (_luaL_error($L,13128,$vararg_buffer)|0);
 }
 $3 = (_searchpath($L,$0,$1,73176,29576)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_loadfunc($L,$3,$0)|0);
 $6 = ($5|0)==(0);
 if ($6) {
  (_lua_pushstring($L,$3)|0);
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $7 = (_lua_tolstring($L,1,0)|0);
  $8 = (_lua_tolstring($L,-1,0)|0);
  HEAP32[$vararg_buffer1>>2] = $7;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $3;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $8;
  $9 = (_luaL_error($L,13160,$vararg_buffer1)|0);
  $$0 = $9;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _searcher_Croot($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer6 = 0, $vararg_ptr4 = 0;
 var $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_strchr($0,46)|0);
 $2 = ($1|0)==(0|0);
 if ($2) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $3 = $1;
 $4 = $0;
 $5 = (($3) - ($4))|0;
 (_lua_pushlstring($L,$0,$5)|0);
 $6 = (_lua_tolstring($L,-1,0)|0);
 (_lua_getfield($L,-1001001,12816)|0);
 $7 = (_lua_tolstring($L,-1,0)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  HEAP32[$vararg_buffer>>2] = 12816;
  (_luaL_error($L,13128,$vararg_buffer)|0);
 }
 $9 = (_searchpath($L,$6,$7,73176,29576)|0);
 $10 = ($9|0)==(0|0);
 if ($10) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = (_loadfunc($L,$9,$0)|0);
 if ((($11|0) == 2)) {
  HEAP32[$vararg_buffer6>>2] = $0;
  $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
  HEAP32[$vararg_ptr9>>2] = $9;
  (_lua_pushfstring($L,13208,$vararg_buffer6)|0);
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 } else if ((($11|0) == 0)) {
  (_lua_pushstring($L,$9)|0);
  $$0 = 2;
  STACKTOP = sp;return ($$0|0);
 } else {
  $12 = (_lua_tolstring($L,1,0)|0);
  $13 = (_lua_tolstring($L,-1,0)|0);
  HEAP32[$vararg_buffer1>>2] = $12;
  $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
  HEAP32[$vararg_ptr4>>2] = $9;
  $vararg_ptr5 = ((($vararg_buffer1)) + 8|0);
  HEAP32[$vararg_ptr5>>2] = $13;
  $14 = (_luaL_error($L,13160,$vararg_buffer1)|0);
  $$0 = $14;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _setpath($L,$fieldname,$envname1,$envname2,$def) {
 $L = $L|0;
 $fieldname = $fieldname|0;
 $envname1 = $envname1|0;
 $envname2 = $envname2|0;
 $def = $def|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $path$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getenv(($envname1|0))|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_getenv(($envname2|0))|0);
  $3 = ($2|0)==(0|0);
  if (!($3)) {
   $path$01 = $2;
   label = 3;
  }
 } else {
  $path$01 = $0;
  label = 3;
 }
 if ((label|0) == 3) {
  (_lua_getfield($L,-1001000,13088)|0);
  $4 = (_lua_toboolean($L,-1)|0);
  _lua_settop($L,-2);
  $5 = ($4|0)==(0);
  if ($5) {
   $6 = (_luaL_gsub($L,$path$01,13104,13112)|0);
   (_luaL_gsub($L,$6,13120,$def)|0);
   _lua_rotate($L,-2,-1);
   _lua_settop($L,-2);
   _lua_setfield($L,-2,$fieldname);
   return;
  }
 }
 (_lua_pushstring($L,$def)|0);
 _lua_setfield($L,-2,$fieldname);
 return;
}
function _ll_require($L) {
 $L = $L|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0$i = 0;
 var $msg$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_ptr3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $msg$i = sp + 16|0;
 $0 = (_luaL_checklstring($L,1,0)|0);
 _lua_settop($L,1);
 (_lua_getfield($L,-1001000,12952)|0);
 (_lua_getfield($L,2,$0)|0);
 $1 = (_lua_toboolean($L,-1)|0);
 $2 = ($1|0)==(0);
 if (!($2)) {
  STACKTOP = sp;return 1;
 }
 _lua_settop($L,-2);
 _luaL_buffinit($L,$msg$i);
 $3 = (_lua_getfield($L,-1001001,12608)|0);
 $4 = ($3|0)==(5);
 if ($4) {
  $i$0$i = 1;
 } else {
  (_luaL_error($L,13016,$vararg_buffer)|0);
  $i$0$i = 1;
 }
 while(1) {
  $5 = ($i$0$i|0)<(0);
  $6 = $5 << 31 >> 31;
  $7 = (_lua_rawgeti($L,3,$i$0$i,$6)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   _lua_settop($L,-2);
   _luaL_pushresult($msg$i);
   $9 = (_lua_tolstring($L,-1,0)|0);
   HEAP32[$vararg_buffer1>>2] = $0;
   $vararg_ptr3 = ((($vararg_buffer1)) + 4|0);
   HEAP32[$vararg_ptr3>>2] = $9;
   (_luaL_error($L,13056,$vararg_buffer1)|0);
  }
  (_lua_pushstring($L,$0)|0);
  _lua_callk($L,1,2,0,0);
  $10 = (_lua_type($L,-2)|0);
  $11 = ($10|0)==(6);
  if ($11) {
   break;
  }
  $12 = (_lua_isstring($L,-2)|0);
  $13 = ($12|0)==(0);
  if ($13) {
   _lua_settop($L,-3);
  } else {
   _lua_settop($L,-2);
   _luaL_addvalue($msg$i);
  }
  $14 = (($i$0$i) + 1)|0;
  $i$0$i = $14;
 }
 (_lua_pushstring($L,$0)|0);
 _lua_rotate($L,-2,1);
 _lua_callk($L,2,1,0,0);
 $15 = (_lua_type($L,-1)|0);
 $16 = ($15|0)==(0);
 if (!($16)) {
  _lua_setfield($L,2,$0);
 }
 $17 = (_lua_getfield($L,2,$0)|0);
 $18 = ($17|0)==(0);
 if (!($18)) {
  STACKTOP = sp;return 1;
 }
 _lua_pushboolean($L,1);
 _lua_pushvalue($L,-1);
 _lua_setfield($L,2,$0);
 STACKTOP = sp;return 1;
}
function _searchpath($L,$name,$path,$sep,$dirsep) {
 $L = $L|0;
 $name = $name|0;
 $path = $path|0;
 $sep = $sep|0;
 $dirsep = $dirsep|0;
 var $$0 = 0, $$0$i = 0, $$01$ph = 0, $$lcssa = 0, $$lcssa12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $l$0$i = 0, $msg = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 4128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $msg = sp + 8|0;
 _luaL_buffinit($L,$msg);
 $0 = HEAP8[$sep>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$01$ph = $name;
 } else {
  $2 = (_luaL_gsub($L,$name,$sep,$dirsep)|0);
  $$01$ph = $2;
 }
 $$0$i = $path;
 while(1) {
  $3 = HEAP8[$$0$i>>0]|0;
  if ((($3<<24>>24) == 59)) {
   $4 = ((($$0$i)) + 1|0);
   $$0$i = $4;
   continue;
  } else if ((($3<<24>>24) == 0)) {
   label = 12;
   break;
  }
  $5 = (_strchr($$0$i,59)|0);
  $6 = ($5|0)==(0|0);
  if ($6) {
   $7 = (_strlen(($$0$i|0))|0);
   $8 = (($$0$i) + ($7)|0);
   $l$0$i = $8;
  } else {
   $l$0$i = $5;
  }
  $9 = $l$0$i;
  $10 = $$0$i;
  $11 = (($9) - ($10))|0;
  (_lua_pushlstring($L,$$0$i,$11)|0);
  $12 = ($l$0$i|0)==(0|0);
  if ($12) {
   label = 12;
   break;
  }
  $13 = (_lua_tolstring($L,-1,0)|0);
  $14 = (_luaL_gsub($L,$13,37376,$$01$ph)|0);
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
  $15 = (_fopen(($14|0),(13328|0))|0);
  $16 = ($15|0)==(0|0);
  if (!($16)) {
   $$lcssa = $14;$$lcssa12 = $15;
   label = 10;
   break;
  }
  HEAP32[$vararg_buffer>>2] = $14;
  (_lua_pushfstring($L,13336,$vararg_buffer)|0);
  _lua_rotate($L,-2,-1);
  _lua_settop($L,-2);
  _luaL_addvalue($msg);
  $$0$i = $l$0$i;
 }
 if ((label|0) == 10) {
  (_fclose(($$lcssa12|0))|0);
  $$0 = $$lcssa;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 12) {
  _luaL_pushresult($msg);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _loadfunc($L,$filename,$modname) {
 $L = $L|0;
 $filename = $filename|0;
 $modname = $modname|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_luaL_gsub($L,$modname,73176,13240)|0);
 $1 = (_strchr($0,45)|0);
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $$01 = $0;
  } else {
   $3 = $1;
   $4 = $0;
   $5 = (($3) - ($4))|0;
   $6 = (_lua_pushlstring($L,$0,$5)|0);
   HEAP32[$vararg_buffer>>2] = $6;
   $7 = (_lua_pushfstring($L,13248,$vararg_buffer)|0);
   $8 = (_lookforfunc($L,$filename,$7)|0);
   $9 = ($8|0)==(2);
   if ($9) {
    $10 = ((($1)) + 1|0);
    $$01 = $10;
    break;
   } else {
    $$0 = $8;
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP32[$vararg_buffer1>>2] = $$01;
 $11 = (_lua_pushfstring($L,13248,$vararg_buffer1)|0);
 $12 = (_lookforfunc($L,$filename,$11)|0);
 $$0 = $12;
 STACKTOP = sp;return ($$0|0);
}
function _lookforfunc($L,$path,$sym) {
 $L = $L|0;
 $path = $path|0;
 $sym = $sym|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_lua_rawgetp($L,-1001000,12536)|0);
 (_lua_getfield($L,-1,$path)|0);
 $0 = (_lua_touserdata($L,-1)|0);
 _lua_settop($L,-3);
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_lua_pushlstring($L,13264,58)|0);
  $$0 = 1;
  return ($$0|0);
 }
 $2 = HEAP8[$sym>>0]|0;
 $3 = ($2<<24>>24)==(42);
 if ($3) {
  _lua_pushboolean($L,1);
  $$0 = 0;
  return ($$0|0);
 } else {
  (_lua_pushlstring($L,13264,58)|0);
  $$0 = 2;
  return ($$0|0);
 }
 return (0)|0;
}
function _ll_loadlib($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_luaL_checklstring($L,2,0)|0);
 $2 = (_lookforfunc($L,$0,$1)|0);
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 1;
  return ($$0|0);
 }
 _lua_pushnil($L);
 _lua_rotate($L,-2,1);
 $4 = ($2|0)==(1);
 $5 = $4 ? 13416 : 13424;
 (_lua_pushstring($L,$5)|0);
 $$0 = 3;
 return ($$0|0);
}
function _ll_searchpath($L) {
 $L = $L|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_luaL_checklstring($L,1,0)|0);
 $1 = (_luaL_checklstring($L,2,0)|0);
 $2 = (_luaL_optlstring($L,3,73176,0)|0);
 $3 = (_luaL_optlstring($L,4,29576,0)|0);
 $4 = (_searchpath($L,$0,$1,$2,$3)|0);
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  $$0 = 1;
  return ($$0|0);
 }
 _lua_pushnil($L);
 _lua_rotate($L,-2,1);
 $$0 = 2;
 return ($$0|0);
}
function _readline($prompt) {
 $prompt = $prompt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $eof$0$lcssa$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13584>>2]|0;
 $1 = ($0|0)==(-1);
 if ($1) {
  (_rl_clear_pending_input()|0);
  $$0 = 0;
  return ($$0|0);
 }
 $2 = HEAP32[13528>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 $4 = ($prompt|0)==(0|0);
 if ($4) {
  $9 = 0;
 } else {
  $5 = (_strlen(($prompt|0))|0);
  $6 = (($5) + 1)|0;
  $7 = (_xmalloc($6)|0);
  $8 = (_strcpy(($7|0),($prompt|0))|0);
  $9 = $8;
 }
 HEAP32[13528>>2] = $9;
 $10 = ($9|0)!=(0|0);
 $11 = $10 ? $9 : 37352;
 HEAP32[32272>>2] = $11;
 $12 = (_rl_expand_prompt($9)|0);
 HEAP32[13536>>2] = $12;
 (_rl_initialize()|0);
 $13 = HEAP32[28592>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  $15 = HEAP32[13736>>2]|0;
  FUNCTION_TABLE_vi[$13 & 511]($15);
 }
 (_rl_set_signals()|0);
 _readline_internal_setup();
 $16 = HEAP32[13776>>2]|0;
 $17 = ($16|0)==(0);
 if ($17) {
  while(1) {
   $18 = (_readline_internal_char()|0);
   $19 = HEAP32[13776>>2]|0;
   $20 = ($19|0)==(0);
   if (!($20)) {
    $eof$0$lcssa$i$i = $18;
    break;
   }
  }
 } else {
  $eof$0$lcssa$i$i = 1;
 }
 $21 = (_readline_internal_teardown($eof$0$lcssa$i$i)|0);
 $22 = HEAP32[28600>>2]|0;
 $23 = ($22|0)==(0|0);
 if (!($23)) {
  FUNCTION_TABLE_v[$22 & 511]();
 }
 (_rl_clear_signals()|0);
 $$0 = $21;
 return ($$0|0);
}
function _rl_initialize() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14000>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[13488>>2]|0;
  $3 = $2 | 1;
  HEAP32[13488>>2] = $3;
  $4 = HEAP32[13504>>2]|0;
  $5 = ($4|0)==(0|0);
  $6 = $4;
  if ($5) {
   $7 = HEAP32[_stdin>>2]|0;
   HEAP32[13504>>2] = $7;
   $12 = $7;
  } else {
   $12 = $6;
  }
  $8 = HEAP32[13512>>2]|0;
  $9 = ($8|0)==(0|0);
  $10 = $8;
  if ($9) {
   $11 = HEAP32[_stdout>>2]|0;
   HEAP32[13512>>2] = $11;
   $13 = $11;
  } else {
   $13 = $10;
  }
  HEAP32[13744>>2] = $12;
  HEAP32[13752>>2] = $13;
  $14 = HEAP32[13632>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   HEAP32[13640>>2] = 256;
   $16 = (_xmalloc(256)|0);
   HEAP32[13632>>2] = $16;
  }
  $17 = HEAP32[13592>>2]|0;
  $18 = ($17|0)==(0|0);
  if ($18) {
   $19 = (_sh_get_env_value(38592)|0);
   HEAP32[13592>>2] = $19;
   $20 = $19;
  } else {
   $20 = $17;
  }
  (__rl_init_terminal_io($20)|0);
  $21 = HEAP32[13704>>2]|0;
  $22 = ($21|0)==(0);
  if (!($22)) {
   $23 = HEAP32[13432>>2]|0;
   _rl_tty_set_default_bindings($23);
  }
  _rl_initialize_funmap();
  (__rl_init_eightbit()|0);
  (_rl_read_init_file(0)|0);
  $24 = HEAP32[13600>>2]|0;
  $25 = ($24|0)!=(0);
  $26 = HEAP32[35096>>2]|0;
  $27 = ($26|0)!=(0);
  $or$cond$i = $25 & $27;
  if ($or$cond$i) {
   $28 = HEAP32[35112>>2]|0;
   $29 = (($28) + -1)|0;
   HEAP32[35112>>2] = $29;
   $30 = HEAP32[35120>>2]|0;
   $31 = HEAP32[35128>>2]|0;
   $32 = (($31) - ($30))|0;
   HEAP32[35128>>2] = $32;
  }
  _rl_set_keymap_from_edit_mode();
  _bind_arrow_keys_internal(22352);
  _bind_arrow_keys_internal(24408);
  $33 = HEAP8[(24624)>>0]|0;
  $34 = ($33<<24>>24)==(1);
  if ($34) {
   (_rl_bind_keyseq_in_map(14008,0,24408)|0);
  }
  _bind_arrow_keys_internal(26464);
  $35 = HEAP32[29112>>2]|0;
  $36 = ($35|0)==(0|0);
  if ($36) {
   $37 = HEAP32[7274]|0;
   HEAP32[29112>>2] = $37;
  }
  $38 = HEAP32[28976>>2]|0;
  $39 = ($38|0)==(0);
  if (!($39)) {
   __rl_parse_colors();
  }
  HEAP32[13664>>2] = 16;
  $40 = (_malloc(16)|0);
  HEAP32[13656>>2] = $40;
  $41 = ($40|0)==(0|0);
  if (!($41)) {
   HEAP8[$40>>0] = 0;
  }
  $42 = HEAP32[13488>>2]|0;
  $43 = $42 & -4;
  $44 = HEAP32[14000>>2]|0;
  $45 = (($44) + 1)|0;
  HEAP32[14000>>2] = $45;
  $46 = $43 | 2;
  HEAP32[13488>>2] = $46;
 }
 HEAP32[13952>>2] = 0;
 HEAP32[13768>>2] = 0;
 HEAP32[13784>>2] = 0;
 $47 = HEAP32[13632>>2]|0;
 HEAP32[14016>>2] = $47;
 HEAP8[$47>>0] = 0;
 HEAP32[13776>>2] = 0;
 $48 = HEAP32[13488>>2]|0;
 $49 = $48 & -16777217;
 HEAP32[13488>>2] = $49;
 __rl_start_using_history();
 (_rl_reset_line_state()|0);
 HEAP32[13496>>2] = 0;
 HEAP8[13680>>0] = 0;
 $50 = HEAP32[13440>>2]|0;
 $51 = ($50|0)==(0);
 if (!($51)) {
  __rl_set_insert_mode(1,1);
  return 0;
 }
 __rl_vi_initialize_line();
 __rl_set_insert_mode(1,1);
 return 0;
}
function _readline_internal_setup() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13504>>2]|0;
 HEAP32[13744>>2] = $0;
 $1 = HEAP32[13512>>2]|0;
 HEAP32[13752>>2] = $1;
 $2 = HEAP32[35104>>2]|0;
 $3 = HEAP32[13488>>2]|0;
 $4 = $2 & 4;
 $5 = $4 & $3;
 $6 = ($5|0)==(0);
 if (!($6)) {
  __rl_enable_meta_key();
 }
 $7 = HEAP32[13560>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  (FUNCTION_TABLE_i[$7 & 511]()|0);
 }
 $9 = HEAP32[13440>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  (_rl_vi_insertion_mode(1,105)|0);
 }
 $11 = HEAP32[13520>>2]|0;
 $12 = ($11|0)==(0);
 $13 = HEAP32[32248>>2]|0;
 $14 = ($13|0)==(296|0);
 $or$cond = $12 & $14;
 $15 = HEAP32[13528>>2]|0;
 $16 = ($15|0)!=(0|0);
 $17 = HEAP32[13544>>2]|0;
 if ($or$cond) {
  $18 = ($17|0)==(0);
  $or$cond3 = $16 & $18;
  if ($or$cond3) {
   $19 = (__rl_strip_prompt($15)|0);
   $20 = HEAP32[13752>>2]|0;
   (_fputs(($19|0),($20|0))|0);
   $21 = HEAP32[13752>>2]|0;
   (_fflush(($21|0))|0);
   _xfree($19);
  }
 } else {
  $22 = ($17|0)!=(0);
  $or$cond5 = $16 & $22;
  if ($or$cond5) {
   (_rl_on_new_line_with_prompt()|0);
  } else {
   (_rl_on_new_line()|0);
  }
  $23 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$23 & 511]();
 }
 $24 = HEAP32[13568>>2]|0;
 $25 = ($24|0)==(0|0);
 if (!($25)) {
  (FUNCTION_TABLE_i[$24 & 511]()|0);
 }
 $26 = HEAP32[32656>>2]|0;
 $27 = ($26|0)==(0);
 if ($27) {
  return;
 }
 $28 = HEAP32[32656>>2]|0;
 __rl_signal_handler($28);
 return;
}
function _readline_internal_teardown($eof) {
 $eof = $eof|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32656>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = HEAP32[32656>>2]|0;
  __rl_signal_handler($2);
 }
 $3 = (_current_history()|0);
 $4 = ($3|0)!=(0|0);
 $5 = HEAP32[34424>>2]|0;
 $6 = ($5|0)!=(0|0);
 $or$cond = $4 & $6;
 if ($or$cond) {
  $7 = HEAP32[14016>>2]|0;
  $8 = (_strlen(($7|0))|0);
  $9 = (($8) + 1)|0;
  $10 = (_xmalloc($9)|0);
  $11 = HEAP32[14016>>2]|0;
  $12 = (_strcpy(($10|0),($11|0))|0);
  (_rl_revert_line(1,0)|0);
  $13 = (_where_history()|0);
  $14 = HEAP32[14016>>2]|0;
  $15 = (_replace_history_entry($13,$14,0)|0);
  __rl_free_history_entry($15);
  $16 = HEAP32[14016>>2]|0;
  (_strcpy(($16|0),($12|0))|0);
  _xfree($12);
 }
 $17 = HEAP32[13712>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  __rl_revert_all_lines();
 }
 $19 = HEAP32[34424>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  _rl_free_undo_list();
 }
 __rl_disable_meta_key();
 __rl_set_insert_mode(1,0);
 $21 = ($eof|0)==(0);
 if (!($21)) {
  $28 = 0;
  return ($28|0);
 }
 $22 = HEAP32[14016>>2]|0;
 $23 = (_strlen(($22|0))|0);
 $24 = (($23) + 1)|0;
 $25 = (_xmalloc($24)|0);
 $26 = HEAP32[14016>>2]|0;
 $27 = (_strcpy(($25|0),($26|0))|0);
 $28 = $27;
 return ($28|0);
}
function __rl_internal_char_cleanup() {
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13440>>2]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[13432>>2]|0;
 $3 = ($2|0)==(24408|0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  (_rl_vi_check()|0);
 }
 $4 = HEAP32[13760>>2]|0;
 $5 = ($4|0)==(0);
 $6 = HEAP32[13768>>2]|0;
 $7 = ($6|0)<($4|0);
 $or$cond11 = $5 | $7;
 if (!($or$cond11)) {
  $8 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$8 & 511]();
  HEAP32[32264>>2] = 0;
  (_rl_newline(1,10)|0);
 }
 $9 = HEAP32[13776>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $11 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$11 & 511]();
  HEAP32[32264>>2] = 0;
  $$pre = HEAP32[13776>>2]|0;
  $15 = $$pre;
 } else {
  $15 = $9;
 }
 $12 = HEAP32[13624>>2]|0;
 $13 = ($12|0)!=(0);
 $14 = ($15|0)!=(0);
 $or$cond3 = $13 & $14;
 $16 = HEAP32[13496>>2]|0;
 $17 = ($16|0)==(150|0);
 $or$cond5 = $or$cond3 & $17;
 $18 = HEAP32[13784>>2]|0;
 $19 = HEAP32[13768>>2]|0;
 $20 = $19 | $18;
 $21 = ($20|0)==(0);
 $22 = $or$cond5 & $21;
 if (!($22)) {
  return;
 }
 __rl_erase_entire_line();
 return;
}
function _readline_internal_char() {
 var $$ = 0, $$0$reg2mem$0 = 0, $$old2 = 0, $$reg2mem39$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $cond = 0, $cond1 = 0, $cond2 = 0;
 var $cond3 = 0, $cond4 = 0, $cond5 = 0, $cond6 = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond10 = 0, $or$cond3$not = 0, $or$cond6 = 0, $or$cond8 = 0, _setjmpTable = 0, _setjmpTableSize = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _setjmpTableSize = 4;_setjmpTable = _malloc(40) | 0;HEAP32[_setjmpTable>>2]=0;
 HEAP32[14024>>2] = -1;
 $0 = HEAP32[13456>>2]|0;
 _setjmpTable = _saveSetjmp(13792,1,_setjmpTable|0,_setjmpTableSize|0)|0;_setjmpTableSize = tempRet0;
 __THREW__ = 0;
 $1 = __THREW__; __THREW__ = 0;
 if ((($1|0) != 0) & ((threwValue|0) != 0)) { $2 = _testSetjmp(HEAP32[$1>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($2|0) == 0) { _longjmp($1|0, threwValue|0); } tempRet0 = (threwValue); } else { $2 = -1; };
 $3 = tempRet0;
 $cond = ($2|0)==(1);
 if ($cond) {
  $$reg2mem39$0 = $3;
 } else {
  $$reg2mem39$0 = 0;
 }
 while(1) {
  $4 = ($$reg2mem39$0|0)==(0);
  if (!($4)) {
   $5 = HEAP32[32248>>2]|0;
   __THREW__ = 0;
   invoke_v($5|0);
   $6 = __THREW__; __THREW__ = 0;
   if ((($6|0) != 0) & ((threwValue|0) != 0)) { $7 = _testSetjmp(HEAP32[$6>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($7|0) == 0) { _longjmp($6|0, threwValue|0); } tempRet0 = (threwValue); } else { $7 = -1; };
   $8 = tempRet0;
   $cond1 = ($7|0)==(1);
   if ($cond1) {
    $$reg2mem39$0 = $8;
    continue;
   }
   HEAP32[32264>>2] = 0;
   $9 = HEAP32[13488>>2]|0;
   $10 = $9 & 524288;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $$0$reg2mem$0 = 0;
    label = 24;
    break;
   }
  }
  $12 = HEAP32[13584>>2]|0;
  $13 = ($12|0)==(0);
  if ($13) {
   __THREW__ = 0;
   invoke_v(355);
   $14 = __THREW__; __THREW__ = 0;
   if ((($14|0) != 0) & ((threwValue|0) != 0)) { $15 = _testSetjmp(HEAP32[$14>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($15|0) == 0) { _longjmp($14|0, threwValue|0); } tempRet0 = (threwValue); } else { $15 = -1; };
   $16 = tempRet0;
   $cond6 = ($15|0)==(1);
   if ($cond6) {
    $$reg2mem39$0 = $16;
    continue;
   }
   HEAP32[13552>>2] = 0;
   $17 = HEAP32[13656>>2]|0;
   HEAP8[$17>>0] = 0;
  }
  $18 = HEAP32[13488>>2]|0;
  $19 = $18 | 8;
  HEAP32[13488>>2] = $19;
  __THREW__ = 0;
  $20 = (invoke_i(356)|0);
  $21 = __THREW__; __THREW__ = 0;
  if ((($21|0) != 0) & ((threwValue|0) != 0)) { $22 = _testSetjmp(HEAP32[$21>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($22|0) == 0) { _longjmp($21|0, threwValue|0); } tempRet0 = (threwValue); } else { $22 = -1; };
  $23 = tempRet0;
  $cond2 = ($22|0)==(1);
  if ($cond2) {
   $$reg2mem39$0 = $23;
   continue;
  }
  $24 = HEAP32[13488>>2]|0;
  $25 = $24 & -9;
  HEAP32[13488>>2] = $25;
  $26 = ($20|0)==(-2);
  if ($26) {
   label = 11;
   break;
  }
  $28 = ($20|0)==(-1);
  $29 = HEAP32[13768>>2]|0;
  $30 = ($29|0)!=(0);
  $or$cond = $28 & $30;
  $$ = $or$cond ? 10 : $20;
  $31 = HEAP32[13576>>2]|0;
  $32 = ($$|0)==($31|0);
  if ($32) {
   $33 = HEAP32[14024>>2]|0;
   $notlhs = ($33|0)==($$|0);
   $notrhs = ($$|0)!=(-1);
   $or$cond3$not = $notrhs & $notlhs;
   $or$cond8 = $30 | $or$cond3$not;
   if (!($or$cond8)) {
    label = 15;
    break;
   }
  } else {
   $$old2 = ($$|0)!=(-1);
   $or$cond6 = $30 | $$old2;
   if (!($or$cond6)) {
    label = 15;
    break;
   }
  }
  HEAP32[14024>>2] = $$;
  $35 = $$ & 255;
  $36 = HEAP32[13432>>2]|0;
  HEAP32[13960>>2] = $36;
  __THREW__ = 0;
  (invoke_iiii(357,($35|0),($36|0),0)|0);
  $37 = __THREW__; __THREW__ = 0;
  if ((($37|0) != 0) & ((threwValue|0) != 0)) { $38 = _testSetjmp(HEAP32[$37>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($38|0) == 0) { _longjmp($37|0, threwValue|0); } tempRet0 = (threwValue); } else { $38 = -1; };
  $39 = tempRet0;
  $cond3 = ($38|0)==(1);
  if ($cond3) {
   $$reg2mem39$0 = $39;
   continue;
  }
  $40 = HEAP32[32656>>2]|0;
  $41 = ($40|0)==(0);
  if (!($41)) {
   $42 = HEAP32[32656>>2]|0;
   __THREW__ = 0;
   invoke_vi(358,($42|0));
   $43 = __THREW__; __THREW__ = 0;
   if ((($43|0) != 0) & ((threwValue|0) != 0)) { $44 = _testSetjmp(HEAP32[$43>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($44|0) == 0) { _longjmp($43|0, threwValue|0); } tempRet0 = (threwValue); } else { $44 = -1; };
   $45 = tempRet0;
   $cond4 = ($44|0)==(1);
   if ($cond4) {
    $$reg2mem39$0 = $45;
    continue;
   }
  }
  $46 = HEAP32[13584>>2]|0;
  $47 = ($46|0)==(0);
  $48 = HEAP32[13456>>2]|0;
  $49 = ($0|0)==($48|0);
  $or$cond10 = $47 & $49;
  if ($or$cond10) {
   HEAP32[13456>>2] = 0;
  }
  __THREW__ = 0;
  invoke_v(359);
  $50 = __THREW__; __THREW__ = 0;
  if ((($50|0) != 0) & ((threwValue|0) != 0)) { $51 = _testSetjmp(HEAP32[$50>>2]|0, _setjmpTable|0, _setjmpTableSize|0)|0; if (($51|0) == 0) { _longjmp($50|0, threwValue|0); } tempRet0 = (threwValue); } else { $51 = -1; };
  $52 = tempRet0;
  $cond5 = ($51|0)==(1);
  if ($cond5) {
   $$reg2mem39$0 = $52;
  } else {
   label = 23;
   break;
  }
 }
 if ((label|0) == 11) {
  $27 = $25 | 16777216;
  HEAP32[13488>>2] = $27;
  HEAP32[13776>>2] = 1;
  $$0$reg2mem$0 = 1;
  _free(_setjmpTable|0);
  return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 15) {
  $34 = $25 | 16777216;
  HEAP32[13488>>2] = $34;
  HEAP32[13776>>2] = 1;
  $$0$reg2mem$0 = 1;
  _free(_setjmpTable|0);
  return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 23) {
  $$0$reg2mem$0 = 0;
  _free(_setjmpTable|0);
  return ($$0$reg2mem$0|0);
 }
 else if ((label|0) == 24) {
  _free(_setjmpTable|0);
  return ($$0$reg2mem$0|0);
 }
 return (0)|0;
}
function __rl_dispatch($key,$map) {
 $key = $key|0;
 $map = $map|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13960>>2] = $map;
 $0 = (__rl_dispatch_subseq($key,$map,0)|0);
 return ($0|0);
}
function __rl_set_the_line() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13632>>2]|0;
 HEAP32[14016>>2] = $0;
 return;
}
function __rl_dispatch_subseq($key,$map,$got_subseq) {
 $key = $key|0;
 $map = $map|0;
 $got_subseq = $got_subseq|0;
 var $$$i = 0, $$$v$i = 0, $$0 = 0, $$lcssa157 = 0, $$lcssa159 = 0, $$lcssa168 = 0, $$lcssa65 = 0, $$pre = 0, $$pre66 = 0, $$pre67 = 0, $$pre69 = 0, $$pre70 = 0, $$pre72 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0;
 var $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0;
 var $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0;
 var $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0;
 var $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0;
 var $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0;
 var $195 = 0, $196 = 0, $197 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $got_subseq$tr$ph = 0, $got_subseq$tr39 = 0, $got_subseq$tr39$lcssa145 = 0, $got_subseq$tr39$lcssa145$lcssa150 = 0, $got_subseq$tr39$lcssa147 = 0, $key$tr$lcssa = 0, $key$tr$ph = 0, $key$tr$ph$be = 0, $key$tr38 = 0;
 var $key$tr38$lcssa151 = 0, $key$tr38$lcssa152 = 0, $key$tr38$lcssa153 = 0, $key$tr38$lcssa154 = 0, $key$tr38$lcssa46$lcssa52 = 0, $key$tr38156 = 0, $map$tr$ph = 0, $map$tr$ph$lcssa161 = 0, $map$tr$ph$lcssa164 = 0, $map$tr$ph$lcssa165 = 0, $map$tr$ph$lcssa59 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond3 = 0, $or$cond337 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $r$0 = 0;
 var $storemerge = 0, $storemerge$in$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $got_subseq$tr$ph = $got_subseq;$key$tr$ph = $key;$map$tr$ph = $map;
 L1: while(1) {
  $0 = $key$tr$ph & -128;
  $1 = ($0|0)==(128);
  $2 = HEAP32[13688>>2]|0;
  $3 = ($2|0)!=(0);
  $or$cond337 = $1 & $3;
  L3: do {
   if ($or$cond337) {
    $key$tr$lcssa = $key$tr$ph;
    label = 3;
   } else {
    $got_subseq$tr39 = $got_subseq$tr$ph;$key$tr38 = $key$tr$ph;
    while(1) {
     $23 = HEAP32[13488>>2]|0;
     $24 = $23 & 4096;
     $25 = ($24|0)==(0);
     if (!($25)) {
      __rl_add_macro_char($key$tr38);
     }
     $26 = (($map$tr$ph) + ($key$tr38<<3)|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = $27 << 24 >> 24;
     if ((($28|0) == 1)) {
      $got_subseq$tr39$lcssa145 = $got_subseq$tr39;$key$tr38$lcssa151 = $key$tr38;
      break;
     } else if ((($28|0) == 2)) {
      $key$tr38$lcssa152 = $key$tr38;$map$tr$ph$lcssa161 = $map$tr$ph;
      label = 64;
      break L1;
     } else if (!((($28|0) == 0))) {
      $key$tr38156 = $key$tr38;$r$0 = 0;
      break L1;
     }
     $29 = (((($map$tr$ph) + ($key$tr38<<3)|0)) + 4|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==(0|0);
     if ($31) {
      $got_subseq$tr39$lcssa147 = $got_subseq$tr39;$key$tr38$lcssa153 = $key$tr38;$map$tr$ph$lcssa164 = $map$tr$ph;
      label = 29;
      break L1;
     }
     $32 = ($30|0)==(173|0);
     if (!($32)) {
      $$lcssa157 = $29;$$lcssa159 = $30;$key$tr38$lcssa154 = $key$tr38;$map$tr$ph$lcssa165 = $map$tr$ph;
      label = 21;
      break L1;
     }
     $33 = $key$tr38 & 255;
     $34 = ($33|0)==($key$tr38|0);
     if ($34) {
      $35 = (_isupper($key$tr38)|0);
      $36 = ($35|0)==(0);
      if ($36) {
       $39 = $key$tr38;
      } else {
       $37 = (_tolower($key$tr38)|0);
       $39 = $37;
      }
     } else {
      $39 = $key$tr38;
     }
     HEAP32[13960>>2] = $map$tr$ph;
     $38 = $39 & -128;
     $40 = ($38|0)==(128);
     $41 = HEAP32[13688>>2]|0;
     $42 = ($41|0)!=(0);
     $or$cond3 = $40 & $42;
     if ($or$cond3) {
      $key$tr$lcssa = $39;
      label = 3;
      break L3;
     } else {
      $got_subseq$tr39 = 0;$key$tr38 = $39;
     }
    }
    $91 = (((($map$tr$ph) + ($key$tr38$lcssa151<<3)|0)) + 4|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==(0|0);
    if ($93) {
     label = 63;
     break L1;
    }
    $94 = HEAP32[13440>>2]|0;
    $95 = ($94|0)==(0);
    $96 = ($key$tr38$lcssa151|0)==(27);
    $or$cond5 = $96 & $95;
    $97 = ($map$tr$ph|0)==(26464|0);
    $or$cond7 = $97 & $or$cond5;
    if (!($or$cond7)) {
     $$lcssa168 = $91;$$lcssa65 = $96;$got_subseq$tr39$lcssa145$lcssa150 = $got_subseq$tr39$lcssa145;$key$tr38$lcssa46$lcssa52 = $key$tr38$lcssa151;$map$tr$ph$lcssa59 = $map$tr$ph;
     label = 43;
     break L1;
    }
    $98 = HEAP32[13672>>2]|0;
    $99 = ($98|0)>(0);
    $100 = ($98*1000)|0;
    $101 = $99 ? $100 : 0;
    $102 = (__rl_input_queued($101)|0);
    $103 = ($102|0)==(0);
    if ($103) {
     $key$tr$ph$be = 256;$storemerge$in$in = $91;
    } else {
     $$lcssa168 = $91;$$lcssa65 = 1;$got_subseq$tr39$lcssa145$lcssa150 = $got_subseq$tr39$lcssa145;$key$tr38$lcssa46$lcssa52 = 27;$map$tr$ph$lcssa59 = 26464;
     label = 43;
     break L1;
    }
   }
  } while(0);
  if ((label|0) == 3) {
   label = 0;
   $4 = ((($map$tr$ph)) + 216|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(1);
   if (!($6)) {
    label = 11;
    break;
   }
   $7 = HEAP32[13488>>2]|0;
   $8 = $7 & 4096;
   $9 = ($8|0)==(0);
   if (!($9)) {
    __rl_add_macro_char(27);
   }
   $10 = HEAP32[13552>>2]|0;
   $11 = (($10) + 2)|0;
   $12 = HEAP32[13664>>2]|0;
   $13 = ($11|0)<($12|0);
   if ($13) {
    $$pre72 = HEAP32[13656>>2]|0;
    $18 = $10;$20 = $$pre72;
   } else {
    $14 = (($12) + 16)|0;
    HEAP32[13664>>2] = $14;
    $15 = HEAP32[13656>>2]|0;
    $16 = (_xrealloc($15,$14)|0);
    HEAP32[13656>>2] = $16;
    $$pre70 = HEAP32[13552>>2]|0;
    $18 = $$pre70;$20 = $16;
   }
   $17 = (($18) + 1)|0;
   HEAP32[13552>>2] = $17;
   $19 = (($20) + ($18)|0);
   HEAP8[$19>>0] = 27;
   $21 = ((($map$tr$ph)) + 220|0);
   $22 = $key$tr$lcssa & -129;
   $key$tr$ph$be = $22;$storemerge$in$in = $21;
  }
  $storemerge = HEAP32[$storemerge$in$in>>2]|0;
  HEAP32[13960>>2] = $storemerge;
  $got_subseq$tr$ph = 0;$key$tr$ph = $key$tr$ph$be;$map$tr$ph = $storemerge;
 }
 if ((label|0) == 11) {
  (_rl_ding()|0);
  $$0 = 0;
  return ($$0|0);
 }
 else if ((label|0) == 21) {
  HEAP32[13968>>2] = $map$tr$ph$lcssa165;
  HEAP32[13976>>2] = $key$tr38$lcssa154;
  $43 = HEAP32[13552>>2]|0;
  $44 = (($43) + 2)|0;
  $45 = HEAP32[13664>>2]|0;
  $46 = ($44|0)<($45|0);
  if ($46) {
   $$pre69 = HEAP32[13656>>2]|0;
   $52 = $43;$54 = $$pre69;
  } else {
   $47 = (($45) + 16)|0;
   HEAP32[13664>>2] = $47;
   $48 = HEAP32[13656>>2]|0;
   $49 = (_xrealloc($48,$47)|0);
   HEAP32[13656>>2] = $49;
   $$pre67 = HEAP32[13552>>2]|0;
   $52 = $$pre67;$54 = $49;
  }
  $50 = $key$tr38$lcssa154&255;
  $51 = (($52) + 1)|0;
  HEAP32[13552>>2] = $51;
  $53 = (($54) + ($52)|0);
  HEAP8[$53>>0] = $50;
  $55 = HEAP32[13552>>2]|0;
  $56 = HEAP32[13656>>2]|0;
  $57 = (($56) + ($55)|0);
  HEAP8[$57>>0] = 0;
  HEAP32[13984>>2] = 1;
  $58 = HEAP32[13488>>2]|0;
  $59 = $58 | 32;
  HEAP32[13488>>2] = $59;
  $60 = HEAP32[13464>>2]|0;
  $61 = HEAP32[13480>>2]|0;
  $62 = Math_imul($61, $60)|0;
  $63 = (FUNCTION_TABLE_iii[$$lcssa159 & 511]($62,$key$tr38$lcssa154)|0);
  $64 = HEAP32[13488>>2]|0;
  $65 = $64 & -33;
  HEAP32[13488>>2] = $65;
  HEAP32[13984>>2] = 0;
  $66 = HEAP32[13584>>2]|0;
  $67 = ($66|0)==(0);
  if ($67) {
   $68 = HEAP32[$$lcssa157>>2]|0;
   $69 = ($68|0)==(172|0);
   if (!($69)) {
    HEAP32[13496>>2] = $68;
   }
  }
  $70 = HEAP32[32656>>2]|0;
  $71 = ($70|0)==(0);
  if ($71) {
   $key$tr38156 = $key$tr38$lcssa154;$r$0 = $63;
  } else {
   $72 = HEAP32[32656>>2]|0;
   __rl_signal_handler($72);
   $key$tr38156 = $key$tr38$lcssa154;$r$0 = $63;
  }
 }
 else if ((label|0) == 29) {
  $73 = ((($map$tr$ph$lcssa164)) + 2052|0);
  $74 = HEAP32[$73>>2]|0;
  $75 = ($74|0)==(0|0);
  if (!($75)) {
   $76 = HEAP32[13488>>2]|0;
   $77 = $76 & 2048;
   $78 = ($77|0)==(0);
   if ($78) {
    (__rl_unget_char($key$tr38$lcssa153)|0);
    $$0 = -2;
    return ($$0|0);
   } else {
    (__rl_prev_macro_key()|0);
    $$0 = -2;
    return ($$0|0);
   }
  }
  $79 = ($got_subseq$tr39$lcssa147|0)==(0);
  $80 = HEAP32[13488>>2]|0;
  if ($79) {
   $83 = $80 & -2097153;
   HEAP32[13488>>2] = $83;
   $84 = HEAP32[13648>>2]|0;
   $85 = ($84|0)==(0|0);
   if ($85) {
    (__rl_abort_internal()|0);
    // unreachable;
   } else {
    $87 = $84;
   }
   while(1) {
    $86 = ((($87)) + 24|0);
    $88 = HEAP32[$86>>2]|0;
    HEAP32[13648>>2] = $88;
    _xfree($87);
    $89 = HEAP32[13648>>2]|0;
    $90 = ($89|0)==(0|0);
    if ($90) {
     break;
    } else {
     $87 = $89;
    }
   }
   (__rl_abort_internal()|0);
   // unreachable;
  }
  $81 = $80 & 2048;
  $82 = ($81|0)==(0);
  if ($82) {
   (__rl_unget_char($key$tr38$lcssa153)|0);
   $$0 = -1;
   return ($$0|0);
  } else {
   (__rl_prev_macro_key()|0);
   $$0 = -1;
   return ($$0|0);
  }
 }
 else if ((label|0) == 43) {
  $104 = HEAP32[13552>>2]|0;
  $105 = (($104) + 2)|0;
  $106 = HEAP32[13664>>2]|0;
  $107 = ($105|0)<($106|0);
  if ($107) {
   $$pre66 = HEAP32[13656>>2]|0;
   $113 = $104;$115 = $$pre66;
  } else {
   $108 = (($106) + 16)|0;
   HEAP32[13664>>2] = $108;
   $109 = HEAP32[13656>>2]|0;
   $110 = (_xrealloc($109,$108)|0);
   HEAP32[13656>>2] = $110;
   $$pre = HEAP32[13552>>2]|0;
   $113 = $$pre;$115 = $110;
  }
  $111 = $key$tr38$lcssa46$lcssa52&255;
  $112 = (($113) + 1)|0;
  HEAP32[13552>>2] = $112;
  $114 = (($115) + ($113)|0);
  HEAP8[$114>>0] = $111;
  $116 = HEAP32[$$lcssa168>>2]|0;
  HEAP32[13960>>2] = $116;
  $117 = HEAP32[13488>>2]|0;
  $118 = $117 & 524288;
  $119 = ($118|0)==(0);
  if (!($119)) {
   $120 = $117 & 2097152;
   $121 = ($120|0)!=(0);
   $122 = $121 ? -3 : 0;
   $123 = (_xmalloc(32)|0);
   $124 = ((($123)) + 8|0);
   HEAP32[$124>>2] = 0;
   $125 = ((($123)) + 4|0);
   HEAP32[$125>>2] = 0;
   HEAP32[$123>>2] = 0;
   $126 = ((($123)) + 20|0);
   HEAP32[$126>>2] = 0;
   $127 = HEAP32[13648>>2]|0;
   $128 = ((($123)) + 24|0);
   HEAP32[$128>>2] = $127;
   $129 = ((($123)) + 28|0);
   HEAP32[$129>>2] = 42;
   $130 = ($got_subseq$tr39$lcssa145$lcssa150|0)==(0);
   if ($130) {
    HEAP32[$126>>2] = $key$tr38$lcssa46$lcssa52;
    $134 = ((($123)) + 16|0);
    HEAP32[$134>>2] = $map$tr$ph$lcssa59;
    $135 = HEAP32[13960>>2]|0;
    $136 = ((($123)) + 12|0);
    HEAP32[$136>>2] = $135;
    $137 = ((($135)) + 2052|0);
    $138 = HEAP32[$137>>2]|0;
    $139 = ($138|0)!=(0|0);
    $141 = $139;
   } else {
    HEAP32[$123>>2] = 2;
    HEAP32[$126>>2] = $key$tr38$lcssa46$lcssa52;
    $131 = ((($123)) + 16|0);
    HEAP32[$131>>2] = $map$tr$ph$lcssa59;
    $132 = HEAP32[13960>>2]|0;
    $133 = ((($123)) + 12|0);
    HEAP32[$133>>2] = $132;
    $141 = 1;
   }
   $140 = $141&1;
   HEAP32[$125>>2] = $140;
   $142 = HEAP32[13488>>2]|0;
   $143 = $142 | 2097152;
   HEAP32[13488>>2] = $143;
   HEAP32[13648>>2] = $123;
   $$0 = $122;
   return ($$0|0);
  }
  $144 = HEAP32[13672>>2]|0;
  $145 = ($144|0)>(0);
  $146 = $117 & 133120;
  $147 = ($146|0)==(0);
  $or$cond = $147 & $145;
  if ($or$cond) {
   $148 = (__rl_pushed_input_available()|0);
   $149 = ($148|0)==(0);
   if ($149) {
    $150 = HEAP32[13960>>2]|0;
    $151 = ((($150)) + 2052|0);
    $152 = HEAP32[$151>>2]|0;
    $153 = ($152|0)==(0|0);
    if (!($153)) {
     $154 = HEAP32[13672>>2]|0;
     $155 = ($154*1000)|0;
     $156 = (__rl_input_queued($155)|0);
     $157 = ($156|0)==(0);
     if ($157) {
      $158 = (__rl_subseq_result(-2,$map$tr$ph$lcssa59,$key$tr38$lcssa46$lcssa52,$got_subseq$tr39$lcssa145$lcssa150)|0);
      $$0 = $158;
      return ($$0|0);
     }
    }
   }
  }
  $159 = HEAP32[13488>>2]|0;
  if ($$lcssa65) {
   $160 = $159 | 16;
   HEAP32[13488>>2] = $160;
   $162 = $160;
  } else {
   $162 = $159;
  }
  $161 = $162 | 64;
  HEAP32[13488>>2] = $161;
  $163 = (_rl_read_key()|0);
  $164 = HEAP32[13488>>2]|0;
  $$$v$i = $$lcssa65 ? -81 : -65;
  $$$i = $164 & $$$v$i;
  HEAP32[13488>>2] = $$$i;
  $165 = ($163|0)<(0);
  if ($165) {
   (__rl_abort_internal()|0);
   // unreachable;
  }
  $166 = HEAP32[13960>>2]|0;
  $167 = ($got_subseq$tr39$lcssa145$lcssa150|0)==(0);
  if (!($167)) {
   $172 = 1;
   $171 = $172&1;
   $173 = (__rl_dispatch_subseq($163,$166,$171)|0);
   $174 = (__rl_subseq_result($173,$map$tr$ph$lcssa59,$key$tr38$lcssa46$lcssa52,$got_subseq$tr39$lcssa145$lcssa150)|0);
   return ($174|0);
  }
  $168 = ((($map$tr$ph$lcssa59)) + 2052|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = ($169|0)!=(0|0);
  $172 = $170;
  $171 = $172&1;
  $173 = (__rl_dispatch_subseq($163,$166,$171)|0);
  $174 = (__rl_subseq_result($173,$map$tr$ph$lcssa59,$key$tr38$lcssa46$lcssa52,$got_subseq$tr39$lcssa145$lcssa150)|0);
  return ($174|0);
 }
 else if ((label|0) == 63) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 else if ((label|0) == 64) {
  $175 = (((($map$tr$ph$lcssa161) + ($key$tr38$lcssa152<<3)|0)) + 4|0);
  $176 = HEAP32[$175>>2]|0;
  $177 = ($176|0)==(0|0);
  if ($177) {
   $key$tr38156 = $key$tr38$lcssa152;$r$0 = 0;
  } else {
   $178 = HEAP32[13552>>2]|0;
   $179 = HEAP32[13656>>2]|0;
   $180 = (($179) + ($178)|0);
   HEAP8[$180>>0] = 0;
   $181 = HEAP32[$175>>2]|0;
   $182 = (_strlen(($181|0))|0);
   $183 = (($182) + 1)|0;
   $184 = (_xmalloc($183)|0);
   $185 = HEAP32[$175>>2]|0;
   $186 = (_strcpy(($184|0),($185|0))|0);
   __rl_with_macro_input($186);
   $$0 = 0;
   return ($$0|0);
  }
 }
 $187 = HEAP32[13440>>2]|0;
 $188 = ($187|0)==(0);
 $189 = HEAP32[13432>>2]|0;
 $190 = ($189|0)==(24408|0);
 $or$cond9 = $188 & $190;
 $191 = ($key$tr38156|0)!=(256);
 $or$cond11 = $191 & $or$cond9;
 $192 = HEAP32[13552>>2]|0;
 $193 = ($192|0)==(1);
 $or$cond13 = $193 & $or$cond11;
 if (!($or$cond13)) {
  $$0 = $r$0;
  return ($$0|0);
 }
 $194 = (__rl_vi_textmod_command($key$tr38156)|0);
 $195 = ($194|0)==(0);
 if ($195) {
  $$0 = $r$0;
  return ($$0|0);
 }
 $196 = HEAP32[13464>>2]|0;
 $197 = HEAP32[13480>>2]|0;
 __rl_vi_set_last($key$tr38156,$196,$197);
 $$0 = $r$0;
 return ($$0|0);
}
function _bind_arrow_keys_internal($map) {
 $map = $map|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[3358]|0;
 HEAP32[13432>>2] = $map;
 (_rl_bind_keyseq_if_unbound(14032,208)|0);
 (_rl_bind_keyseq_if_unbound(14040,200)|0);
 (_rl_bind_keyseq_if_unbound(14048,185)|0);
 (_rl_bind_keyseq_if_unbound(14056,153)|0);
 (_rl_bind_keyseq_if_unbound(14064,159)|0);
 (_rl_bind_keyseq_if_unbound(14072,181)|0);
 (_rl_bind_keyseq_if_unbound(14080,208)|0);
 (_rl_bind_keyseq_if_unbound(14088,200)|0);
 (_rl_bind_keyseq_if_unbound(14096,185)|0);
 (_rl_bind_keyseq_if_unbound(14104,153)|0);
 (_rl_bind_keyseq_if_unbound(14112,159)|0);
 (_rl_bind_keyseq_if_unbound(14120,181)|0);
 HEAP32[3358] = $0;
 return;
}
function __rl_subseq_result($r,$map,$key,$got_subseq) {
 $r = $r|0;
 $map = $map|0;
 $key = $key|0;
 $got_subseq = $got_subseq|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($r|0) == -2)) {
  $0 = HEAP32[13960>>2]|0;
  $1 = ((($0)) + 2048|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = ((($0)) + 2052|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($2<<24>>24)==(0);
  $6 = ($4|0)==(173|0);
  $or$cond = $5 & $6;
  if ($or$cond) {
   $7 = $key & 255;
   $8 = ($7|0)==($key|0);
   if ($8) {
    $9 = (_isupper($key)|0);
    $10 = ($9|0)==(0);
    if ($10) {
     $12 = $key;
    } else {
     $11 = (_tolower($key)|0);
     $12 = $11;
    }
   } else {
    $12 = $key;
   }
   HEAP32[13960>>2] = $map;
   $13 = (__rl_dispatch_subseq($12,$map,0)|0);
   $$0 = $13;
   return ($$0|0);
  } else {
   $14 = ($4|0)==(215|0);
   $or$cond3 = $5 & $14;
   if ($or$cond3) {
    $15 = (($0) + ($key<<3)|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = (((($0) + ($key<<3)|0)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    HEAP8[$15>>0] = 0;
    HEAP32[$17>>2] = 215;
    HEAP32[13960>>2] = $0;
    $19 = (__rl_dispatch_subseq($key,$0,0)|0);
    HEAP8[$15>>0] = $16;
    HEAP32[$17>>2] = $18;
    $$0 = $19;
    return ($$0|0);
   } else {
    HEAP32[13960>>2] = $0;
    $20 = (__rl_dispatch_subseq(256,$0,0)|0);
    $$0 = $20;
    return ($$0|0);
   }
  }
 } else if ((($r|0) == 0)) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $21 = ((($map)) + 2052|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $24 = HEAP32[13488>>2]|0;
   $25 = $24 & 2048;
   $26 = ($25|0)==(0);
   if ($26) {
    (__rl_unget_char($key)|0);
   } else {
    (__rl_prev_macro_key()|0);
   }
   HEAP32[13960>>2] = $map;
   $$0 = -2;
   return ($$0|0);
  }
  $27 = ($got_subseq|0)==(0);
  if ($27) {
   $$0 = $r;
   return ($$0|0);
  }
  $28 = HEAP32[13488>>2]|0;
  $29 = $28 & 2048;
  $30 = ($29|0)==(0);
  if ($30) {
   (__rl_unget_char($key)|0);
  } else {
   (__rl_prev_macro_key()|0);
  }
  HEAP32[13960>>2] = $map;
  $$0 = -1;
  return ($$0|0);
 }
 return (0)|0;
}
function __rl_vi_initialize_line() {
 var $0 = 0, $1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 dest=14144; stop=dest+104|0; do { HEAP32[dest>>2]=4294967295|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & -4194305;
 HEAP32[13488>>2] = $1;
 return;
}
function __rl_vi_reset_last() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[14128>>2] = 105;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = 1;
 HEAP32[14264>>2] = 0;
 return;
}
function __rl_vi_set_last($key,$repeat,$sign) {
 $key = $key|0;
 $repeat = $repeat|0;
 $sign = $sign|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = $repeat;
 HEAP32[14256>>2] = $sign;
 return;
}
function _rl_vi_insertion_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $0 = HEAP32[13728>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function __rl_vi_textmod_command($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $memchr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(0);
 if ($0) {
  $3 = 0;
  return ($3|0);
 }
 $memchr = (_memchr(14280,$c,23)|0);
 $1 = ($memchr|0)!=(0|0);
 $2 = $1&1;
 $3 = $2;
 return ($3|0);
}
function _rl_vi_redo($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $$01$i = 0, $$01$i11 = 0, $$01$i14 = 0, $$01$i19 = 0, $$01$i24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0;
 var $or$cond7 = 0, $or$cond9 = 0, $r$0 = 0, $storemerge$i = 0, $storemerge$i12 = 0, $storemerge$i17 = 0, $storemerge$i22 = 0, $storemerge$i27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[14248>>2]|0;
  HEAP32[13464>>2] = $2;
  $3 = HEAP32[14256>>2]|0;
  HEAP32[13480>>2] = $3;
 }
 HEAP32[14304>>2] = 1;
 $4 = HEAP32[14128>>2]|0;
 $5 = ($4|0)==(105);
 $6 = HEAP32[14312>>2]|0;
 $7 = ($6|0)!=(0|0);
 $or$cond = $5 & $7;
 if ($or$cond) {
  $8 = HEAP8[$6>>0]|0;
  $9 = ($8<<24>>24)==(0);
  if (!($9)) {
   (_rl_begin_undo_group()|0);
   $10 = ($count|0)==(0);
   if (!($10)) {
    $$01$i = $count;
    while(1) {
     $11 = (($$01$i) + -1)|0;
     $12 = HEAP32[14312>>2]|0;
     (_rl_insert_text($12)|0);
     $13 = ($11|0)==(0);
     if ($13) {
      break;
     } else {
      $$01$i = $11;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $14 = HEAP32[13784>>2]|0;
   $15 = ($14|0)>(0);
   if (!($15)) {
    $r$0 = 0;
    HEAP32[14304>>2] = 0;
    return ($r$0|0);
   }
   $16 = HEAP32[36240>>2]|0;
   $17 = ($16|0)==(0);
   if ($17) {
    $18 = HEAP32[13632>>2]|0;
    $19 = (__rl_find_prev_mbchar($18,$14,1)|0);
    $storemerge$i = $19;
   } else {
    $20 = (($14) + -1)|0;
    $storemerge$i = $20;
   }
   HEAP32[13784>>2] = $storemerge$i;
   $r$0 = 0;
   HEAP32[14304>>2] = 0;
   return ($r$0|0);
  }
 }
 $21 = ($4|0)==(82);
 $or$cond3 = $21 & $7;
 if ($or$cond3) {
  $22 = HEAP8[$6>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $24 = (_strlen(($6|0))|0);
   (_rl_begin_undo_group()|0);
   $25 = ($count|0)==(0);
   if (!($25)) {
    $26 = (($24) + -1)|0;
    $$01$i11 = $count;
    while(1) {
     $27 = (($$01$i11) + -1)|0;
     $28 = HEAP32[14312>>2]|0;
     $29 = HEAP32[13784>>2]|0;
     $30 = (($26) + ($29))|0;
     (__rl_replace_text($28,$29,$30)|0);
     $31 = ($27|0)==(0);
     if ($31) {
      break;
     } else {
      $$01$i11 = $27;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $32 = HEAP32[13784>>2]|0;
   $33 = ($32|0)>(0);
   if (!($33)) {
    $r$0 = 0;
    HEAP32[14304>>2] = 0;
    return ($r$0|0);
   }
   $34 = HEAP32[36240>>2]|0;
   $35 = ($34|0)==(0);
   if ($35) {
    $36 = HEAP32[13632>>2]|0;
    $37 = (__rl_find_prev_mbchar($36,$32,1)|0);
    $storemerge$i12 = $37;
   } else {
    $38 = (($32) + -1)|0;
    $storemerge$i12 = $38;
   }
   HEAP32[13784>>2] = $storemerge$i12;
   $r$0 = 0;
   HEAP32[14304>>2] = 0;
   return ($r$0|0);
  }
 }
 $39 = ($4|0)==(73);
 $or$cond5 = $39 & $7;
 if ($or$cond5) {
  $40 = HEAP8[$6>>0]|0;
  $41 = ($40<<24>>24)==(0);
  if (!($41)) {
   (_rl_beg_of_line(1,73)|0);
   (_rl_begin_undo_group()|0);
   $42 = ($count|0)==(0);
   if (!($42)) {
    $$01$i14 = $count;
    while(1) {
     $43 = (($$01$i14) + -1)|0;
     $44 = HEAP32[14312>>2]|0;
     (_rl_insert_text($44)|0);
     $45 = ($43|0)==(0);
     if ($45) {
      break;
     } else {
      $$01$i14 = $43;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $46 = HEAP32[13784>>2]|0;
   $47 = ($46|0)>(0);
   if (!($47)) {
    $r$0 = 0;
    HEAP32[14304>>2] = 0;
    return ($r$0|0);
   }
   $48 = HEAP32[36240>>2]|0;
   $49 = ($48|0)==(0);
   if ($49) {
    $50 = HEAP32[13632>>2]|0;
    $51 = (__rl_find_prev_mbchar($50,$46,1)|0);
    $storemerge$i17 = $51;
   } else {
    $52 = (($46) + -1)|0;
    $storemerge$i17 = $52;
   }
   HEAP32[13784>>2] = $storemerge$i17;
   $r$0 = 0;
   HEAP32[14304>>2] = 0;
   return ($r$0|0);
  }
 }
 $53 = ($4|0)==(97);
 $or$cond7 = $53 & $7;
 if ($or$cond7) {
  $54 = HEAP8[$6>>0]|0;
  $55 = ($54<<24>>24)==(0);
  if (!($55)) {
   $56 = HEAP32[13784>>2]|0;
   $57 = HEAP32[13768>>2]|0;
   $58 = ($56|0)<($57|0);
   do {
    if ($58) {
     $59 = HEAP32[36240>>2]|0;
     $60 = ($59|0)==(0);
     if (!($60)) {
      $61 = (($56) + 1)|0;
      HEAP32[13784>>2] = $61;
      break;
     }
     $62 = (__rl_forward_char_internal(1)|0);
     HEAP32[13784>>2] = $62;
     $63 = ($56|0)==($62|0);
     if ($63) {
      $64 = HEAP32[13768>>2]|0;
      HEAP32[13784>>2] = $64;
     }
    }
   } while(0);
   (_rl_begin_undo_group()|0);
   $65 = ($count|0)==(0);
   if (!($65)) {
    $$01$i19 = $count;
    while(1) {
     $66 = (($$01$i19) + -1)|0;
     $67 = HEAP32[14312>>2]|0;
     (_rl_insert_text($67)|0);
     $68 = ($66|0)==(0);
     if ($68) {
      break;
     } else {
      $$01$i19 = $66;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $69 = HEAP32[13784>>2]|0;
   $70 = ($69|0)>(0);
   if (!($70)) {
    $r$0 = 0;
    HEAP32[14304>>2] = 0;
    return ($r$0|0);
   }
   $71 = HEAP32[36240>>2]|0;
   $72 = ($71|0)==(0);
   if ($72) {
    $73 = HEAP32[13632>>2]|0;
    $74 = (__rl_find_prev_mbchar($73,$69,1)|0);
    $storemerge$i22 = $74;
   } else {
    $75 = (($69) + -1)|0;
    $storemerge$i22 = $75;
   }
   HEAP32[13784>>2] = $storemerge$i22;
   $r$0 = 0;
   HEAP32[14304>>2] = 0;
   return ($r$0|0);
  }
 }
 $76 = ($4|0)==(65);
 $or$cond9 = $76 & $7;
 if ($or$cond9) {
  $77 = HEAP8[$6>>0]|0;
  $78 = ($77<<24>>24)==(0);
  if (!($78)) {
   (_rl_end_of_line(1,65)|0);
   (_rl_begin_undo_group()|0);
   $79 = ($count|0)==(0);
   if (!($79)) {
    $$01$i24 = $count;
    while(1) {
     $80 = (($$01$i24) + -1)|0;
     $81 = HEAP32[14312>>2]|0;
     (_rl_insert_text($81)|0);
     $82 = ($80|0)==(0);
     if ($82) {
      break;
     } else {
      $$01$i24 = $80;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $83 = HEAP32[13784>>2]|0;
   $84 = ($83|0)>(0);
   if (!($84)) {
    $r$0 = 0;
    HEAP32[14304>>2] = 0;
    return ($r$0|0);
   }
   $85 = HEAP32[36240>>2]|0;
   $86 = ($85|0)==(0);
   if ($86) {
    $87 = HEAP32[13632>>2]|0;
    $88 = (__rl_find_prev_mbchar($87,$83,1)|0);
    $storemerge$i27 = $88;
   } else {
    $89 = (($83) + -1)|0;
    $storemerge$i27 = $89;
   }
   HEAP32[13784>>2] = $storemerge$i27;
   $r$0 = 0;
   HEAP32[14304>>2] = 0;
   return ($r$0|0);
  }
 }
 $90 = HEAP32[13432>>2]|0;
 $91 = (__rl_dispatch($4,$90)|0);
 $r$0 = $91;
 HEAP32[14304>>2] = 0;
 return ($r$0|0);
}
function _rl_vi_undo($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_undo_command($count,$key)|0);
 return ($0|0);
}
function _rl_vi_yank_arg($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_yank_nth_arg(36,0)|0);
  return 0;
 } else {
  $2 = (($count) + -1)|0;
  (_rl_yank_nth_arg($2,0)|0);
  return 0;
 }
 return (0)|0;
}
function _rl_vi_fetch_history($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_beginning_of_history($count,0)|0);
  return 0;
 }
 $2 = HEAP32[36080>>2]|0;
 $3 = (_where_history()|0);
 $4 = (($2) - ($count))|0;
 $5 = (($4) + ($3))|0;
 $6 = ($5|0)<(1);
 if ($6) {
  (_rl_beginning_of_history(0,0)|0);
  return 0;
 } else {
  (_rl_get_previous_history($5,$c)|0);
  return 0;
 }
 return (0)|0;
}
function _rl_vi_search_again($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if ((($key|0) == 78)) {
  (_rl_noninc_forward_search_again($count,78)|0);
  return 0;
 } else if ((($key|0) == 110)) {
  (_rl_noninc_reverse_search_again($count,110)|0);
  return 0;
 } else {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 if ((($key|0) == 47)) {
  (__rl_free_saved_history_line()|0);
  (_rl_noninc_reverse_search($count,47)|0);
  return 0;
 } else if ((($key|0) == 63)) {
  (__rl_free_saved_history_line()|0);
  (_rl_noninc_forward_search($count,63)|0);
  return 0;
 } else {
  (_rl_ding()|0);
  return 0;
 }
 return (0)|0;
}
function _rl_vi_complete($ignore,$key) {
 $ignore = $ignore|0;
 $key = $key|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 if ($2) {
  $3 = HEAP32[13632>>2]|0;
  $4 = (($3) + ($0)|0);
  $5 = HEAP8[$4>>0]|0;
  if (!((($5<<24>>24) == 9) | (($5<<24>>24) == 32))) {
   $6 = (($0) + 1)|0;
   $7 = (($3) + ($6)|0);
   $8 = HEAP8[$7>>0]|0;
   if ((($8<<24>>24) == 9) | (($8<<24>>24) == 32)) {
    $10 = $0;
   } else {
    (_rl_vi_end_word(1,69)|0);
    $$pre = HEAP32[13784>>2]|0;
    $10 = $$pre;
   }
   $9 = (($10) + 1)|0;
   HEAP32[13784>>2] = $9;
  }
 }
 if ((($key|0) == 42)) {
  (_rl_complete_internal(42)|0);
 } else if ((($key|0) == 92)) {
  (_rl_complete_internal(9)|0);
 } else if ((($key|0) == 61)) {
  (_rl_complete_internal(63)|0);
  return 0;
 } else {
  (_rl_complete(0,$key)|0);
  return 0;
 }
 $11 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $11;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $12 = HEAP32[13728>>2]|0;
 $13 = ($12|0)==(0);
 if ($13) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_end_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$in$i = 0, $$ph1 = 0, $$pre$i = 0, $$pre17$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $1 = $key & 255;
 $2 = ($1|0)==($key|0);
 if ($2) {
  $3 = (_isupper($key)|0);
  $4 = ($3|0)==(0);
  if (!($4)) {
   $5 = ($count|0)==(0);
   if ($5) {
    $$0 = 0;
    return ($$0|0);
   }
   $$pre$i = HEAP32[13784>>2]|0;
   $$pre17$i = HEAP32[13768>>2]|0;
   $6 = (($$pre17$i) + -1)|0;
   $$in$i = $count;$9 = $$pre$i;
   while(1) {
    $7 = (($$in$i) + -1)|0;
    $8 = ($9|0)<($6|0);
    if (!($8)) {
     $$0 = 0;
     label = 22;
     break;
    }
    $10 = HEAP32[13632>>2]|0;
    $11 = (($10) + ($9)|0);
    $12 = HEAP8[$11>>0]|0;
    if ((($12<<24>>24) == 9) | (($12<<24>>24) == 32)) {
     $15 = $9;
    } else {
     $13 = (($9) + 1)|0;
     HEAP32[13784>>2] = $13;
     $15 = $13;
    }
    $14 = ($15|0)<($$pre17$i|0);
    L17: do {
     if ($14) {
      $17 = $15;
      while(1) {
       $16 = (($10) + ($17)|0);
       $18 = HEAP8[$16>>0]|0;
       if (!((($18<<24>>24) == 9) | (($18<<24>>24) == 32))) {
        $22 = $17;
        break L17;
       }
       $19 = (($17) + 1)|0;
       HEAP32[13784>>2] = $19;
       $20 = ($19|0)<($$pre17$i|0);
       if ($20) {
        $17 = $19;
       } else {
        $22 = $19;
        break;
       }
      }
     } else {
      $22 = $15;
     }
    } while(0);
    $21 = ($22|0)!=(0);
    $23 = ($22|0)<($$pre17$i|0);
    $or$cond$i = $21 & $23;
    if ($or$cond$i) {
     $25 = $22;
     while(1) {
      $24 = (($10) + ($25)|0);
      $26 = HEAP8[$24>>0]|0;
      if (!((($26<<24>>24) == 9) | (($26<<24>>24) == 32))) {
       $$ph1 = $25;
       break;
      }
      $28 = (($25) + 1)|0;
      HEAP32[13784>>2] = $28;
      $29 = ($28|0)<($$pre17$i|0);
      if ($29) {
       $25 = $28;
      } else {
       $$ph1 = $28;
       break;
      }
     }
     $27 = ($$ph1|0)<($$pre17$i|0);
     L27: do {
      if ($27) {
       $31 = $$ph1;
       while(1) {
        $30 = (($10) + ($31)|0);
        $32 = HEAP8[$30>>0]|0;
        if ((($32<<24>>24) == 9) | (($32<<24>>24) == 32)) {
         $36 = $31;
         break L27;
        }
        $33 = (($31) + 1)|0;
        HEAP32[13784>>2] = $33;
        $34 = ($33|0)<($$pre17$i|0);
        if ($34) {
         $31 = $33;
        } else {
         $36 = $33;
         break;
        }
       }
      } else {
       $36 = $$ph1;
      }
     } while(0);
     $35 = (($36) + -1)|0;
     HEAP32[13784>>2] = $35;
     $38 = $35;
    } else {
     $38 = $22;
    }
    $37 = ($7|0)==(0);
    if ($37) {
     $$0 = 0;
     label = 22;
     break;
    } else {
     $$in$i = $7;$9 = $38;
    }
   }
   if ((label|0) == 22) {
    return ($$0|0);
   }
  }
 }
 (_rl_vi_eword($count,0)|0);
 $$0 = 0;
 return ($$0|0);
}
function _rl_vi_tilde_expand($ignore,$key) {
 $ignore = $ignore|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_tilde_expand(0,$key)|0);
 $0 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $0;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $1 = HEAP32[13728>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_prev_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$in$i = 0, $$lcssa = 0, $$lcssa6 = 0, $$ph$i = 0, $$pr$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_vi_next_word($1,$key)|0);
  return 0;
 }
 $2 = HEAP32[13784>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  (_rl_ding()|0);
  return 0;
 }
 $4 = $key & 255;
 $5 = ($4|0)==($key|0);
 if ($5) {
  $6 = (_isupper($key)|0);
  $7 = ($6|0)==(0);
  if (!($7)) {
   $8 = ($count|0)!=(0);
   $9 = HEAP32[13784>>2]|0;
   $10 = ($9|0)>(0);
   $11 = $8 & $10;
   if (!($11)) {
    return 0;
   }
   $$pre$i = HEAP32[13632>>2]|0;
   $$in$i = $count;$$pr$i = $9;
   L15: while(1) {
    $12 = (($$in$i) + -1)|0;
    $13 = (($$pre$i) + ($$pr$i)|0);
    $14 = HEAP8[$13>>0]|0;
    if ((($14<<24>>24) == 9) | (($14<<24>>24) == 32)) {
     $$ph$i = $$pr$i;
    } else {
     $15 = (($$pr$i) + -1)|0;
     $16 = (($$pre$i) + ($15)|0);
     $17 = HEAP8[$16>>0]|0;
     if ((($17<<24>>24) == 9) | (($17<<24>>24) == 32)) {
      HEAP32[13784>>2] = $15;
      $$ph$i = $15;
     } else {
      $$ph$i = $$pr$i;
     }
    }
    $18 = ($$ph$i|0)>(0);
    if ($18) {
     $20 = $$ph$i;
    } else {
     label = 21;
     break;
    }
    while(1) {
     $19 = (($$pre$i) + ($20)|0);
     $21 = HEAP8[$19>>0]|0;
     if (!((($21<<24>>24) == 9) | (($21<<24>>24) == 32))) {
      $25 = $20;
      break;
     }
     $22 = (($20) + -1)|0;
     HEAP32[13784>>2] = $22;
     $23 = ($20|0)>(1);
     if ($23) {
      $20 = $22;
     } else {
      $25 = $22;
      break;
     }
    }
    $24 = ($25|0)>(0);
    if ($24) {
     $27 = $25;
    } else {
     label = 21;
     break;
    }
    while(1) {
     $26 = (($27) + -1)|0;
     HEAP32[13784>>2] = $26;
     $28 = ($27|0)>(0);
     if (!($28)) {
      $$lcssa = $27;
      label = 17;
      break L15;
     }
     $29 = (($$pre$i) + ($26)|0);
     $30 = HEAP8[$29>>0]|0;
     if ((($30<<24>>24) == 9) | (($30<<24>>24) == 32)) {
      $$lcssa6 = $27;
      break;
     } else {
      $27 = $26;
     }
    }
    HEAP32[13784>>2] = $$lcssa6;
    $31 = ($12|0)==(0);
    if ($31) {
     label = 21;
     break;
    } else {
     $$in$i = $12;$$pr$i = $$lcssa6;
    }
   }
   if ((label|0) == 17) {
    HEAP32[13784>>2] = $$lcssa;
    return 0;
   }
   else if ((label|0) == 21) {
    return 0;
   }
  }
 }
 (_rl_vi_bword($count,0)|0);
 return 0;
}
function _rl_vi_next_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$in$i = 0, $$lcssa12 = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre4$i = 0, $$pre5$i = 0, $$pre6$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_vi_prev_word($1,$key)|0);
  return 0;
 }
 $2 = HEAP32[13784>>2]|0;
 $3 = HEAP32[13768>>2]|0;
 $4 = (($3) + -1)|0;
 $5 = ($2|0)<($4|0);
 if (!($5)) {
  (_rl_ding()|0);
  return 0;
 }
 $6 = $key & 255;
 $7 = ($6|0)==($key|0);
 if ($7) {
  $8 = (_isupper($key)|0);
  $9 = ($8|0)==(0);
  if (!($9)) {
   $10 = ($count|0)==(0);
   if ($10) {
    return 0;
   }
   $$pre$i = HEAP32[13784>>2]|0;
   $$pre4$i = HEAP32[13768>>2]|0;
   $11 = (($$pre4$i) + -1)|0;
   $$in$i = $count;$15 = $$pre$i;
   while(1) {
    $13 = (($$in$i) + -1)|0;
    $14 = ($15|0)<($11|0);
    if (!($14)) {
     label = 19;
     break;
    }
    $$pre5$i = HEAP32[13632>>2]|0;
    $17 = $15;
    while(1) {
     $16 = (($$pre5$i) + ($17)|0);
     $18 = HEAP8[$16>>0]|0;
     if ((($18<<24>>24) == 9) | (($18<<24>>24) == 32)) {
      $22 = $17;$24 = $18;
      break;
     }
     $19 = ($17|0)<($$pre4$i|0);
     if (!($19)) {
      $22 = $17;$24 = $18;
      break;
     }
     $20 = (($17) + 1)|0;
     HEAP32[13784>>2] = $20;
     $17 = $20;
    }
    while(1) {
     if (!((($24<<24>>24) == 9) | (($24<<24>>24) == 32))) {
      $$lcssa12 = $22;
      break;
     }
     $21 = ($22|0)<($$pre4$i|0);
     if (!($21)) {
      $$lcssa12 = $22;
      break;
     }
     $23 = (($22) + 1)|0;
     HEAP32[13784>>2] = $23;
     $$phi$trans$insert$i = (($$pre5$i) + ($23)|0);
     $$pre6$i = HEAP8[$$phi$trans$insert$i>>0]|0;
     $22 = $23;$24 = $$pre6$i;
    }
    $12 = ($13|0)==(0);
    if ($12) {
     label = 19;
     break;
    } else {
     $$in$i = $13;$15 = $$lcssa12;
    }
   }
   if ((label|0) == 19) {
    return 0;
   }
  }
 }
 (_rl_vi_fword($count,0)|0);
 return 0;
}
function _rl_vi_bWord($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$lcssa = 0, $$lcssa10 = 0, $$ph = 0, $$pr = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)!=(0);
 $1 = HEAP32[13784>>2]|0;
 $2 = ($1|0)>(0);
 $3 = $0 & $2;
 if (!($3)) {
  return 0;
 }
 $$pre = HEAP32[13632>>2]|0;
 $$in = $count;$$pr = $1;
 L4: while(1) {
  $4 = (($$in) + -1)|0;
  $5 = (($$pre) + ($$pr)|0);
  $6 = HEAP8[$5>>0]|0;
  if ((($6<<24>>24) == 9) | (($6<<24>>24) == 32)) {
   $$ph = $$pr;
  } else {
   $7 = (($$pr) + -1)|0;
   $8 = (($$pre) + ($7)|0);
   $9 = HEAP8[$8>>0]|0;
   if ((($9<<24>>24) == 9) | (($9<<24>>24) == 32)) {
    HEAP32[13784>>2] = $7;
    $$ph = $7;
   } else {
    $$ph = $$pr;
   }
  }
  $10 = ($$ph|0)>(0);
  if ($10) {
   $12 = $$ph;
  } else {
   label = 14;
   break;
  }
  while(1) {
   $11 = (($$pre) + ($12)|0);
   $13 = HEAP8[$11>>0]|0;
   if (!((($13<<24>>24) == 9) | (($13<<24>>24) == 32))) {
    $17 = $12;
    break;
   }
   $14 = (($12) + -1)|0;
   HEAP32[13784>>2] = $14;
   $15 = ($12|0)>(1);
   if ($15) {
    $12 = $14;
   } else {
    $17 = $14;
    break;
   }
  }
  $16 = ($17|0)>(0);
  if ($16) {
   $19 = $17;
  } else {
   label = 14;
   break;
  }
  while(1) {
   $18 = (($19) + -1)|0;
   HEAP32[13784>>2] = $18;
   $20 = ($19|0)>(0);
   if (!($20)) {
    $$lcssa = $19;
    label = 11;
    break L4;
   }
   $21 = (($$pre) + ($18)|0);
   $22 = HEAP8[$21>>0]|0;
   if ((($22<<24>>24) == 9) | (($22<<24>>24) == 32)) {
    $$lcssa10 = $19;
    break;
   } else {
    $19 = $18;
   }
  }
  HEAP32[13784>>2] = $$lcssa10;
  $23 = ($4|0)==(0);
  if ($23) {
   label = 14;
   break;
  } else {
   $$in = $4;$$pr = $$lcssa10;
  }
 }
 if ((label|0) == 11) {
  HEAP32[13784>>2] = $$lcssa;
  return 0;
 }
 else if ((label|0) == 14) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_bword($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$ph12 = 0, $$phi$trans$insert = 0, $$pr10 = 0, $$pre16 = 0, $$pre19 = 0, $$pre20 = 0, $$pre24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0;
 var $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0;
 var $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0;
 var $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $or$cond = 0, $or$cond4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)!=(0);
 $1 = HEAP32[13784>>2]|0;
 $2 = ($1|0)>(0);
 $3 = $0 & $2;
 if ($3) {
  $$in = $count;$7 = $1;
 } else {
  return 0;
 }
 L3: while(1) {
  $4 = (($$in) + -1)|0;
  $5 = HEAP32[13632>>2]|0;
  $6 = (($5) + ($7)|0);
  $8 = HEAP8[$6>>0]|0;
  if ((($8<<24>>24) == 9) | (($8<<24>>24) == 32)) {
   $13 = $7;
  } else {
   $9 = (($7) + -1)|0;
   $10 = (($5) + ($9)|0);
   $11 = HEAP8[$10>>0]|0;
   if ((($11<<24>>24) == 9) | (($11<<24>>24) == 32)) {
    HEAP32[13784>>2] = $9;
    $13 = $9;
   } else {
    $13 = $7;
   }
  }
  $12 = (($13) + -1)|0;
  $14 = (($5) + ($12)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15 << 24 >> 24;
  $17 = (_isalnum($16)|0);
  $18 = ($17|0)==(0);
  $19 = HEAP32[13784>>2]|0;
  if ($18) {
   $20 = (($19) + -1)|0;
   $21 = HEAP32[13632>>2]|0;
   $22 = (($21) + ($20)|0);
   $23 = HEAP8[$22>>0]|0;
   $24 = ($23<<24>>24)==(95);
   $26 = $21;$36 = $24;
  } else {
   $$pre16 = HEAP32[13632>>2]|0;
   $26 = $$pre16;$36 = 1;
  }
  $25 = (($26) + ($19)|0);
  $27 = HEAP8[$25>>0]|0;
  $28 = $27 << 24 >> 24;
  $29 = (_isalnum($28)|0);
  $30 = ($29|0)==(0);
  $31 = HEAP32[13784>>2]|0;
  if ($30) {
   $32 = HEAP32[13632>>2]|0;
   $33 = (($32) + ($31)|0);
   $34 = HEAP8[$33>>0]|0;
   $35 = ($34<<24>>24)!=(95);
   $or$cond = $36 | $35;
   if ($or$cond) {
    $38 = $34;
    label = 12;
   } else {
    $47 = $31;
    label = 14;
   }
  } else {
   if ($36) {
    $$pre19 = HEAP32[13632>>2]|0;
    $$phi$trans$insert = (($$pre19) + ($31)|0);
    $$pre20 = HEAP8[$$phi$trans$insert>>0]|0;
    $38 = $$pre20;
    label = 12;
   } else {
    $47 = $31;
    label = 14;
   }
  }
  if ((label|0) == 12) {
   label = 0;
   $37 = $38 << 24 >> 24;
   $39 = (_isalnum($37)|0);
   $40 = ($39|0)==(0);
   $41 = HEAP32[13784>>2]|0;
   if ($40) {
    $42 = HEAP32[13632>>2]|0;
    $43 = (($42) + ($41)|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = ($44<<24>>24)!=(95);
    $or$cond4 = $36 & $45;
    if ($or$cond4) {
     $47 = $41;
     label = 14;
    } else {
     $$ph12 = $41;
    }
   } else {
    $$ph12 = $41;
   }
  }
  if ((label|0) == 14) {
   label = 0;
   $46 = (($47) + -1)|0;
   HEAP32[13784>>2] = $46;
   $$ph12 = $46;
  }
  $48 = ($$ph12|0)>(0);
  if (!($48)) {
   label = 30;
   break;
  }
  $$pre24 = HEAP32[13632>>2]|0;
  $50 = $$ph12;
  while(1) {
   $49 = (($$pre24) + ($50)|0);
   $51 = HEAP8[$49>>0]|0;
   if (!((($51<<24>>24) == 9) | (($51<<24>>24) == 32))) {
    $55 = $50;
    break;
   }
   $52 = (($50) + -1)|0;
   HEAP32[13784>>2] = $52;
   $53 = ($50|0)>(1);
   if ($53) {
    $50 = $52;
   } else {
    $55 = $52;
    break;
   }
  }
  $54 = ($55|0)>(0);
  if (!($54)) {
   label = 30;
   break;
  }
  $56 = HEAP32[13632>>2]|0;
  $57 = (($56) + ($55)|0);
  $58 = HEAP8[$57>>0]|0;
  $59 = $58 << 24 >> 24;
  $60 = (_isalnum($59)|0);
  $61 = ($60|0)==(0);
  L29: do {
   if ($61) {
    $62 = HEAP32[13784>>2]|0;
    $63 = HEAP32[13632>>2]|0;
    $64 = (($63) + ($62)|0);
    $65 = HEAP8[$64>>0]|0;
    $66 = ($65<<24>>24)==(95);
    if ($66) {
     $68 = $62;
     label = 23;
    } else {
     $82 = $62;$85 = $63;
     while(1) {
      $81 = (($82) + -1)|0;
      HEAP32[13784>>2] = $81;
      $83 = ($82|0)>(0);
      if (!($83)) {
       $95 = $81;
       label = 29;
       break L29;
      }
      $84 = (($85) + ($81)|0);
      $86 = HEAP8[$84>>0]|0;
      $87 = $86 << 24 >> 24;
      $88 = (_isalnum($87)|0);
      $89 = ($88|0)==(0);
      $90 = HEAP32[13784>>2]|0;
      if (!($89)) {
       $95 = $90;
       label = 29;
       break L29;
      }
      $91 = HEAP32[13632>>2]|0;
      $92 = (($91) + ($90)|0);
      $93 = HEAP8[$92>>0]|0;
      if ((($93<<24>>24) == 9) | (($93<<24>>24) == 32) | (($93<<24>>24) == 95)) {
       $95 = $90;
       label = 29;
       break;
      } else {
       $82 = $90;$85 = $91;
      }
     }
    }
   } else {
    label = 22;
   }
  } while(0);
  while(1) {
   if ((label|0) == 22) {
    label = 0;
    $$pr10 = HEAP32[13784>>2]|0;
    $68 = $$pr10;
    label = 23;
    continue;
   }
   else if ((label|0) == 23) {
    label = 0;
    $67 = (($68) + -1)|0;
    HEAP32[13784>>2] = $67;
    $69 = ($68|0)>(0);
    if (!($69)) {
     $95 = $67;
     label = 29;
     continue;
    }
    $70 = HEAP32[13632>>2]|0;
    $71 = (($70) + ($67)|0);
    $72 = HEAP8[$71>>0]|0;
    $73 = $72 << 24 >> 24;
    $74 = (_isalnum($73)|0);
    $75 = ($74|0)==(0);
    if (!($75)) {
     label = 22;
     continue;
    }
    $76 = HEAP32[13784>>2]|0;
    $77 = HEAP32[13632>>2]|0;
    $78 = (($77) + ($76)|0);
    $79 = HEAP8[$78>>0]|0;
    $80 = ($79<<24>>24)==(95);
    if ($80) {
     $68 = $76;
     label = 23;
     continue;
    } else {
     $95 = $76;
     label = 29;
     continue;
    }
   }
   else if ((label|0) == 29) {
    label = 0;
    $94 = (($95) + 1)|0;
    HEAP32[13784>>2] = $94;
    $96 = ($4|0)!=(0);
    $97 = ($95|0)>(-1);
    $98 = $96 & $97;
    if ($98) {
     $$in = $4;$7 = $94;
     continue L3;
    } else {
     label = 30;
     break L3;
    }
   }
  }
 }
 if ((label|0) == 30) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_fWord($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$lcssa14 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre4 = 0, $$pre5 = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  return 0;
 }
 $$pre = HEAP32[13784>>2]|0;
 $$pre4 = HEAP32[13768>>2]|0;
 $1 = (($$pre4) + -1)|0;
 $$in = $count;$5 = $$pre;
 while(1) {
  $3 = (($$in) + -1)|0;
  $4 = ($5|0)<($1|0);
  if (!($4)) {
   label = 12;
   break;
  }
  $$pre5 = HEAP32[13632>>2]|0;
  $7 = $5;
  while(1) {
   $6 = (($$pre5) + ($7)|0);
   $8 = HEAP8[$6>>0]|0;
   if ((($8<<24>>24) == 9) | (($8<<24>>24) == 32)) {
    $12 = $7;$14 = $8;
    break;
   }
   $9 = ($7|0)<($$pre4|0);
   if (!($9)) {
    $12 = $7;$14 = $8;
    break;
   }
   $10 = (($7) + 1)|0;
   HEAP32[13784>>2] = $10;
   $7 = $10;
  }
  while(1) {
   if (!((($14<<24>>24) == 9) | (($14<<24>>24) == 32))) {
    $$lcssa14 = $12;
    break;
   }
   $11 = ($12|0)<($$pre4|0);
   if (!($11)) {
    $$lcssa14 = $12;
    break;
   }
   $13 = (($12) + 1)|0;
   HEAP32[13784>>2] = $13;
   $$phi$trans$insert = (($$pre5) + ($13)|0);
   $$pre6 = HEAP8[$$phi$trans$insert>>0]|0;
   $12 = $13;$14 = $$pre6;
  }
  $2 = ($3|0)==(0);
  if ($2) {
   label = 12;
   break;
  } else {
   $$in = $3;$5 = $$lcssa14;
  }
 }
 if ((label|0) == 12) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_fword($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$lcssa24 = 0, $$old = 0, $$old22 = 0, $$pre = 0, $$pre16 = 0, $$pre16$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0;
 var $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0;
 var $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  return 0;
 }
 $$pre = HEAP32[13784>>2]|0;
 $$in = $count;$6 = $$pre;
 while(1) {
  $2 = (($$in) + -1)|0;
  $3 = HEAP32[13768>>2]|0;
  $4 = (($3) + -1)|0;
  $5 = ($6|0)<($4|0);
  if (!($5)) {
   label = 20;
   break;
  }
  $7 = HEAP32[13632>>2]|0;
  $8 = (($7) + ($6)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9 << 24 >> 24;
  $11 = (_isalnum($10)|0);
  $12 = ($11|0)==(0);
  $13 = HEAP32[13784>>2]|0;
  if ($12) {
   $14 = HEAP32[13632>>2]|0;
   $15 = (($14) + ($13)|0);
   $16 = HEAP8[$15>>0]|0;
   $17 = ($16<<24>>24)==(95);
   if ($17) {
    $23 = $13;
    label = 8;
   } else {
    $18 = $16 << 24 >> 24;
    $19 = (_isalnum($18)|0);
    $20 = ($19|0)==(0);
    L10: do {
     if ($20) {
      while(1) {
       $36 = HEAP32[13784>>2]|0;
       $37 = HEAP32[13632>>2]|0;
       $38 = (($37) + ($36)|0);
       $39 = HEAP8[$38>>0]|0;
       if ((($39<<24>>24) == 9) | (($39<<24>>24) == 32) | (($39<<24>>24) == 95)) {
        break L10;
       }
       $40 = HEAP32[13768>>2]|0;
       $41 = ($36|0)<($40|0);
       if (!($41)) {
        break L10;
       }
       $42 = (($36) + 1)|0;
       HEAP32[13784>>2] = $42;
       $43 = (($37) + ($42)|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44 << 24 >> 24;
       $46 = (_isalnum($45)|0);
       $47 = ($46|0)==(0);
       if (!($47)) {
        break;
       }
      }
     }
    } while(0);
    $$pre16$pre = HEAP32[13784>>2]|0;
    $$pre16 = $$pre16$pre;
   }
  } else {
   $23 = $13;
   label = 8;
  }
  L16: do {
   if ((label|0) == 8) {
    while(1) {
     label = 0;
     $21 = HEAP32[13632>>2]|0;
     $22 = (($21) + ($23)|0);
     $24 = HEAP8[$22>>0]|0;
     $25 = $24 << 24 >> 24;
     $26 = (_isalnum($25)|0);
     $27 = ($26|0)==(0);
     $28 = HEAP32[13784>>2]|0;
     if ($27) {
      $29 = HEAP32[13632>>2]|0;
      $30 = (($29) + ($28)|0);
      $31 = HEAP8[$30>>0]|0;
      $32 = ($31<<24>>24)==(95);
      $33 = HEAP32[13768>>2]|0;
      $34 = ($28|0)<($33|0);
      $or$cond = $32 & $34;
      if (!($or$cond)) {
       $$pre16 = $28;
       break L16;
      }
     } else {
      $$old = HEAP32[13768>>2]|0;
      $$old22 = ($28|0)<($$old|0);
      if (!($$old22)) {
       $$pre16 = $28;
       break L16;
      }
     }
     $35 = (($28) + 1)|0;
     HEAP32[13784>>2] = $35;
     $23 = $35;
     label = 8;
    }
   }
  } while(0);
  $$pre17 = HEAP32[13632>>2]|0;
  $49 = $$pre16;
  while(1) {
   $48 = (($$pre17) + ($49)|0);
   $50 = HEAP8[$48>>0]|0;
   if (!((($50<<24>>24) == 9) | (($50<<24>>24) == 32))) {
    $$lcssa24 = $49;
    break;
   }
   $51 = HEAP32[13768>>2]|0;
   $52 = ($49|0)<($51|0);
   if (!($52)) {
    $$lcssa24 = $49;
    break;
   }
   $53 = (($49) + 1)|0;
   HEAP32[13784>>2] = $53;
   $49 = $53;
  }
  $1 = ($2|0)==(0);
  if ($1) {
   label = 20;
   break;
  } else {
   $$in = $2;$6 = $$lcssa24;
  }
 }
 if ((label|0) == 20) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_eWord($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$pre = 0, $$pre17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  return 0;
 }
 $$pre = HEAP32[13784>>2]|0;
 $$pre17 = HEAP32[13768>>2]|0;
 $1 = (($$pre17) + -1)|0;
 $$in = $count;$4 = $$pre;
 while(1) {
  $2 = (($$in) + -1)|0;
  $3 = ($4|0)<($1|0);
  if (!($3)) {
   label = 18;
   break;
  }
  $5 = HEAP32[13632>>2]|0;
  $6 = (($5) + ($4)|0);
  $7 = HEAP8[$6>>0]|0;
  if ((($7<<24>>24) == 9) | (($7<<24>>24) == 32)) {
   $10 = $4;
  } else {
   $8 = (($4) + 1)|0;
   HEAP32[13784>>2] = $8;
   $10 = $8;
  }
  $9 = ($10|0)<($$pre17|0);
  L10: do {
   if ($9) {
    $12 = $10;
    while(1) {
     $11 = (($5) + ($12)|0);
     $13 = HEAP8[$11>>0]|0;
     if (!((($13<<24>>24) == 9) | (($13<<24>>24) == 32))) {
      $17 = $12;
      break L10;
     }
     $14 = (($12) + 1)|0;
     HEAP32[13784>>2] = $14;
     $15 = ($14|0)<($$pre17|0);
     if ($15) {
      $12 = $14;
     } else {
      $17 = $14;
      break;
     }
    }
   } else {
    $17 = $10;
   }
  } while(0);
  $16 = ($17|0)!=(0);
  $18 = ($17|0)<($$pre17|0);
  $or$cond = $16 & $18;
  if ($or$cond) {
   $19 = ($17|0)<($$pre17|0);
   L17: do {
    if ($19) {
     $21 = $17;
     while(1) {
      $20 = (($5) + ($21)|0);
      $22 = HEAP8[$20>>0]|0;
      if (!((($22<<24>>24) == 9) | (($22<<24>>24) == 32))) {
       $24 = $21;
       break L17;
      }
      $25 = (($21) + 1)|0;
      HEAP32[13784>>2] = $25;
      $26 = ($25|0)<($$pre17|0);
      if ($26) {
       $21 = $25;
      } else {
       $24 = $25;
       break;
      }
     }
    } else {
     $24 = $17;
    }
   } while(0);
   $23 = ($24|0)<($$pre17|0);
   L22: do {
    if ($23) {
     $28 = $24;
     while(1) {
      $27 = (($5) + ($28)|0);
      $29 = HEAP8[$27>>0]|0;
      if ((($29<<24>>24) == 9) | (($29<<24>>24) == 32)) {
       $33 = $28;
       break L22;
      }
      $30 = (($28) + 1)|0;
      HEAP32[13784>>2] = $30;
      $31 = ($30|0)<($$pre17|0);
      if ($31) {
       $28 = $30;
      } else {
       $33 = $30;
       break;
      }
     }
    } else {
     $33 = $24;
    }
   } while(0);
   $32 = (($33) + -1)|0;
   HEAP32[13784>>2] = $32;
   $35 = $32;
  } else {
   $35 = $17;
  }
  $34 = ($2|0)==(0);
  if ($34) {
   label = 18;
   break;
  } else {
   $$in = $2;$4 = $35;
  }
 }
 if ((label|0) == 18) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_eword($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  return 0;
 }
 $$pre = HEAP32[13784>>2]|0;
 $$in = $count;$5 = $$pre;
 while(1) {
  $1 = (($$in) + -1)|0;
  $2 = HEAP32[13768>>2]|0;
  $3 = (($2) + -1)|0;
  $4 = ($5|0)<($3|0);
  if (!($4)) {
   label = 20;
   break;
  }
  $6 = HEAP32[13632>>2]|0;
  $7 = (($6) + ($5)|0);
  $8 = HEAP8[$7>>0]|0;
  if ((($8<<24>>24) == 9) | (($8<<24>>24) == 32)) {
   $11 = $5;
  } else {
   $9 = (($5) + 1)|0;
   HEAP32[13784>>2] = $9;
   $11 = $9;
  }
  $10 = ($11|0)<($2|0);
  L10: do {
   if ($10) {
    $13 = $11;
    while(1) {
     $12 = (($6) + ($13)|0);
     $14 = HEAP8[$12>>0]|0;
     if (!((($14<<24>>24) == 9) | (($14<<24>>24) == 32))) {
      $18 = $13;
      break L10;
     }
     $15 = (($13) + 1)|0;
     HEAP32[13784>>2] = $15;
     $16 = ($15|0)<($2|0);
     if ($16) {
      $13 = $15;
     } else {
      $18 = $15;
      break;
     }
    }
   } else {
    $18 = $11;
   }
  } while(0);
  $17 = ($18|0)<($2|0);
  L15: do {
   if ($17) {
    $19 = (($6) + ($18)|0);
    $20 = HEAP8[$19>>0]|0;
    $21 = $20 << 24 >> 24;
    $22 = (_isalnum($21)|0);
    $23 = ($22|0)==(0);
    $24 = HEAP32[13784>>2]|0;
    if ($23) {
     $25 = HEAP32[13632>>2]|0;
     $26 = (($25) + ($24)|0);
     $27 = HEAP8[$26>>0]|0;
     $28 = ($27<<24>>24)==(95);
     if (!($28)) {
      $48 = $24;$52 = $25;
      while(1) {
       $47 = (($48) + 1)|0;
       HEAP32[13784>>2] = $47;
       $49 = HEAP32[13768>>2]|0;
       $50 = ($47|0)<($49|0);
       if (!($50)) {
        $62 = $47;
        break L15;
       }
       $51 = (($52) + ($47)|0);
       $53 = HEAP8[$51>>0]|0;
       $54 = $53 << 24 >> 24;
       $55 = (_isalnum($54)|0);
       $56 = ($55|0)==(0);
       $57 = HEAP32[13784>>2]|0;
       if (!($56)) {
        $62 = $57;
        break L15;
       }
       $58 = HEAP32[13632>>2]|0;
       $59 = (($58) + ($57)|0);
       $60 = HEAP8[$59>>0]|0;
       if ((($60<<24>>24) == 9) | (($60<<24>>24) == 32) | (($60<<24>>24) == 95)) {
        $62 = $57;
        break L15;
       } else {
        $48 = $57;$52 = $58;
       }
      }
     }
    }
    $29 = (($24) + 1)|0;
    HEAP32[13784>>2] = $29;
    $30 = HEAP32[13768>>2]|0;
    $31 = ($29|0)<($30|0);
    if ($31) {
     $34 = $29;
     while(1) {
      $32 = HEAP32[13632>>2]|0;
      $33 = (($32) + ($34)|0);
      $35 = HEAP8[$33>>0]|0;
      $36 = $35 << 24 >> 24;
      $37 = (_isalnum($36)|0);
      $38 = ($37|0)==(0);
      $39 = HEAP32[13784>>2]|0;
      if ($38) {
       $40 = HEAP32[13632>>2]|0;
       $41 = (($40) + ($39)|0);
       $42 = HEAP8[$41>>0]|0;
       $43 = ($42<<24>>24)==(95);
       if (!($43)) {
        $62 = $39;
        break L15;
       }
      }
      $44 = (($39) + 1)|0;
      HEAP32[13784>>2] = $44;
      $45 = HEAP32[13768>>2]|0;
      $46 = ($44|0)<($45|0);
      if ($46) {
       $34 = $44;
      } else {
       $62 = $44;
       break;
      }
     }
    } else {
     $62 = $29;
    }
   } else {
    $62 = $18;
   }
  } while(0);
  $61 = (($62) + -1)|0;
  HEAP32[13784>>2] = $61;
  $63 = ($1|0)==(0);
  if ($63) {
   label = 20;
   break;
  } else {
   $$in = $1;$5 = $61;
  }
 }
 if ((label|0) == 20) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_insert_beg($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_beg_of_line(1,$key)|0);
 $0 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $0;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $1 = HEAP32[13728>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_insert_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $0;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $1 = HEAP32[13728>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_append_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 do {
  if ($2) {
   $3 = HEAP32[36240>>2]|0;
   $4 = ($3|0)==(0);
   if (!($4)) {
    $5 = (($0) + 1)|0;
    HEAP32[13784>>2] = $5;
    break;
   }
   $6 = (__rl_forward_char_internal(1)|0);
   HEAP32[13784>>2] = $6;
   $7 = ($0|0)==($6|0);
   if ($7) {
    $8 = HEAP32[13768>>2]|0;
    HEAP32[13784>>2] = $8;
   }
  }
 } while(0);
 $9 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $9;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $10 = HEAP32[13728>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_append_eol($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_end_of_line(1,$key)|0);
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 do {
  if ($2) {
   $3 = HEAP32[36240>>2]|0;
   $4 = ($3|0)==(0);
   if (!($4)) {
    $5 = (($0) + 1)|0;
    HEAP32[13784>>2] = $5;
    break;
   }
   $6 = (__rl_forward_char_internal(1)|0);
   HEAP32[13784>>2] = $6;
   $7 = ($0|0)==($6|0);
   if ($7) {
    $8 = HEAP32[13768>>2]|0;
    HEAP32[13784>>2] = $8;
   }
  }
 } while(0);
 $9 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $9;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $10 = HEAP32[13728>>2]|0;
 $11 = ($10|0)==(0);
 if ($11) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_vi_eof_maybe($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_newline(1,10)|0);
 return ($0|0);
}
function __rl_vi_done_inserting() {
 var $$pr = 0, $$pre$i$i = 0, $$pre$i$i6 = 0, $$pre$i$i9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14320>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $58 = HEAP32[34424>>2]|0;
  $59 = ($58|0)==(0|0);
  $$pr = HEAP32[14272>>2]|0;
  L3: do {
   if ($59) {
    $85 = ($$pr|0)==(67);
    if ($85) {
     label = 29;
    }
   } else {
    switch ($$pr|0) {
    case 65: case 73: case 97: case 105:  {
     break;
    }
    case 67:  {
     label = 29;
     break L3;
     break;
    }
    default: {
     break L3;
    }
    }
    $60 = ((($58)) + 16|0);
    $61 = HEAP32[$60>>2]|0;
    $62 = ($61|0)==(1);
    if (!($62)) {
     $63 = HEAP32[14336>>2]|0;
     $64 = ($63|0)>(0);
     if (!($64)) {
      break;
     }
     $65 = HEAP32[14312>>2]|0;
     HEAP8[$65>>0] = 0;
     break;
    }
    $66 = ((($58)) + 4|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ((($58)) + 8|0);
    $69 = HEAP32[$68>>2]|0;
    $70 = (($69) - ($67))|0;
    $71 = (($70) + 1)|0;
    $72 = HEAP32[14336>>2]|0;
    $73 = ($72|0)>($71|0);
    if ($73) {
     $$pre$i$i9 = HEAP32[14312>>2]|0;
     $82 = $$pre$i$i9;
    } else {
     $74 = (($70) + 33)|0;
     $75 = (($71|0) % 32)&-1;
     $76 = (($74) + ($72))|0;
     $77 = (($76) - ($75))|0;
     HEAP32[14336>>2] = $77;
     $78 = HEAP32[14312>>2]|0;
     $79 = (_xrealloc($78,$77)|0);
     HEAP32[14312>>2] = $79;
     $82 = $79;
    }
    $80 = HEAP32[13632>>2]|0;
    $81 = (($80) + ($67)|0);
    (_strncpy(($82|0),($81|0),($70|0))|0);
    $83 = HEAP32[14312>>2]|0;
    $84 = (($83) + ($70)|0);
    HEAP8[$84>>0] = 0;
   }
  } while(0);
  if ((label|0) == 29) {
   (_rl_end_undo_group()|0);
  }
  $86 = HEAP32[34416>>2]|0;
  $87 = ($86|0)>(0);
  if (!($87)) {
   return;
  }
  while(1) {
   (_rl_end_undo_group()|0);
   $88 = HEAP32[34416>>2]|0;
   $89 = ($88|0)>(0);
   if (!($89)) {
    break;
   }
  }
  return;
 }
 (_rl_end_undo_group()|0);
 HEAP32[14320>>2] = 0;
 $2 = HEAP32[14272>>2]|0;
 $3 = ($2|0)==(82);
 $4 = HEAP32[34424>>2]|0;
 if ($3) {
  $5 = ($4|0)==(0|0);
  if (!($5)) {
   $6 = ((($4)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)!=(3);
   $9 = HEAP32[14328>>2]|0;
   $10 = ($9|0)<(1);
   $or$cond$i = $8 | $10;
   if (!($or$cond$i)) {
    $14 = HEAP32[13784>>2]|0;
    $15 = (1 - ($9))|0;
    $16 = (($15) + ($14))|0;
    $17 = (($9) + 1)|0;
    $18 = HEAP32[14336>>2]|0;
    $19 = ($18|0)>($17|0);
    if ($19) {
     $$pre$i$i = HEAP32[14312>>2]|0;
     $28 = $$pre$i$i;
    } else {
     $20 = (($9) + 33)|0;
     $21 = (($17|0) % 32)&-1;
     $22 = (($20) + ($18))|0;
     $23 = (($22) - ($21))|0;
     HEAP32[14336>>2] = $23;
     $24 = HEAP32[14312>>2]|0;
     $25 = (_xrealloc($24,$23)|0);
     HEAP32[14312>>2] = $25;
     $28 = $25;
    }
    $26 = HEAP32[13632>>2]|0;
    $27 = (($26) + ($16)|0);
    (_strncpy(($28|0),($27|0),($9|0))|0);
    $29 = HEAP32[14312>>2]|0;
    $30 = (($29) + ($9)|0);
    HEAP8[$30>>0] = 0;
    return;
   }
  }
  $11 = HEAP32[14336>>2]|0;
  $12 = ($11|0)>(0);
  if (!($12)) {
   return;
  }
  $13 = HEAP32[14312>>2]|0;
  HEAP8[$13>>0] = 0;
  return;
 } else {
  $31 = HEAP32[$4>>2]|0;
  $32 = ($31|0)==(0|0);
  if (!($32)) {
   $33 = ((($31)) + 16|0);
   $34 = HEAP32[$33>>2]|0;
   $35 = ($34|0)==(1);
   if ($35) {
    $39 = ((($31)) + 4|0);
    $40 = HEAP32[$39>>2]|0;
    $41 = ((($31)) + 8|0);
    $42 = HEAP32[$41>>2]|0;
    $43 = (($42) - ($40))|0;
    $44 = (($43) + 1)|0;
    $45 = HEAP32[14336>>2]|0;
    $46 = ($45|0)>($44|0);
    if ($46) {
     $$pre$i$i6 = HEAP32[14312>>2]|0;
     $55 = $$pre$i$i6;
    } else {
     $47 = (($43) + 33)|0;
     $48 = (($44|0) % 32)&-1;
     $49 = (($47) + ($45))|0;
     $50 = (($49) - ($48))|0;
     HEAP32[14336>>2] = $50;
     $51 = HEAP32[14312>>2]|0;
     $52 = (_xrealloc($51,$50)|0);
     HEAP32[14312>>2] = $52;
     $55 = $52;
    }
    $53 = HEAP32[13632>>2]|0;
    $54 = (($53) + ($40)|0);
    (_strncpy(($55|0),($54|0),($43|0))|0);
    $56 = HEAP32[14312>>2]|0;
    $57 = (($56) + ($43)|0);
    HEAP8[$57>>0] = 0;
    return;
   }
  }
  $36 = HEAP32[14336>>2]|0;
  $37 = ($36|0)>(0);
  if (!($37)) {
   return;
  }
  $38 = HEAP32[14312>>2]|0;
  HEAP8[$38>>0] = 0;
  return;
 }
}
function _rl_vi_movement_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)>(0);
 if ($1) {
  (_rl_backward_char(1,$key)|0);
 }
 HEAP32[13432>>2] = 24408;
 __rl_vi_done_inserting();
 $2 = HEAP32[13488>>2]|0;
 $3 = $2 & 4194304;
 $4 = ($3|0)==(0);
 if ($4) {
  _rl_free_undo_list();
 }
 $5 = HEAP32[13728>>2]|0;
 $6 = ($5|0)==(0);
 if (!($6)) {
  __rl_reset_prompt();
 }
 $7 = HEAP32[13488>>2]|0;
 $8 = $7 | 4194304;
 HEAP32[13488>>2] = $8;
 return 0;
}
function _rl_vi_arg_digit($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13464>>2]|0;
 $notlhs = ($c|0)!=(48);
 $notrhs = ($0|0)!=(1);
 $or$cond$not = $notlhs | $notrhs;
 $1 = HEAP32[13472>>2]|0;
 $2 = ($1|0)!=(0);
 $or$cond3 = $or$cond$not | $2;
 if ($or$cond3) {
  $4 = (_rl_digit_argument($count,$c)|0);
  $$0 = $4;
  return ($$0|0);
 } else {
  $3 = (_rl_beg_of_line(1,48)|0);
  $$0 = $3;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_vi_change_case($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$count$i = 0, $$in = 0, $$in$i = 0, $$in7 = 0, $$lcssa32 = 0, $$lcssa33 = 0, $$phi$trans$insert = 0, $$phi$trans$insert16 = 0, $$phi$trans$insert21 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i2 = 0, $$pre11 = 0, $$pre12 = 0, $$pre14 = 0, $$pre15 = 0, $$pre17 = 0, $$pre17$lcssa = 0, $$pre19 = 0;
 var $$pre2$i = 0, $$pre2$i$i = 0, $$pre20 = 0, $$pre22 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $15 = 0, $16 = 0, $17 = 0;
 var $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$0$ph$be = 0, $c$0$ph6 = 0, $c$1 = 0, $end$0$$i = 0, $end$0$$i$i = 0, $end$0$i = 0, $end$0$i$i = 0, $mb$i = 0, $or$cond$i = 0, $or$cond$i$i = 0;
 var $or$cond$i1$i = 0, $or$cond$i3 = 0, $ps$i = 0, $storemerge$i = 0, $wc$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $wc$i = sp + 8|0;
 $mb$i = sp + 12|0;
 $ps$i = sp;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 if (!($2)) {
  STACKTOP = sp;return 0;
 }
 $3 = HEAP32[36240>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = $ps$i;
  $7 = $6;
  HEAP32[$7>>2] = 0;
  $8 = (($6) + 4)|0;
  $9 = $8;
  HEAP32[$9>>2] = 0;
  $10 = HEAP32[13632>>2]|0;
  $11 = (__rl_adjust_point($10,$0,$ps$i)|0);
  $12 = ($11|0)>(0);
  $13 = $12 << 31 >> 31;
  $$count$i = (($13) + ($count))|0;
  $14 = ($$count$i|0)==(0);
  L6: do {
   if (!($14)) {
    $$in$i = $$count$i;
    while(1) {
     $15 = (($$in$i) + -1)|0;
     $16 = HEAP32[13784>>2]|0;
     $17 = HEAP32[13768>>2]|0;
     $18 = ($17|0)>($16|0);
     if (!($18)) {
      break L6;
     }
     $19 = HEAP32[13632>>2]|0;
     $20 = (($19) + ($16)|0);
     $21 = (($17) - ($16))|0;
     $22 = (_mbrtowc($wc$i,$20,$21,$ps$i)|0);
     $23 = ($22>>>0)>(4294967293);
     do {
      if ($23) {
       $24 = HEAP32[13784>>2]|0;
       $25 = HEAP32[13632>>2]|0;
       $26 = (($25) + ($24)|0);
       $27 = HEAP8[$26>>0]|0;
       $28 = $27 << 24 >> 24;
       HEAP32[$wc$i>>2] = $28;
       $30 = $28;
      } else {
       $29 = ($22|0)==(0);
       if ($29) {
        HEAP32[$wc$i>>2] = 0;
        $30 = 0;
        break;
       } else {
        $$pre$i = HEAP32[$wc$i>>2]|0;
        $30 = $$pre$i;
        break;
       }
      }
     } while(0);
     $31 = (_iswupper($30)|0);
     $32 = ($31|0)==(0);
     $33 = HEAP32[$wc$i>>2]|0;
     do {
      if ($32) {
       $35 = (_iswlower($33)|0);
       $36 = ($35|0)==(0);
       if ($36) {
        (_rl_forward_char(1,0)|0);
        break;
       } else {
        $37 = HEAP32[$wc$i>>2]|0;
        $38 = (_towupper($37)|0);
        $storemerge$i = $38;
        label = 17;
        break;
       }
      } else {
       $34 = (_towlower($33)|0);
       $storemerge$i = $34;
       label = 17;
      }
     } while(0);
     do {
      if ((label|0) == 17) {
       label = 0;
       HEAP32[$wc$i>>2] = $storemerge$i;
       $40 = ($storemerge$i|0)==(0);
       if ($40) {
        (_rl_forward_char(1,0)|0);
        break;
       }
       $41 = HEAP32[13784>>2]|0;
       $42 = (_wcrtomb($mb$i,$storemerge$i,$ps$i)|0);
       $43 = ($42|0)>(-1);
       if ($43) {
        $44 = (($mb$i) + ($42)|0);
        HEAP8[$44>>0] = 0;
       }
       (_rl_begin_undo_group()|0);
       $45 = HEAP32[13768>>2]|0;
       $46 = ($45|0)==(0);
       if ($46) {
        (_rl_ding()|0);
       } else {
        $47 = HEAP32[36240>>2]|0;
        $48 = ($47|0)==(0);
        if ($48) {
         $49 = HEAP32[13632>>2]|0;
         $50 = HEAP32[13784>>2]|0;
         $51 = (__rl_find_next_mbchar($49,$50,1,1)|0);
         $$pre$i$i = HEAP32[13768>>2]|0;
         $$pre2$i$i = HEAP32[13784>>2]|0;
         $55 = $$pre$i$i;$56 = $$pre2$i$i;$end$0$i$i = $51;
        } else {
         $52 = HEAP32[13784>>2]|0;
         $53 = (($52) + 1)|0;
         $55 = $45;$56 = $52;$end$0$i$i = $53;
        }
        $54 = ($end$0$i$i|0)<($55|0);
        $end$0$$i$i = $54 ? $end$0$i$i : $55;
        (_rl_kill_text($56,$end$0$$i$i)|0);
        $57 = HEAP32[13784>>2]|0;
        $58 = ($57|0)>(0);
        $59 = HEAP32[13768>>2]|0;
        $60 = ($57|0)==($59|0);
        $or$cond$i$i = $58 & $60;
        if ($or$cond$i$i) {
         (_rl_backward_char(1,0)|0);
        }
       }
       $61 = HEAP32[13784>>2]|0;
       $62 = ($61|0)<($41|0);
       if ($62) {
        $63 = (($61) + 1)|0;
        HEAP32[13784>>2] = $63;
       }
       (_rl_insert_text($mb$i)|0);
       (_rl_end_undo_group()|0);
       $64 = HEAP32[13784>>2]|0;
       $65 = ($64|0)!=(0);
       $66 = HEAP32[13768>>2]|0;
       $67 = ($64|0)==($66|0);
       $or$cond$i1$i = $65 & $67;
       if ($or$cond$i1$i) {
        $68 = HEAP32[36240>>2]|0;
        $69 = ($68|0)==(0);
        if ($69) {
         $70 = HEAP32[13632>>2]|0;
         $71 = (__rl_find_prev_mbchar($70,$64,1)|0);
         HEAP32[13784>>2] = $71;
         break;
        } else {
         $72 = (($64) + -1)|0;
         HEAP32[13784>>2] = $72;
         break;
        }
       }
      }
     } while(0);
     $39 = ($15|0)==(0);
     if ($39) {
      break;
     } else {
      $$in$i = $15;
     }
    }
   }
  } while(0);
  STACKTOP = sp;return 0;
 }
 $5 = ($count|0)==(0);
 if ($5) {
  STACKTOP = sp;return 0;
 } else {
  $$in = $count;$c$0$ph6 = 0;
 }
 L53: while(1) {
  $$in7 = $$in;
  while(1) {
   $73 = (($$in7) + -1)|0;
   $74 = HEAP32[13784>>2]|0;
   $75 = HEAP32[13768>>2]|0;
   $76 = ($74|0)<($75|0);
   if (!($76)) {
    label = 66;
    break L53;
   }
   $77 = HEAP32[13632>>2]|0;
   $78 = (($77) + ($74)|0);
   $79 = HEAP8[$78>>0]|0;
   $80 = $79&255;
   $81 = $79 << 24 >> 24;
   $82 = ($80|0)==($81|0);
   if ($82) {
    $83 = (_isupper($80)|0);
    $84 = ($83|0)==(0);
    $$pre14 = HEAP32[13784>>2]|0;
    $$pre15 = HEAP32[13632>>2]|0;
    $$phi$trans$insert16 = (($$pre15) + ($$pre14)|0);
    $$pre17 = HEAP8[$$phi$trans$insert16>>0]|0;
    if ($84) {
     $95 = $$pre17;
    } else {
     $$lcssa32 = $73;$$pre17$lcssa = $$pre17;
     label = 38;
     break;
    }
   } else {
    $95 = $79;
   }
   $94 = $95&255;
   $96 = $95 << 24 >> 24;
   $97 = ($94|0)==($96|0);
   if ($97) {
    $98 = (_islower($94)|0);
    $99 = ($98|0)==(0);
    if (!($99)) {
     $$lcssa33 = $73;
     label = 44;
     break;
    }
   }
   (_rl_forward_char(1,$c$0$ph6)|0);
   $113 = ($73|0)==(0);
   if ($113) {
    label = 66;
    break L53;
   } else {
    $$in7 = $73;
   }
  }
  do {
   if ((label|0) == 38) {
    label = 0;
    $85 = $$pre17$lcssa&255;
    $86 = $$pre17$lcssa << 24 >> 24;
    $87 = ($85|0)==($86|0);
    if ($87) {
     $88 = (_isupper($85)|0);
     $89 = ($88|0)==(0);
     $$pre = HEAP32[13784>>2]|0;
     $$pre11 = HEAP32[13632>>2]|0;
     $$phi$trans$insert = (($$pre11) + ($$pre)|0);
     $$pre12 = HEAP8[$$phi$trans$insert>>0]|0;
     if ($89) {
      $93 = $$pre12;
     } else {
      $90 = $$pre12&255;
      $91 = (_tolower($90)|0);
      $145 = $$lcssa32;$c$1 = $91;
      break;
     }
    } else {
     $93 = $$pre17$lcssa;
    }
    $92 = $93 << 24 >> 24;
    $145 = $$lcssa32;$c$1 = $92;
   }
   else if ((label|0) == 44) {
    label = 0;
    $100 = HEAP32[13784>>2]|0;
    $101 = HEAP32[13632>>2]|0;
    $102 = (($101) + ($100)|0);
    $103 = HEAP8[$102>>0]|0;
    $104 = $103&255;
    $105 = $103 << 24 >> 24;
    $106 = ($104|0)==($105|0);
    if ($106) {
     $107 = (_islower($104)|0);
     $108 = ($107|0)==(0);
     $$pre19 = HEAP32[13784>>2]|0;
     $$pre20 = HEAP32[13632>>2]|0;
     $$phi$trans$insert21 = (($$pre20) + ($$pre19)|0);
     $$pre22 = HEAP8[$$phi$trans$insert21>>0]|0;
     if ($108) {
      $112 = $$pre22;
     } else {
      $109 = $$pre22&255;
      $110 = (_toupper($109)|0);
      $145 = $$lcssa33;$c$1 = $110;
      break;
     }
    } else {
     $112 = $103;
    }
    $111 = $112 << 24 >> 24;
    $145 = $$lcssa33;$c$1 = $111;
   }
  } while(0);
  $114 = ($c$1|0)==(0);
  do {
   if ($114) {
    (_rl_forward_char(1,0)|0);
    $c$0$ph$be = 0;
   } else {
    $115 = HEAP32[13784>>2]|0;
    (_rl_begin_undo_group()|0);
    $116 = HEAP32[13768>>2]|0;
    $117 = ($116|0)==(0);
    if ($117) {
     (_rl_ding()|0);
    } else {
     $118 = HEAP32[36240>>2]|0;
     $119 = ($118|0)==(0);
     if ($119) {
      $120 = HEAP32[13632>>2]|0;
      $121 = HEAP32[13784>>2]|0;
      $122 = (__rl_find_next_mbchar($120,$121,1,1)|0);
      $$pre$i2 = HEAP32[13768>>2]|0;
      $$pre2$i = HEAP32[13784>>2]|0;
      $126 = $$pre$i2;$127 = $$pre2$i;$end$0$i = $122;
     } else {
      $123 = HEAP32[13784>>2]|0;
      $124 = (($123) + 1)|0;
      $126 = $116;$127 = $123;$end$0$i = $124;
     }
     $125 = ($end$0$i|0)<($126|0);
     $end$0$$i = $125 ? $end$0$i : $126;
     (_rl_kill_text($127,$end$0$$i)|0);
     $128 = HEAP32[13784>>2]|0;
     $129 = ($128|0)>(0);
     $130 = HEAP32[13768>>2]|0;
     $131 = ($128|0)==($130|0);
     $or$cond$i = $129 & $131;
     if ($or$cond$i) {
      (_rl_backward_char(1,$c$1)|0);
     }
    }
    $132 = HEAP32[13784>>2]|0;
    $133 = ($132|0)<($115|0);
    if ($133) {
     $134 = (($132) + 1)|0;
     HEAP32[13784>>2] = $134;
    }
    (__rl_insert_char(1,$c$1)|0);
    (_rl_end_undo_group()|0);
    $135 = HEAP32[13784>>2]|0;
    $136 = ($135|0)!=(0);
    $137 = HEAP32[13768>>2]|0;
    $138 = ($135|0)==($137|0);
    $or$cond$i3 = $136 & $138;
    if ($or$cond$i3) {
     $139 = HEAP32[36240>>2]|0;
     $140 = ($139|0)==(0);
     if ($140) {
      $141 = HEAP32[13632>>2]|0;
      $142 = (__rl_find_prev_mbchar($141,$135,1)|0);
      HEAP32[13784>>2] = $142;
      $c$0$ph$be = $c$1;
      break;
     } else {
      $143 = (($135) + -1)|0;
      HEAP32[13784>>2] = $143;
      $c$0$ph$be = $c$1;
      break;
     }
    } else {
     $c$0$ph$be = $c$1;
    }
   }
  } while(0);
  $144 = ($145|0)==(0);
  if ($144) {
   label = 66;
   break;
  } else {
   $$in = $145;$c$0$ph6 = $c$0$ph$be;
  }
 }
 if ((label|0) == 66) {
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function _rl_vi_delete($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $end$0 = 0, $end$0$ = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = (_rl_vi_rubout($1,$key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13768>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $5 = HEAP32[36240>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = HEAP32[13632>>2]|0;
  $8 = HEAP32[13784>>2]|0;
  $9 = (__rl_find_next_mbchar($7,$8,$count,1)|0);
  $$pre = HEAP32[13768>>2]|0;
  $$pre2 = HEAP32[13784>>2]|0;
  $13 = $$pre;$14 = $$pre2;$end$0 = $9;
 } else {
  $10 = HEAP32[13784>>2]|0;
  $11 = (($10) + ($count))|0;
  $13 = $3;$14 = $10;$end$0 = $11;
 }
 $12 = ($end$0|0)<($13|0);
 $end$0$ = $12 ? $end$0 : $13;
 (_rl_kill_text($14,$end$0$)|0);
 $15 = HEAP32[13784>>2]|0;
 $16 = ($15|0)>(0);
 $17 = HEAP32[13768>>2]|0;
 $18 = ($15|0)==($17|0);
 $or$cond = $16 & $18;
 if (!($or$cond)) {
  $$0 = 0;
  return ($$0|0);
 }
 (_rl_backward_char(1,$key)|0);
 $$0 = 0;
 return ($$0|0);
}
function _rl_vi_check() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[13768>>2]|0;
 $3 = ($0|0)==($2|0);
 $or$cond = $1 & $3;
 if (!($or$cond)) {
  return 0;
 }
 $4 = HEAP32[36240>>2]|0;
 $5 = ($4|0)==(0);
 if ($5) {
  $6 = HEAP32[13632>>2]|0;
  $7 = (__rl_find_prev_mbchar($6,$0,1)|0);
  HEAP32[13784>>2] = $7;
  return 0;
 } else {
  $8 = (($0) + -1)|0;
  HEAP32[13784>>2] = $8;
  return 0;
 }
 return (0)|0;
}
function _rl_vi_put($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $key & 255;
 $1 = ($0|0)==($key|0);
 if ($1) {
  $2 = (_isupper($key)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $4 = HEAP32[13784>>2]|0;
  $5 = HEAP32[13768>>2]|0;
  $6 = ($4|0)<($5|0);
  if ($6) {
   $7 = HEAP32[13632>>2]|0;
   $8 = (__rl_find_next_mbchar($7,$4,1,1)|0);
   HEAP32[13784>>2] = $8;
  }
 }
 $9 = ($count|0)==(0);
 if ($9) {
  (_rl_backward_char(1,$key)|0);
  return 0;
 } else {
  $$01 = $count;
 }
 while(1) {
  $10 = (($$01) + -1)|0;
  (_rl_yank(1,$key)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   break;
  } else {
   $$01 = $10;
  }
 }
 (_rl_backward_char(1,$key)|0);
 return 0;
}
function _rl_vi_column($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13768>>2]|0;
 $1 = ($0|0)<($count|0);
 if ($1) {
  (_rl_end_of_line(1,$key)|0);
  return 0;
 } else {
  $2 = (($count) + -1)|0;
  HEAP32[13784>>2] = $2;
  return 0;
 }
 return (0)|0;
}
function _rl_vi_delete_to($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $r$0 = 0, $r$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(36)|0);
 HEAP32[$0>>2] = 1;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 16|0);
 HEAP32[$4>>2] = -1;
 $5 = HEAP32[13784>>2]|0;
 $6 = ((($0)) + 20|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[13768>>2]|0;
 $8 = ((($0)) + 24|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 28|0);
 HEAP32[$9>>2] = $key;
 $10 = ((($0)) + 32|0);
 HEAP32[$10>>2] = -1;
 HEAP32[14136>>2] = $0;
 $11 = HEAP32[13784>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $12;
 $13 = $key & 255;
 $14 = ($13|0)==($key|0);
 if ($14) {
  $15 = (_isupper($key)|0);
  $16 = ($15|0)==(0);
  if ($16) {
   label = 4;
  } else {
   $17 = HEAP32[14136>>2]|0;
   $18 = ((($17)) + 32|0);
   HEAP32[$18>>2] = 36;
   $19 = (_rl_domove_motion_callback($17)|0);
   $r$0 = $19;
   label = 13;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $20 = HEAP32[14304>>2]|0;
   $21 = ($20|0)!=(0);
   $22 = HEAP32[14264>>2]|0;
   $23 = ($22|0)!=(100);
   $or$cond = $21 & $23;
   if ($or$cond) {
    $24 = HEAP32[14136>>2]|0;
    $25 = ((($24)) + 32|0);
    HEAP32[$25>>2] = $22;
    $26 = (_rl_domove_motion_callback($24)|0);
    $r$0 = $26;
    label = 13;
    break;
   }
   if ($21) {
    $27 = HEAP32[14136>>2]|0;
    $28 = ((($27)) + 32|0);
    HEAP32[$28>>2] = $22;
    $29 = HEAP32[13768>>2]|0;
    HEAP32[13952>>2] = $29;
    (_rl_beg_of_line(1,$key)|0);
    $30 = HEAP32[13488>>2]|0;
    $31 = $30 & -1048577;
    HEAP32[13488>>2] = $31;
    $32 = HEAP32[14136>>2]|0;
    $33 = (_vidomove_dispatch($32)|0);
    $r$0 = $33;
    label = 13;
    break;
   }
   $34 = HEAP32[13488>>2]|0;
   $35 = $34 & 524288;
   $36 = ($35|0)==(0);
   if (!($36)) {
    $37 = $34 | 1048576;
    HEAP32[13488>>2] = $37;
    $$0 = 0;
    return ($$0|0);
   }
   $38 = HEAP32[14136>>2]|0;
   $39 = $34 | 64;
   HEAP32[13488>>2] = $39;
   $40 = (_rl_read_key()|0);
   $41 = HEAP32[13488>>2]|0;
   $42 = $41 & -65;
   HEAP32[13488>>2] = $42;
   $43 = ((($38)) + 32|0);
   HEAP32[$43>>2] = $40;
   $44 = ($40|0)<(0);
   if ($44) {
    HEAP32[$43>>2] = 0;
    label = 14;
    break;
   } else {
    $45 = (_rl_domove_read_callback($38)|0);
    $r$0 = $45;
    label = 13;
    break;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $46 = ($r$0|0)<(0);
  if ($46) {
   label = 14;
  } else {
   $r$1 = $r$0;
  }
 }
 if ((label|0) == 14) {
  (_rl_ding()|0);
  $r$1 = -1;
 }
 $47 = HEAP32[14136>>2]|0;
 _xfree($47);
 HEAP32[14136>>2] = 0;
 $$0 = $r$1;
 return ($$0|0);
}
function _rl_vi_change_to($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $r$0 = 0, $r$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(36)|0);
 HEAP32[$0>>2] = 2;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 16|0);
 HEAP32[$4>>2] = -1;
 $5 = HEAP32[13784>>2]|0;
 $6 = ((($0)) + 20|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[13768>>2]|0;
 $8 = ((($0)) + 24|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 28|0);
 HEAP32[$9>>2] = $key;
 $10 = ((($0)) + 32|0);
 HEAP32[$10>>2] = -1;
 HEAP32[14136>>2] = $0;
 $11 = HEAP32[13784>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $12;
 $13 = $key & 255;
 $14 = ($13|0)==($key|0);
 if ($14) {
  $15 = (_isupper($key)|0);
  $16 = ($15|0)==(0);
  if ($16) {
   label = 4;
  } else {
   $17 = HEAP32[14136>>2]|0;
   $18 = ((($17)) + 32|0);
   HEAP32[$18>>2] = 36;
   $19 = (_rl_domove_motion_callback($17)|0);
   $r$0 = $19;
   label = 13;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $20 = HEAP32[14304>>2]|0;
   $21 = ($20|0)!=(0);
   $22 = HEAP32[14264>>2]|0;
   $23 = ($22|0)!=(99);
   $or$cond = $21 & $23;
   if ($or$cond) {
    $24 = HEAP32[14136>>2]|0;
    $25 = ((($24)) + 32|0);
    HEAP32[$25>>2] = $22;
    $26 = (_rl_domove_motion_callback($24)|0);
    $r$0 = $26;
    label = 13;
    break;
   }
   if ($21) {
    $27 = HEAP32[14136>>2]|0;
    $28 = ((($27)) + 32|0);
    HEAP32[$28>>2] = $22;
    $29 = HEAP32[13768>>2]|0;
    HEAP32[13952>>2] = $29;
    (_rl_beg_of_line(1,$key)|0);
    $30 = HEAP32[13488>>2]|0;
    $31 = $30 & -1048577;
    HEAP32[13488>>2] = $31;
    $32 = HEAP32[14136>>2]|0;
    $33 = (_vidomove_dispatch($32)|0);
    $r$0 = $33;
    label = 13;
    break;
   }
   $34 = HEAP32[13488>>2]|0;
   $35 = $34 & 524288;
   $36 = ($35|0)==(0);
   if (!($36)) {
    $37 = $34 | 1048576;
    HEAP32[13488>>2] = $37;
    $$0 = 0;
    return ($$0|0);
   }
   $38 = HEAP32[14136>>2]|0;
   $39 = $34 | 64;
   HEAP32[13488>>2] = $39;
   $40 = (_rl_read_key()|0);
   $41 = HEAP32[13488>>2]|0;
   $42 = $41 & -65;
   HEAP32[13488>>2] = $42;
   $43 = ((($38)) + 32|0);
   HEAP32[$43>>2] = $40;
   $44 = ($40|0)<(0);
   if ($44) {
    HEAP32[$43>>2] = 0;
    label = 14;
    break;
   } else {
    $45 = (_rl_domove_read_callback($38)|0);
    $r$0 = $45;
    label = 13;
    break;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $46 = ($r$0|0)<(0);
  if ($46) {
   label = 14;
  } else {
   $r$1 = $r$0;
  }
 }
 if ((label|0) == 14) {
  (_rl_ding()|0);
  $r$1 = -1;
 }
 $47 = HEAP32[14136>>2]|0;
 _xfree($47);
 HEAP32[14136>>2] = 0;
 $$0 = $r$1;
 return ($$0|0);
}
function _rl_vi_yank_to($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $r$0 = 0, $r$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(36)|0);
 HEAP32[$0>>2] = 4;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 $3 = ((($0)) + 12|0);
 HEAP32[$3>>2] = 0;
 $4 = ((($0)) + 16|0);
 HEAP32[$4>>2] = -1;
 $5 = HEAP32[13784>>2]|0;
 $6 = ((($0)) + 20|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[13768>>2]|0;
 $8 = ((($0)) + 24|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 28|0);
 HEAP32[$9>>2] = $key;
 $10 = ((($0)) + 32|0);
 HEAP32[$10>>2] = -1;
 HEAP32[14136>>2] = $0;
 $11 = HEAP32[13784>>2]|0;
 HEAP32[$6>>2] = $11;
 $12 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $12;
 $13 = $key & 255;
 $14 = ($13|0)==($key|0);
 if ($14) {
  $15 = (_isupper($key)|0);
  $16 = ($15|0)==(0);
  if ($16) {
   label = 4;
  } else {
   $17 = HEAP32[14136>>2]|0;
   $18 = ((($17)) + 32|0);
   HEAP32[$18>>2] = 36;
   $19 = (_rl_domove_motion_callback($17)|0);
   $r$0 = $19;
   label = 13;
  }
 } else {
  label = 4;
 }
 do {
  if ((label|0) == 4) {
   $20 = HEAP32[14304>>2]|0;
   $21 = ($20|0)!=(0);
   $22 = HEAP32[14264>>2]|0;
   $23 = ($22|0)!=(121);
   $or$cond = $21 & $23;
   if ($or$cond) {
    $24 = HEAP32[14136>>2]|0;
    $25 = ((($24)) + 32|0);
    HEAP32[$25>>2] = $22;
    $26 = (_rl_domove_motion_callback($24)|0);
    $r$0 = $26;
    label = 13;
    break;
   }
   if ($21) {
    $27 = HEAP32[14136>>2]|0;
    $28 = ((($27)) + 32|0);
    HEAP32[$28>>2] = $22;
    $29 = HEAP32[13768>>2]|0;
    HEAP32[13952>>2] = $29;
    (_rl_beg_of_line(1,$key)|0);
    $30 = HEAP32[13488>>2]|0;
    $31 = $30 & -1048577;
    HEAP32[13488>>2] = $31;
    $32 = HEAP32[14136>>2]|0;
    $33 = (_vidomove_dispatch($32)|0);
    $r$0 = $33;
    label = 13;
    break;
   }
   $34 = HEAP32[13488>>2]|0;
   $35 = $34 & 524288;
   $36 = ($35|0)==(0);
   if (!($36)) {
    $37 = $34 | 1048576;
    HEAP32[13488>>2] = $37;
    $$0 = 0;
    return ($$0|0);
   }
   $38 = HEAP32[14136>>2]|0;
   $39 = $34 | 64;
   HEAP32[13488>>2] = $39;
   $40 = (_rl_read_key()|0);
   $41 = HEAP32[13488>>2]|0;
   $42 = $41 & -65;
   HEAP32[13488>>2] = $42;
   $43 = ((($38)) + 32|0);
   HEAP32[$43>>2] = $40;
   $44 = ($40|0)<(0);
   if ($44) {
    HEAP32[$43>>2] = 0;
    label = 14;
    break;
   } else {
    $45 = (_rl_domove_read_callback($38)|0);
    $r$0 = $45;
    label = 13;
    break;
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $46 = ($r$0|0)<(0);
  if ($46) {
   label = 14;
  } else {
   $r$1 = $r$0;
  }
 }
 if ((label|0) == 14) {
  (_rl_ding()|0);
  $r$1 = -1;
 }
 $47 = HEAP32[14136>>2]|0;
 _xfree($47);
 HEAP32[14136>>2] = 0;
 $$0 = $r$1;
 return ($$0|0);
}
function _rl_vi_rubout($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = (_rl_vi_delete($1,$key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $5 = ($count|0)>(1);
 $6 = HEAP32[36240>>2]|0;
 $7 = ($6|0)==(0);
 $or$cond = $5 & $7;
 do {
  if ($or$cond) {
   (_rl_backward_char($count,$key)|0);
   $$pr = HEAP32[13784>>2]|0;
   $12 = $$pr;
  } else {
   if ($7) {
    $8 = HEAP32[13632>>2]|0;
    $9 = (__rl_find_prev_mbchar($8,$3,1)|0);
    HEAP32[13784>>2] = $9;
    $12 = $9;
    break;
   } else {
    $10 = (($3) - ($count))|0;
    HEAP32[13784>>2] = $10;
    $12 = $10;
    break;
   }
  }
 } while(0);
 $11 = ($12|0)<(0);
 if ($11) {
  HEAP32[13784>>2] = 0;
  $13 = 0;
 } else {
  $13 = $12;
 }
 (_rl_kill_text($13,$3)|0);
 $$0 = 0;
 return ($$0|0);
}
function _rl_vi_back_to_indent($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_beg_of_line(1,$key)|0);
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 if (!($2)) {
  return 0;
 }
 $$pre = HEAP32[13632>>2]|0;
 $4 = $0;
 while(1) {
  $3 = (($$pre) + ($4)|0);
  $5 = HEAP8[$3>>0]|0;
  if (!((($5<<24>>24) == 9) | (($5<<24>>24) == 32))) {
   label = 5;
   break;
  }
  $6 = (($4) + 1)|0;
  HEAP32[13784>>2] = $6;
  $7 = ($6|0)<($1|0);
  if ($7) {
   $4 = $6;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_first_print($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pre$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_beg_of_line(1,$key)|0);
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)<($1|0);
 if (!($2)) {
  return 0;
 }
 $$pre$i = HEAP32[13632>>2]|0;
 $4 = $0;
 while(1) {
  $3 = (($$pre$i) + ($4)|0);
  $5 = HEAP8[$3>>0]|0;
  if (!((($5<<24>>24) == 9) | (($5<<24>>24) == 32))) {
   label = 5;
   break;
  }
  $6 = (($4) + 1)|0;
  HEAP32[13784>>2] = $6;
  $7 = ($6|0)<($1|0);
  if ($7) {
   $4 = $6;
  } else {
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  return 0;
 }
 return (0)|0;
}
function _rl_vi_char_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($key|0)==(59);
 L1: do {
  switch ($key|0) {
  case 116:  {
   HEAP32[14360>>2] = 1;
   HEAP32[14344>>2] = 1;
   label = 8;
   break;
  }
  case 44: case 59:  {
   $1 = HEAP32[14344>>2]|0;
   $2 = ($1|0)==(0);
   $3 = HEAP32[14352>>2]|0;
   $4 = ($3|0)==(0);
   $or$cond = $2 | $4;
   if ($or$cond) {
    $$0 = -1;
    return ($$0|0);
   } else {
    $5 = (0 - ($1))|0;
    $6 = $0 ? $1 : $5;
    HEAP32[14360>>2] = $6;
    $18 = $3;
    break L1;
   }
   break;
  }
  case 70:  {
   HEAP32[14360>>2] = -2;
   HEAP32[14344>>2] = -2;
   label = 8;
   break;
  }
  case 84:  {
   HEAP32[14360>>2] = -1;
   HEAP32[14344>>2] = -1;
   label = 8;
   break;
  }
  case 102:  {
   HEAP32[14360>>2] = 2;
   HEAP32[14344>>2] = 2;
   label = 8;
   break;
  }
  default: {
   label = 8;
  }
  }
 } while(0);
 do {
  if ((label|0) == 8) {
   $7 = HEAP32[14304>>2]|0;
   $8 = ($7|0)==(0);
   if (!($8)) {
    $$pre = HEAP32[14352>>2]|0;
    $18 = $$pre;
    break;
   }
   $9 = HEAP32[13488>>2]|0;
   $10 = $9 & 524288;
   $11 = ($10|0)==(0);
   if (!($11)) {
    $12 = (__rl_callback_data_alloc($count)|0);
    HEAP32[35064>>2] = $12;
    $13 = HEAP32[14360>>2]|0;
    $14 = ((($12)) + 4|0);
    HEAP32[$14>>2] = $13;
    HEAP32[35056>>2] = 360;
    $$0 = 0;
    return ($$0|0);
   }
   $15 = (__rl_read_mbchar(14368,16)|0);
   $16 = ($15|0)<(1);
   if ($16) {
    $$0 = -1;
    return ($$0|0);
   } else {
    HEAP32[14352>>2] = $15;
    $18 = $15;
    break;
   }
  }
 } while(0);
 HEAP32[14384>>2] = 14368;
 $17 = HEAP32[14360>>2]|0;
 $19 = (__rl_char_search_internal($count,$17,14368,$18)|0);
 $$0 = $19;
 return ($$0|0);
}
function _rl_vi_match($ignore,$key) {
 $ignore = $ignore|0;
 $key = $key|0;
 var $$ = 0, $$0 = 0, $$0$i$ph$ph = 0, $$0$i1 = 0, $$0$i3 = 0, $$0$i315 = 0, $$count$0 = 0, $$lcssa = 0, $$lcssa107 = 0, $$lcssa108 = 0, $$lcssa111 = 0, $$lcssa112 = 0, $$lcssa115 = 0, $$lcssa116 = 0, $$lcssa119 = 0, $$phi$trans$insert = 0, $$phi$trans$insert38 = 0, $$pre = 0, $$pre35 = 0, $$pre36 = 0;
 var $$pre37 = 0, $$pre39 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brack$19$ph = 0, $count$0$be = 0, $count$032 = 0;
 var $count$1$be = 0, $count$1$be$v = 0, $count$130 = 0, $pos$031 = 0, $pos$1 = 0, $pos$2$ph = 0, $pos$229 = 0, $pos$3 = 0, $pos$4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13632>>2]|0;
 $2 = (($1) + ($0)|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = $3 << 24 >> 24;
 L1: do {
  switch ($4|0) {
  case 123:  {
   $52 = $1;$brack$19$ph = 3;$pos$2$ph = $0;
   label = 19;
   break;
  }
  case 91:  {
   $52 = $1;$brack$19$ph = 2;$pos$2$ph = $0;
   label = 19;
   break;
  }
  case 93:  {
   $$0$i$ph$ph = -2;
   label = 14;
   break;
  }
  case 41:  {
   $$0$i$ph$ph = -1;
   label = 14;
   break;
  }
  case 125:  {
   $$0$i$ph$ph = -3;
   label = 14;
   break;
  }
  case 40:  {
   $52 = $1;$brack$19$ph = 1;$pos$2$ph = $0;
   label = 19;
   break;
  }
  default: {
   $5 = HEAP32[36240>>2]|0;
   $6 = ($5|0)==(0);
   L7: do {
    if ($6) {
     $11 = $0;$53 = $1;$8 = $3;
     L15: while(1) {
      $7 = $8 << 24 >> 24;
      switch ($7|0) {
      case 125: case 93: case 41:  {
       break L7;
       break;
      }
      case 123:  {
       $$lcssa107 = $53;$$lcssa111 = $11;
       label = 15;
       break L15;
       break;
      }
      case 91:  {
       $52 = $53;$brack$19$ph = 2;$pos$2$ph = $11;
       label = 19;
       break L1;
       break;
      }
      case 40:  {
       $$lcssa = $53;$$lcssa108 = $11;
       label = 17;
       break L15;
       break;
      }
      default: {
      }
      }
      (_rl_forward_char(1,$key)|0);
      $9 = HEAP32[13784>>2]|0;
      $10 = ($11|0)==($9|0);
      if ($10) {
       break L7;
      }
      $$pre37 = HEAP32[13632>>2]|0;
      $$phi$trans$insert38 = (($$pre37) + ($9)|0);
      $$pre39 = HEAP8[$$phi$trans$insert38>>0]|0;
      $11 = $9;$53 = $$pre37;$8 = $$pre39;
     }
     if ((label|0) == 15) {
      $52 = $$lcssa107;$brack$19$ph = 3;$pos$2$ph = $$lcssa111;
      label = 19;
      break L1;
     }
     else if ((label|0) == 17) {
      $52 = $$lcssa;$brack$19$ph = 1;$pos$2$ph = $$lcssa108;
      label = 19;
      break L1;
     }
    } else {
     $13 = $3;$17 = $0;$54 = $1;
     L8: while(1) {
      $12 = $13 << 24 >> 24;
      switch ($12|0) {
      case 125: case 93: case 41:  {
       break L7;
       break;
      }
      case 40:  {
       $$lcssa112 = $54;$$lcssa116 = $17;
       label = 18;
       break L8;
       break;
      }
      case 91:  {
       $52 = $54;$brack$19$ph = 2;$pos$2$ph = $17;
       label = 19;
       break L1;
       break;
      }
      case 123:  {
       $$lcssa115 = $54;$$lcssa119 = $17;
       label = 16;
       break L8;
       break;
      }
      default: {
      }
      }
      $14 = HEAP32[13768>>2]|0;
      $15 = (($14) + -1)|0;
      $16 = ($17|0)<($15|0);
      if (!($16)) {
       break L7;
      }
      (_rl_forward_char(1,$key)|0);
      $$pre = HEAP32[13784>>2]|0;
      $$pre35 = HEAP32[13632>>2]|0;
      $$phi$trans$insert = (($$pre35) + ($$pre)|0);
      $$pre36 = HEAP8[$$phi$trans$insert>>0]|0;
      $13 = $$pre36;$17 = $$pre;$54 = $$pre35;
     }
     if ((label|0) == 16) {
      $52 = $$lcssa115;$brack$19$ph = 3;$pos$2$ph = $$lcssa119;
      label = 19;
      break L1;
     }
     else if ((label|0) == 18) {
      $52 = $$lcssa112;$brack$19$ph = 1;$pos$2$ph = $$lcssa116;
      label = 19;
      break L1;
     }
    }
   } while(0);
   HEAP32[13784>>2] = $0;
   (_rl_ding()|0);
   $$0 = -1;
   return ($$0|0);
  }
  }
 } while(0);
 L24: do {
  if ((label|0) == 14) {
   $18 = (0 - ($$0$i$ph$ph))|0;
   $23 = $1;$count$032 = 1;$pos$031 = $0;
   while(1) {
    $20 = HEAP32[36240>>2]|0;
    $21 = ($20|0)==(0);
    if ($21) {
     $24 = (__rl_find_prev_mbchar($23,$pos$031,0)|0);
     $25 = ($pos$031|0)==($24|0);
     $26 = $25 << 31 >> 31;
     $$ = (($26) + ($24))|0;
     $pos$1 = $$;
    } else {
     $22 = (($pos$031) + -1)|0;
     $pos$1 = $22;
    }
    $27 = ($pos$1|0)>(-1);
    if (!($27)) {
     break;
    }
    $28 = HEAP32[13632>>2]|0;
    $29 = (($28) + ($pos$1)|0);
    $30 = HEAP8[$29>>0]|0;
    $31 = $30 << 24 >> 24;
    switch ($31|0) {
    case 93:  {
     $$0$i315 = -2;
     label = 33;
     break;
    }
    case 125:  {
     $$0$i315 = -3;
     label = 33;
     break;
    }
    case 91:  {
     $$0$i3 = 2;
     label = 30;
     break;
    }
    case 40:  {
     $$0$i3 = 1;
     label = 30;
     break;
    }
    case 123:  {
     $$0$i3 = 3;
     label = 30;
     break;
    }
    case 41:  {
     $$0$i315 = -1;
     label = 33;
     break;
    }
    default: {
     $$0$i3 = 0;
     label = 30;
    }
    }
    if ((label|0) == 30) {
     label = 0;
     $32 = ($$0$i3|0)==($18|0);
     if ($32) {
      $33 = (($count$032) + -1)|0;
      $count$0$be = $33;
     } else {
      $$0$i315 = $$0$i3;
      label = 33;
     }
    }
    if ((label|0) == 33) {
     label = 0;
     $35 = ($$0$i315|0)==($$0$i$ph$ph|0);
     $36 = $35&1;
     $$count$0 = (($36) + ($count$032))|0;
     $count$0$be = $$count$0;
    }
    $34 = ($count$0$be|0)==(0);
    if ($34) {
     $pos$4 = $pos$1;
     break L24;
    } else {
     $23 = $28;$count$032 = $count$0$be;$pos$031 = $pos$1;
    }
   }
   (_rl_ding()|0);
   $$0 = -1;
   return ($$0|0);
  }
  else if ((label|0) == 19) {
   $19 = (0 - ($brack$19$ph))|0;
   $40 = $52;$count$130 = 1;$pos$229 = $pos$2$ph;
   while(1) {
    $37 = HEAP32[36240>>2]|0;
    $38 = ($37|0)==(0);
    if ($38) {
     $41 = (__rl_find_next_mbchar($40,$pos$229,1,0)|0);
     $pos$3 = $41;
    } else {
     $39 = (($pos$229) + 1)|0;
     $pos$3 = $39;
    }
    $42 = HEAP32[13768>>2]|0;
    $43 = ($pos$3|0)<($42|0);
    if (!($43)) {
     break;
    }
    $44 = HEAP32[13632>>2]|0;
    $45 = (($44) + ($pos$3)|0);
    $46 = HEAP8[$45>>0]|0;
    $47 = $46 << 24 >> 24;
    switch ($47|0) {
    case 41:  {
     $$0$i1 = -1;
     break;
    }
    case 91:  {
     $$0$i1 = 2;
     break;
    }
    case 93:  {
     $$0$i1 = -2;
     break;
    }
    case 40:  {
     $$0$i1 = 1;
     break;
    }
    case 123:  {
     $$0$i1 = 3;
     break;
    }
    case 125:  {
     $$0$i1 = -3;
     break;
    }
    default: {
     $$0$i1 = 0;
    }
    }
    $48 = ($$0$i1|0)==($19|0);
    $49 = ($$0$i1|0)==($brack$19$ph|0);
    $50 = $49&1;
    $count$1$be$v = $48 ? -1 : $50;
    $count$1$be = (($count$130) + ($count$1$be$v))|0;
    $51 = ($count$1$be|0)==(0);
    if ($51) {
     $pos$4 = $pos$3;
     break L24;
    } else {
     $40 = $44;$count$130 = $count$1$be;$pos$229 = $pos$3;
    }
   }
   (_rl_ding()|0);
   $$0 = -1;
   return ($$0|0);
  }
 } while(0);
 HEAP32[13784>>2] = $pos$4;
 $$0 = 0;
 return ($$0|0);
}
function _rl_vi_change_char($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $c$0 = 0, $mb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mb = sp;
 $0 = HEAP32[14304>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $5 = HEAP32[13488>>2]|0;
  $6 = $5 & 524288;
  $7 = ($6|0)==(0);
  if (!($7)) {
   $8 = (__rl_callback_data_alloc($count)|0);
   HEAP32[35064>>2] = $8;
   HEAP32[35056>>2] = 361;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $9 = $5 | 64;
  HEAP32[13488>>2] = $9;
  $10 = (_rl_read_key()|0);
  $11 = HEAP32[13488>>2]|0;
  $12 = $11 & -65;
  HEAP32[13488>>2] = $12;
  $13 = ($10|0)<(0);
  if ($13) {
   $$0$i = -1;
  } else {
   $14 = HEAP32[36240>>2]|0;
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = (__rl_read_mbstring($10,$mb,16)|0);
    $$0$i = $16;
   } else {
    $$0$i = $10;
   }
  }
  HEAP32[14392>>2] = $$0$i;
  $c$0 = $$0$i;
 } else {
  $2 = HEAP32[14392>>2]|0;
  $3 = $2&255;
  HEAP8[$mb>>0] = $3;
  $4 = ((($mb)) + 1|0);
  HEAP8[$4>>0] = 0;
  $c$0 = $2;
 }
 $17 = ($c$0|0)<(0);
 if ($17) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $18 = (__rl_vi_change_char($count,$c$0,$mb)|0);
 $$0 = $18;
 STACKTOP = sp;return ($$0|0);
}
function _rl_vi_subst($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14304>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = ($key|0)==(83);
  $3 = $2 ? 99 : 108;
  (_rl_stuff_char($3)|0);
 }
 $4 = (_rl_vi_change_to(0,99)|0);
 return ($4|0);
}
function _rl_vi_overstrike($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14320>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP32[14320>>2] = 1;
  (_rl_begin_undo_group()|0);
 }
 $2 = ($count|0)>(0);
 if (!($2)) {
  return 0;
 }
 (__rl_overwrite_char($count,$key)|0);
 $3 = HEAP32[14328>>2]|0;
 $4 = (($3) + ($count))|0;
 HEAP32[14328>>2] = $4;
 return 0;
}
function _rl_vi_overstrike_delete($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)>(0);
 L1: do {
  if ($0) {
   $i$02 = 0;
   while(1) {
    $1 = HEAP32[14328>>2]|0;
    $2 = ($1|0)==(0);
    if ($2) {
     break;
    }
    $3 = HEAP32[13784>>2]|0;
    $4 = (_rl_do_undo()|0);
    $5 = ($4|0)==(0);
    if (!($5)) {
     $6 = HEAP32[14328>>2]|0;
     $7 = (($6) + -1)|0;
     HEAP32[14328>>2] = $7;
    }
    $8 = HEAP32[13784>>2]|0;
    $9 = ($8|0)==($3|0);
    if ($9) {
     (_rl_backward_char(1,$key)|0);
    }
    $10 = (($i$02) + 1)|0;
    $11 = ($10|0)<($count|0);
    if ($11) {
     $i$02 = $10;
    } else {
     break L1;
    }
   }
   (_rl_ding()|0);
  }
 } while(0);
 $12 = HEAP32[14328>>2]|0;
 $13 = ($12|0)==(0);
 $14 = HEAP32[14320>>2]|0;
 $15 = ($14|0)!=(0);
 $or$cond = $13 & $15;
 if (!($or$cond)) {
  return 0;
 }
 (_rl_end_undo_group()|0);
 (_rl_do_undo()|0);
 HEAP32[14320>>2] = 0;
 return 0;
}
function _rl_vi_replace($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond4 = 0, $i$03 = 0, $i$12 = 0, $or$cond = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 HEAP32[14328>>2] = 0;
 $0 = HEAP32[14400>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_rl_make_bare_keymap()|0);
  HEAP32[14400>>2] = $2;
  $i$03 = 0;
  while(1) {
   $4 = (26464 + ($i$03<<3)|0);
   $5 = HEAP8[$4>>0]|0;
   $6 = ($5<<24>>24)==(0);
   if ($6) {
    $7 = (((26464 + ($i$03<<3)|0)) + 4|0);
    $8 = HEAP32[$7>>2]|0;
    $9 = HEAP32[14400>>2]|0;
    $10 = (((($9) + ($i$03<<3)|0)) + 4|0);
    HEAP32[$10>>2] = $8;
   }
   $11 = (($i$03) + 1)|0;
   $exitcond4 = ($11|0)==(32);
   if ($exitcond4) {
    break;
   } else {
    $i$03 = $11;
   }
  }
  $3 = HEAP32[14400>>2]|0;
  $13 = $3;$i$12 = 32;
  while(1) {
   $12 = (((($13) + ($i$12<<3)|0)) + 4|0);
   HEAP32[$12>>2] = 263;
   $14 = (($i$12) + 1)|0;
   $15 = HEAP32[14400>>2]|0;
   $exitcond = ($14|0)==(257);
   if ($exitcond) {
    $$lcssa = $15;
    break;
   } else {
    $13 = $15;$i$12 = $14;
   }
  }
  $16 = ((($$lcssa)) + 1020|0);
  HEAP32[$16>>2] = 264;
  $17 = HEAP32[14400>>2]|0;
  $18 = ((($17)) + 220|0);
  HEAP32[$18>>2] = 261;
  $19 = HEAP32[14400>>2]|0;
  $20 = ((($19)) + 108|0);
  HEAP32[$20>>2] = 150;
  $21 = HEAP32[14400>>2]|0;
  $22 = ((($21)) + 84|0);
  HEAP32[$22>>2] = 150;
  $23 = HEAP8[(26528)>>0]|0;
  $24 = ($23<<24>>24)==(0);
  $25 = HEAP32[(26532)>>2]|0;
  $26 = ($25|0)==(154|0);
  $or$cond = $24 & $26;
  if ($or$cond) {
   $27 = HEAP32[14400>>2]|0;
   $28 = ((($27)) + 68|0);
   HEAP32[$28>>2] = 264;
  }
 }
 $29 = HEAP32[13480>>2]|0;
 HEAP32[14128>>2] = $key;
 HEAP32[14248>>2] = 1;
 HEAP32[14256>>2] = $29;
 HEAP32[13432>>2] = 26464;
 HEAP32[14272>>2] = $key;
 $30 = HEAP32[13728>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  HEAP32[14272>>2] = $key;
  $32 = HEAP32[14400>>2]|0;
  HEAP32[3358] = $32;
  return 0;
 }
 __rl_reset_prompt();
 HEAP32[14272>>2] = $key;
 $32 = HEAP32[14400>>2]|0;
 HEAP32[3358] = $32;
 return 0;
}
function _rl_vi_set_mark($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$off$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 524288;
 $2 = ($1|0)==(0);
 if (!($2)) {
  HEAP32[35064>>2] = 0;
  HEAP32[35056>>2] = 362;
  $$0 = 0;
  return ($$0|0);
 }
 $3 = $0 | 64;
 HEAP32[13488>>2] = $3;
 $4 = (_rl_read_key()|0);
 $5 = HEAP32[13488>>2]|0;
 $6 = $5 & -65;
 HEAP32[13488>>2] = $6;
 $$off$i = (($4) + -97)|0;
 $7 = ($$off$i>>>0)>(25);
 if ($7) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 } else {
  $8 = HEAP32[13784>>2]|0;
  $9 = (14144 + ($$off$i<<2)|0);
  HEAP32[$9>>2] = $8;
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_vi_goto_mark($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 524288;
 $2 = ($1|0)==(0);
 if (!($2)) {
  HEAP32[35064>>2] = 0;
  HEAP32[35056>>2] = 363;
  $$0 = 0;
  return ($$0|0);
 }
 $3 = $0 | 64;
 HEAP32[13488>>2] = $3;
 $4 = (_rl_read_key()|0);
 $5 = HEAP32[13488>>2]|0;
 $6 = $5 & -65;
 HEAP32[13488>>2] = $6;
 $7 = ($4|0)==(96);
 if ($7) {
  $8 = HEAP32[13952>>2]|0;
  HEAP32[13784>>2] = $8;
  $$0 = 0;
  return ($$0|0);
 }
 $$off$i = (($4) + -97)|0;
 $9 = ($$off$i>>>0)>(25);
 if ($9) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $10 = (14144 + ($$off$i<<2)|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = ($11|0)==(-1);
 if ($12) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 } else {
  HEAP32[13784>>2] = $11;
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_domove_read_callback($m) {
 $m = $m|0;
 var $$0 = 0, $$lcssa = 0, $$off = 0, $$off$i = 0, $$off$i$i = 0, $$off$i19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $memchr = 0, $storemerge$i = 0, $storemerge$i$i = 0, $storemerge$i20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($m)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $memchr = (_memchr(14496,$1,22)|0);
  $3 = ($memchr|0)==(0|0);
  if (!($3)) {
   $4 = HEAP32[13488>>2]|0;
   $5 = $4 & 1573888;
   $6 = ($5|0)==(1573888);
   if ($6) {
    $7 = $4 & -1025;
    HEAP32[13488>>2] = $7;
   }
   $8 = (_rl_domove_motion_callback($m)|0);
   $$0 = $8;
   return ($$0|0);
  }
 }
 $9 = ((($m)) + 28|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==($1|0);
 if ($11) {
  if ((($1|0) == 99) | (($1|0) == 121) | (($1|0) == 100)) {
   $12 = HEAP32[13768>>2]|0;
   HEAP32[13952>>2] = $12;
   (_rl_beg_of_line(1,$1)|0);
   HEAP32[14264>>2] = $1;
   $13 = HEAP32[13488>>2]|0;
   $14 = $13 & -1048577;
   HEAP32[13488>>2] = $14;
   $15 = (_vidomove_dispatch($m)|0);
   $$0 = $15;
   return ($$0|0);
  }
 }
 $$off = (($1) + -48)|0;
 $16 = ($$off>>>0)<(10);
 $17 = HEAP32[13488>>2]|0;
 if (!($16)) {
  $87 = $17 & -1049601;
  HEAP32[13488>>2] = $87;
  $$0 = 1;
  return ($$0|0);
 }
 $18 = $17 & 1573888;
 if ((($18|0) == 1572864)) {
  $35 = $17 | 1024;
  HEAP32[13488>>2] = $35;
  $36 = HEAP32[13432>>2]|0;
  $37 = (($36) + ($1<<3)|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $40 = (((($36) + ($1<<3)|0)) + 4|0);
   $41 = HEAP32[$40>>2]|0;
   $42 = ($41|0)==(225|0);
   if ($42) {
    $43 = HEAP32[13464>>2]|0;
    $44 = $43 << 2;
    HEAP32[13464>>2] = $44;
    $$0 = 1;
    return ($$0|0);
   }
  }
  $45 = $1 & -129;
  $$off$i19 = (($45) + -48)|0;
  $46 = ($$off$i19>>>0)<(10);
  if (!($46)) {
   (_rl_clear_message()|0);
   (_rl_stuff_char($1)|0);
   $$0 = 0;
   return ($$0|0);
  }
  $47 = HEAP32[13472>>2]|0;
  $48 = ($47|0)==(0);
  if ($48) {
   $storemerge$i20 = $$off$i19;
  } else {
   $49 = HEAP32[13464>>2]|0;
   $50 = ($49*10)|0;
   $51 = (($50) + ($$off$i19))|0;
   $storemerge$i20 = $51;
  }
  HEAP32[13464>>2] = $storemerge$i20;
  HEAP32[13472>>2] = 1;
  $$0 = 1;
  return ($$0|0);
 } else if ((($18|0) == 1573888)) {
  $19 = HEAP32[13432>>2]|0;
  $20 = (($19) + ($1<<3)|0);
  $21 = HEAP8[$20>>0]|0;
  $22 = ($21<<24>>24)==(0);
  if ($22) {
   $23 = (((($19) + ($1<<3)|0)) + 4|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = ($24|0)==(225|0);
   if ($25) {
    $26 = HEAP32[13464>>2]|0;
    $27 = $26 << 2;
    HEAP32[13464>>2] = $27;
    $$0 = 1;
    return ($$0|0);
   }
  }
  $28 = $1 & -129;
  $$off$i = (($28) + -48)|0;
  $29 = ($$off$i>>>0)<(10);
  if (!($29)) {
   (_rl_clear_message()|0);
   (_rl_stuff_char($1)|0);
   $$0 = 0;
   return ($$0|0);
  }
  $30 = HEAP32[13472>>2]|0;
  $31 = ($30|0)==(0);
  if ($31) {
   $storemerge$i = $$off$i;
  } else {
   $32 = HEAP32[13464>>2]|0;
   $33 = ($32*10)|0;
   $34 = (($33) + ($$off$i))|0;
   $storemerge$i = $34;
  }
  HEAP32[13464>>2] = $storemerge$i;
  HEAP32[13472>>2] = 1;
  $$0 = 1;
  return ($$0|0);
 } else {
  $52 = HEAP32[13464>>2]|0;
  HEAP32[13464>>2] = $$off;
  HEAP32[13472>>2] = 1;
  $53 = $17 | 1024;
  HEAP32[13488>>2] = $53;
  $54 = (__rl_arg_overflow()|0);
  $55 = ($54|0)==(0);
  L48: do {
   if ($55) {
    while(1) {
     $56 = (__rl_arg_getchar()|0);
     $57 = ($56|0)>(-1);
     if ($57) {
      $58 = HEAP32[13432>>2]|0;
      $59 = (($58) + ($56<<3)|0);
      $60 = HEAP8[$59>>0]|0;
      $61 = ($60<<24>>24)==(0);
      if ($61) {
       $62 = (((($58) + ($56<<3)|0)) + 4|0);
       $63 = HEAP32[$62>>2]|0;
       $64 = ($63|0)==(225|0);
       if ($64) {
        $65 = HEAP32[13464>>2]|0;
        $66 = $65 << 2;
        HEAP32[13464>>2] = $66;
       } else {
        label = 33;
       }
      } else {
       label = 33;
      }
     } else {
      label = 33;
     }
     if ((label|0) == 33) {
      label = 0;
      $69 = $56 & -129;
      $$off$i$i = (($69) + -48)|0;
      $70 = ($$off$i$i>>>0)<(10);
      if (!($70)) {
       $$lcssa = $56;
       break;
      }
      $71 = HEAP32[13472>>2]|0;
      $72 = ($71|0)==(0);
      if ($72) {
       $storemerge$i$i = $$off$i$i;
      } else {
       $73 = HEAP32[13464>>2]|0;
       $74 = ($73*10)|0;
       $75 = (($74) + ($$off$i$i))|0;
       $storemerge$i$i = $75;
      }
      HEAP32[13464>>2] = $storemerge$i$i;
      HEAP32[13472>>2] = 1;
     }
     $67 = (__rl_arg_overflow()|0);
     $68 = ($67|0)==(0);
     if (!($68)) {
      break L48;
     }
    }
    (_rl_clear_message()|0);
    (_rl_stuff_char($$lcssa)|0);
    $76 = HEAP32[13488>>2]|0;
    $77 = $76 & -1025;
    HEAP32[13488>>2] = $77;
   }
  } while(0);
  $78 = HEAP32[13464>>2]|0;
  $79 = Math_imul($78, $52)|0;
  HEAP32[13464>>2] = $79;
  $80 = HEAP32[13488>>2]|0;
  $81 = $80 | 64;
  HEAP32[13488>>2] = $81;
  $82 = (_rl_read_key()|0);
  $83 = HEAP32[13488>>2]|0;
  $84 = $83 & -65;
  HEAP32[13488>>2] = $84;
  $85 = ($82|0)<(0);
  if ($85) {
   HEAP32[$0>>2] = 0;
   $$0 = -1;
   return ($$0|0);
  } else {
   HEAP32[$0>>2] = $82;
   $86 = (_rl_domove_motion_callback($m)|0);
   $$0 = $86;
   return ($$0|0);
  }
 }
 return (0)|0;
}
function _rl_domove_motion_callback($m) {
 $m = $m|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($m)) + 32|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[14264>>2] = $1;
 $2 = HEAP32[13768>>2]|0;
 $3 = (($2) + 1)|0;
 HEAP32[13768>>2] = $3;
 $4 = HEAP32[13632>>2]|0;
 $5 = (($4) + ($2)|0);
 HEAP8[$5>>0] = 32;
 $6 = HEAP32[13768>>2]|0;
 $7 = HEAP32[13632>>2]|0;
 $8 = (($7) + ($6)|0);
 HEAP8[$8>>0] = 0;
 $9 = HEAP32[13432>>2]|0;
 (__rl_dispatch($1,$9)|0);
 HEAP32[13768>>2] = $2;
 $10 = HEAP32[13632>>2]|0;
 $11 = (($10) + ($2)|0);
 HEAP8[$11>>0] = 0;
 $12 = HEAP32[13784>>2]|0;
 $13 = HEAP32[13768>>2]|0;
 $14 = ($12|0)>($13|0);
 if ($14) {
  HEAP32[13784>>2] = $13;
  $17 = $13;
 } else {
  $17 = $12;
 }
 $15 = HEAP32[13952>>2]|0;
 $16 = ($15|0)==($17|0);
 if ($16) {
  $$0 = -1;
  return ($$0|0);
 }
 $18 = $1 & 255;
 $19 = ($18|0)==($1|0);
 if ($19) {
  $20 = (_islower($1)|0);
  $21 = ($20|0)==(0);
  if ($21) {
   $24 = $1;
  } else {
   $22 = (_toupper($1)|0);
   $24 = $22;
  }
 } else {
  $24 = $1;
 }
 $23 = ($24|0)==(87);
 if ($23) {
  $25 = HEAP32[13784>>2]|0;
  $26 = HEAP32[13768>>2]|0;
  $27 = ($25|0)<($26|0);
  $28 = HEAP32[13952>>2]|0;
  $29 = ($25|0)>($28|0);
  $or$cond = $27 & $29;
  if ($or$cond) {
   $30 = HEAP32[13632>>2]|0;
   $31 = (($30) + ($25)|0);
   $32 = HEAP8[$31>>0]|0;
   if (!((($32<<24>>24) == 9) | (($32<<24>>24) == 32))) {
    $33 = (($25) + -1)|0;
    HEAP32[13784>>2] = $33;
   }
  }
 }
 $34 = ((($m)) + 28|0);
 $35 = HEAP32[$34>>2]|0;
 $36 = ($35|0)==(99);
 do {
  if ($36) {
   $37 = HEAP32[13784>>2]|0;
   $38 = HEAP32[13952>>2]|0;
   $39 = ($37|0)<($38|0);
   if (!($39)) {
    if ($19) {
     $40 = (_islower($1)|0);
     $41 = ($40|0)==(0);
     if ($41) {
      $44 = $1;
     } else {
      $42 = (_toupper($1)|0);
      $44 = $42;
     }
    } else {
     $44 = $1;
    }
    $43 = ($44|0)==(87);
    if ($43) {
     $45 = HEAP32[13784>>2]|0;
     $46 = HEAP32[13952>>2]|0;
     $47 = ($45|0)>($46|0);
     L24: do {
      if ($47) {
       $$pre = HEAP32[13632>>2]|0;
       $49 = $45;
       while(1) {
        $48 = (($$pre) + ($49)|0);
        $50 = HEAP8[$48>>0]|0;
        if (!((($50<<24>>24) == 9) | (($50<<24>>24) == 32))) {
         $54 = $49;
         break L24;
        }
        $51 = (($49) + -1)|0;
        HEAP32[13784>>2] = $51;
        $52 = ($51|0)>($46|0);
        if ($52) {
         $49 = $51;
        } else {
         $54 = $51;
         break;
        }
       }
      } else {
       $54 = $45;
      }
     } while(0);
     $53 = ($54|0)==($46|0);
     if ($53) {
      $55 = (($46) + 1)|0;
      HEAP32[13784>>2] = $55;
      break;
     }
     $56 = ($54|0)>(-1);
     if ($56) {
      $57 = HEAP32[13768>>2]|0;
      $58 = (($57) + -1)|0;
      $59 = ($54|0)<($58|0);
      if ($59) {
       $60 = HEAP32[13632>>2]|0;
       $61 = (($60) + ($54)|0);
       $62 = HEAP8[$61>>0]|0;
       if (!((($62<<24>>24) == 9) | (($62<<24>>24) == 32))) {
        $63 = (($54) + 1)|0;
        HEAP32[13784>>2] = $63;
       }
      }
     }
    }
   }
  }
 } while(0);
 $64 = HEAP32[13952>>2]|0;
 $65 = HEAP32[13784>>2]|0;
 $66 = ($64|0)<($65|0);
 if ($66) {
  HEAP32[13784>>2] = $64;
  HEAP32[13952>>2] = $65;
 }
 $67 = HEAP32[13488>>2]|0;
 $68 = $67 & 524288;
 $69 = ($68|0)==(0);
 if (!($69)) {
  $70 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$70 & 511]();
 }
 $71 = (_vidomove_dispatch($m)|0);
 $$0 = $71;
 return ($$0|0);
}
function _vidomove_dispatch($m) {
 $m = $m|0;
 var $$pre$i = 0, $$pre$i3 = 0, $$pre$phi$iZ2D = 0, $$pre1$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $8 = 0, $9 = 0, $memchr$i = 0, $memchr$i1 = 0, $memchr$i2 = 0, $r$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[$m>>2]|0;
 do {
  if ((($0|0) == 2)) {
   $13 = ((($m)) + 32|0);
   $14 = HEAP32[$13>>2]|0;
   $memchr$i1 = (_memchr(14424,$14,14)|0);
   $15 = ($memchr$i1|0)==(0|0);
   if ($15) {
    $16 = HEAP32[13784>>2]|0;
    $17 = ((($m)) + 20|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($16|0)<($18|0);
    if ($19) {
     $25 = $14;
    } else {
     $20 = HEAP32[13952>>2]|0;
     $21 = HEAP32[13768>>2]|0;
     $22 = ($20|0)<($21|0);
     if ($22) {
      $23 = (($20) + 1)|0;
      HEAP32[13952>>2] = $23;
      $$pre$i = HEAP32[$13>>2]|0;
      $25 = $$pre$i;
     } else {
      $25 = $14;
     }
    }
   } else {
    $25 = $14;
   }
   $24 = $25 & 255;
   $26 = ($24|0)==($25|0);
   if ($26) {
    $27 = (_islower($25)|0);
    $28 = ($27|0)==(0);
    $$pre1$i = HEAP32[$13>>2]|0;
    if ($28) {
     $32 = $$pre1$i;
    } else {
     $29 = $$pre1$i & 255;
     $30 = (_toupper($29)|0);
     $32 = $30;
    }
   } else {
    $32 = $25;
   }
   $31 = ($32|0)==(87);
   if ($31) {
    $33 = HEAP32[13784>>2]|0;
    $34 = ((($m)) + 20|0);
    $35 = HEAP32[$34>>2]|0;
    $36 = ($33|0)<($35|0);
    if ($36) {
     HEAP32[13784>>2] = $35;
    }
   }
   $37 = HEAP32[14304>>2]|0;
   $38 = ($37|0)==(0);
   if ($38) {
    (_rl_begin_undo_group()|0);
    $49 = HEAP32[13784>>2]|0;
    $50 = HEAP32[13952>>2]|0;
    (_rl_kill_text($49,$50)|0);
    $51 = ((($m)) + 28|0);
    $52 = HEAP32[$51>>2]|0;
    $53 = $52 & 255;
    $54 = ($53|0)==($52|0);
    if ($54) {
     $55 = (_isupper($52)|0);
     $56 = ($55|0)==(0);
     if ($56) {
      label = 26;
     }
    } else {
     label = 26;
    }
    if ((label|0) == 26) {
     HEAP32[14320>>2] = 1;
    }
    $57 = HEAP32[$51>>2]|0;
    $58 = HEAP32[13464>>2]|0;
    $59 = HEAP32[13480>>2]|0;
    HEAP32[14128>>2] = $57;
    HEAP32[14248>>2] = $58;
    HEAP32[14256>>2] = $59;
    HEAP32[13432>>2] = 26464;
    HEAP32[14272>>2] = $57;
    $60 = HEAP32[13728>>2]|0;
    $61 = ($60|0)==(0);
    if ($61) {
     $r$0 = 0;
     break;
    }
    __rl_reset_prompt();
    $r$0 = 0;
    break;
   }
   $39 = HEAP32[14312>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    $41 = HEAP8[$39>>0]|0;
    $42 = ($41<<24>>24)==(0);
    if (!($42)) {
     (_rl_begin_undo_group()|0);
    }
   }
   $43 = HEAP32[13784>>2]|0;
   $44 = HEAP32[13952>>2]|0;
   (_rl_delete_text($43,$44)|0);
   $45 = HEAP32[14312>>2]|0;
   $46 = ($45|0)==(0|0);
   if ($46) {
    $r$0 = 0;
   } else {
    $47 = HEAP8[$45>>0]|0;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $r$0 = 0;
    } else {
     (_rl_insert_text($45)|0);
     (_rl_end_undo_group()|0);
     $r$0 = 0;
    }
   }
  } else if ((($0|0) == 4)) {
   $62 = ((($m)) + 32|0);
   $63 = HEAP32[$62>>2]|0;
   $memchr$i2 = (_memchr(14440,$63,13)|0);
   $64 = ($memchr$i2|0)==(0|0);
   if ($64) {
    $65 = HEAP32[13784>>2]|0;
    $66 = ((($m)) + 20|0);
    $67 = HEAP32[$66>>2]|0;
    $68 = ($65|0)<($67|0);
    if ($68) {
     $$pre$phi$iZ2D = $66;
    } else {
     $69 = HEAP32[13952>>2]|0;
     $70 = HEAP32[13768>>2]|0;
     $71 = ($69|0)<($70|0);
     if ($71) {
      $72 = (($69) + 1)|0;
      HEAP32[13952>>2] = $72;
      $$pre$phi$iZ2D = $66;
     } else {
      $$pre$phi$iZ2D = $66;
     }
    }
   } else {
    $$pre$i3 = ((($m)) + 20|0);
    $$pre$phi$iZ2D = $$pre$i3;
   }
   (_rl_begin_undo_group()|0);
   $73 = HEAP32[13784>>2]|0;
   $74 = HEAP32[13952>>2]|0;
   (_rl_kill_text($73,$74)|0);
   (_rl_end_undo_group()|0);
   (_rl_do_undo()|0);
   $75 = HEAP32[$$pre$phi$iZ2D>>2]|0;
   HEAP32[13784>>2] = $75;
   $r$0 = 0;
  } else if ((($0|0) == 1)) {
   $1 = ((($m)) + 32|0);
   $2 = HEAP32[$1>>2]|0;
   $memchr$i = (_memchr(14408,$2,12)|0);
   $3 = ($memchr$i|0)==(0|0);
   $4 = HEAP32[13784>>2]|0;
   if ($3) {
    $5 = ((($m)) + 20|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($4|0)<($6|0);
    if (!($7)) {
     $8 = HEAP32[13952>>2]|0;
     $9 = HEAP32[13768>>2]|0;
     $10 = ($8|0)<($9|0);
     if ($10) {
      $11 = (($8) + 1)|0;
      HEAP32[13952>>2] = $11;
     }
    }
   }
   $12 = HEAP32[13952>>2]|0;
   (_rl_kill_text($4,$12)|0);
   $r$0 = 0;
  } else {
   HEAP32[$vararg_buffer>>2] = $0;
   __rl_errmsg(14456,$vararg_buffer);
   $r$0 = 1;
  }
 } while(0);
 $76 = HEAP32[13488>>2]|0;
 $77 = $76 & -1048577;
 HEAP32[13488>>2] = $77;
 STACKTOP = sp;return ($r$0|0);
}
function __rl_vi_callback_char_search($data) {
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__rl_read_mbchar(14368,16)|0);
 HEAP32[14352>>2] = $0;
 $1 = ($0|0)<(1);
 if ($1) {
  $$0 = -1;
  return ($$0|0);
 }
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $2 = HEAP32[$data>>2]|0;
 $3 = HEAP32[14360>>2]|0;
 $4 = (__rl_char_search_internal($2,$3,14368,$0)|0);
 $$0 = $4;
 return ($$0|0);
}
function __rl_vi_callback_change_char($data) {
 $data = $data|0;
 var $$0 = 0, $$0$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mb = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mb = sp;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 $2 = (_rl_read_key()|0);
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 & -65;
 HEAP32[13488>>2] = $4;
 $5 = ($2|0)<(0);
 if ($5) {
  HEAP32[14392>>2] = -1;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[36240>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = (__rl_read_mbstring($2,$mb,16)|0);
  HEAP32[14392>>2] = $8;
  $9 = ($8|0)<(0);
  if ($9) {
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$0$i2 = $8;
  }
 } else {
  HEAP32[14392>>2] = $2;
  $$0$i2 = $2;
 }
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $10 = HEAP32[$data>>2]|0;
 $11 = (__rl_vi_change_char($10,$$0$i2,$mb)|0);
 $$0 = $11;
 STACKTOP = sp;return ($$0|0);
}
function __rl_vi_change_char($count,$c,$mb) {
 $count = $count|0;
 $c = $c|0;
 $mb = $mb|0;
 var $$0 = 0, $$in = 0, $$pre$i = 0, $$pre2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $end$0$$i = 0, $end$0$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ((($c|0) == 3) | (($c|0) == 27)) {
  $$0 = -1;
  return ($$0|0);
 }
 (_rl_begin_undo_group()|0);
 $0 = ($count|0)==(0);
 L4: do {
  if (!($0)) {
   $$in = $count;
   while(1) {
    $1 = (($$in) + -1)|0;
    $2 = HEAP32[13784>>2]|0;
    $3 = HEAP32[13768>>2]|0;
    $4 = ($2|0)<($3|0);
    if (!($4)) {
     break L4;
    }
    $5 = ($3|0)==(0);
    if ($5) {
     (_rl_ding()|0);
    } else {
     $6 = HEAP32[36240>>2]|0;
     $7 = ($6|0)==(0);
     if ($7) {
      $8 = HEAP32[13632>>2]|0;
      $9 = (__rl_find_next_mbchar($8,$2,1,1)|0);
      $$pre$i = HEAP32[13768>>2]|0;
      $$pre2$i = HEAP32[13784>>2]|0;
      $12 = $$pre$i;$13 = $$pre2$i;$end$0$i = $9;
     } else {
      $10 = (($2) + 1)|0;
      $12 = $3;$13 = $2;$end$0$i = $10;
     }
     $11 = ($end$0$i|0)<($12|0);
     $end$0$$i = $11 ? $end$0$i : $12;
     (_rl_kill_text($13,$end$0$$i)|0);
     $14 = HEAP32[13784>>2]|0;
     $15 = ($14|0)>(0);
     $16 = HEAP32[13768>>2]|0;
     $17 = ($14|0)==($16|0);
     $or$cond$i = $15 & $17;
     if ($or$cond$i) {
      (_rl_backward_char(1,$c)|0);
     }
    }
    $18 = HEAP32[13784>>2]|0;
    $19 = ($18|0)<($2|0);
    if ($19) {
     $20 = (($18) + 1)|0;
     HEAP32[13784>>2] = $20;
    }
    $21 = HEAP32[36240>>2]|0;
    $22 = ($21|0)==(0);
    if ($22) {
     (_rl_insert_text($mb)|0);
    } else {
     (__rl_insert_char(1,$c)|0);
    }
    $23 = ($1|0)==(0);
    if ($23) {
     break;
    } else {
     $$in = $1;
    }
   }
  }
 } while(0);
 (_rl_backward_char(1,$c)|0);
 (_rl_end_undo_group()|0);
 $$0 = 0;
 return ($$0|0);
}
function __rl_vi_callback_set_mark($data) {
 $data = $data|0;
 var $$0$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 $2 = (_rl_read_key()|0);
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 & -65;
 HEAP32[13488>>2] = $4;
 $$off$i = (($2) + -97)|0;
 $5 = ($$off$i>>>0)>(25);
 if ($5) {
  (_rl_ding()|0);
  $$0$i = -1;
  return ($$0$i|0);
 } else {
  $6 = HEAP32[13784>>2]|0;
  $7 = (14144 + ($$off$i<<2)|0);
  HEAP32[$7>>2] = $6;
  $$0$i = 0;
  return ($$0$i|0);
 }
 return (0)|0;
}
function __rl_vi_callback_goto_mark($data) {
 $data = $data|0;
 var $$0$i = 0, $$off$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 $2 = (_rl_read_key()|0);
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 & -65;
 HEAP32[13488>>2] = $4;
 $5 = ($2|0)==(96);
 if ($5) {
  $6 = HEAP32[13952>>2]|0;
  HEAP32[13784>>2] = $6;
  $$0$i = 0;
  return ($$0$i|0);
 }
 $$off$i = (($2) + -97)|0;
 $7 = ($$off$i>>>0)>(25);
 if ($7) {
  (_rl_ding()|0);
  $$0$i = -1;
  return ($$0$i|0);
 }
 $8 = (14144 + ($$off$i<<2)|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($9|0)==(-1);
 if ($10) {
  (_rl_ding()|0);
  $$0$i = -1;
  return ($$0$i|0);
 } else {
  HEAP32[13784>>2] = $9;
  $$0$i = 0;
  return ($$0$i|0);
 }
 return (0)|0;
}
function _rl_initialize_funmap() {
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14552>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  return;
 }
 $$pre = HEAP32[14536>>2]|0;
 $7 = $$pre;$i$01 = 0;
 while(1) {
  $2 = (14560 + ($i$01<<3)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = (((14560 + ($i$01<<3)|0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($7) + 2)|0;
  $8 = HEAP32[14544>>2]|0;
  $9 = ($6|0)<($8|0);
  if (!($9)) {
   $10 = (($8) + 64)|0;
   HEAP32[14544>>2] = $10;
   $11 = HEAP32[14520>>2]|0;
   $12 = $10 << 2;
   $13 = (_xrealloc($11,$12)|0);
   HEAP32[14520>>2] = $13;
  }
  $14 = (_xmalloc(8)|0);
  $15 = HEAP32[14536>>2]|0;
  $16 = HEAP32[14520>>2]|0;
  $17 = (($16) + ($15<<2)|0);
  HEAP32[$17>>2] = $14;
  $18 = HEAP32[14520>>2]|0;
  $19 = (($18) + ($15<<2)|0);
  $20 = HEAP32[$19>>2]|0;
  HEAP32[$20>>2] = $3;
  $21 = HEAP32[14520>>2]|0;
  $22 = (($21) + ($15<<2)|0);
  $23 = HEAP32[$22>>2]|0;
  $24 = ((($23)) + 4|0);
  HEAP32[$24>>2] = $5;
  $25 = (($15) + 1)|0;
  HEAP32[14536>>2] = $25;
  $26 = HEAP32[14520>>2]|0;
  $27 = (($26) + ($25<<2)|0);
  HEAP32[$27>>2] = 0;
  $28 = (($i$01) + 1)|0;
  $29 = ($28|0)==(133);
  if ($29) {
   break;
  } else {
   $7 = $25;$i$01 = $28;
  }
 }
 HEAP32[14552>>2] = 1;
 HEAP32[14528>>2] = 133;
 return;
}
function _rl_funmap_names() {
 var $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $result$0$lcssa = 0, $result$01 = 0, $result$1 = 0, $result_index$0$lcssa = 0, $result_index$03 = 0, $result_size$02 = 0, $result_size$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[14552>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $$pre$i = HEAP32[14536>>2]|0;
  $7 = $$pre$i;$i$01$i = 0;
  while(1) {
   $2 = (14560 + ($i$01$i<<3)|0);
   $3 = HEAP32[$2>>2]|0;
   $4 = (((14560 + ($i$01$i<<3)|0)) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (($7) + 2)|0;
   $8 = HEAP32[14544>>2]|0;
   $9 = ($6|0)<($8|0);
   if (!($9)) {
    $10 = (($8) + 64)|0;
    HEAP32[14544>>2] = $10;
    $11 = HEAP32[14520>>2]|0;
    $12 = $10 << 2;
    $13 = (_xrealloc($11,$12)|0);
    HEAP32[14520>>2] = $13;
   }
   $14 = (_xmalloc(8)|0);
   $15 = HEAP32[14536>>2]|0;
   $16 = HEAP32[14520>>2]|0;
   $17 = (($16) + ($15<<2)|0);
   HEAP32[$17>>2] = $14;
   $18 = HEAP32[14520>>2]|0;
   $19 = (($18) + ($15<<2)|0);
   $20 = HEAP32[$19>>2]|0;
   HEAP32[$20>>2] = $3;
   $21 = HEAP32[14520>>2]|0;
   $22 = (($21) + ($15<<2)|0);
   $23 = HEAP32[$22>>2]|0;
   $24 = ((($23)) + 4|0);
   HEAP32[$24>>2] = $5;
   $25 = (($15) + 1)|0;
   HEAP32[14536>>2] = $25;
   $26 = HEAP32[14520>>2]|0;
   $27 = (($26) + ($25<<2)|0);
   HEAP32[$27>>2] = 0;
   $28 = (($i$01$i) + 1)|0;
   $29 = ($28|0)==(133);
   if ($29) {
    break;
   } else {
    $7 = $25;$i$01$i = $28;
   }
  }
  HEAP32[14552>>2] = 1;
  HEAP32[14528>>2] = 133;
 }
 $30 = HEAP32[14520>>2]|0;
 $31 = HEAP32[$30>>2]|0;
 $32 = ($31|0)==(0|0);
 if ($32) {
  $result$0$lcssa = 0;$result_index$0$lcssa = 0;
  _qsort($result$0$lcssa,$result_index$0$lcssa,4,364);
  return ($result$0$lcssa|0);
 } else {
  $49 = $30;$result$01 = 0;$result_index$03 = 0;$result_size$02 = 0;
 }
 while(1) {
  $33 = (($result_index$03) + 2)|0;
  $34 = ($33|0)>($result_size$02|0);
  if ($34) {
   $35 = (($result_size$02) + 20)|0;
   $36 = $35 << 2;
   $37 = (_xrealloc($result$01,$36)|0);
   $$pre = HEAP32[14520>>2]|0;
   $39 = $$pre;$result$1 = $37;$result_size$1 = $35;
  } else {
   $39 = $49;$result$1 = $result$01;$result_size$1 = $result_size$02;
  }
  $38 = (($39) + ($result_index$03<<2)|0);
  $40 = HEAP32[$38>>2]|0;
  $41 = HEAP32[$40>>2]|0;
  $42 = (($result$1) + ($result_index$03<<2)|0);
  HEAP32[$42>>2] = $41;
  $43 = (($result_index$03) + 1)|0;
  $44 = (($result$1) + ($43<<2)|0);
  HEAP32[$44>>2] = 0;
  $45 = HEAP32[14520>>2]|0;
  $46 = (($45) + ($43<<2)|0);
  $47 = HEAP32[$46>>2]|0;
  $48 = ($47|0)==(0|0);
  if ($48) {
   $result$0$lcssa = $result$1;$result_index$0$lcssa = $43;
   break;
  } else {
   $49 = $45;$result$01 = $result$1;$result_index$03 = $43;$result_size$02 = $result_size$1;
  }
 }
 _qsort($result$0$lcssa,$result_index$0$lcssa,4,364);
 return ($result$0$lcssa|0);
}
function _rl_make_bare_keymap() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(2056)|0);
 $i$01 = 0;
 while(1) {
  $1 = (($0) + ($i$01<<3)|0);
  HEAP8[$1>>0] = 0;
  $2 = (((($0) + ($i$01<<3)|0)) + 4|0);
  HEAP32[$2>>2] = 0;
  $3 = (($i$01) + 1)|0;
  $exitcond = ($3|0)==(257);
  if ($exitcond) {
   break;
  } else {
   $i$01 = $3;
  }
 }
 return ($0|0);
}
function _rl_noninc_forward_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($key|0)==(63);
 $1 = $0 ? 63 : 0;
 $2 = (_noninc_search(1,$1)|0);
 return ($2|0);
}
function _rl_noninc_reverse_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($key|0)==(47);
 $1 = $0 ? 47 : 0;
 $2 = (_noninc_search(-1,$1)|0);
 return ($2|0);
}
function _rl_noninc_forward_search_again($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[28528>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 } else {
  $2 = (_noninc_dosearch($0,1)|0);
  $3 = ($2|0)!=(1);
  $4 = $3&1;
  $$0 = $4;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_noninc_reverse_search_again($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[28528>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 } else {
  $2 = (_noninc_dosearch($0,-1)|0);
  $3 = ($2|0)!=(1);
  $4 = $3&1;
  $$0 = $4;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_history_search_forward($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP32[13496>>2]|0;
 $2 = ($1|0)!=(189|0);
 $3 = ($1|0)!=(188|0);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $4 = (_where_history()|0);
  HEAP32[28536>>2] = $4;
  $5 = HEAP32[13784>>2]|0;
  HEAP32[28544>>2] = $5;
  HEAP32[28552>>2] = 1;
  HEAP32[28560>>2] = 0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[28568>>2]|0;
   $8 = (($7) + -2)|0;
   $9 = ($5|0)<($8|0);
   if ($9) {
    $$pre = HEAP32[28576>>2]|0;
    $13 = $$pre;
   } else {
    $10 = (($5) + 2)|0;
    HEAP32[28568>>2] = $10;
    $11 = HEAP32[28576>>2]|0;
    $12 = (_xrealloc($11,$10)|0);
    HEAP32[28576>>2] = $12;
    $13 = $12;
   }
   HEAP8[$13>>0] = 94;
   $14 = HEAP32[28576>>2]|0;
   $15 = ((($14)) + 1|0);
   $16 = HEAP32[13632>>2]|0;
   $17 = HEAP32[13784>>2]|0;
   (_strncpy(($15|0),($16|0),($17|0))|0);
   $18 = HEAP32[13784>>2]|0;
   $19 = (($18) + 1)|0;
   $20 = HEAP32[28576>>2]|0;
   $21 = (($20) + ($19)|0);
   HEAP8[$21>>0] = 0;
  }
  (__rl_free_saved_history_line()|0);
 }
 $22 = HEAP32[28544>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $24 = (_rl_get_next_history($count,$ignore)|0);
  $$0 = $24;
  return ($$0|0);
 } else {
  $25 = ($count|0)>(-1);
  $26 = (0 - ($count))|0;
  $27 = $25 ? $count : $26;
  $28 = ($count|0)>(0);
  $29 = $28 ? 1 : -1;
  $30 = (_rl_history_search_internal($27,$29)|0);
  $$0 = $30;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_history_search_backward($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP32[13496>>2]|0;
 $2 = ($1|0)!=(189|0);
 $3 = ($1|0)!=(188|0);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $4 = (_where_history()|0);
  HEAP32[28536>>2] = $4;
  $5 = HEAP32[13784>>2]|0;
  HEAP32[28544>>2] = $5;
  HEAP32[28552>>2] = 1;
  HEAP32[28560>>2] = 0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[28568>>2]|0;
   $8 = (($7) + -2)|0;
   $9 = ($5|0)<($8|0);
   if ($9) {
    $$pre = HEAP32[28576>>2]|0;
    $13 = $$pre;
   } else {
    $10 = (($5) + 2)|0;
    HEAP32[28568>>2] = $10;
    $11 = HEAP32[28576>>2]|0;
    $12 = (_xrealloc($11,$10)|0);
    HEAP32[28576>>2] = $12;
    $13 = $12;
   }
   HEAP8[$13>>0] = 94;
   $14 = HEAP32[28576>>2]|0;
   $15 = ((($14)) + 1|0);
   $16 = HEAP32[13632>>2]|0;
   $17 = HEAP32[13784>>2]|0;
   (_strncpy(($15|0),($16|0),($17|0))|0);
   $18 = HEAP32[13784>>2]|0;
   $19 = (($18) + 1)|0;
   $20 = HEAP32[28576>>2]|0;
   $21 = (($20) + ($19)|0);
   HEAP8[$21>>0] = 0;
  }
  (__rl_free_saved_history_line()|0);
 }
 $22 = HEAP32[28544>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  $24 = (_rl_get_previous_history($count,$ignore)|0);
  $$0 = $24;
  return ($$0|0);
 } else {
  $25 = ($count|0)>(-1);
  $26 = (0 - ($count))|0;
  $27 = $25 ? $count : $26;
  $28 = ($count|0)>(0);
  $29 = $28 ? -1 : 1;
  $30 = (_rl_history_search_internal($27,$29)|0);
  $$0 = $30;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_history_substr_search_forward($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$0 = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP32[13496>>2]|0;
 $2 = ($1|0)!=(191|0);
 $3 = ($1|0)!=(190|0);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $4 = (_where_history()|0);
  HEAP32[28536>>2] = $4;
  $5 = HEAP32[13784>>2]|0;
  HEAP32[28544>>2] = $5;
  HEAP32[28552>>2] = 0;
  HEAP32[28560>>2] = 0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[28568>>2]|0;
   $8 = (($7) + -2)|0;
   $9 = ($5|0)<($8|0);
   if ($9) {
    $$pre = HEAP32[28576>>2]|0;
    $14 = $$pre;$15 = $5;
   } else {
    $10 = (($5) + 2)|0;
    HEAP32[28568>>2] = $10;
    $11 = HEAP32[28576>>2]|0;
    $12 = (_xrealloc($11,$10)|0);
    HEAP32[28576>>2] = $12;
    $$pre2 = HEAP32[13784>>2]|0;
    $14 = $12;$15 = $$pre2;
   }
   $13 = HEAP32[13632>>2]|0;
   (_strncpy(($14|0),($13|0),($15|0))|0);
   $16 = HEAP32[13784>>2]|0;
   $17 = HEAP32[28576>>2]|0;
   $18 = (($17) + ($16)|0);
   HEAP8[$18>>0] = 0;
  }
  (__rl_free_saved_history_line()|0);
 }
 $19 = HEAP32[28544>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  $21 = (_rl_get_next_history($count,$ignore)|0);
  $$0 = $21;
  return ($$0|0);
 } else {
  $22 = ($count|0)>(-1);
  $23 = (0 - ($count))|0;
  $24 = $22 ? $count : $23;
  $25 = ($count|0)>(0);
  $26 = $25 ? 1 : -1;
  $27 = (_rl_history_search_internal($24,$26)|0);
  $$0 = $27;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_history_substr_search_backward($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$0 = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP32[13496>>2]|0;
 $2 = ($1|0)!=(191|0);
 $3 = ($1|0)!=(190|0);
 $or$cond = $2 & $3;
 if ($or$cond) {
  $4 = (_where_history()|0);
  HEAP32[28536>>2] = $4;
  $5 = HEAP32[13784>>2]|0;
  HEAP32[28544>>2] = $5;
  HEAP32[28552>>2] = 0;
  HEAP32[28560>>2] = 0;
  $6 = ($5|0)==(0);
  if (!($6)) {
   $7 = HEAP32[28568>>2]|0;
   $8 = (($7) + -2)|0;
   $9 = ($5|0)<($8|0);
   if ($9) {
    $$pre = HEAP32[28576>>2]|0;
    $14 = $$pre;$15 = $5;
   } else {
    $10 = (($5) + 2)|0;
    HEAP32[28568>>2] = $10;
    $11 = HEAP32[28576>>2]|0;
    $12 = (_xrealloc($11,$10)|0);
    HEAP32[28576>>2] = $12;
    $$pre2 = HEAP32[13784>>2]|0;
    $14 = $12;$15 = $$pre2;
   }
   $13 = HEAP32[13632>>2]|0;
   (_strncpy(($14|0),($13|0),($15|0))|0);
   $16 = HEAP32[13784>>2]|0;
   $17 = HEAP32[28576>>2]|0;
   $18 = (($17) + ($16)|0);
   HEAP8[$18>>0] = 0;
  }
  (__rl_free_saved_history_line()|0);
 }
 $19 = HEAP32[28544>>2]|0;
 $20 = ($19|0)==(0);
 if ($20) {
  $21 = (_rl_get_previous_history($count,$ignore)|0);
  $$0 = $21;
  return ($$0|0);
 } else {
  $22 = ($count|0)>(-1);
  $23 = (0 - ($count))|0;
  $24 = $22 ? $count : $23;
  $25 = ($count|0)>(0);
  $26 = $25 ? -1 : 1;
  $27 = (_rl_history_search_internal($24,$26)|0);
  $$0 = $27;
  return ($$0|0);
 }
 return (0)|0;
}
function _noninc_search($dir,$pchar) {
 $dir = $dir|0;
 $pchar = $pchar|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = (__rl_scxt_alloc(2,0)|0);
 $1 = ($dir|0)<(0);
 if ($1) {
  $2 = ((($0)) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = $3 | 1;
  HEAP32[$2>>2] = $4;
 }
 $5 = ((($0)) + 72|0);
 HEAP32[$5>>2] = $dir;
 $6 = ((($0)) + 44|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($0)) + 68|0);
 HEAP32[$8>>2] = $7;
 (_rl_maybe_save_line()|0);
 HEAP32[34424>>2] = 0;
 $9 = HEAP32[13632>>2]|0;
 HEAP8[$9>>0] = 0;
 HEAP32[13784>>2] = 0;
 HEAP32[13768>>2] = 0;
 $10 = ($pchar|0)!=(0);
 $11 = $10 ? $pchar : 58;
 $12 = (__rl_make_prompt_for_search($11)|0);
 HEAP32[$vararg_buffer>>2] = $12;
 (_rl_message(34480,$vararg_buffer)|0);
 _xfree($12);
 $13 = HEAP32[13488>>2]|0;
 $14 = $13 | 256;
 HEAP32[13488>>2] = $14;
 HEAP32[28520>>2] = $0;
 $15 = $13 & 524288;
 $16 = ($15|0)==(0);
 if (!($16)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 while(1) {
  $17 = (__rl_search_getchar($0)|0);
  $18 = ($17|0)==(0);
  if ($18) {
   break;
  }
  $19 = (__rl_nsearch_dispatch($0,$17)|0);
  $20 = ($19|0)<(0);
  if ($20) {
   $$0 = 1;
   label = 9;
   break;
  }
  $21 = ($19|0)==(0);
  if ($21) {
   break;
  }
 }
 if ((label|0) == 9) {
  STACKTOP = sp;return ($$0|0);
 }
 $22 = (__rl_nsearch_dosearch($0)|0);
 $23 = ($22|0)>(-1);
 if (!($23)) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 __rl_scxt_dispose($0,0);
 HEAP32[28520>>2] = 0;
 $24 = HEAP32[13488>>2]|0;
 $25 = $24 & -257;
 HEAP32[13488>>2] = $25;
 $26 = ($22|0)!=(1);
 $27 = $26&1;
 $$0 = $27;
 STACKTOP = sp;return ($$0|0);
}
function _noninc_dosearch($string,$dir) {
 $string = $string|0;
 $dir = $dir|0;
 var $$0 = 0, $$idx$val = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $ret$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($string|0)==(0|0);
 if (!($0)) {
  $1 = HEAP8[$string>>0]|0;
  $2 = ($1<<24>>24)==(0);
  $3 = HEAP32[28584>>2]|0;
  $4 = ($3|0)<(0);
  $or$cond = $2 | $4;
  if (!($or$cond)) {
   $5 = (($3) + ($dir))|0;
   $6 = ($5|0)<(0);
   do {
    if (!($6)) {
     $7 = (_where_history()|0);
     $8 = (_history_set_pos($5)|0);
     $9 = ($8|0)==(0);
     if (!($9)) {
      $10 = HEAP32[13488>>2]|0;
      $11 = $10 | 512;
      HEAP32[13488>>2] = $11;
      $12 = HEAP8[$string>>0]|0;
      $13 = ($12<<24>>24)==(94);
      if ($13) {
       $14 = ((($string)) + 1|0);
       $15 = (_history_search_prefix($14,$dir)|0);
       $ret$0$i = $15;
      } else {
       $16 = (_history_search($string,$dir)|0);
       $ret$0$i = $16;
      }
      $17 = HEAP32[13488>>2]|0;
      $18 = $17 & -513;
      HEAP32[13488>>2] = $18;
      $19 = ($ret$0$i|0)==(-1);
      if ($19) {
       (_history_set_pos($7)|0);
       break;
      }
      $20 = (_where_history()|0);
      (_history_set_pos($7)|0);
      $21 = ($20|0)==(-1);
      if (!($21)) {
       HEAP32[28584>>2] = $20;
       $22 = (_where_history()|0);
       $23 = HEAP32[28584>>2]|0;
       (_history_set_pos($23)|0);
       $24 = (_current_history()|0);
       $25 = HEAP32[13440>>2]|0;
       $26 = ($25|0)==(0);
       if (!($26)) {
        (_history_set_pos($22)|0);
       }
       $$idx$val = HEAP32[$24>>2]|0;
       $27 = HEAP32[13768>>2]|0;
       (__rl_replace_text($$idx$val,0,$27)|0);
       __rl_fix_point(1);
       $28 = HEAP32[13440>>2]|0;
       $29 = ($28|0)==(0);
       if ($29) {
        _rl_free_undo_list();
       }
       $30 = HEAP32[36056>>2]|0;
       $31 = ($30|0)==(0|0);
       if (!($31)) {
        __rl_free_history_entry($30);
       }
       HEAP32[36056>>2] = 0;
       HEAP32[13784>>2] = 0;
       $32 = HEAP32[13768>>2]|0;
       HEAP32[13952>>2] = $32;
       (_rl_clear_message()|0);
       $$0 = 1;
       return ($$0|0);
      }
     }
    }
   } while(0);
   (_rl_maybe_unsave_line()|0);
   (_rl_clear_message()|0);
   HEAP32[13784>>2] = 0;
   (_rl_ding()|0);
   $$0 = 0;
   return ($$0|0);
  }
 }
 (_rl_ding()|0);
 $$0 = 0;
 return ($$0|0);
}
function __rl_nsearch_dispatch($cxt,$c) {
 $cxt = $cxt|0;
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 L1: do {
  switch ($c|0) {
  case 23:  {
   (_rl_unix_word_rubout(1,23)|0);
   break;
  }
  case 7: case 3:  {
   (_rl_ding()|0);
   (_rl_maybe_unsave_line()|0);
   (_rl_clear_message()|0);
   $8 = ((($cxt)) + 36|0);
   $9 = HEAP32[$8>>2]|0;
   HEAP32[13784>>2] = $9;
   $10 = ((($cxt)) + 40|0);
   $11 = HEAP32[$10>>2]|0;
   HEAP32[13952>>2] = $11;
   _rl_restore_prompt();
   $12 = HEAP32[13488>>2]|0;
   $13 = $12 & -257;
   HEAP32[13488>>2] = $13;
   $$0 = -1;
   return ($$0|0);
   break;
  }
  case 127: case 8:  {
   $0 = HEAP32[13784>>2]|0;
   $1 = ($0|0)==(0);
   if (!($1)) {
    (__rl_rubout_char(1,$c)|0);
    break L1;
   }
   (_rl_maybe_unsave_line()|0);
   (_rl_clear_message()|0);
   $2 = ((($cxt)) + 36|0);
   $3 = HEAP32[$2>>2]|0;
   HEAP32[13784>>2] = $3;
   $4 = ((($cxt)) + 40|0);
   $5 = HEAP32[$4>>2]|0;
   HEAP32[13952>>2] = $5;
   _rl_restore_prompt();
   $6 = HEAP32[13488>>2]|0;
   $7 = $6 & -257;
   HEAP32[13488>>2] = $7;
   $$0 = -1;
   return ($$0|0);
   break;
  }
  case 10: case 13:  {
   $$0 = 0;
   return ($$0|0);
   break;
  }
  case 21:  {
   (_rl_unix_line_discard(1,21)|0);
   break;
  }
  default: {
   $14 = HEAP32[36240>>2]|0;
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = ((($cxt)) + 84|0);
    (_rl_insert_text($16)|0);
    break L1;
   } else {
    (__rl_insert_char(1,$c)|0);
    break L1;
   }
  }
  }
 } while(0);
 $17 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$17 & 511]();
 $$0 = 1;
 return ($$0|0);
}
function __rl_nsearch_dosearch($cxt) {
 $cxt = $cxt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($cxt)) + 40|0);
 $1 = HEAP32[$0>>2]|0;
 HEAP32[13952>>2] = $1;
 $2 = HEAP32[13784>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $4 = HEAP32[28528>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   (_rl_ding()|0);
   _rl_restore_prompt();
   $6 = HEAP32[13488>>2]|0;
   $7 = $6 & -257;
   HEAP32[13488>>2] = $7;
   $$0 = -1;
   return ($$0|0);
  }
 } else {
  $8 = ((($cxt)) + 44|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[28584>>2] = $9;
  $10 = HEAP32[28528>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   _free($10);
  }
  $12 = HEAP32[13632>>2]|0;
  $13 = (_strlen(($12|0))|0);
  $14 = (($13) + 1)|0;
  $15 = (_xmalloc($14)|0);
  $16 = HEAP32[13632>>2]|0;
  $17 = (_strcpy(($15|0),($16|0))|0);
  HEAP32[28528>>2] = $17;
  _rl_free_undo_list();
 }
 _rl_restore_prompt();
 $18 = HEAP32[28528>>2]|0;
 $19 = ((($cxt)) + 72|0);
 $20 = HEAP32[$19>>2]|0;
 $21 = (_noninc_dosearch($18,$20)|0);
 $$0 = $21;
 return ($$0|0);
}
function _rl_history_search_internal($count,$dir) {
 $count = $count|0;
 $dir = $dir|0;
 var $$0 = 0, $$01$ph35 = 0, $$lcssa = 0, $$lcssa44 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $ret$0$i = 0, $storemerge2 = 0, $storemerge3 = 0, $temp$0 = 0, $temp$0$idx$val = 0, $temp$0$lcssa41 = 0, $temp$0$ph34 = 0, $temp$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_maybe_save_line()|0);
 $0 = ($count|0)==(0);
 L1: do {
  if ($0) {
   $temp$07 = 0;
  } else {
   $$01$ph35 = $count;$temp$0$ph34 = 0;
   L2: while(1) {
    $temp$0 = $temp$0$ph34;
    while(1) {
     $1 = HEAP32[32656>>2]|0;
     $2 = ($1|0)==(0);
     if (!($2)) {
      $3 = HEAP32[32656>>2]|0;
      __rl_signal_handler($3);
     }
     $4 = HEAP32[28576>>2]|0;
     $5 = HEAP32[28536>>2]|0;
     $6 = (($5) + ($dir))|0;
     $7 = ($6|0)<(0);
     if ($7) {
      $temp$07 = $temp$0;
      break L1;
     }
     $8 = (_where_history()|0);
     $9 = (_history_set_pos($6)|0);
     $10 = ($9|0)==(0);
     if ($10) {
      $temp$07 = $temp$0;
      break L1;
     }
     $11 = HEAP32[13488>>2]|0;
     $12 = $11 | 512;
     HEAP32[13488>>2] = $12;
     $13 = HEAP8[$4>>0]|0;
     $14 = ($13<<24>>24)==(94);
     if ($14) {
      $15 = ((($4)) + 1|0);
      $16 = (_history_search_prefix($15,$dir)|0);
      $ret$0$i = $16;
     } else {
      $17 = (_history_search($4,$dir)|0);
      $ret$0$i = $17;
     }
     $18 = HEAP32[13488>>2]|0;
     $19 = $18 & -513;
     HEAP32[13488>>2] = $19;
     $20 = ($ret$0$i|0)==(-1);
     if ($20) {
      $$lcssa = $8;$temp$0$lcssa41 = $temp$0;
      break L2;
     }
     $21 = (_where_history()|0);
     (_history_set_pos($8)|0);
     $22 = ($21|0)==(-1);
     if ($22) {
      $temp$07 = $temp$0;
      break L1;
     }
     HEAP32[28536>>2] = $21;
     $23 = (_where_history()|0);
     $24 = HEAP32[28536>>2]|0;
     (_history_set_pos($24)|0);
     $25 = (_current_history()|0);
     (_history_set_pos($23)|0);
     $26 = HEAP32[28560>>2]|0;
     $27 = ($26|0)==(0|0);
     if ($27) {
      $$lcssa44 = $25;
      break;
     }
     $28 = HEAP8[$26>>0]|0;
     $29 = HEAP32[$25>>2]|0;
     $30 = HEAP8[$29>>0]|0;
     $31 = ($28<<24>>24)==($30<<24>>24);
     if (!($31)) {
      $$lcssa44 = $25;
      break;
     }
     $32 = (_strcmp($26,$29)|0);
     $33 = ($32|0)==(0);
     if ($33) {
      $temp$0 = $25;
     } else {
      $$lcssa44 = $25;
      break;
     }
    }
    $34 = HEAP32[$$lcssa44>>2]|0;
    HEAP32[28560>>2] = $34;
    $35 = (($$01$ph35) + -1)|0;
    $36 = ($35|0)==(0);
    if ($36) {
     $temp$07 = $$lcssa44;
     break L1;
    } else {
     $$01$ph35 = $35;$temp$0$ph34 = $$lcssa44;
    }
   }
   (_history_set_pos($$lcssa)|0);
   $temp$07 = $temp$0$lcssa41;
  }
 } while(0);
 $37 = ($temp$07|0)==(0|0);
 if ($37) {
  (_rl_maybe_unsave_line()|0);
  (_rl_ding()|0);
  $38 = HEAP32[28544>>2]|0;
  $$0 = 1;$storemerge3 = $38;
  HEAP32[13784>>2] = $storemerge3;
  $storemerge2 = HEAP32[13768>>2]|0;
  HEAP32[13952>>2] = $storemerge2;
  return ($$0|0);
 }
 $temp$0$idx$val = HEAP32[$temp$07>>2]|0;
 $39 = HEAP32[13768>>2]|0;
 (__rl_replace_text($temp$0$idx$val,0,$39)|0);
 __rl_fix_point(1);
 $40 = HEAP32[13440>>2]|0;
 $41 = ($40|0)==(0);
 if ($41) {
  _rl_free_undo_list();
 }
 $42 = HEAP32[36056>>2]|0;
 $43 = ($42|0)==(0|0);
 if (!($43)) {
  __rl_free_history_entry($42);
 }
 HEAP32[36056>>2] = 0;
 $44 = HEAP32[28552>>2]|0;
 $45 = $44 & 1;
 $46 = ($45|0)==(0);
 if (!($46)) {
  $47 = HEAP32[28544>>2]|0;
  $$0 = 0;$storemerge3 = $47;
  HEAP32[13784>>2] = $storemerge3;
  $storemerge2 = HEAP32[13768>>2]|0;
  HEAP32[13952>>2] = $storemerge2;
  return ($$0|0);
 }
 $48 = HEAP32[13632>>2]|0;
 $49 = HEAP32[28576>>2]|0;
 $50 = (_strstr($48,$49)|0);
 $51 = ($50|0)==(0|0);
 if ($51) {
  $57 = HEAP32[13768>>2]|0;
  $$0 = 0;$storemerge3 = $57;
  HEAP32[13784>>2] = $storemerge3;
  $storemerge2 = HEAP32[13768>>2]|0;
  HEAP32[13952>>2] = $storemerge2;
  return ($$0|0);
 } else {
  $52 = $50;
  $53 = $48;
  $54 = (($52) - ($53))|0;
  $55 = HEAP32[28544>>2]|0;
  $56 = (($54) + ($55))|0;
  $$0 = 0;$storemerge3 = $56;
  HEAP32[13784>>2] = $storemerge3;
  $storemerge2 = HEAP32[13768>>2]|0;
  HEAP32[13952>>2] = $storemerge2;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_prep_terminal($meta_flag) {
 $meta_flag = $meta_flag|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0;
 var $98 = 0, $99 = 0, $or$cond$i = 0, $tio = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $w$i$i = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $w$i$i = sp + 80|0;
 $tio = sp + 20|0;
 $0 = HEAP32[28608>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  STACKTOP = sp;return;
 }
 __rl_block_sigint();
 $2 = HEAP32[13504>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = HEAP32[_stdin>>2]|0;
  $6 = (_fileno(($5|0))|0);
  $7 = $6;
 } else {
  $4 = (_fileno(($2|0))|0);
  $7 = $4;
 }
 HEAP32[$vararg_buffer>>2] = $w$i$i;
 $8 = (_ioctl(($7|0),21523,($vararg_buffer|0))|0);
 $9 = ($8|0)==(0);
 if ($9) {
  HEAP32[$vararg_buffer1>>2] = $w$i$i;
  (_ioctl(($7|0),21524,($vararg_buffer1|0))|0);
 }
 $10 = (___errno_location()|0);
 HEAP32[$10>>2] = 0;
 while(1) {
  $11 = (_tcgetattr(($7|0),($tio|0))|0);
  $12 = ($11|0)<(0);
  if (!($12)) {
   label = 10;
   break;
  }
  $13 = HEAP32[$10>>2]|0;
  if ((($13|0) == 95) | (($13|0) == 22) | (($13|0) == 25)) {
   label = 12;
   break;
  } else if (!((($13|0) == 4))) {
   break;
  }
 }
 if ((label|0) == 10) {
  $14 = ((($tio)) + 12|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = $15 & 4096;
  $17 = ($16|0)==(0);
  if ($17) {
   $171 = $15;
  } else {
   __rl_errmsg(28616,$vararg_buffer4);
   $18 = HEAP32[$14>>2]|0;
   $19 = $18 & -4097;
   HEAP32[$14>>2] = $19;
   $171 = $19;
  }
  dest=28656; src=$tio; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $20 = HEAP32[13704>>2]|0;
  $21 = ($20|0)==(0);
  do {
   if ($21) {
    $$pre = HEAP32[13488>>2]|0;
    $98 = $$pre;
   } else {
    $22 = HEAP32[13440>>2]|0;
    $23 = ($22|0)==(0);
    if ($23) {
     $24 = HEAP32[13488>>2]|0;
     $25 = $24 & 262144;
     $26 = ($25|0)==(0);
     if ($26) {
      $98 = $24;
      break;
     }
     $27 = HEAP8[28720>>0]|0;
     $28 = ($27<<24>>24)==(0);
     if (!($28)) {
      $29 = $27&255;
      $30 = (26464 + ($29<<3)|0);
      $31 = HEAP8[$30>>0]|0;
      $32 = ($31<<24>>24)==(0);
      if ($32) {
       $33 = (((26464 + ($29<<3)|0)) + 4|0);
       HEAP32[$33>>2] = 215;
      }
     }
     $34 = HEAP8[28728>>0]|0;
     $35 = ($34<<24>>24)==(0);
     if (!($35)) {
      $36 = $34&255;
      $37 = (26464 + ($36<<3)|0);
      $38 = HEAP8[$37>>0]|0;
      $39 = ($38<<24>>24)==(0);
      if ($39) {
       $40 = (((26464 + ($36<<3)|0)) + 4|0);
       HEAP32[$40>>2] = 215;
      }
     }
     $41 = HEAP8[28736>>0]|0;
     $42 = ($41<<24>>24)==(0);
     if (!($42)) {
      $43 = $41&255;
      $44 = (26464 + ($43<<3)|0);
      $45 = HEAP8[$44>>0]|0;
      $46 = ($45<<24>>24)==(0);
      if ($46) {
       $47 = (((26464 + ($43<<3)|0)) + 4|0);
       HEAP32[$47>>2] = 215;
      }
     }
     $48 = HEAP8[28744>>0]|0;
     $49 = ($48<<24>>24)==(0);
     if ($49) {
      $98 = $24;
      break;
     }
     $50 = $48&255;
     $51 = (26464 + ($50<<3)|0);
     $52 = HEAP8[$51>>0]|0;
     $53 = ($52<<24>>24)==(0);
     if (!($53)) {
      $98 = $24;
      break;
     }
     $54 = (((26464 + ($50<<3)|0)) + 4|0);
     HEAP32[$54>>2] = 215;
     $98 = $24;
     break;
    } else {
     $55 = HEAP32[13432>>2]|0;
     $56 = HEAP32[13488>>2]|0;
     $57 = $56 & 262144;
     $58 = ($57|0)==(0);
     if ($58) {
      $98 = $56;
      break;
     }
     $59 = HEAP8[28720>>0]|0;
     $60 = ($59<<24>>24)==(0);
     if (!($60)) {
      $61 = $59&255;
      $62 = (($55) + ($61<<3)|0);
      $63 = HEAP8[$62>>0]|0;
      $64 = ($63<<24>>24)==(0);
      if ($64) {
       $65 = (((($55) + ($61<<3)|0)) + 4|0);
       HEAP32[$65>>2] = 215;
      }
     }
     $66 = HEAP8[28728>>0]|0;
     $67 = ($66<<24>>24)==(0);
     if (!($67)) {
      $68 = $66&255;
      $69 = (($55) + ($68<<3)|0);
      $70 = HEAP8[$69>>0]|0;
      $71 = ($70<<24>>24)==(0);
      if ($71) {
       $72 = (((($55) + ($68<<3)|0)) + 4|0);
       HEAP32[$72>>2] = 215;
      }
     }
     $73 = HEAP8[28736>>0]|0;
     $74 = ($73<<24>>24)==(0);
     if (!($74)) {
      $75 = $73&255;
      $76 = (($55) + ($75<<3)|0);
      $77 = HEAP8[$76>>0]|0;
      $78 = ($77<<24>>24)==(0);
      if ($78) {
       $79 = (((($55) + ($75<<3)|0)) + 4|0);
       HEAP32[$79>>2] = 215;
      }
     }
     $80 = HEAP8[28744>>0]|0;
     $81 = ($80<<24>>24)==(0);
     if ($81) {
      $98 = $56;
      break;
     }
     $82 = $80&255;
     $83 = (($55) + ($82<<3)|0);
     $84 = HEAP8[$83>>0]|0;
     $85 = ($84<<24>>24)==(0);
     if (!($85)) {
      $98 = $56;
      break;
     }
     $86 = (((($55) + ($82<<3)|0)) + 4|0);
     HEAP32[$86>>2] = 215;
     $98 = $56;
     break;
    }
   }
  } while(0);
  $87 = HEAP8[(28675)>>0]|0;
  HEAP8[28720>>0] = $87;
  $88 = HEAP8[(28687)>>0]|0;
  HEAP8[28744>>0] = $88;
  $89 = HEAP8[(28676)>>0]|0;
  HEAP8[28728>>0] = $89;
  $90 = HEAP8[(28673)>>0]|0;
  $91 = $90&255;
  HEAP32[32672>>2] = $91;
  $92 = HEAP8[(28674)>>0]|0;
  $93 = $92&255;
  HEAP32[32680>>2] = $93;
  $94 = HEAP8[(28683)>>0]|0;
  $95 = $94&255;
  HEAP32[32688>>2] = $95;
  $96 = HEAP8[(28688)>>0]|0;
  HEAP8[28736>>0] = $96;
  $97 = $98 | 262144;
  HEAP32[13488>>2] = $97;
  do {
   if (!($21)) {
    $99 = HEAP32[13440>>2]|0;
    $100 = ($99|0)==(0);
    if ($100) {
     $101 = ((($tio)) + 19|0);
     $102 = HEAP8[$101>>0]|0;
     $103 = ((($tio)) + 20|0);
     $104 = HEAP8[$103>>0]|0;
     $105 = ((($tio)) + 31|0);
     $106 = HEAP8[$105>>0]|0;
     $107 = ((($tio)) + 32|0);
     $108 = HEAP8[$107>>0]|0;
     $109 = ($102<<24>>24)==(0);
     if (!($109)) {
      $110 = $102&255;
      $111 = (26464 + ($110<<3)|0);
      $112 = HEAP8[$111>>0]|0;
      $113 = ($112<<24>>24)==(0);
      if ($113) {
       $114 = (((26464 + ($110<<3)|0)) + 4|0);
       HEAP32[$114>>2] = 154;
      }
     }
     $115 = ($104<<24>>24)==(0);
     if (!($115)) {
      $116 = $104&255;
      $117 = (26464 + ($116<<3)|0);
      $118 = HEAP8[$117>>0]|0;
      $119 = ($118<<24>>24)==(0);
      if ($119) {
       $120 = (((26464 + ($116<<3)|0)) + 4|0);
       HEAP32[$120>>2] = 227;
      }
     }
     $121 = ($108<<24>>24)==(0);
     if (!($121)) {
      $122 = $108&255;
      $123 = (26464 + ($122<<3)|0);
      $124 = HEAP8[$123>>0]|0;
      $125 = ($124<<24>>24)==(0);
      if ($125) {
       $126 = (((26464 + ($122<<3)|0)) + 4|0);
       HEAP32[$126>>2] = 210;
      }
     }
     $127 = ($106<<24>>24)==(0);
     if ($127) {
      break;
     }
     $128 = $106&255;
     $129 = (26464 + ($128<<3)|0);
     $130 = HEAP8[$129>>0]|0;
     $131 = ($130<<24>>24)==(0);
     if (!($131)) {
      break;
     }
     $132 = (((26464 + ($128<<3)|0)) + 4|0);
     HEAP32[$132>>2] = 228;
     break;
    } else {
     $133 = HEAP32[13432>>2]|0;
     $134 = ((($tio)) + 19|0);
     $135 = HEAP8[$134>>0]|0;
     $136 = ((($tio)) + 20|0);
     $137 = HEAP8[$136>>0]|0;
     $138 = ((($tio)) + 31|0);
     $139 = HEAP8[$138>>0]|0;
     $140 = ((($tio)) + 32|0);
     $141 = HEAP8[$140>>0]|0;
     $142 = ($135<<24>>24)==(0);
     if (!($142)) {
      $143 = $135&255;
      $144 = (($133) + ($143<<3)|0);
      $145 = HEAP8[$144>>0]|0;
      $146 = ($145<<24>>24)==(0);
      if ($146) {
       $147 = (((($133) + ($143<<3)|0)) + 4|0);
       HEAP32[$147>>2] = 154;
      }
     }
     $148 = ($137<<24>>24)==(0);
     if (!($148)) {
      $149 = $137&255;
      $150 = (($133) + ($149<<3)|0);
      $151 = HEAP8[$150>>0]|0;
      $152 = ($151<<24>>24)==(0);
      if ($152) {
       $153 = (((($133) + ($149<<3)|0)) + 4|0);
       HEAP32[$153>>2] = 227;
      }
     }
     $154 = ($141<<24>>24)==(0);
     if (!($154)) {
      $155 = $141&255;
      $156 = (($133) + ($155<<3)|0);
      $157 = HEAP8[$156>>0]|0;
      $158 = ($157<<24>>24)==(0);
      if ($158) {
       $159 = (((($133) + ($155<<3)|0)) + 4|0);
       HEAP32[$159>>2] = 210;
      }
     }
     $160 = ($139<<24>>24)==(0);
     if ($160) {
      break;
     }
     $161 = $139&255;
     $162 = (($133) + ($161<<3)|0);
     $163 = HEAP8[$162>>0]|0;
     $164 = ($163<<24>>24)==(0);
     if (!($164)) {
      break;
     }
     $165 = (((($133) + ($161<<3)|0)) + 4|0);
     HEAP32[$165>>2] = 228;
     break;
    }
   }
  } while(0);
  $166 = HEAP32[(28668)>>2]|0;
  $167 = HEAP8[(28677)>>0]|0;
  $168 = $166 & 8;
  HEAP32[13520>>2] = $168;
  $169 = $166 & 512;
  HEAP32[32664>>2] = $169;
  $170 = $171 & -11;
  HEAP32[$14>>2] = $170;
  $172 = ($167<<24>>24)==(0);
  if (!($172)) {
   $173 = $167&255;
   HEAP32[13576>>2] = $173;
  }
  $174 = ((($tio)) + 8|0);
  $175 = HEAP32[$174>>2]|0;
  $176 = $175 & 48;
  $177 = ($176|0)==(48);
  $178 = ($meta_flag|0)!=(0);
  $or$cond$i = $178 | $177;
  $179 = HEAP32[$tio>>2]|0;
  if ($or$cond$i) {
   $180 = $179 & -49;
   HEAP32[$tio>>2] = $180;
   $182 = $180;
  } else {
   $182 = $179;
  }
  $181 = $182 & -321;
  HEAP32[$tio>>2] = $181;
  $183 = $170 | 1;
  HEAP32[$14>>2] = $183;
  $184 = ((($tio)) + 23|0);
  HEAP8[$184>>0] = 1;
  $185 = ((($tio)) + 22|0);
  HEAP8[$185>>0] = 0;
  $186 = $171 & 4096;
  $187 = ($186|0)==(0);
  if (!($187)) {
   $188 = $183 & -4107;
   HEAP32[$14>>2] = $188;
  }
  $189 = ((($tio)) + 32|0);
  HEAP8[$189>>0] = 0;
  $190 = (_tcsetattr(($7|0),1,($tio|0))|0);
  $191 = ($190|0)<(0);
  L99: do {
   if ($191) {
    while(1) {
     $192 = HEAP32[$10>>2]|0;
     $193 = ($192|0)==(4);
     if (!($193)) {
      break;
     }
     HEAP32[$10>>2] = 0;
     $194 = (_tcsetattr(($7|0),1,($tio|0))|0);
     $195 = ($194|0)<(0);
     if (!($195)) {
      break L99;
     }
    }
    __rl_release_sigint();
    STACKTOP = sp;return;
   }
  } while(0);
  $196 = HEAP32[35240>>2]|0;
  $197 = ($196|0)==(0);
  if (!($197)) {
   __rl_control_keypad(1);
  }
  $198 = HEAP32[13512>>2]|0;
  (_fflush(($198|0))|0);
  HEAP32[28608>>2] = 1;
  $199 = HEAP32[13488>>2]|0;
  $200 = $199 | 4;
  HEAP32[13488>>2] = $200;
  __rl_release_sigint();
  STACKTOP = sp;return;
 }
 else if ((label|0) == 12) {
  HEAP32[13520>>2] = 1;
 }
 __rl_release_sigint();
 STACKTOP = sp;return;
}
function _rl_deprep_terminal() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[28608>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return;
 }
 __rl_block_sigint();
 $2 = HEAP32[13504>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = HEAP32[_stdin>>2]|0;
  $6 = (_fileno(($5|0))|0);
  $10 = $6;
 } else {
  $4 = (_fileno(($2|0))|0);
  $10 = $4;
 }
 $7 = HEAP32[35240>>2]|0;
 $8 = ($7|0)==(0);
 if (!($8)) {
  __rl_control_keypad(0);
 }
 $9 = HEAP32[13512>>2]|0;
 (_fflush(($9|0))|0);
 $11 = (_tcsetattr(($10|0),1,(28656|0))|0);
 $12 = ($11|0)<(0);
 L11: do {
  if ($12) {
   $13 = (___errno_location()|0);
   while(1) {
    $14 = HEAP32[$13>>2]|0;
    $15 = ($14|0)==(4);
    if (!($15)) {
     break;
    }
    HEAP32[$13>>2] = 0;
    $16 = (_tcsetattr(($10|0),1,(28656|0))|0);
    $17 = ($16|0)<(0);
    if (!($17)) {
     break L11;
    }
   }
   __rl_release_sigint();
   return;
  }
 } while(0);
 HEAP32[28608>>2] = 0;
 $18 = HEAP32[13488>>2]|0;
 $19 = $18 & -5;
 HEAP32[13488>>2] = $19;
 __rl_release_sigint();
 return;
}
function _rl_restart_output($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13512>>2]|0;
 $1 = (_fileno(($0|0))|0);
 (_tcflow(($1|0),1)|0);
 return 0;
}
function _rltty_set_default_bindings($kmap) {
 $kmap = $kmap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ttybuff = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $w$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 96|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $w$i$i = sp + 80|0;
 $ttybuff = sp + 20|0;
 $0 = HEAP32[13504>>2]|0;
 $1 = (_fileno(($0|0))|0);
 HEAP32[$vararg_buffer>>2] = $w$i$i;
 $2 = (_ioctl(($1|0),21523,($vararg_buffer|0))|0);
 $3 = ($2|0)==(0);
 if ($3) {
  HEAP32[$vararg_buffer1>>2] = $w$i$i;
  (_ioctl(($1|0),21524,($vararg_buffer1|0))|0);
 }
 $4 = (___errno_location()|0);
 HEAP32[$4>>2] = 0;
 while(1) {
  $5 = (_tcgetattr(($1|0),($ttybuff|0))|0);
  $6 = ($5|0)<(0);
  if (!($6)) {
   break;
  }
  $7 = HEAP32[$4>>2]|0;
  $8 = ($7|0)==(4);
  if (!($8)) {
   label = 20;
   break;
  }
 }
 if ((label|0) == 20) {
  STACKTOP = sp;return;
 }
 $9 = ((($ttybuff)) + 12|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $10 & 4096;
 $12 = ($11|0)==(0);
 if (!($12)) {
  __rl_errmsg(28616,$vararg_buffer4);
  $13 = HEAP32[$9>>2]|0;
  $14 = $13 & -4097;
  HEAP32[$9>>2] = $14;
 }
 $15 = ((($ttybuff)) + 19|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ((($ttybuff)) + 20|0);
 $18 = HEAP8[$17>>0]|0;
 $19 = ((($ttybuff)) + 31|0);
 $20 = HEAP8[$19>>0]|0;
 $21 = ((($ttybuff)) + 32|0);
 $22 = HEAP8[$21>>0]|0;
 $23 = ($16<<24>>24)==(0);
 if (!($23)) {
  $24 = $16&255;
  $25 = (($kmap) + ($24<<3)|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = ($26<<24>>24)==(0);
  if ($27) {
   $28 = (((($kmap) + ($24<<3)|0)) + 4|0);
   HEAP32[$28>>2] = 154;
  }
 }
 $29 = ($18<<24>>24)==(0);
 if (!($29)) {
  $30 = $18&255;
  $31 = (($kmap) + ($30<<3)|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = ($32<<24>>24)==(0);
  if ($33) {
   $34 = (((($kmap) + ($30<<3)|0)) + 4|0);
   HEAP32[$34>>2] = 227;
  }
 }
 $35 = ($22<<24>>24)==(0);
 if (!($35)) {
  $36 = $22&255;
  $37 = (($kmap) + ($36<<3)|0);
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(0);
  if ($39) {
   $40 = (((($kmap) + ($36<<3)|0)) + 4|0);
   HEAP32[$40>>2] = 210;
  }
 }
 $41 = ($20<<24>>24)==(0);
 if ($41) {
  STACKTOP = sp;return;
 }
 $42 = $20&255;
 $43 = (($kmap) + ($42<<3)|0);
 $44 = HEAP8[$43>>0]|0;
 $45 = ($44<<24>>24)==(0);
 if (!($45)) {
  STACKTOP = sp;return;
 }
 $46 = (((($kmap) + ($42<<3)|0)) + 4|0);
 HEAP32[$46>>2] = 228;
 STACKTOP = sp;return;
}
function _rl_tty_set_default_bindings($kmap) {
 $kmap = $kmap|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 _rltty_set_default_bindings($kmap);
 return;
}
function __rl_disable_tty_signals() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0;
 var src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[28752>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[13504>>2]|0;
 $3 = (_fileno(($2|0))|0);
 while(1) {
  $4 = (_tcgetattr(($3|0),(28760|0))|0);
  $5 = ($4|0)<(0);
  if (!($5)) {
   break;
  }
  $6 = (___errno_location()|0);
  $7 = HEAP32[$6>>2]|0;
  $8 = ($7|0)==(4);
  if (!($8)) {
   $$0 = -1;
   label = 15;
   break;
  }
 }
 if ((label|0) == 15) {
  STACKTOP = sp;return ($$0|0);
 }
 $9 = HEAP32[(28772)>>2]|0;
 $10 = $9 & 4096;
 $11 = ($10|0)==(0);
 if (!($11)) {
  __rl_errmsg(28616,$vararg_buffer);
  $12 = HEAP32[(28772)>>2]|0;
  $13 = $12 & -4097;
  HEAP32[(28772)>>2] = $13;
 }
 dest=28824; src=28760; stop=dest+60|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $14 = HEAP32[(28836)>>2]|0;
 $15 = $14 & -2;
 HEAP32[(28836)>>2] = $15;
 $16 = HEAP32[28824>>2]|0;
 $17 = $16 & -1025;
 HEAP32[28824>>2] = $17;
 $18 = HEAP32[13504>>2]|0;
 $19 = (_fileno(($18|0))|0);
 $20 = (_tcsetattr(($19|0),1,(28824|0))|0);
 $21 = ($20|0)<(0);
 L13: do {
  if ($21) {
   $22 = (___errno_location()|0);
   while(1) {
    $23 = HEAP32[$22>>2]|0;
    $24 = ($23|0)==(4);
    if (!($24)) {
     break;
    }
    HEAP32[$22>>2] = 0;
    $25 = (_tcsetattr(($19|0),1,(28824|0))|0);
    $26 = ($25|0)<(0);
    if (!($26)) {
     break L13;
    }
   }
   $27 = HEAP32[13504>>2]|0;
   $28 = (_fileno(($27|0))|0);
   $29 = (_tcsetattr(($28|0),1,(28760|0))|0);
   $30 = ($29|0)<(0);
   if (!($30)) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
   while(1) {
    $31 = HEAP32[$22>>2]|0;
    $32 = ($31|0)==(4);
    if (!($32)) {
     $$0 = -1;
     label = 15;
     break;
    }
    HEAP32[$22>>2] = 0;
    $33 = (_tcsetattr(($28|0),1,(28760|0))|0);
    $34 = ($33|0)<(0);
    if (!($34)) {
     $$0 = 0;
     label = 15;
     break;
    }
   }
   if ((label|0) == 15) {
    STACKTOP = sp;return ($$0|0);
   }
  }
 } while(0);
 HEAP32[28752>>2] = 1;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __rl_restore_tty_signals() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[28752>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = HEAP32[13504>>2]|0;
 $3 = (_fileno(($2|0))|0);
 $4 = (_tcsetattr(($3|0),1,(28760|0))|0);
 $5 = ($4|0)<(0);
 L4: do {
  if ($5) {
   $6 = (___errno_location()|0);
   while(1) {
    $7 = HEAP32[$6>>2]|0;
    $8 = ($7|0)==(4);
    if (!($8)) {
     $$0 = -1;
     break;
    }
    HEAP32[$6>>2] = 0;
    $9 = (_tcsetattr(($3|0),1,(28760|0))|0);
    $10 = ($9|0)<(0);
    if (!($10)) {
     break L4;
    }
   }
   return ($$0|0);
  }
 } while(0);
 HEAP32[28752>>2] = 0;
 $$0 = 0;
 return ($$0|0);
}
function _rl_complete($ignore,$invoking_key) {
 $ignore = $ignore|0;
 $invoking_key = $invoking_key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[29240>>2] = $invoking_key;
 $0 = HEAP32[29248>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (__rl_insert_char($ignore,$invoking_key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13496>>2]|0;
 $4 = ($3|0)!=(165|0);
 $5 = HEAP32[29288>>2]|0;
 $6 = ($5|0)!=(0);
 $or$cond = $4 | $6;
 if (!($or$cond)) {
  $7 = (_rl_complete_internal(63)|0);
  $$0 = $7;
  return ($$0|0);
 }
 $8 = HEAP32[28896>>2]|0;
 $9 = ($8|0)==(0);
 if (!($9)) {
  $10 = (_rl_complete_internal(33)|0);
  $$0 = $10;
  return ($$0|0);
 }
 $11 = HEAP32[28904>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  $14 = (_rl_complete_internal(9)|0);
  $$0 = $14;
  return ($$0|0);
 } else {
  $13 = (_rl_complete_internal(64)|0);
  $$0 = $13;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_complete_internal($what_to_do) {
 $what_to_do = $what_to_do|0;
 var $$0 = 0, $$0$i = 0, $$point$i = 0, $$pre = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $delimiter = 0, $found_quote = 0, $i$01$i = 0, $i$01$i3 = 0, $i$09$i = 0, $matches = 0;
 var $or$cond$i = 0, $or$cond$i2$i = 0, $or$cond3$i$i = 0, $or$cond3$i3$i = 0, $or$cond5$i$i = 0, $or$cond5$i6$i = 0, $quote_char = 0, $replacement$0$i$i = 0, $replacement$0$i7$i = 0, $should_quote$0$i$i = 0, $should_quote$0$i4$i = 0, $tlen$0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $matches = sp + 12|0;
 $delimiter = sp + 8|0;
 $found_quote = sp + 4|0;
 $quote_char = sp + 16|0;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 16384;
 HEAP32[13488>>2] = $1;
 HEAP32[29160>>2] = 0;
 HEAP32[29168>>2] = 1;
 HEAP32[29072>>2] = $what_to_do;
 HEAP32[29224>>2] = 0;
 HEAP32[29208>>2] = 0;
 HEAP32[29216>>2] = 32;
 $2 = HEAP32[28920>>2]|0;
 HEAP32[29280>>2] = $2;
 $3 = HEAP32[13632>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $30 = 0;
 } else {
  $5 = (_strlen(($3|0))|0);
  $6 = (($5) + 1)|0;
  $7 = (_xmalloc($6)|0);
  $8 = HEAP32[13632>>2]|0;
  $9 = (_strcpy(($7|0),($8|0))|0);
  $30 = $9;
 }
 $10 = HEAP32[29040>>2]|0;
 $11 = ($10|0)!=(0|0);
 $12 = $11 ? $10 : 365;
 $13 = HEAP32[13784>>2]|0;
 HEAP32[$delimiter>>2] = 0;
 HEAP32[$found_quote>>2] = 0;
 HEAP8[$quote_char>>0] = 0;
 $14 = ($13|0)==(0);
 if ($14) {
  $16 = 0;$20 = 0;
 } else {
  $15 = (__rl_find_completion_word($found_quote,$delimiter)|0);
  HEAP8[$quote_char>>0] = $15;
  $$pre = HEAP32[13784>>2]|0;
  $16 = $$pre;$20 = $15;
 }
 HEAP32[13784>>2] = $13;
 $17 = (_rl_copy_text($16,$13)|0);
 $18 = HEAP32[$found_quote>>2]|0;
 $19 = $20 << 24 >> 24;
 $21 = (_gen_completion_matches($17,$16,$13,$12,$18,$19)|0);
 HEAP32[$matches>>2] = $21;
 $22 = ($21|0)==(0|0);
 if ($22) {
  $27 = 0;
 } else {
  $23 = HEAP32[$21>>2]|0;
  $24 = (_strcmp($17,$23)|0);
  $25 = ($24|0)!=(0);
  $27 = $25;
 }
 $26 = $27&1;
 if ((($what_to_do|0) == 33) | (($what_to_do|0) == 64)) {
  $28 = (_strlen(($17|0))|0);
  $tlen$0 = $28;
 } else {
  $tlen$0 = 0;
 }
 _xfree($17);
 if ($22) {
  (_rl_ding()|0);
  $29 = ($30|0)==(0|0);
  if (!($29)) {
   _free($30);
  }
  HEAP32[29288>>2] = 0;
  $31 = HEAP32[13488>>2]|0;
  $32 = $31 & -16385;
  HEAP32[13488>>2] = $32;
  HEAP32[29256>>2] = 0;
  HEAP32[29264>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $33 = HEAP32[29160>>2]|0;
 $34 = (_postprocess_matches($matches,$33)|0);
 $35 = ($34|0)==(0);
 if ($35) {
  (_rl_ding()|0);
  $36 = ($30|0)==(0|0);
  if (!($36)) {
   _free($30);
  }
  HEAP32[29288>>2] = 0;
  $37 = HEAP32[13488>>2]|0;
  $38 = $37 & -16385;
  HEAP32[13488>>2] = $38;
  HEAP32[29256>>2] = 0;
  HEAP32[29264>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 L27: do {
  switch ($what_to_do|0) {
  case 42:  {
   $66 = HEAP32[$matches>>2]|0;
   (_rl_begin_undo_group()|0);
   $67 = HEAP8[$quote_char>>0]|0;
   $68 = ($67<<24>>24)!=(0);
   $69 = ($16|0)!=(0);
   $or$cond$i = $69 & $68;
   if ($or$cond$i) {
    $70 = (($16) + -1)|0;
    $71 = HEAP32[13632>>2]|0;
    $72 = (($71) + ($70)|0);
    $73 = HEAP8[$72>>0]|0;
    $74 = ($73<<24>>24)==($67<<24>>24);
    $$point$i = $74 ? $70 : $16;
    $$0$i = $$point$i;
   } else {
    $$0$i = $16;
   }
   $75 = HEAP32[13784>>2]|0;
   (_rl_delete_text($$0$i,$75)|0);
   HEAP32[13784>>2] = $$0$i;
   $76 = ((($66)) + 4|0);
   $77 = HEAP32[$76>>2]|0;
   $78 = ($77|0)==(0|0);
   if ($78) {
    $109 = HEAP32[$66>>2]|0;
    $110 = ($109|0)!=(0|0);
    $111 = HEAP32[29128>>2]|0;
    $112 = ($111|0)!=(0|0);
    $or$cond$i2$i = $110 & $112;
    $113 = HEAP32[29160>>2]|0;
    $114 = ($113|0)!=(0);
    $or$cond3$i3$i = $or$cond$i2$i & $114;
    if ($or$cond3$i3$i) {
     $115 = HEAP32[29168>>2]|0;
     $116 = ($115|0)!=(0);
     $117 = $116&1;
     if ($116) {
      $118 = HEAP8[$quote_char>>0]|0;
      $119 = ($118<<24>>24)==(0);
      if ($119) {
       $124 = 1;
      } else {
       $120 = $118 << 24 >> 24;
       $121 = (_strchr($111,$120)|0);
       $122 = ($121|0)!=(0|0);
       $124 = $122;
      }
      $123 = $124&1;
      $should_quote$0$i4$i = $123;
     } else {
      $should_quote$0$i4$i = $117;
     }
     $125 = ($should_quote$0$i4$i|0)==(0);
     if ($125) {
      $replacement$0$i7$i = $109;
     } else {
      $126 = HEAP32[29136>>2]|0;
      $127 = ($126|0)==(0|0);
      if ($127) {
       $replacement$0$i7$i = $109;
      } else {
       $128 = (_strpbrk($109,$126)|0);
       $129 = ($128|0)!=(0|0);
       $130 = HEAP32[29184>>2]|0;
       $131 = ($130|0)!=(0|0);
       $or$cond5$i6$i = $129 & $131;
       if ($or$cond5$i6$i) {
        $132 = (FUNCTION_TABLE_iiii[$130 & 511]($109,1,$quote_char)|0);
        $replacement$0$i7$i = $132;
       } else {
        $replacement$0$i7$i = $109;
       }
      }
     }
    } else {
     $replacement$0$i7$i = $109;
    }
    (_rl_insert_text($replacement$0$i7$i)|0);
    (_rl_insert_text(36328)|0);
    $133 = HEAP32[$66>>2]|0;
    $134 = ($replacement$0$i7$i|0)==($133|0);
    if (!($134)) {
     _xfree($replacement$0$i7$i);
    }
   } else {
    $103 = $76;$96 = $77;$i$09$i = 1;
    while(1) {
     $79 = HEAP32[29128>>2]|0;
     $80 = ($79|0)!=(0|0);
     $81 = HEAP32[29160>>2]|0;
     $82 = ($81|0)!=(0);
     $or$cond3$i$i = $80 & $82;
     if ($or$cond3$i$i) {
      $83 = HEAP32[29168>>2]|0;
      $84 = ($83|0)!=(0);
      $85 = $84&1;
      if ($84) {
       $86 = HEAP8[$quote_char>>0]|0;
       $87 = ($86<<24>>24)==(0);
       if ($87) {
        $92 = 1;
       } else {
        $88 = $86 << 24 >> 24;
        $89 = (_strchr($79,$88)|0);
        $90 = ($89|0)!=(0|0);
        $92 = $90;
       }
       $91 = $92&1;
       $should_quote$0$i$i = $91;
      } else {
       $should_quote$0$i$i = $85;
      }
      $93 = ($should_quote$0$i$i|0)==(0);
      if ($93) {
       $replacement$0$i$i = $96;
      } else {
       $94 = HEAP32[29136>>2]|0;
       $95 = ($94|0)==(0|0);
       if ($95) {
        $replacement$0$i$i = $96;
       } else {
        $97 = (_strpbrk($96,$94)|0);
        $98 = ($97|0)!=(0|0);
        $99 = HEAP32[29184>>2]|0;
        $100 = ($99|0)!=(0|0);
        $or$cond5$i$i = $98 & $100;
        if ($or$cond5$i$i) {
         $101 = (FUNCTION_TABLE_iiii[$99 & 511]($96,1,$quote_char)|0);
         $replacement$0$i$i = $101;
        } else {
         $replacement$0$i$i = $96;
        }
       }
      }
     } else {
      $replacement$0$i$i = $96;
     }
     (_rl_insert_text($replacement$0$i$i)|0);
     (_rl_insert_text(36328)|0);
     $102 = HEAP32[$103>>2]|0;
     $104 = ($replacement$0$i$i|0)==($102|0);
     if (!($104)) {
      _xfree($replacement$0$i$i);
     }
     $105 = (($i$09$i) + 1)|0;
     $106 = (($66) + ($105<<2)|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==(0|0);
     if ($108) {
      break;
     } else {
      $103 = $106;$96 = $107;$i$09$i = $105;
     }
    }
   }
   (_rl_end_undo_group()|0);
   $153 = $66;
   label = 72;
   break;
  }
  case 63:  {
   $135 = HEAP32[28888>>2]|0;
   $136 = ($135|0)==(0|0);
   if ($136) {
    HEAP32[32696>>2] = 366;
    $137 = HEAP32[$matches>>2]|0;
    HEAP32[32704>>2] = $137;
    $138 = $137;
    $139 = $138;
   } else {
    $$pre8 = HEAP32[$matches>>2]|0;
    $139 = $$pre8;
   }
   _display_matches($139);
   HEAP32[32696>>2] = 0;
   HEAP32[32704>>2] = 0;
   $153 = $139;
   label = 72;
   break;
  }
  case 64: case 33: case 9:  {
   $39 = ($what_to_do|0)==(9);
   $40 = HEAP32[$matches>>2]|0;
   $41 = HEAP32[$40>>2]|0;
   $42 = HEAP8[$41>>0]|0;
   $43 = ($42<<24>>24)==(0);
   do {
    if ($39) {
     if (!($43)) {
      $44 = ((($40)) + 4|0);
      $45 = HEAP32[$44>>2]|0;
      $46 = ($45|0)!=(0|0);
      $47 = $46 ? 2 : 1;
      _insert_match($41,$16,$47,$quote_char);
     }
    } else {
     if (!($43)) {
      $48 = ((($40)) + 4|0);
      $49 = HEAP32[$48>>2]|0;
      $50 = ($49|0)==(0|0);
      if ($50) {
       _insert_match($41,$16,1,$quote_char);
       break;
      }
      $51 = (_strlen(($41|0))|0);
      $52 = ($51|0)<($tlen$0|0);
      if (!($52)) {
       $53 = ((($40)) + 4|0);
       $54 = HEAP32[$53>>2]|0;
       $55 = ($54|0)!=(0|0);
       $56 = $55 ? 2 : 1;
       _insert_match($41,$16,$56,$quote_char);
      }
     }
    }
   } while(0);
   $57 = ((($40)) + 4|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = ($58|0)==(0|0);
   if ($59) {
    $62 = HEAP32[$40>>2]|0;
    $63 = HEAP32[$delimiter>>2]|0;
    $64 = HEAP8[$quote_char>>0]|0;
    $65 = $64 << 24 >> 24;
    _append_to_match($62,$63,$65,$26);
    $155 = $40;
    label = 73;
    break L27;
   }
   if ((($what_to_do|0) == 33)) {
    _display_matches($40);
    $155 = $40;
    label = 73;
    break L27;
   } else if ((($what_to_do|0) == 64)) {
    if ($27) {
     $155 = $40;
     label = 73;
     break L27;
    }
    _display_matches($40);
    $155 = $40;
    label = 73;
    break L27;
   } else {
    $60 = HEAP32[13440>>2]|0;
    $61 = ($60|0)==(0);
    if ($61) {
     $155 = $40;
     label = 73;
     break L27;
    }
    (_rl_ding()|0);
    $155 = $40;
    label = 73;
    break L27;
   }
   break;
  }
  default: {
   HEAP32[$vararg_buffer>>2] = $what_to_do;
   __rl_ttymsg(29296,$vararg_buffer);
   (_rl_ding()|0);
   $140 = ($30|0)==(0|0);
   if (!($140)) {
    _free($30);
   }
   $141 = HEAP32[13488>>2]|0;
   $142 = $141 & -16385;
   HEAP32[13488>>2] = $142;
   $143 = HEAP32[$matches>>2]|0;
   $144 = ($143|0)==(0|0);
   if (!($144)) {
    $145 = HEAP32[$143>>2]|0;
    $146 = ($145|0)==(0|0);
    if (!($146)) {
     $147 = $145;$i$01$i3 = 0;
     while(1) {
      _xfree($147);
      $148 = (($i$01$i3) + 1)|0;
      $149 = (($143) + ($148<<2)|0);
      $150 = HEAP32[$149>>2]|0;
      $151 = ($150|0)==(0|0);
      if ($151) {
       break;
      } else {
       $147 = $150;$i$01$i3 = $148;
      }
     }
    }
    _xfree($143);
   }
   HEAP32[29256>>2] = 0;
   HEAP32[29264>>2] = 0;
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  }
 } while(0);
 if ((label|0) == 72) {
  $152 = ($153|0)==(0|0);
  if (!($152)) {
   $155 = $153;
   label = 73;
  }
 }
 if ((label|0) == 73) {
  $154 = HEAP32[$155>>2]|0;
  $156 = ($154|0)==(0|0);
  if (!($156)) {
   $157 = $154;$i$01$i = 0;
   while(1) {
    _xfree($157);
    $158 = (($i$01$i) + 1)|0;
    $159 = (($155) + ($158<<2)|0);
    $160 = HEAP32[$159>>2]|0;
    $161 = ($160|0)==(0|0);
    if ($161) {
     break;
    } else {
     $157 = $160;$i$01$i = $158;
    }
   }
  }
  _xfree($155);
 }
 $162 = ($30|0)==(0|0);
 if (!($162)) {
  $163 = HEAP32[13632>>2]|0;
  $164 = (_strcmp($163,$30)|0);
  $165 = ($164|0)!=(0);
  $166 = $165&1;
  HEAP32[29288>>2] = $166;
  _xfree($30);
 }
 $167 = HEAP32[13488>>2]|0;
 $168 = $167 & -16385;
 HEAP32[13488>>2] = $168;
 HEAP32[29256>>2] = 0;
 HEAP32[29264>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _rl_possible_completions($ignore,$invoking_key) {
 $ignore = $ignore|0;
 $invoking_key = $invoking_key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[29240>>2] = $invoking_key;
 $0 = (_rl_complete_internal(63)|0);
 return ($0|0);
}
function _rl_insert_completions($ignore,$invoking_key) {
 $ignore = $ignore|0;
 $invoking_key = $invoking_key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[29240>>2] = $invoking_key;
 $0 = (_rl_complete_internal(42)|0);
 return ($0|0);
}
function __rl_reset_completion_state() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[29256>>2] = 0;
 HEAP32[29264>>2] = 0;
 return;
}
function __rl_find_completion_word($fp,$dp) {
 $fp = $fp|0;
 $dp = $dp|0;
 var $$ = 0, $$brkchars$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre13 = 0, $$pre14$pre$pre = 0, $$sink3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $brkchars$0 = 0, $cond = 0, $delimiter$0 = 0, $delimiter$1 = 0, $found_quote$09 = 0, $found_quote$1 = 0, $found_quote$2 = 0, $or$cond = 0, $or$cond2 = 0, $pass_next$010 = 0, $pass_next$1 = 0, $quote_char$011 = 0, $quote_char$1 = 0, $quote_char$2 = 0, $scan$0$be = 0, $scan$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[29120>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $brkchars$0 = 0;
 } else {
  $3 = (FUNCTION_TABLE_i[$1 & 511]()|0);
  $brkchars$0 = $3;
 }
 $4 = ($brkchars$0|0)==(0|0);
 $5 = HEAP32[29112>>2]|0;
 $$brkchars$0 = $4 ? $5 : $brkchars$0;
 $6 = HEAP32[29128>>2]|0;
 $7 = ($6|0)!=(0|0);
 $8 = ($0|0)>(0);
 $or$cond = $7 & $8;
 if ($or$cond) {
  $found_quote$09 = 0;$pass_next$010 = 0;$quote_char$011 = 0;$scan$07 = 0;
  while(1) {
   $9 = ($pass_next$010|0)==(0);
   do {
    if ($9) {
     $cond = ($quote_char$011<<24>>24)==(39);
     $$pre = HEAP32[13632>>2]|0;
     $$phi$trans$insert = (($$pre) + ($scan$07)|0);
     $$pre13 = HEAP8[$$phi$trans$insert>>0]|0;
     if (!($cond)) {
      $10 = ($$pre13<<24>>24)==(92);
      if ($10) {
       $11 = $found_quote$09 | 4;
       $found_quote$1 = $11;$pass_next$1 = 1;$quote_char$1 = $quote_char$011;
       break;
      }
      $12 = ($quote_char$011<<24>>24)==(0);
      if ($12) {
       $14 = HEAP32[29128>>2]|0;
       $15 = $$pre13 << 24 >> 24;
       $16 = (_strchr($14,$15)|0);
       $17 = ($16|0)==(0|0);
       if ($17) {
        $found_quote$1 = $found_quote$09;$pass_next$1 = 0;$quote_char$1 = 0;
        break;
       }
       $18 = (($scan$07) + 1)|0;
       HEAP32[13784>>2] = $18;
       if ((($$pre13<<24>>24) == 34)) {
        $20 = $found_quote$09 | 2;
        $found_quote$1 = $20;$pass_next$1 = 0;$quote_char$1 = 34;
        break;
       } else if ((($$pre13<<24>>24) == 39)) {
        $19 = $found_quote$09 | 1;
        $found_quote$1 = $19;$pass_next$1 = 0;$quote_char$1 = 39;
        break;
       } else {
        $21 = $found_quote$09 | 8;
        $found_quote$1 = $21;$pass_next$1 = 0;$quote_char$1 = $$pre13;
        break;
       }
      }
     }
     $13 = ($$pre13<<24>>24)==($quote_char$011<<24>>24);
     if ($13) {
      HEAP32[13784>>2] = $0;
      $found_quote$1 = $found_quote$09;$pass_next$1 = 0;$quote_char$1 = 0;
     } else {
      $found_quote$1 = $found_quote$09;$pass_next$1 = 0;$quote_char$1 = $quote_char$011;
     }
    } else {
     $found_quote$1 = $found_quote$09;$pass_next$1 = 0;$quote_char$1 = $quote_char$011;
    }
   } while(0);
   $22 = HEAP32[36240>>2]|0;
   $23 = ($22|0)==(0);
   if ($23) {
    $24 = HEAP32[13632>>2]|0;
    $25 = (__rl_find_next_mbchar($24,$scan$07,1,0)|0);
    $scan$0$be = $25;
   } else {
    $26 = (($scan$07) + 1)|0;
    $scan$0$be = $26;
   }
   $27 = ($scan$0$be|0)<($0|0);
   if ($27) {
    $found_quote$09 = $found_quote$1;$pass_next$010 = $pass_next$1;$quote_char$011 = $quote_char$1;$scan$07 = $scan$0$be;
   } else {
    $found_quote$2 = $found_quote$1;$quote_char$2 = $quote_char$1;
    break;
   }
  }
 } else {
  $found_quote$2 = 0;$quote_char$2 = 0;
 }
 $28 = HEAP32[13784>>2]|0;
 $29 = ($28|0)==($0|0);
 $30 = ($quote_char$2<<24>>24)==(0);
 $or$cond2 = $30 & $29;
 L28: do {
  if ($or$cond2) {
   $31 = ($found_quote$2|0)==(0);
   if ($31) {
    $54 = $0;
    while(1) {
     $51 = HEAP32[36240>>2]|0;
     $52 = ($51|0)==(0);
     if ($52) {
      $53 = HEAP32[13632>>2]|0;
      $55 = (__rl_find_prev_mbchar($53,$54,0)|0);
      $57 = $55;
     } else {
      $56 = (($54) + -1)|0;
      $57 = $56;
     }
     HEAP32[13784>>2] = $57;
     $58 = ($57|0)==(0);
     if ($58) {
      $67 = 0;
      break L28;
     }
     $59 = HEAP32[13632>>2]|0;
     $60 = (($59) + ($57)|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61 << 24 >> 24;
     $63 = (_strchr($$brkchars$0,$62)|0);
     $64 = ($63|0)==(0|0);
     if ($64) {
      $54 = $57;
     } else {
      $67 = $57;
      break L28;
     }
    }
   }
   while(1) {
    $32 = HEAP32[36240>>2]|0;
    $33 = ($32|0)==(0);
    if ($33) {
     $36 = HEAP32[13632>>2]|0;
     $37 = HEAP32[13784>>2]|0;
     $38 = (__rl_find_prev_mbchar($36,$37,0)|0);
     $39 = $38;
    } else {
     $34 = HEAP32[13784>>2]|0;
     $35 = (($34) + -1)|0;
     $39 = $35;
    }
    HEAP32[13784>>2] = $39;
    $40 = ($39|0)==(0);
    if ($40) {
     $67 = 0;
     break L28;
    }
    $41 = HEAP32[13632>>2]|0;
    $42 = (($41) + ($39)|0);
    $43 = HEAP8[$42>>0]|0;
    $44 = $43 << 24 >> 24;
    $45 = (_strchr($$brkchars$0,$44)|0);
    $46 = ($45|0)==(0|0);
    if ($46) {
     continue;
    }
    $47 = HEAP32[29200>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     $67 = $39;
     break L28;
    }
    $49 = (FUNCTION_TABLE_iii[$47 & 511]($41,$39)|0);
    $50 = ($49|0)==(0);
    if ($50) {
     break;
    }
   }
   $$pre14$pre$pre = HEAP32[13784>>2]|0;
   $67 = $$pre14$pre$pre;
  } else {
   $67 = $28;
  }
 } while(0);
 $65 = HEAP32[13632>>2]|0;
 $66 = (($65) + ($67)|0);
 $68 = HEAP8[$66>>0]|0;
 $69 = $68 << 24 >> 24;
 $70 = ($68<<24>>24)==(0);
 do {
  if ($70) {
   $delimiter$1 = 0;
  } else {
   $71 = HEAP32[29200>>2]|0;
   $72 = ($71|0)==(0|0);
   if ($72) {
    $77 = (_strchr($$brkchars$0,$69)|0);
    $$sink3 = $77;
   } else {
    $73 = ($found_quote$2|0)==(0);
    if (!($73)) {
     $74 = (FUNCTION_TABLE_iii[$71 & 511]($65,$67)|0);
     $75 = ($74|0)==(0);
     if (!($75)) {
      $delimiter$1 = 0;
      break;
     }
    }
    $76 = (_strchr($$brkchars$0,$69)|0);
    $$sink3 = $76;
   }
   $78 = ($$sink3|0)==(0|0);
   if ($78) {
    $delimiter$1 = 0;
   } else {
    $79 = HEAP32[29104>>2]|0;
    $80 = ($79|0)==(0|0);
    if ($80) {
     $delimiter$0 = 0;
    } else {
     $81 = (_strchr($79,$69)|0);
     $82 = ($81|0)==(0|0);
     if ($82) {
      $delimiter$0 = 0;
     } else {
      $83 = HEAP32[13784>>2]|0;
      $84 = (($0) - ($83))|0;
      $85 = ($84|0)>(1);
      $$ = $85 ? $69 : 0;
      $delimiter$0 = $$;
     }
    }
    $86 = HEAP32[29144>>2]|0;
    $87 = ($86|0)==(0|0);
    if (!($87)) {
     $88 = (_strchr($86,$69)|0);
     $89 = ($88|0)==(0|0);
     if (!($89)) {
      $delimiter$1 = $delimiter$0;
      break;
     }
    }
    $90 = HEAP32[13784>>2]|0;
    $91 = (($90) + 1)|0;
    HEAP32[13784>>2] = $91;
    $delimiter$1 = $delimiter$0;
   }
  }
 } while(0);
 $92 = ($fp|0)==(0|0);
 if (!($92)) {
  HEAP32[$fp>>2] = $found_quote$2;
 }
 $93 = ($dp|0)==(0|0);
 if ($93) {
  return ($quote_char$2|0);
 }
 HEAP32[$dp>>2] = $delimiter$1;
 return ($quote_char$2|0);
}
function _rl_display_match_list($matches,$len,$max) {
 $matches = $matches|0;
 $len = $len|0;
 $max = $max|0;
 var $$0 = 0, $$0$i = 0, $$0$i33 = 0, $$0$i43 = 0, $$cols$0$i = 0, $$lcssa = 0, $$lcssa191 = 0, $$lcssa206 = 0, $$limit$0 = 0, $$neg62 = 0, $$pn$i = 0, $$pn$i$lcssa = 0, $$pn$i26 = 0, $$pn$i26$lcssa = 0, $$pn$i36 = 0, $$pn$i36$lcssa = 0, $$pr = 0, $$pre$i48 = 0, $$pre$i52 = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cols$0$i = 0, $exitcond = 0, $exitcond118 = 0, $i$096 = 0, $i$1$ph103 = 0, $i$199 = 0, $j$091 = 0, $k$089 = 0;
 var $k$197 = 0, $l$092 = 0, $limit$0 = 0, $limit$2 = 0, $lines$095 = 0, $lines$1 = 0, $lines$2$ph$be = 0, $lines$2$ph102 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond10 = 0, $or$cond1090 = 0, $or$cond11 = 0, $or$cond2$i = 0, $or$cond2$i18 = 0, $or$cond3 = 0, $or$cond3$i = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0;
 var $or$cond9$i = 0, $or$cond9$i51 = 0, $phitmp1$i = 0, $phitmp1$i31 = 0, $phitmp1$i41 = 0, $pos$0$be$i = 0, $pos$0$be$i20 = 0, $pos$03$i = 0, $pos$03$i17 = 0, $ps$i = 0, $ps$i13 = 0, $sind$0 = 0, $wc$i = 0, $wc$i15 = 0, $width$0$be$i = 0, $width$0$be$i21 = 0, $width$0$lcssa$i = 0, $width$0$lcssa$i23 = 0, $width$04$i = 0, $width$04$i16 = 0;
 var $x$0$i = 0, $x$0$i27 = 0, $x$0$i37 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps$i13 = sp + 8|0;
 $wc$i15 = sp + 20|0;
 $ps$i = sp;
 $wc$i = sp + 16|0;
 $0 = HEAP32[28952>>2]|0;
 $1 = ($0|0)>(0);
 if ($1) {
  $2 = HEAP32[$matches>>2]|0;
  $3 = HEAP32[29160>>2]|0;
  $4 = ($3|0)==(0);
  L3: do {
   if ($4) {
    $$0$i = $2;
   } else {
    $5 = (_strrchr($2,47)|0);
    $6 = ($5|0)==(0|0);
    if ($6) {
     $$0$i = $2;
    } else {
     $7 = HEAP8[$5>>0]|0;
     $8 = ($7<<24>>24)==(0);
     if ($8) {
      $$0$i = $2;
     } else {
      $9 = ((($5)) + 1|0);
      $10 = HEAP8[$9>>0]|0;
      $11 = ($10<<24>>24)==(0);
      if ($11) {
       $$pn$i = $5;
       while(1) {
        $x$0$i = ((($$pn$i)) + -1|0);
        $12 = ($x$0$i>>>0)>($2>>>0);
        $13 = HEAP8[$x$0$i>>0]|0;
        $14 = ($13<<24>>24)==(47);
        if (!($12)) {
         $$lcssa206 = $14;$$pn$i$lcssa = $$pn$i;
         break;
        }
        if ($14) {
         $$0$i = $$pn$i;
         break L3;
        } else {
         $$pn$i = $x$0$i;
        }
       }
       $phitmp1$i = $$lcssa206 ? $$pn$i$lcssa : $2;
       $$0$i = $phitmp1$i;
      } else {
       $$0$i = $9;
      }
     }
    }
   }
  } while(0);
  $15 = (_strrchr($$0$i,47)|0);
  $16 = ($15|0)!=(0|0);
  if ($16) {
   $17 = (_strlen(($15|0))|0);
   $18 = (($17) + 1)|0;
   $19 = $ps$i;
   $20 = $19;
   HEAP32[$20>>2] = 0;
   $21 = (($19) + 4)|0;
   $22 = $21;
   HEAP32[$22>>2] = 0;
   $23 = HEAP8[$15>>0]|0;
   $24 = ($23<<24>>24)==(0);
   L14: do {
    if ($24) {
     $width$0$lcssa$i = 0;
    } else {
     $26 = $23;$31 = $15;$pos$03$i = 0;$width$04$i = 0;
     while(1) {
      $25 = ($26&255)<(32);
      $27 = ($26<<24>>24)==(127);
      $or$cond2$i = $25 | $27;
      do {
       if ($or$cond2$i) {
        $28 = (($width$04$i) + 2)|0;
        $29 = (($pos$03$i) + 1)|0;
        $pos$0$be$i = $29;$width$0$be$i = $28;
       } else {
        $30 = (($18) - ($pos$03$i))|0;
        $32 = (_mbrtowc($wc$i,$31,$30,$ps$i)|0);
        $33 = ($32>>>0)>(4294967293);
        if ($33) {
         $34 = (($width$04$i) + 1)|0;
         $35 = (($pos$03$i) + 1)|0;
         $36 = $ps$i;
         $37 = $36;
         HEAP32[$37>>2] = 0;
         $38 = (($36) + 4)|0;
         $39 = $38;
         HEAP32[$39>>2] = 0;
         $pos$0$be$i = $35;$width$0$be$i = $34;
         break;
        }
        $43 = ($32|0)==(0);
        if ($43) {
         $width$0$lcssa$i = $width$04$i;
         break L14;
        }
        $44 = (($32) + ($pos$03$i))|0;
        $45 = HEAP32[$wc$i>>2]|0;
        $46 = (_wcwidth($45)|0);
        $47 = ($46|0)>(-1);
        $48 = $47 ? $46 : 1;
        $49 = (($48) + ($width$04$i))|0;
        $pos$0$be$i = $44;$width$0$be$i = $49;
       }
      } while(0);
      $40 = (($15) + ($pos$0$be$i)|0);
      $41 = HEAP8[$40>>0]|0;
      $42 = ($41<<24>>24)==(0);
      if ($42) {
       $width$0$lcssa$i = $width$0$be$i;
       break;
      } else {
       $26 = $41;$31 = $40;$pos$03$i = $pos$0$be$i;$width$04$i = $width$0$be$i;
      }
     }
    }
   } while(0);
   $87 = $width$0$lcssa$i;
  } else {
   $50 = (_strlen(($$0$i|0))|0);
   $51 = (($50) + 1)|0;
   $52 = $ps$i13;
   $53 = $52;
   HEAP32[$53>>2] = 0;
   $54 = (($52) + 4)|0;
   $55 = $54;
   HEAP32[$55>>2] = 0;
   $56 = HEAP8[$$0$i>>0]|0;
   $57 = ($56<<24>>24)==(0);
   L27: do {
    if ($57) {
     $width$0$lcssa$i23 = 0;
    } else {
     $59 = $56;$64 = $$0$i;$pos$03$i17 = 0;$width$04$i16 = 0;
     while(1) {
      $58 = ($59&255)<(32);
      $60 = ($59<<24>>24)==(127);
      $or$cond2$i18 = $58 | $60;
      do {
       if ($or$cond2$i18) {
        $61 = (($width$04$i16) + 2)|0;
        $62 = (($pos$03$i17) + 1)|0;
        $pos$0$be$i20 = $62;$width$0$be$i21 = $61;
       } else {
        $63 = (($51) - ($pos$03$i17))|0;
        $65 = (_mbrtowc($wc$i15,$64,$63,$ps$i13)|0);
        $66 = ($65>>>0)>(4294967293);
        if ($66) {
         $67 = (($width$04$i16) + 1)|0;
         $68 = (($pos$03$i17) + 1)|0;
         $69 = $ps$i13;
         $70 = $69;
         HEAP32[$70>>2] = 0;
         $71 = (($69) + 4)|0;
         $72 = $71;
         HEAP32[$72>>2] = 0;
         $pos$0$be$i20 = $68;$width$0$be$i21 = $67;
         break;
        }
        $76 = ($65|0)==(0);
        if ($76) {
         $width$0$lcssa$i23 = $width$04$i16;
         break L27;
        }
        $77 = (($65) + ($pos$03$i17))|0;
        $78 = HEAP32[$wc$i15>>2]|0;
        $79 = (_wcwidth($78)|0);
        $80 = ($79|0)>(-1);
        $81 = $80 ? $79 : 1;
        $82 = (($81) + ($width$04$i16))|0;
        $pos$0$be$i20 = $77;$width$0$be$i21 = $82;
       }
      } while(0);
      $73 = (($$0$i) + ($pos$0$be$i20)|0);
      $74 = HEAP8[$73>>0]|0;
      $75 = ($74<<24>>24)==(0);
      if ($75) {
       $width$0$lcssa$i23 = $width$0$be$i21;
       break;
      } else {
       $59 = $74;$64 = $73;$pos$03$i17 = $pos$0$be$i20;$width$04$i16 = $width$0$be$i21;
      }
     }
    }
   } while(0);
   $87 = $width$0$lcssa$i23;
  }
  if ($16) {
   $83 = (_strlen(($15|0))|0);
   $228 = $83;
  } else {
   $84 = (_strlen(($$0$i|0))|0);
   $228 = $84;
  }
  $85 = HEAP32[28952>>2]|0;
  $86 = ($87|0)>($85|0);
  $88 = ($87|0)>(3);
  $or$cond = $88 & $86;
  if ($or$cond) {
   $$neg62 = (($max) + 3)|0;
   $89 = (($$neg62) - ($87))|0;
   $$0 = $89;$sind$0 = $228;
  } else {
   $$0 = $max;$sind$0 = 0;
  }
 } else {
  $$0 = $max;$sind$0 = 0;
 }
 $90 = HEAP32[28960>>2]|0;
 $91 = ($90|0)<(0);
 $92 = HEAP32[35112>>2]|0;
 $93 = ($90|0)>($92|0);
 $or$cond$i = $91 | $93;
 if ($or$cond$i) {
  $94 = (_getenv((38576|0))|0);
  $95 = ($94|0)==(0|0);
  if ($95) {
   $cols$0$i = $90;
  } else {
   $96 = HEAP8[$94>>0]|0;
   $97 = ($96<<24>>24)==(0);
   if ($97) {
    $cols$0$i = $90;
   } else {
    $98 = (_atoi($94)|0);
    $cols$0$i = $98;
   }
  }
  $99 = ($cols$0$i|0)<(0);
  $100 = ($cols$0$i|0)>($92|0);
  $or$cond3$i = $99 | $100;
  $$cols$0$i = $or$cond3$i ? $92 : $cols$0$i;
  $103 = $$cols$0$i;
 } else {
  $103 = $90;
 }
 $101 = (($$0) + 2)|0;
 $102 = (($103|0) / ($101|0))&-1;
 $104 = ($102|0)!=(1);
 $105 = Math_imul($102, $101)|0;
 $106 = ($105|0)==($103|0);
 $or$cond9 = $104 & $106;
 $107 = $or$cond9 << 31 >> 31;
 $limit$0 = (($107) + ($102))|0;
 $108 = ($103|0)<($92|0);
 $109 = ($limit$0|0)<(0);
 $or$cond3 = $108 & $109;
 $$limit$0 = $or$cond3 ? 1 : $limit$0;
 $110 = ($$limit$0|0)==(0);
 $limit$2 = $110 ? 1 : $$limit$0;
 $111 = (($len) + -1)|0;
 $112 = (($111) + ($limit$2))|0;
 $113 = (($112|0) / ($limit$2|0))&-1;
 $114 = HEAP32[29152>>2]|0;
 $115 = ($114|0)==(0);
 $116 = HEAP32[29232>>2]|0;
 $117 = ($116|0)!=(0);
 $or$cond5 = $115 & $117;
 if ($or$cond5) {
  $118 = ((($matches)) + 4|0);
  _qsort($118,$len,4,364);
 }
 (_rl_crlf()|0);
 $119 = HEAP32[29272>>2]|0;
 $120 = ($119|0)==(0);
 if ($120) {
  $126 = ($113|0)<(1);
  if ($126) {
   STACKTOP = sp;return;
  }
  $127 = ($limit$2|0)<(1);
  $i$096 = 1;$lines$095 = 0;
  L61: while(1) {
   $128 = ($i$096|0)>($len|0);
   $or$cond1090 = $127 | $128;
   L63: do {
    if (!($or$cond1090)) {
     $j$091 = 0;$l$092 = $i$096;
     while(1) {
      $129 = (($matches) + ($l$092<<2)|0);
      $130 = HEAP32[$129>>2]|0;
      $131 = ($130|0)==(0|0);
      if ($131) {
       break L63;
      }
      $132 = HEAP32[29160>>2]|0;
      $133 = ($132|0)==(0);
      L67: do {
       if ($133) {
        $$0$i33 = $130;
       } else {
        $134 = (_strrchr($130,47)|0);
        $135 = ($134|0)==(0|0);
        if ($135) {
         $$0$i33 = $130;
        } else {
         $136 = HEAP8[$134>>0]|0;
         $137 = ($136<<24>>24)==(0);
         if ($137) {
          $$0$i33 = $130;
         } else {
          $138 = ((($134)) + 1|0);
          $139 = HEAP8[$138>>0]|0;
          $140 = ($139<<24>>24)==(0);
          if ($140) {
           $$pn$i26 = $134;
           while(1) {
            $x$0$i27 = ((($$pn$i26)) + -1|0);
            $141 = ($x$0$i27>>>0)>($130>>>0);
            $142 = HEAP8[$x$0$i27>>0]|0;
            $143 = ($142<<24>>24)==(47);
            if (!($141)) {
             $$lcssa = $143;$$pn$i26$lcssa = $$pn$i26;
             break;
            }
            if ($143) {
             $$0$i33 = $$pn$i26;
             break L67;
            } else {
             $$pn$i26 = $x$0$i27;
            }
           }
           $phitmp1$i31 = $$lcssa ? $$pn$i26$lcssa : $130;
           $$0$i33 = $phitmp1$i31;
          } else {
           $$0$i33 = $138;
          }
         }
        }
       }
      } while(0);
      $144 = (_print_filename($$0$i33,$130,$sind$0)|0);
      $145 = (($j$091) + 1)|0;
      $146 = ($145|0)<($limit$2|0);
      if ($146) {
       $147 = (($101) - ($144))|0;
       $148 = ($147|0)>(0);
       if ($148) {
        $k$089 = 0;
        while(1) {
         $149 = HEAP32[13512>>2]|0;
         (_putc(32,($149|0))|0);
         $150 = (($k$089) + 1)|0;
         $exitcond = ($150|0)==($147|0);
         if ($exitcond) {
          break;
         } else {
          $k$089 = $150;
         }
        }
       }
      }
      $151 = (($l$092) + ($113))|0;
      $152 = ($145|0)>=($limit$2|0);
      $153 = ($151|0)>($len|0);
      $or$cond10 = $152 | $153;
      if ($or$cond10) {
       break;
      } else {
       $j$091 = $145;$l$092 = $151;
      }
     }
    }
   } while(0);
   (_rl_crlf()|0);
   $154 = (($lines$095) + 1)|0;
   $155 = HEAP32[29088>>2]|0;
   $156 = ($155|0)==(0);
   L82: do {
    if ($156) {
     $lines$1 = $154;
    } else {
     $157 = HEAP32[35120>>2]|0;
     $158 = (($157) + -1)|0;
     $159 = ($154|0)>=($158|0);
     $160 = ($i$096|0)<($113|0);
     $or$cond11 = $160 & $159;
     if ($or$cond11) {
      $161 = HEAP32[13512>>2]|0;
      (_fwrite((29344|0),8,1,($161|0))|0);
      $162 = HEAP32[13512>>2]|0;
      (_fflush(($162|0))|0);
      $163 = HEAP32[13488>>2]|0;
      $164 = $163 & 524288;
      $165 = ($164|0)==(0);
      L85: do {
       if ($165) {
        $167 = $163;
        while(1) {
         $166 = $167 | 64;
         HEAP32[13488>>2] = $166;
         $168 = (_rl_read_key()|0);
         $169 = HEAP32[13488>>2]|0;
         $170 = $169 & -65;
         HEAP32[13488>>2] = $170;
         switch ($168|0) {
         case 78: case 110: case 127:  {
          label = 67;
          break L61;
          break;
         }
         case 32: case 89: case 121:  {
          break L85;
          break;
         }
         default: {
         }
         }
         $171 = ($168|0)==(7);
         $172 = ($168|0)<(0);
         $or$cond9$i = $171 | $172;
         if ($or$cond9$i) {
          label = 63;
          break L61;
         }
         if ((($168|0) == 10) | (($168|0) == 13)) {
          break;
         }
         $173 = $168 & -33;
         $174 = ($173|0)==(81);
         if ($174) {
          label = 67;
          break L61;
         }
         (_rl_ding()|0);
         $$pre$i48 = HEAP32[13488>>2]|0;
         $167 = $$pre$i48;
        }
        __rl_erase_entire_line();
        $175 = ($lines$095|0)<(0);
        if ($175) {
         label = 100;
         break L61;
        } else {
         $lines$1 = $lines$095;
         break L82;
        }
       }
      } while(0);
      __rl_erase_entire_line();
      $lines$1 = 0;
     } else {
      $lines$1 = $154;
     }
    }
   } while(0);
   $176 = (($i$096) + 1)|0;
   $177 = ($i$096|0)<($113|0);
   if ($177) {
    $i$096 = $176;$lines$095 = $lines$1;
   } else {
    label = 100;
    break;
   }
  }
  if ((label|0) == 63) {
   (__rl_abort_internal()|0);
   // unreachable;
  }
  else if ((label|0) == 67) {
   __rl_erase_entire_line();
   STACKTOP = sp;return;
  }
  else if ((label|0) == 100) {
   STACKTOP = sp;return;
  }
 }
 $121 = ((($matches)) + 4|0);
 $122 = HEAP32[$121>>2]|0;
 $123 = ($122|0)==(0|0);
 L102: do {
  if (!($123)) {
   $124 = ($limit$2|0)==(1);
   $125 = ($limit$2|0)>(1);
   $229 = $122;$i$1$ph103 = 1;$lines$2$ph102 = 0;
   L104: while(1) {
    $207 = (($lines$2$ph102) + 1)|0;
    $208 = ($lines$2$ph102|0)<(0);
    $180 = $229;$i$199 = $i$1$ph103;
    L106: while(1) {
     $178 = HEAP32[29160>>2]|0;
     $179 = ($178|0)==(0);
     L108: do {
      if ($179) {
       $$0$i43 = $180;
      } else {
       $181 = (_strrchr($180,47)|0);
       $182 = ($181|0)==(0|0);
       if ($182) {
        $$0$i43 = $180;
       } else {
        $183 = HEAP8[$181>>0]|0;
        $184 = ($183<<24>>24)==(0);
        if ($184) {
         $$0$i43 = $180;
        } else {
         $185 = ((($181)) + 1|0);
         $186 = HEAP8[$185>>0]|0;
         $187 = ($186<<24>>24)==(0);
         if ($187) {
          $$pn$i36 = $181;
          while(1) {
           $x$0$i37 = ((($$pn$i36)) + -1|0);
           $188 = ($x$0$i37>>>0)>($180>>>0);
           $189 = HEAP8[$x$0$i37>>0]|0;
           $190 = ($189<<24>>24)==(47);
           if (!($188)) {
            $$lcssa191 = $190;$$pn$i36$lcssa = $$pn$i36;
            break;
           }
           if ($190) {
            $$0$i43 = $$pn$i36;
            break L108;
           } else {
            $$pn$i36 = $x$0$i37;
           }
          }
          $phitmp1$i41 = $$lcssa191 ? $$pn$i36$lcssa : $180;
          $$0$i43 = $phitmp1$i41;
         } else {
          $$0$i43 = $185;
         }
        }
       }
      }
     } while(0);
     $191 = (_print_filename($$0$i43,$180,$sind$0)|0);
     $192 = (($i$199) + 1)|0;
     $193 = (($matches) + ($192<<2)|0);
     $194 = HEAP32[$193>>2]|0;
     $195 = ($194|0)==(0|0);
     if ($195) {
      break L102;
     }
     do {
      if ($124) {
       label = 84;
      } else {
       $197 = ($i$199|0)!=(0);
       $or$cond7 = $125 & $197;
       if ($or$cond7) {
        $200 = (($i$199|0) % ($limit$2|0))&-1;
        $201 = ($200|0)==(0);
        if ($201) {
         label = 84;
         break;
        }
       }
       $198 = (($101) - ($191))|0;
       $199 = ($198|0)>(0);
       if ($199) {
        $k$197 = 0;
        while(1) {
         $226 = HEAP32[13512>>2]|0;
         (_putc(32,($226|0))|0);
         $227 = (($k$197) + 1)|0;
         $exitcond118 = ($227|0)==($198|0);
         if ($exitcond118) {
          break;
         } else {
          $k$197 = $227;
         }
        }
       }
      }
     } while(0);
     if ((label|0) == 84) {
      label = 0;
      (_rl_crlf()|0);
      $202 = HEAP32[29088>>2]|0;
      $203 = ($202|0)==(0);
      if ($203) {
       $224 = $193;$230 = $192;$lines$2$ph$be = $207;
       break;
      }
      $204 = HEAP32[35120>>2]|0;
      $205 = (($204) + -1)|0;
      $206 = ($207|0)<($205|0);
      if ($206) {
       $224 = $193;$230 = $192;$lines$2$ph$be = $207;
       break;
      }
      $209 = HEAP32[13512>>2]|0;
      (_fwrite((29344|0),8,1,($209|0))|0);
      $210 = HEAP32[13512>>2]|0;
      (_fflush(($210|0))|0);
      $211 = HEAP32[13488>>2]|0;
      $212 = $211 & 524288;
      $213 = ($212|0)==(0);
      if ($213) {
       $215 = $211;
      } else {
       $231 = $193;$232 = $192;
       label = 95;
       break;
      }
      while(1) {
       $214 = $215 | 64;
       HEAP32[13488>>2] = $214;
       $216 = (_rl_read_key()|0);
       $217 = HEAP32[13488>>2]|0;
       $218 = $217 & -65;
       HEAP32[13488>>2] = $218;
       switch ($216|0) {
       case 78: case 110: case 127:  {
        label = 94;
        break L104;
        break;
       }
       case 32: case 89: case 121:  {
        $231 = $193;$232 = $192;
        label = 95;
        break L106;
        break;
       }
       default: {
       }
       }
       $219 = ($216|0)==(7);
       $220 = ($216|0)<(0);
       $or$cond9$i51 = $219 | $220;
       if ($or$cond9$i51) {
        label = 90;
        break L104;
       }
       if ((($216|0) == 10) | (($216|0) == 13)) {
        break;
       }
       $221 = $216 & -33;
       $222 = ($221|0)==(81);
       if ($222) {
        label = 94;
        break L104;
       }
       (_rl_ding()|0);
       $$pre$i52 = HEAP32[13488>>2]|0;
       $215 = $$pre$i52;
      }
      __rl_erase_entire_line();
      if ($208) {
       label = 100;
       break L104;
      }
     }
     $$pr = HEAP32[$193>>2]|0;
     $196 = ($$pr|0)==(0|0);
     if ($196) {
      break L102;
     } else {
      $180 = $$pr;$i$199 = $192;
     }
    }
    if ((label|0) == 95) {
     label = 0;
     __rl_erase_entire_line();
     $224 = $231;$230 = $232;$lines$2$ph$be = 0;
    }
    $223 = HEAP32[$224>>2]|0;
    $225 = ($223|0)==(0|0);
    if ($225) {
     break L102;
    } else {
     $229 = $223;$i$1$ph103 = $230;$lines$2$ph102 = $lines$2$ph$be;
    }
   }
   if ((label|0) == 90) {
    (__rl_abort_internal()|0);
    // unreachable;
   }
   else if ((label|0) == 94) {
    __rl_erase_entire_line();
    STACKTOP = sp;return;
   }
   else if ((label|0) == 100) {
    STACKTOP = sp;return;
   }
  }
 } while(0);
 (_rl_crlf()|0);
 STACKTOP = sp;return;
}
function _rl_filename_completion_function($text,$state) {
 $text = $text|0;
 $state = $state|0;
 var $$0 = 0, $$0$i = 0, $$lcssa = 0, $$lcssa160 = 0, $$old = 0, $$old$lcssa = 0, $$old10 = 0, $$old1052 = 0, $$old8 = 0, $$old8$old = 0, $$old8$old53 = 0, $$pre = 0, $$pre$i = 0, $$pre32$i = 0, $$pre34$i = 0, $$pre36$i = 0, $$pre75 = 0, $$text = 0, $0 = 0, $1 = 0;
 var $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0;
 var $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0;
 var $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0;
 var $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0;
 var $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0;
 var $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0;
 var $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0;
 var $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0;
 var $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0;
 var $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0;
 var $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $convfn$2 = 0, $convfn$2$lcssa = 0, $convfn$2169 = 0, $convfn$2171 = 0, $convfn$2172 = 0, $convlen$0 = 0, $dirlen$0 = 0, $len$0$i = 0, $len$1$i = 0, $len$2$i = 0, $len$3$i = 0, $len$4$i = 0, $or$cond = 0;
 var $or$cond$i = 0, $or$cond11 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $ps1$i = 0, $ps2$i = 0, $s1$0$i = 0, $s1$1$i = 0, $s1$2$i = 0, $s1$3$i = 0, $s1$4$i = 0, $s2$0$i = 0, $s2$1$i = 0, $s2$2$i = 0, $s2$3$i = 0, $s2$4$i = 0, $storemerge = 0, $temp$0 = 0;
 var $temp$1 = 0, $wc1$i = 0, $wc2$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps1$i = sp + 8|0;
 $ps2$i = sp;
 $wc1$i = sp + 20|0;
 $wc2$i = sp + 16|0;
 $0 = ($state|0)==(0);
 if ($0) {
  $1 = HEAP32[29360>>2]|0;
  $2 = ($1|0)==(0|0);
  if (!($2)) {
   (_closedir(($1|0))|0);
   HEAP32[29360>>2] = 0;
  }
  $3 = HEAP32[29368>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   _free($3);
  }
  $5 = HEAP32[29376>>2]|0;
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   _free($5);
  }
  $7 = HEAP32[29384>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   _free($7);
  }
  $9 = (_strlen(($text|0))|0);
  $10 = (($9) + 1)|0;
  $11 = (_xmalloc($10)|0);
  $12 = (_strcpy(($11|0),($text|0))|0);
  HEAP32[29376>>2] = $12;
  $13 = HEAP8[$text>>0]|0;
  $14 = ($13<<24>>24)==(0);
  $$text = $14 ? 73176 : $text;
  $15 = (_strlen(($$text|0))|0);
  $16 = (($15) + 1)|0;
  $17 = (_xmalloc($16)|0);
  $18 = (_strcpy(($17|0),($$text|0))|0);
  HEAP32[29368>>2] = $18;
  $19 = (_strrchr($18,47)|0);
  $20 = ($19|0)==(0|0);
  if ($20) {
   HEAP8[$18>>0] = 46;
   $23 = HEAP32[29368>>2]|0;
   $24 = ((($23)) + 1|0);
   HEAP8[$24>>0] = 0;
  } else {
   $21 = HEAP32[29376>>2]|0;
   $22 = ((($19)) + 1|0);
   (_strcpy(($21|0),($22|0))|0);
   HEAP8[$22>>0] = 0;
  }
  $25 = HEAP32[29256>>2]|0;
  $26 = ($25|0)!=(0);
  $27 = HEAP32[29192>>2]|0;
  $28 = ($27|0)!=(0|0);
  $or$cond = $26 & $28;
  $29 = HEAP32[29368>>2]|0;
  if ($or$cond) {
   $30 = HEAP32[29264>>2]|0;
   $31 = (FUNCTION_TABLE_iii[$27 & 511]($29,$30)|0);
   $storemerge = $31;
  } else {
   $32 = (_strlen(($29|0))|0);
   $33 = (($32) + 1)|0;
   $34 = (_xmalloc($33)|0);
   $35 = HEAP32[29368>>2]|0;
   $36 = (_strcpy(($34|0),($35|0))|0);
   $storemerge = $36;
  }
  HEAP32[29384>>2] = $storemerge;
  $37 = HEAP32[29368>>2]|0;
  $38 = HEAP8[$37>>0]|0;
  $39 = ($38<<24>>24)==(126);
  if ($39) {
   $40 = (_tilde_expand($37)|0);
   $41 = HEAP32[29368>>2]|0;
   _xfree($41);
   HEAP32[29368>>2] = $40;
  }
  $42 = HEAP32[29008>>2]|0;
  $43 = ($42|0)==(0|0);
  do {
   if ($43) {
    $44 = HEAP32[29000>>2]|0;
    $45 = ($44|0)==(0|0);
    if (!($45)) {
     $46 = (FUNCTION_TABLE_ii[$44 & 511](29368)|0);
     $47 = ($46|0)==(0);
     if (!($47)) {
      $48 = HEAP32[29384>>2]|0;
      _xfree($48);
      $49 = HEAP32[29368>>2]|0;
      $50 = (_strlen(($49|0))|0);
      $51 = (($50) + 1)|0;
      $52 = (_xmalloc($51)|0);
      $53 = HEAP32[29368>>2]|0;
      $54 = (_strcpy(($52|0),($53|0))|0);
      HEAP32[29384>>2] = $54;
      break;
     }
    }
    $55 = HEAP32[29256>>2]|0;
    $56 = ($55|0)!=(0);
    $57 = HEAP32[29192>>2]|0;
    $58 = ($57|0)!=(0|0);
    $or$cond3 = $56 & $58;
    if ($or$cond3) {
     $59 = HEAP32[29368>>2]|0;
     _xfree($59);
     $60 = HEAP32[29384>>2]|0;
     $61 = (_strlen(($60|0))|0);
     $62 = (($61) + 1)|0;
     $63 = (_xmalloc($62)|0);
     $64 = HEAP32[29384>>2]|0;
     $65 = (_strcpy(($63|0),($64|0))|0);
     HEAP32[29368>>2] = $65;
    }
   } else {
    (FUNCTION_TABLE_ii[$42 & 511](29368)|0);
   }
  } while(0);
  $66 = HEAP32[29368>>2]|0;
  $67 = (_opendir(($66|0))|0);
  HEAP32[29360>>2] = $67;
  $68 = HEAP32[29376>>2]|0;
  $69 = HEAP8[$68>>0]|0;
  $70 = ($69<<24>>24)!=(0);
  $71 = HEAP32[29256>>2]|0;
  $72 = ($71|0)!=(0);
  $or$cond5 = $70 & $72;
  $73 = HEAP32[29192>>2]|0;
  $74 = ($73|0)!=(0|0);
  $or$cond7 = $or$cond5 & $74;
  if ($or$cond7) {
   $75 = HEAP32[29264>>2]|0;
   $76 = (FUNCTION_TABLE_iii[$73 & 511]($68,$75)|0);
   $77 = HEAP32[29376>>2]|0;
   _xfree($77);
   HEAP32[29376>>2] = $76;
   $78 = $76;
  } else {
   $78 = $68;
  }
  $79 = (_strlen(($78|0))|0);
  HEAP32[29392>>2] = $79;
  HEAP32[29160>>2] = 1;
 }
 $$old1052 = HEAP32[29360>>2]|0;
 $$old8$old53 = ($$old1052|0)==(0|0);
 do {
  if (!($$old8$old53)) {
   $80 = $$old1052;
   L41: while(1) {
    $81 = (_readdir(($80|0))|0);
    $82 = ($81|0)==(0|0);
    if ($82) {
     label = 90;
     break;
    } else {
     $84 = $81;
    }
    while(1) {
     $83 = ((($84)) + 11|0);
     $85 = (_strlen(($83|0))|0);
     $86 = HEAP32[29024>>2]|0;
     $87 = ($86|0)==(0|0);
     if ($87) {
      $convfn$2 = $83;$convlen$0 = $85;
     } else {
      $88 = (FUNCTION_TABLE_iii[$86 & 511]($83,$85)|0);
      $89 = ($88|0)==($83|0);
      if ($89) {
       $convfn$2 = $83;$convlen$0 = $85;
      } else {
       $90 = (_strlen(($88|0))|0);
       $convfn$2 = $88;$convlen$0 = $90;
      }
     }
     $91 = HEAP32[29392>>2]|0;
     $92 = ($91|0)==(0);
     if ($92) {
      $93 = HEAP32[28944>>2]|0;
      $94 = ($93|0)==(0);
      $95 = HEAP8[$convfn$2>>0]|0;
      $96 = ($95<<24>>24)==(46);
      if ($94) {
       label = 36;
       break;
      }
      if (!($96)) {
       $253 = $84;$286 = $83;$convfn$2169 = $convfn$2;
       break L41;
      }
      $97 = ((($convfn$2)) + 1|0);
      $98 = HEAP8[$97>>0]|0;
      if ((($98<<24>>24) == 0)) {
       $287 = $83;$288 = $84;$convfn$2171 = $convfn$2;
       break;
      } else if (!((($98<<24>>24) == 46))) {
       $253 = $84;$286 = $83;$convfn$2169 = $convfn$2;
       break L41;
      }
      $99 = ((($convfn$2)) + 2|0);
      $100 = HEAP8[$99>>0]|0;
      $101 = ($100<<24>>24)==(0);
      $102 = HEAP32[29360>>2]|0;
      $103 = ($102|0)!=(0|0);
      $or$cond9 = $101 & $103;
      if ($or$cond9) {
       $104 = $102;
      } else {
       $253 = $84;$286 = $83;$convfn$2169 = $convfn$2;
       break L41;
      }
     } else {
      $107 = HEAP32[29376>>2]|0;
      $108 = $ps1$i;
      $109 = $108;
      HEAP32[$109>>2] = 0;
      $110 = (($108) + 4)|0;
      $111 = $110;
      HEAP32[$111>>2] = 0;
      $112 = $ps2$i;
      $113 = $112;
      HEAP32[$113>>2] = 0;
      $114 = (($112) + 4)|0;
      $115 = $114;
      HEAP32[$115>>2] = 0;
      $116 = ($convlen$0|0)<($91|0);
      L55: do {
       if ($116) {
        $$0$i = 1;
       } else {
        $117 = HEAP32[28928>>2]|0;
        $118 = ($117|0)!=(0);
        $119 = HEAP32[28936>>2]|0;
        $120 = ($119|0)!=(0);
        $or$cond$i = $118 & $120;
        if ($or$cond$i) {
         $121 = HEAP32[36240>>2]|0;
         $122 = ($121|0)==(0);
         if ($122) {
          $len$0$i = $91;$s1$0$i = $convfn$2;$s2$0$i = $107;
          while(1) {
           $123 = (_mbrtowc($wc1$i,$s1$0$i,$convlen$0,$ps1$i)|0);
           $124 = (_mbrtowc($wc2$i,$s2$0$i,$91,$ps2$i)|0);
           $125 = $124 | $123;
           $126 = ($125|0)==(0);
           if ($126) {
            $$0$i = 0;
            break L55;
           }
           $127 = ($123>>>0)>(4294967293);
           $128 = ($124>>>0)>(4294967293);
           $129 = $127 | $128;
           do {
            if ($129) {
             $130 = HEAP8[$s1$0$i>>0]|0;
             $131 = HEAP8[$s2$0$i>>0]|0;
             $132 = ($130<<24>>24)==($131<<24>>24);
             if (!($132)) {
              $$0$i = 1;
              break L55;
             }
             if ((($130<<24>>24) == 95) | (($130<<24>>24) == 45)) {
              $$0$i = 1;
              break L55;
             }
             $133 = ((($s1$0$i)) + 1|0);
             $134 = ((($s2$0$i)) + 1|0);
             $135 = (($len$0$i) + -1)|0;
             $len$1$i = $135;$s1$1$i = $133;$s2$1$i = $134;
            } else {
             $136 = HEAP32[$wc1$i>>2]|0;
             $137 = (_towlower($136)|0);
             HEAP32[$wc1$i>>2] = $137;
             $138 = HEAP32[$wc2$i>>2]|0;
             $139 = (_towlower($138)|0);
             HEAP32[$wc2$i>>2] = $139;
             $140 = (($s1$0$i) + ($123)|0);
             $141 = (($s2$0$i) + ($123)|0);
             $142 = (($len$0$i) - ($123))|0;
             $143 = HEAP32[$wc1$i>>2]|0;
             if ((($143|0) == 45) | (($143|0) == 95)) {
              if ((($139|0) == 45) | (($139|0) == 95)) {
               $len$1$i = $142;$s1$1$i = $140;$s2$1$i = $141;
               break;
              }
             }
             $144 = ($143|0)==($139|0);
             if ($144) {
              $len$1$i = $142;$s1$1$i = $140;$s2$1$i = $141;
             } else {
              $$0$i = 1;
              break L55;
             }
            }
           } while(0);
           $145 = ($len$1$i|0)==(0);
           if ($145) {
            $$0$i = 0;
            break L55;
           } else {
            $len$0$i = $len$1$i;$s1$0$i = $s1$1$i;$s2$0$i = $s2$1$i;
           }
          }
         } else {
          $len$2$i = $91;$s1$2$i = $convfn$2;$s2$2$i = $107;
         }
         while(1) {
          $146 = HEAP8[$s1$2$i>>0]|0;
          $147 = $146&255;
          $148 = $146 << 24 >> 24;
          $149 = ($147|0)==($148|0);
          if ($149) {
           $150 = (_isupper($147)|0);
           $151 = ($150|0)==(0);
           $$pre34$i = HEAP8[$s1$2$i>>0]|0;
           if ($151) {
            $155 = $$pre34$i;
            label = 57;
           } else {
            $152 = $$pre34$i&255;
            $153 = (_tolower($152)|0);
            $169 = $153;
           }
          } else {
           $155 = $146;
           label = 57;
          }
          if ((label|0) == 57) {
           label = 0;
           $154 = $155 << 24 >> 24;
           $169 = $154;
          }
          $156 = HEAP8[$s2$2$i>>0]|0;
          $157 = $156&255;
          $158 = $156 << 24 >> 24;
          $159 = ($157|0)==($158|0);
          if ($159) {
           $160 = (_isupper($157)|0);
           $161 = ($160|0)==(0);
           $$pre36$i = HEAP8[$s2$2$i>>0]|0;
           if ($161) {
            $165 = $$pre36$i;
            label = 61;
           } else {
            $162 = $$pre36$i&255;
            $163 = (_tolower($162)|0);
            $170 = $163;
           }
          } else {
           $165 = $156;
           label = 61;
          }
          if ((label|0) == 61) {
           label = 0;
           $164 = $165 << 24 >> 24;
           $170 = $164;
          }
          $166 = HEAP8[$s1$2$i>>0]|0;
          if ((($166<<24>>24) == 95) | (($166<<24>>24) == 45)) {
           $167 = HEAP8[$s2$2$i>>0]|0;
           if (!((($167<<24>>24) == 95) | (($167<<24>>24) == 45))) {
            label = 64;
           }
          } else {
           label = 64;
          }
          if ((label|0) == 64) {
           label = 0;
           $168 = ($169|0)==($170|0);
           if (!($168)) {
            $$0$i = 1;
            break L55;
           }
          }
          $171 = ((($s1$2$i)) + 1|0);
          $172 = ((($s2$2$i)) + 1|0);
          $173 = (($len$2$i) + -1)|0;
          $174 = ($173|0)==(0);
          if ($174) {
           $$0$i = 0;
           break;
          } else {
           $len$2$i = $173;$s1$2$i = $171;$s2$2$i = $172;
          }
         }
        } else {
         if ($118) {
          $175 = HEAP32[36240>>2]|0;
          $176 = ($175|0)==(0);
          if ($176) {
           $len$3$i = $91;$s1$3$i = $convfn$2;$s2$3$i = $107;
           while(1) {
            $177 = (_mbrtowc($wc1$i,$s1$3$i,$convlen$0,$ps1$i)|0);
            $178 = (_mbrtowc($wc2$i,$s2$3$i,$91,$ps2$i)|0);
            $179 = $178 | $177;
            $180 = ($179|0)==(0);
            if ($180) {
             $$0$i = 0;
             break L55;
            }
            $181 = ($177>>>0)>(4294967293);
            $182 = ($178>>>0)>(4294967293);
            $183 = $181 | $182;
            if ($183) {
             $184 = HEAP8[$s1$3$i>>0]|0;
             $185 = HEAP8[$s2$3$i>>0]|0;
             $186 = ($184<<24>>24)==($185<<24>>24);
             if (!($186)) {
              $$0$i = 1;
              break L55;
             }
             $187 = ((($s1$3$i)) + 1|0);
             $188 = ((($s2$3$i)) + 1|0);
             $189 = (($len$3$i) + -1)|0;
             $len$4$i = $189;$s1$4$i = $187;$s2$4$i = $188;
            } else {
             $190 = HEAP32[$wc1$i>>2]|0;
             $191 = (_towlower($190)|0);
             HEAP32[$wc1$i>>2] = $191;
             $192 = HEAP32[$wc2$i>>2]|0;
             $193 = (_towlower($192)|0);
             HEAP32[$wc2$i>>2] = $193;
             $194 = HEAP32[$wc1$i>>2]|0;
             $195 = ($194|0)==($193|0);
             if (!($195)) {
              $$0$i = 1;
              break L55;
             }
             $196 = (($s1$3$i) + ($177)|0);
             $197 = (($s2$3$i) + ($177)|0);
             $198 = (($len$3$i) - ($177))|0;
             $len$4$i = $198;$s1$4$i = $196;$s2$4$i = $197;
            }
            $199 = ($len$4$i|0)==(0);
            if ($199) {
             $$0$i = 0;
             break L55;
            } else {
             $len$3$i = $len$4$i;$s1$3$i = $s1$4$i;$s2$3$i = $s2$4$i;
            }
           }
          }
          $200 = HEAP8[$convfn$2>>0]|0;
          $201 = $200&255;
          $202 = $200 << 24 >> 24;
          $203 = ($201|0)==($202|0);
          if ($203) {
           $204 = (_isupper($201)|0);
           $205 = ($204|0)==(0);
           $$pre$i = HEAP8[$convfn$2>>0]|0;
           if ($205) {
            $209 = $$pre$i;
            label = 78;
           } else {
            $206 = $$pre$i&255;
            $207 = (_tolower($206)|0);
            $221 = $207;
           }
          } else {
           $209 = $200;
           label = 78;
          }
          if ((label|0) == 78) {
           label = 0;
           $208 = $209 << 24 >> 24;
           $221 = $208;
          }
          $210 = HEAP8[$107>>0]|0;
          $211 = $210&255;
          $212 = $210 << 24 >> 24;
          $213 = ($211|0)==($212|0);
          if ($213) {
           $214 = (_isupper($211)|0);
           $215 = ($214|0)==(0);
           $$pre32$i = HEAP8[$107>>0]|0;
           if ($215) {
            $219 = $$pre32$i;
            label = 82;
           } else {
            $216 = $$pre32$i&255;
            $217 = (_tolower($216)|0);
            $222 = $217;
           }
          } else {
           $219 = $210;
           label = 82;
          }
          if ((label|0) == 82) {
           label = 0;
           $218 = $219 << 24 >> 24;
           $222 = $218;
          }
          $220 = ($221|0)==($222|0);
          if ($220) {
           $223 = (_strncasecmp($107,$convfn$2,$91)|0);
           $224 = ($223|0)==(0);
           if ($224) {
            $$0$i = 0;
            break;
           }
          }
         } else {
          $225 = HEAP8[$convfn$2>>0]|0;
          $226 = HEAP8[$107>>0]|0;
          $227 = ($225<<24>>24)==($226<<24>>24);
          if ($227) {
           $228 = (_strncmp($107,$convfn$2,$91)|0);
           $229 = ($228|0)==(0);
           if ($229) {
            $$0$i = 0;
            break;
           }
          }
         }
         $$0$i = 1;
         break;
        }
       }
      } while(0);
      $$old = HEAP32[29360>>2]|0;
      $$old8 = ($$old|0)!=(0|0);
      $or$cond11 = $$0$i & $$old8;
      if ($or$cond11) {
       $104 = $$old;
      } else {
       $$lcssa = $84;$$lcssa160 = $83;$$old$lcssa = $$old;$convfn$2$lcssa = $convfn$2;
       label = 89;
       break L41;
      }
     }
     $105 = (_readdir(($104|0))|0);
     $106 = ($105|0)==(0|0);
     if ($106) {
      label = 90;
      break L41;
     } else {
      $84 = $105;
     }
    }
    if ((label|0) == 36) {
     label = 0;
     if ($96) {
      $287 = $83;$288 = $84;$convfn$2171 = $convfn$2;
     } else {
      $253 = $84;$286 = $83;$convfn$2169 = $convfn$2;
      break;
     }
    }
    $$old10 = HEAP32[29360>>2]|0;
    $$old8$old = ($$old10|0)==(0|0);
    if ($$old8$old) {
     $253 = $288;$286 = $287;$convfn$2169 = $convfn$2171;
     break;
    } else {
     $80 = $$old10;
    }
   }
   if ((label|0) == 89) {
    $230 = ($$lcssa|0)==(0|0);
    if ($230) {
     $232 = $$old$lcssa;
     label = 91;
    } else {
     $253 = $$lcssa;$286 = $$lcssa160;$convfn$2169 = $convfn$2$lcssa;
    }
   }
   else if ((label|0) == 90) {
    $$pre75 = HEAP32[29360>>2]|0;
    $232 = $$pre75;
    label = 91;
   }
   if ((label|0) == 91) {
    $231 = ($232|0)==(0|0);
    if ($231) {
     break;
    }
    (_closedir(($232|0))|0);
    HEAP32[29360>>2] = 0;
    break;
   }
   $239 = HEAP32[29368>>2]|0;
   $240 = ($239|0)==(0|0);
   do {
    if ($240) {
     label = 109;
    } else {
     $241 = HEAP8[$239>>0]|0;
     $242 = ($241<<24>>24)==(46);
     if ($242) {
      $243 = ((($239)) + 1|0);
      $244 = HEAP8[$243>>0]|0;
      $245 = ($244<<24>>24)==(0);
      if ($245) {
       label = 109;
       break;
      }
     }
     $246 = HEAP32[29032>>2]|0;
     $247 = ($246|0)==(0);
     $$pre = HEAP32[29384>>2]|0;
     if ($247) {
      label = 106;
     } else {
      $248 = HEAP8[$$pre>>0]|0;
      $249 = ($248<<24>>24)==(126);
      if ($249) {
       $250 = (_strlen(($239|0))|0);
       $251 = (($250) + 2)|0;
       $252 = ((($253)) + 11|0);
       $254 = (_strlen(($252|0))|0);
       $255 = (($251) + ($254))|0;
       $256 = (_xmalloc($255)|0);
       $257 = HEAP32[29368>>2]|0;
       (_strcpy(($256|0),($257|0))|0);
       $258 = (($250) + -1)|0;
       $259 = HEAP32[29368>>2]|0;
       $260 = (($259) + ($258)|0);
       $261 = HEAP8[$260>>0]|0;
       $262 = ($261<<24>>24)==(47);
       if ($262) {
        $dirlen$0 = $250;$temp$0 = $256;
       } else {
        $263 = (($250) + 1)|0;
        $264 = (($256) + ($250)|0);
        HEAP8[$264>>0] = 47;
        $265 = (($256) + ($263)|0);
        HEAP8[$265>>0] = 0;
        $dirlen$0 = $263;$temp$0 = $256;
       }
      } else {
       label = 106;
      }
     }
     if ((label|0) == 106) {
      $266 = (_strlen(($$pre|0))|0);
      $267 = (($266) + 2)|0;
      $268 = ((($253)) + 11|0);
      $269 = (_strlen(($268|0))|0);
      $270 = (($267) + ($269))|0;
      $271 = (_xmalloc($270)|0);
      $272 = HEAP32[29384>>2]|0;
      (_strcpy(($271|0),($272|0))|0);
      $273 = (($266) + -1)|0;
      $274 = HEAP32[29384>>2]|0;
      $275 = (($274) + ($273)|0);
      $276 = HEAP8[$275>>0]|0;
      $277 = ($276<<24>>24)==(47);
      if ($277) {
       $dirlen$0 = $266;$temp$0 = $271;
      } else {
       $278 = (($266) + 1)|0;
       $279 = (($271) + ($266)|0);
       HEAP8[$279>>0] = 47;
       $dirlen$0 = $278;$temp$0 = $271;
      }
     }
     $280 = (($temp$0) + ($dirlen$0)|0);
     (_strcpy(($280|0),($convfn$2169|0))|0);
     $convfn$2172 = $convfn$2169;$temp$1 = $temp$0;
    }
   } while(0);
   if ((label|0) == 109) {
    $281 = (_strlen(($convfn$2169|0))|0);
    $282 = (($281) + 1)|0;
    $283 = (_xmalloc($282)|0);
    $284 = (_strcpy(($283|0),($convfn$2169|0))|0);
    $convfn$2172 = $convfn$2169;$temp$1 = $284;
   }
   $285 = ($convfn$2172|0)==($286|0);
   if ($285) {
    $$0 = $temp$1;
    STACKTOP = sp;return ($$0|0);
   }
   _xfree($convfn$2172);
   $$0 = $temp$1;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 $233 = HEAP32[29368>>2]|0;
 $234 = ($233|0)==(0|0);
 if (!($234)) {
  _xfree($233);
  HEAP32[29368>>2] = 0;
 }
 $235 = HEAP32[29376>>2]|0;
 $236 = ($235|0)==(0|0);
 if (!($236)) {
  _xfree($235);
  HEAP32[29376>>2] = 0;
 }
 $237 = HEAP32[29384>>2]|0;
 $238 = ($237|0)==(0|0);
 if ($238) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 _xfree($237);
 HEAP32[29384>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _rl_completion_matches($text,$entry_function) {
 $text = $text|0;
 $entry_function = $entry_function|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$04$us = 0, $match_list$0$lcssa = 0, $match_list$0$lcssa15 = 0, $match_list$06 = 0, $match_list$06$us = 0, $match_list$1 = 0, $match_list$1$us = 0, $match_list$2 = 0, $match_list$2$us = 0;
 var $match_list_size$05 = 0, $match_list_size$05$us = 0, $match_list_size$1 = 0, $match_list_size$1$us = 0, $match_list_size$2 = 0, $match_list_size$2$us = 0, $matches$0$lcssa = 0, $matches$07 = 0, $matches$07$us = 0, $matches$1 = 0, $matches$1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(44)|0);
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = 0;
 $2 = (FUNCTION_TABLE_iii[$entry_function & 511]($text,0)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $match_list$0$lcssa15 = $0;
 } else {
  $4 = ($entry_function|0)==(365|0);
  L3: do {
   if ($4) {
    $23 = $2;$match_list$06$us = $0;$match_list_size$05$us = 10;$matches$07$us = 0;
    while(1) {
     $5 = HEAP32[32656>>2]|0;
     $6 = ($5|0)==(0);
     if ($6) {
      $match_list$1$us = $match_list$06$us;$match_list_size$1$us = $match_list_size$05$us;$matches$1$us = $matches$07$us;
     } else {
      $28 = ((($match_list$06$us)) + 4|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0|0);
      if (!($30)) {
       $7 = $29;$i$04$us = 1;
       while(1) {
        _xfree($7);
        $8 = (($i$04$us) + 1)|0;
        $9 = (($match_list$06$us) + ($8<<2)|0);
        $10 = HEAP32[$9>>2]|0;
        $11 = ($10|0)==(0|0);
        if ($11) {
         break;
        } else {
         $7 = $10;$i$04$us = $8;
        }
       }
      }
      _xfree($match_list$06$us);
      $12 = HEAP32[32656>>2]|0;
      $13 = ($12|0)==(0);
      if ($13) {
       $match_list$1$us = 0;$match_list_size$1$us = 0;$matches$1$us = 0;
      } else {
       $14 = HEAP32[32656>>2]|0;
       __rl_signal_handler($14);
       $match_list$1$us = 0;$match_list_size$1$us = 0;$matches$1$us = 0;
      }
     }
     $15 = (($matches$1$us) + 1)|0;
     $16 = ($15|0)<($match_list_size$1$us|0);
     if ($16) {
      $match_list$2$us = $match_list$1$us;$match_list_size$2$us = $match_list_size$1$us;
     } else {
      $17 = (($match_list_size$1$us) + 10)|0;
      $18 = $match_list_size$1$us << 2;
      $19 = (($18) + 44)|0;
      $20 = (_xrealloc($match_list$1$us,$19)|0);
      $match_list$2$us = $20;$match_list_size$2$us = $17;
     }
     $21 = ($match_list$2$us|0)==(0|0);
     if ($21) {
      $$0 = 0;
      break;
     }
     $22 = (($match_list$2$us) + ($15<<2)|0);
     HEAP32[$22>>2] = $23;
     $24 = (($matches$1$us) + 2)|0;
     $25 = (($match_list$2$us) + ($24<<2)|0);
     HEAP32[$25>>2] = 0;
     $26 = (_rl_filename_completion_function($text,$15)|0);
     $27 = ($26|0)==(0|0);
     if ($27) {
      $match_list$0$lcssa = $match_list$2$us;$matches$0$lcssa = $15;
      break L3;
     } else {
      $23 = $26;$match_list$06$us = $match_list$2$us;$match_list_size$05$us = $match_list_size$2$us;$matches$07$us = $15;
     }
    }
    return ($$0|0);
   } else {
    $44 = $2;$match_list$06 = $0;$match_list_size$05 = 10;$matches$07 = 0;
    while(1) {
     $31 = HEAP32[32656>>2]|0;
     $32 = ($31|0)==(0);
     if ($32) {
      $match_list$1 = $match_list$06;$match_list_size$1 = $match_list_size$05;$matches$1 = $matches$07;
     } else {
      _xfree($match_list$06);
      $33 = HEAP32[32656>>2]|0;
      $34 = ($33|0)==(0);
      if ($34) {
       $match_list$1 = 0;$match_list_size$1 = 0;$matches$1 = 0;
      } else {
       $35 = HEAP32[32656>>2]|0;
       __rl_signal_handler($35);
       $match_list$1 = 0;$match_list_size$1 = 0;$matches$1 = 0;
      }
     }
     $36 = (($matches$1) + 1)|0;
     $37 = ($36|0)<($match_list_size$1|0);
     if ($37) {
      $match_list$2 = $match_list$1;$match_list_size$2 = $match_list_size$1;
     } else {
      $38 = (($match_list_size$1) + 10)|0;
      $39 = $match_list_size$1 << 2;
      $40 = (($39) + 44)|0;
      $41 = (_xrealloc($match_list$1,$40)|0);
      $match_list$2 = $41;$match_list_size$2 = $38;
     }
     $42 = ($match_list$2|0)==(0|0);
     if ($42) {
      $$0 = 0;
      break;
     }
     $43 = (($match_list$2) + ($36<<2)|0);
     HEAP32[$43>>2] = $44;
     $45 = (($matches$1) + 2)|0;
     $46 = (($match_list$2) + ($45<<2)|0);
     HEAP32[$46>>2] = 0;
     $47 = (FUNCTION_TABLE_iii[$entry_function & 511]($text,$36)|0);
     $48 = ($47|0)==(0|0);
     if ($48) {
      $match_list$0$lcssa = $match_list$2;$matches$0$lcssa = $36;
      break L3;
     } else {
      $44 = $47;$match_list$06 = $match_list$2;$match_list_size$05 = $match_list_size$2;$matches$07 = $36;
     }
    }
    return ($$0|0);
   }
  } while(0);
  $49 = ($matches$0$lcssa|0)==(0);
  if ($49) {
   $match_list$0$lcssa15 = $match_list$0$lcssa;
  } else {
   _compute_lcd_of_matches($match_list$0$lcssa,$matches$0$lcssa,$text);
   $$0 = $match_list$0$lcssa;
   return ($$0|0);
  }
 }
 _xfree($match_list$0$lcssa15);
 $$0 = 0;
 return ($$0|0);
}
function _rl_old_menu_complete($count,$invoking_key) {
 $count = $count|0;
 $invoking_key = $invoking_key|0;
 var $$pre = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0;
 var $8 = 0, $80 = 0, $81 = 0, $9 = 0, $found_quote = 0, $i$01$i = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $our_func$0 = 0, $storemerge = 0, $storemerge$lcssa = 0, $storemerge9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $found_quote = sp;
 $0 = HEAP32[13496>>2]|0;
 $1 = ($0|0)==(205|0);
 do {
  if (!($1)) {
   $2 = HEAP32[29400>>2]|0;
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    _free($2);
   }
   $4 = HEAP32[29408>>2]|0;
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $6 = HEAP32[$4>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     $8 = $6;$i$01$i = 0;
     while(1) {
      _xfree($8);
      $9 = (($i$01$i) + 1)|0;
      $10 = (($4) + ($9<<2)|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)==(0|0);
      if ($12) {
       break;
      } else {
       $8 = $11;$i$01$i = $9;
      }
     }
    }
    _xfree($4);
   }
   HEAP32[29416>>2] = 0;
   HEAP32[29424>>2] = 0;
   HEAP32[29408>>2] = 0;
   HEAP32[29240>>2] = $invoking_key;
   $13 = HEAP32[13488>>2]|0;
   $14 = $13 | 16384;
   HEAP32[13488>>2] = $14;
   HEAP32[29160>>2] = 0;
   HEAP32[29168>>2] = 1;
   HEAP32[29072>>2] = 37;
   HEAP32[29224>>2] = 0;
   HEAP32[29208>>2] = 0;
   HEAP32[29216>>2] = 32;
   $15 = HEAP32[28920>>2]|0;
   HEAP32[29280>>2] = $15;
   $16 = HEAP32[29048>>2]|0;
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = HEAP32[29040>>2]|0;
    $19 = ($18|0)!=(0|0);
    $20 = $19 ? $18 : 365;
    $our_func$0 = $20;
   } else {
    $our_func$0 = $16;
   }
   $21 = HEAP32[13784>>2]|0;
   HEAP32[29432>>2] = $21;
   HEAP32[29440>>2] = 0;
   HEAP32[$found_quote>>2] = 0;
   HEAP8[29448>>0] = 0;
   $22 = ($21|0)==(0);
   if ($22) {
    $24 = 0;$25 = 0;
   } else {
    $23 = (__rl_find_completion_word($found_quote,29440)|0);
    HEAP8[29448>>0] = $23;
    $$pre = HEAP32[13784>>2]|0;
    $$pre8 = HEAP32[29432>>2]|0;
    $24 = $$pre;$25 = $$pre8;
   }
   HEAP32[29456>>2] = $24;
   HEAP32[13784>>2] = $25;
   $26 = (_rl_copy_text($24,$25)|0);
   HEAP32[29400>>2] = $26;
   $27 = HEAP32[29456>>2]|0;
   $28 = HEAP32[29432>>2]|0;
   $29 = HEAP32[$found_quote>>2]|0;
   $30 = HEAP8[29448>>0]|0;
   $31 = $30 << 24 >> 24;
   $32 = (_gen_completion_matches($26,$27,$28,$our_func$0,$29,$31)|0);
   HEAP32[29408>>2] = $32;
   $33 = ($32|0)==(0|0);
   if (!($33)) {
    $34 = HEAP32[29160>>2]|0;
    $35 = (_postprocess_matches(29408,$34)|0);
    $36 = ($35|0)==(0);
    if (!($36)) {
     $43 = HEAP32[13488>>2]|0;
     $44 = $43 & -16385;
     HEAP32[13488>>2] = $44;
     $45 = HEAP32[29408>>2]|0;
     $storemerge = 0;
     while(1) {
      $46 = (($45) + ($storemerge<<2)|0);
      $47 = HEAP32[$46>>2]|0;
      $48 = ($47|0)==(0|0);
      $49 = (($storemerge) + 1)|0;
      if ($48) {
       $storemerge$lcssa = $storemerge;
       break;
      } else {
       $storemerge = $49;
      }
     }
     HEAP32[29416>>2] = $storemerge$lcssa;
     $50 = ($storemerge$lcssa|0)>(1);
     $51 = HEAP32[28896>>2]|0;
     $52 = ($51|0)!=(0);
     $or$cond = $50 & $52;
     if (!($or$cond)) {
      break;
     }
     _display_matches($45);
     break;
    }
   }
   (_rl_ding()|0);
   $37 = HEAP32[29408>>2]|0;
   $38 = ($37|0)==(0|0);
   if (!($38)) {
    _free($37);
   }
   HEAP32[29408>>2] = 0;
   $39 = HEAP32[29400>>2]|0;
   $40 = ($39|0)==(0|0);
   if (!($40)) {
    _free($39);
   }
   HEAP32[29400>>2] = 0;
   HEAP32[29288>>2] = 0;
   $41 = HEAP32[13488>>2]|0;
   $42 = $41 & -16385;
   HEAP32[13488>>2] = $42;
   STACKTOP = sp;return 0;
  }
 } while(0);
 $53 = HEAP32[29408>>2]|0;
 $54 = ($53|0)==(0|0);
 $55 = HEAP32[29416>>2]|0;
 $56 = ($55|0)==(0);
 $or$cond3 = $54 | $56;
 if ($or$cond3) {
  (_rl_ding()|0);
  $57 = HEAP32[29408>>2]|0;
  $58 = ($57|0)==(0|0);
  if (!($58)) {
   _free($57);
  }
  HEAP32[29408>>2] = 0;
  HEAP32[29288>>2] = 0;
  STACKTOP = sp;return 0;
 }
 $59 = HEAP32[29424>>2]|0;
 $60 = (($59) + ($count))|0;
 HEAP32[29424>>2] = $60;
 $61 = ($60|0)<(0);
 if ($61) {
  $63 = $60;
  while(1) {
   $62 = (($55) + ($63))|0;
   $64 = ($62|0)<(0);
   if ($64) {
    $63 = $62;
   } else {
    $storemerge9 = $62;
    break;
   }
  }
 } else {
  $65 = (($60|0) % ($55|0))&-1;
  $storemerge9 = $65;
 }
 HEAP32[29424>>2] = $storemerge9;
 $66 = ($storemerge9|0)==(0);
 $67 = ($55|0)>(1);
 $or$cond5 = $66 & $67;
 if ($or$cond5) {
  (_rl_ding()|0);
  $68 = HEAP32[29400>>2]|0;
  $69 = HEAP32[29456>>2]|0;
  _insert_match($68,$69,2,29448);
 } else {
  $70 = (($53) + ($storemerge9<<2)|0);
  $71 = HEAP32[$70>>2]|0;
  $72 = HEAP32[29456>>2]|0;
  _insert_match($71,$72,1,29448);
  $73 = HEAP32[29424>>2]|0;
  $74 = HEAP32[29408>>2]|0;
  $75 = (($74) + ($73<<2)|0);
  $76 = HEAP32[$75>>2]|0;
  $77 = HEAP32[29440>>2]|0;
  $78 = HEAP8[29448>>0]|0;
  $79 = $78 << 24 >> 24;
  $80 = HEAP32[29400>>2]|0;
  $81 = (_strcmp($80,$76)|0);
  _append_to_match($76,$77,$79,$81);
 }
 HEAP32[29288>>2] = 1;
 STACKTOP = sp;return 0;
}
function _rl_menu_complete($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$pre = 0, $$pre16 = 0, $$pre17 = 0, $$pre19 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0;
 var $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0;
 var $130 = 0, $131 = 0, $132 = 0, $133 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0;
 var $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0;
 var $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0;
 var $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $found_quote = 0, $i$01$i = 0;
 var $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond9 = 0, $our_func$0 = 0, $storemerge = 0, $storemerge$lcssa = 0, $storemerge20 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $found_quote = sp;
 $0 = HEAP32[13496>>2]|0;
 $1 = ($0|0)!=(198|0);
 $2 = ($0|0)!=(199|0);
 $or$cond = $1 & $2;
 $3 = HEAP32[29464>>2]|0;
 $4 = ($3|0)!=(0);
 $or$cond3 = $or$cond | $4;
 do {
  if ($or$cond3) {
   $5 = HEAP32[29480>>2]|0;
   $6 = ($5|0)==(0|0);
   if (!($6)) {
    _free($5);
   }
   $7 = HEAP32[29488>>2]|0;
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     $11 = $9;$i$01$i = 0;
     while(1) {
      _xfree($11);
      $12 = (($i$01$i) + 1)|0;
      $13 = (($7) + ($12<<2)|0);
      $14 = HEAP32[$13>>2]|0;
      $15 = ($14|0)==(0|0);
      if ($15) {
       break;
      } else {
       $11 = $14;$i$01$i = $12;
      }
     }
    }
    _xfree($7);
   }
   HEAP32[29472>>2] = 0;
   HEAP32[29496>>2] = 0;
   HEAP32[29488>>2] = 0;
   HEAP32[29464>>2] = 0;
   $16 = HEAP32[13488>>2]|0;
   $17 = $16 | 16384;
   HEAP32[13488>>2] = $17;
   HEAP32[29160>>2] = 0;
   HEAP32[29168>>2] = 1;
   HEAP32[29072>>2] = 37;
   HEAP32[29224>>2] = 0;
   HEAP32[29208>>2] = 0;
   HEAP32[29216>>2] = 32;
   $18 = HEAP32[28920>>2]|0;
   HEAP32[29280>>2] = $18;
   $19 = HEAP32[29048>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $21 = HEAP32[29040>>2]|0;
    $22 = ($21|0)!=(0|0);
    $23 = $22 ? $21 : 365;
    $our_func$0 = $23;
   } else {
    $our_func$0 = $19;
   }
   $24 = HEAP32[13784>>2]|0;
   HEAP32[29504>>2] = $24;
   HEAP32[29512>>2] = 0;
   HEAP32[$found_quote>>2] = 0;
   HEAP8[29520>>0] = 0;
   $25 = ($24|0)==(0);
   if ($25) {
    $27 = 0;$28 = 0;
   } else {
    $26 = (__rl_find_completion_word($found_quote,29512)|0);
    HEAP8[29520>>0] = $26;
    $$pre = HEAP32[13784>>2]|0;
    $$pre16 = HEAP32[29504>>2]|0;
    $27 = $$pre;$28 = $$pre16;
   }
   HEAP32[29528>>2] = $27;
   HEAP32[13784>>2] = $28;
   $29 = (_rl_copy_text($27,$28)|0);
   HEAP32[29480>>2] = $29;
   $30 = HEAP32[29528>>2]|0;
   $31 = HEAP32[29504>>2]|0;
   $32 = HEAP32[$found_quote>>2]|0;
   $33 = HEAP8[29520>>0]|0;
   $34 = $33 << 24 >> 24;
   $35 = (_gen_completion_matches($29,$30,$31,$our_func$0,$32,$34)|0);
   HEAP32[29488>>2] = $35;
   $36 = ($35|0)==(0|0);
   if ($36) {
    HEAP32[29536>>2] = 0;
   } else {
    $37 = HEAP32[29480>>2]|0;
    $38 = HEAP32[$35>>2]|0;
    $39 = (_strcmp($37,$38)|0);
    $40 = ($39|0)!=(0);
    $41 = $40&1;
    HEAP32[29536>>2] = $41;
    $42 = HEAP32[29160>>2]|0;
    $43 = (_postprocess_matches(29488,$42)|0);
    $44 = ($43|0)==(0);
    if (!($44)) {
     $51 = HEAP32[13488>>2]|0;
     $52 = $51 & -16385;
     HEAP32[13488>>2] = $52;
     $53 = HEAP32[29488>>2]|0;
     $storemerge = 0;
     while(1) {
      $54 = (($53) + ($storemerge<<2)|0);
      $55 = HEAP32[$54>>2]|0;
      $56 = ($55|0)==(0|0);
      $57 = (($storemerge) + 1)|0;
      if ($56) {
       $storemerge$lcssa = $storemerge;
       break;
      } else {
       $storemerge = $57;
      }
     }
     HEAP32[29472>>2] = $storemerge$lcssa;
     $58 = ($storemerge$lcssa|0)==(0);
     if ($58) {
      (_rl_ding()|0);
      $59 = HEAP32[29488>>2]|0;
      $60 = ($59|0)==(0|0);
      if (!($60)) {
       _free($59);
      }
      HEAP32[29488>>2] = 0;
      HEAP32[29496>>2] = 0;
      HEAP32[29288>>2] = 0;
      STACKTOP = sp;return 0;
     }
     $61 = HEAP32[$53>>2]|0;
     $62 = HEAP8[$61>>0]|0;
     $63 = ($62<<24>>24)==(0);
     if ($63) {
      $101 = $61;$84 = $storemerge$lcssa;$87 = $53;
     } else {
      $64 = HEAP32[29528>>2]|0;
      $65 = ((($53)) + 4|0);
      $66 = HEAP32[$65>>2]|0;
      $67 = ($66|0)!=(0|0);
      $68 = $67 ? 2 : 1;
      _insert_match($61,$64,$68,29520);
      $69 = HEAP32[29528>>2]|0;
      $70 = HEAP32[29488>>2]|0;
      $71 = HEAP32[$70>>2]|0;
      $72 = (_strlen(($71|0))|0);
      $73 = (($72) + ($69))|0;
      HEAP32[29504>>2] = $73;
      $74 = HEAP32[29480>>2]|0;
      $75 = HEAP8[$74>>0]|0;
      $76 = HEAP8[$71>>0]|0;
      $77 = ($75<<24>>24)==($76<<24>>24);
      if ($77) {
       $78 = (_strcmp($74,$71)|0);
       $79 = ($78|0)==(0);
       $81 = $79;
      } else {
       $81 = 0;
      }
      $80 = $81&1;
      $82 = $80 ^ 1;
      HEAP32[29288>>2] = $82;
      $$pre17 = HEAP32[29472>>2]|0;
      $101 = $71;$84 = $$pre17;$87 = $70;
     }
     $83 = ($84|0)>(1);
     $85 = HEAP32[28896>>2]|0;
     $86 = ($85|0)!=(0);
     $or$cond5 = $83 & $86;
     if (!($or$cond5)) {
      $96 = ($84|0)<(2);
      if ($96) {
       $97 = HEAP32[29512>>2]|0;
       $98 = HEAP8[29520>>0]|0;
       $99 = $98 << 24 >> 24;
       $100 = HEAP32[29536>>2]|0;
       _append_to_match($101,$97,$99,$100);
       HEAP32[29464>>2] = 1;
       STACKTOP = sp;return 0;
      }
      $102 = HEAP32[28992>>2]|0;
      $103 = ($102|0)!=(0);
      $or$cond7 = $83 & $103;
      if (!($or$cond7)) {
       $107 = $84;
       break;
      }
      (_rl_ding()|0);
      STACKTOP = sp;return 0;
     }
     _display_matches($87);
     $88 = HEAP32[29080>>2]|0;
     $89 = ($88|0)<(1);
     $90 = HEAP32[29472>>2]|0;
     $91 = ($90|0)<($88|0);
     $or$cond13 = $89 | $91;
     if ($or$cond13) {
      $94 = HEAP32[28992>>2]|0;
      $95 = ($94|0)==(0);
      if ($95) {
       $107 = $90;
       break;
      }
      (_rl_ding()|0);
      STACKTOP = sp;return 0;
     }
     (_rl_ding()|0);
     $92 = HEAP32[29488>>2]|0;
     $93 = ($92|0)==(0|0);
     if (!($93)) {
      _free($92);
     }
     HEAP32[29488>>2] = 0;
     HEAP32[29464>>2] = 1;
     STACKTOP = sp;return 0;
    }
   }
   (_rl_ding()|0);
   $45 = HEAP32[29488>>2]|0;
   $46 = ($45|0)==(0|0);
   if (!($46)) {
    _free($45);
   }
   HEAP32[29488>>2] = 0;
   $47 = HEAP32[29480>>2]|0;
   $48 = ($47|0)==(0|0);
   if (!($48)) {
    _free($47);
   }
   HEAP32[29480>>2] = 0;
   HEAP32[29288>>2] = 0;
   $49 = HEAP32[13488>>2]|0;
   $50 = $49 & -16385;
   HEAP32[13488>>2] = $50;
   STACKTOP = sp;return 0;
  } else {
   $$pre19 = HEAP32[29472>>2]|0;
   $107 = $$pre19;
  }
 } while(0);
 $104 = HEAP32[29488>>2]|0;
 $105 = ($104|0)==(0|0);
 $106 = ($107|0)==(0);
 $or$cond9 = $105 | $106;
 if ($or$cond9) {
  (_rl_ding()|0);
  $108 = HEAP32[29488>>2]|0;
  $109 = ($108|0)==(0|0);
  if (!($109)) {
   _free($108);
  }
  HEAP32[29488>>2] = 0;
  HEAP32[29288>>2] = 0;
  STACKTOP = sp;return 0;
 }
 $110 = HEAP32[29496>>2]|0;
 $111 = (($110) + ($count))|0;
 HEAP32[29496>>2] = $111;
 $112 = ($111|0)<(0);
 if ($112) {
  $114 = $111;
  while(1) {
   $113 = (($107) + ($114))|0;
   $115 = ($113|0)<(0);
   if ($115) {
    $114 = $113;
   } else {
    $storemerge20 = $113;
    break;
   }
  }
 } else {
  $116 = (($111|0) % ($107|0))&-1;
  $storemerge20 = $116;
 }
 HEAP32[29496>>2] = $storemerge20;
 $117 = ($storemerge20|0)==(0);
 $118 = ($107|0)>(1);
 $or$cond11 = $117 & $118;
 if ($or$cond11) {
  (_rl_ding()|0);
  $119 = HEAP32[29488>>2]|0;
  $120 = HEAP32[$119>>2]|0;
  $121 = HEAP32[29528>>2]|0;
  _insert_match($120,$121,2,29520);
 } else {
  $122 = (($104) + ($storemerge20<<2)|0);
  $123 = HEAP32[$122>>2]|0;
  $124 = HEAP32[29528>>2]|0;
  _insert_match($123,$124,1,29520);
  $125 = HEAP32[29496>>2]|0;
  $126 = HEAP32[29488>>2]|0;
  $127 = (($126) + ($125<<2)|0);
  $128 = HEAP32[$127>>2]|0;
  $129 = HEAP32[29512>>2]|0;
  $130 = HEAP8[29520>>0]|0;
  $131 = $130 << 24 >> 24;
  $132 = HEAP32[29480>>2]|0;
  $133 = (_strcmp($132,$128)|0);
  _append_to_match($128,$129,$131,$133);
 }
 HEAP32[29288>>2] = 1;
 STACKTOP = sp;return 0;
}
function _rl_backward_menu_complete($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0 - ($count))|0;
 (_rl_menu_complete($0,0)|0);
 return 0;
}
function _gen_completion_matches($text,$start,$end,$our_func,$found_quote,$quote_char) {
 $text = $text|0;
 $start = $start|0;
 $end = $end|0;
 $our_func = $our_func|0;
 $found_quote = $found_quote|0;
 $quote_char = $quote_char|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i3 = 0, $matches$0 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[29256>>2] = $found_quote;
 HEAP32[29264>>2] = $quote_char;
 $0 = HEAP32[29056>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (FUNCTION_TABLE_iiii[$0 & 511]($text,$start,$end)|0);
  $3 = HEAP32[32656>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
   $matches$0 = $2;
  } else {
   $5 = ($2|0)==(0|0);
   if (!($5)) {
    $6 = HEAP32[$2>>2]|0;
    $7 = ($6|0)==(0|0);
    if (!($7)) {
     $8 = $6;$i$01$i = 0;
     while(1) {
      _xfree($8);
      $9 = (($i$01$i) + 1)|0;
      $10 = (($2) + ($9<<2)|0);
      $11 = HEAP32[$10>>2]|0;
      $12 = ($11|0)==(0|0);
      if ($12) {
       break;
      } else {
       $8 = $11;$i$01$i = $9;
      }
     }
    }
    _xfree($2);
   }
   $13 = HEAP32[32656>>2]|0;
   $14 = ($13|0)==(0);
   if ($14) {
    $matches$0 = 0;
   } else {
    $15 = HEAP32[32656>>2]|0;
    __rl_signal_handler($15);
    $matches$0 = 0;
   }
  }
  $16 = ($matches$0|0)!=(0|0);
  $17 = HEAP32[29064>>2]|0;
  $18 = ($17|0)!=(0);
  $or$cond = $16 | $18;
  if ($or$cond) {
   HEAP32[29064>>2] = 0;
   $$0 = $matches$0;
   return ($$0|0);
  }
 }
 $19 = (_rl_completion_matches($text,$our_func)|0);
 $20 = HEAP32[32656>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  $$0 = $19;
  return ($$0|0);
 }
 $22 = ($19|0)==(0|0);
 if (!($22)) {
  $23 = HEAP32[$19>>2]|0;
  $24 = ($23|0)==(0|0);
  if (!($24)) {
   $25 = $23;$i$01$i3 = 0;
   while(1) {
    _xfree($25);
    $26 = (($i$01$i3) + 1)|0;
    $27 = (($19) + ($26<<2)|0);
    $28 = HEAP32[$27>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     break;
    } else {
     $25 = $28;$i$01$i3 = $26;
    }
   }
  }
  _xfree($19);
 }
 $30 = HEAP32[32656>>2]|0;
 $31 = ($30|0)==(0);
 if ($31) {
  $$0 = 0;
  return ($$0|0);
 }
 $32 = HEAP32[32656>>2]|0;
 __rl_signal_handler($32);
 $$0 = 0;
 return ($$0|0);
}
function _postprocess_matches($matchesp,$matching_filenames) {
 $matchesp = $matchesp|0;
 $matching_filenames = $matching_filenames|0;
 var $$0 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $8 = 0, $9 = 0, $dead_slot$i = 0, $i$0 = 0, $i$0$i = 0;
 var $i$0$i$lcssa = 0, $i$0$lcssa = 0, $i$1$ph11$i = 0, $i$15$i = 0, $i$15$i$phi = 0, $i$24$i = 0, $j$0$lcssa$i = 0, $j$03$i = 0, $j$1$i = 0, $matches$0 = 0, $newlen$0$ph$lcssa$i = 0, $newlen$0$ph10$i = 0, $nmatch$0 = 0, $nmatch$0$lcssa = 0, $or$cond = 0, $or$cond$i = 0, $or$cond2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $dead_slot$i = sp;
 $0 = HEAP32[$matchesp>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = HEAP32[29152>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $matches$0 = $0;
 } else {
  $i$0$i = 0;
  while(1) {
   $4 = (($0) + ($i$0$i<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==(0|0);
   $7 = (($i$0$i) + 1)|0;
   if ($6) {
    $i$0$i$lcssa = $i$0$i;
    break;
   } else {
    $i$0$i = $7;
   }
  }
  $8 = ($i$0$i$lcssa|0)!=(0);
  $9 = HEAP32[29232>>2]|0;
  $10 = ($9|0)!=(0);
  $or$cond$i = $8 & $10;
  $11 = ((($0)) + 4|0);
  if ($or$cond$i) {
   $12 = (($i$0$i$lcssa) + -1)|0;
   _qsort($11,$12,4,364);
  }
  $13 = HEAP32[$0>>2]|0;
  $14 = (_strlen(($13|0))|0);
  $15 = (($14) + 1)|0;
  $16 = (_xmalloc($15)|0);
  $17 = HEAP32[$0>>2]|0;
  $18 = (_strcpy(($16|0),($17|0))|0);
  $19 = HEAP32[$11>>2]|0;
  $20 = ($19|0)==(0|0);
  L12: do {
   if ($20) {
    $newlen$0$ph$lcssa$i = 0;
   } else {
    $73 = $19;$74 = 1;$i$1$ph11$i = 0;$newlen$0$ph10$i = 0;
    while(1) {
     $23 = $73;$27 = $74;$i$15$i = $i$1$ph11$i;
     while(1) {
      $21 = (($0) + ($i$15$i<<2)|0);
      $22 = HEAP32[$21>>2]|0;
      $24 = (_strcmp($22,$23)|0);
      $25 = ($24|0)==(0);
      if (!($25)) {
       $$lcssa = $27;
       break;
      }
      _xfree($22);
      HEAP32[$21>>2] = $dead_slot$i;
      $26 = (($27) + 1)|0;
      $28 = (($0) + ($26<<2)|0);
      $29 = HEAP32[$28>>2]|0;
      $30 = ($29|0)==(0|0);
      if ($30) {
       $newlen$0$ph$lcssa$i = $newlen$0$ph10$i;
       break L12;
      } else {
       $i$15$i$phi = $27;$23 = $29;$27 = $26;$i$15$i = $i$15$i$phi;
      }
     }
     $31 = (($newlen$0$ph10$i) + 1)|0;
     $32 = (($$lcssa) + 1)|0;
     $33 = (($0) + ($32<<2)|0);
     $34 = HEAP32[$33>>2]|0;
     $35 = ($34|0)==(0|0);
     if ($35) {
      $newlen$0$ph$lcssa$i = $31;
      break;
     } else {
      $73 = $34;$74 = $32;$i$1$ph11$i = $$lcssa;$newlen$0$ph10$i = $31;
     }
    }
   }
  } while(0);
  $36 = $newlen$0$ph$lcssa$i << 2;
  $37 = (($36) + 12)|0;
  $38 = (_xmalloc($37)|0);
  $39 = HEAP32[$11>>2]|0;
  $40 = ($39|0)==(0|0);
  if ($40) {
   $j$0$lcssa$i = 1;
  } else {
   $42 = $39;$i$24$i = 1;$j$03$i = 1;
   while(1) {
    $41 = ($42|0)==($dead_slot$i|0);
    if ($41) {
     $j$1$i = $j$03$i;
    } else {
     $43 = (($j$03$i) + 1)|0;
     $44 = (($38) + ($j$03$i<<2)|0);
     HEAP32[$44>>2] = $42;
     $j$1$i = $43;
    }
    $45 = (($i$24$i) + 1)|0;
    $46 = (($0) + ($45<<2)|0);
    $47 = HEAP32[$46>>2]|0;
    $48 = ($47|0)==(0|0);
    if ($48) {
     $j$0$lcssa$i = $j$1$i;
     break;
    } else {
     $42 = $47;$i$24$i = $45;$j$03$i = $j$1$i;
    }
   }
  }
  $49 = (($38) + ($j$0$lcssa$i<<2)|0);
  HEAP32[$49>>2] = 0;
  $50 = HEAP32[$0>>2]|0;
  $51 = ($50|0)==($dead_slot$i|0);
  if (!($51)) {
   _xfree($50);
  }
  HEAP32[$38>>2] = $18;
  $52 = ($j$0$lcssa$i|0)==(2);
  if ($52) {
   $53 = ((($38)) + 4|0);
   $54 = HEAP32[$53>>2]|0;
   $55 = (_strcmp($18,$54)|0);
   $56 = ($55|0)==(0);
   if ($56) {
    _xfree($54);
    HEAP32[$53>>2] = 0;
   }
  }
  _xfree($0);
  $matches$0 = $38;
 }
 $57 = HEAP32[29176>>2]|0;
 $58 = ($57|0)!=(0|0);
 $59 = ($matching_filenames|0)!=(0);
 $or$cond = $59 & $58;
 if ($or$cond) {
  $nmatch$0 = 1;
  while(1) {
   $60 = (($matches$0) + ($nmatch$0<<2)|0);
   $61 = HEAP32[$60>>2]|0;
   $62 = ($61|0)==(0|0);
   $63 = (($nmatch$0) + 1)|0;
   if ($62) {
    $nmatch$0$lcssa = $nmatch$0;
    break;
   } else {
    $nmatch$0 = $63;
   }
  }
  (FUNCTION_TABLE_ii[$57 & 511]($matches$0)|0);
  $64 = HEAP32[$matches$0>>2]|0;
  $65 = ($64|0)==(0|0);
  if ($65) {
   _free($matches$0);
   HEAP32[$matchesp>>2] = 0;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$0 = 1;
  }
  while(1) {
   $66 = (($matches$0) + ($i$0<<2)|0);
   $67 = HEAP32[$66>>2]|0;
   $68 = ($67|0)==(0|0);
   $69 = (($i$0) + 1)|0;
   if ($68) {
    $i$0$lcssa = $i$0;
    break;
   } else {
    $i$0 = $69;
   }
  }
  $70 = ($i$0$lcssa|0)>(1);
  $71 = ($i$0$lcssa|0)<($nmatch$0$lcssa|0);
  $or$cond2 = $70 & $71;
  if ($or$cond2) {
   $72 = (($i$0$lcssa) + -1)|0;
   _compute_lcd_of_matches($matches$0,$72,$64);
   _free($64);
  }
 }
 HEAP32[$matchesp>>2] = $matches$0;
 $$0 = 1;
 STACKTOP = sp;return ($$0|0);
}
function _insert_match($match,$start,$mtype,$qc) {
 $match = $match|0;
 $start = $start|0;
 $mtype = $mtype|0;
 $qc = $qc|0;
 var $$ = 0, $$0$ph = 0, $$08 = 0, $$1$lcssa = 0, $$111 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $9 = 0, $end$0 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3 = 0, $or$cond3$i = 0, $or$cond5 = 0, $or$cond5$i = 0, $phitmp$i = 0, $r$0$lcssa = 0, $r$010 = 0, $replacement$0$i = 0, $should_quote$0$i = 0, $start$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($qc|0)!=(0|0);
 if ($0) {
  $1 = HEAP8[$qc>>0]|0;
  $40 = $1;
 } else {
  $40 = 0;
 }
 $2 = ($match|0)!=(0|0);
 $3 = HEAP32[29128>>2]|0;
 $4 = ($3|0)!=(0|0);
 $or$cond$i = $2 & $4;
 $5 = HEAP32[29160>>2]|0;
 $6 = ($5|0)!=(0);
 $or$cond3$i = $or$cond$i & $6;
 if ($or$cond3$i) {
  $7 = HEAP32[29168>>2]|0;
  $8 = ($7|0)!=(0);
  $9 = $8&1;
  if ($8) {
   $10 = ($qc|0)==(0|0);
   if ($10) {
    $17 = 1;
   } else {
    $11 = HEAP8[$qc>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($12) {
     $17 = 1;
    } else {
     $13 = $11 << 24 >> 24;
     $14 = (_strchr($3,$13)|0);
     $15 = ($14|0)!=(0|0);
     $17 = $15;
    }
   }
   $16 = $17&1;
   $should_quote$0$i = $16;
  } else {
   $should_quote$0$i = $9;
  }
  $18 = ($should_quote$0$i|0)==(0);
  if ($18) {
   $replacement$0$i = $match;
  } else {
   $19 = HEAP32[29136>>2]|0;
   $20 = ($19|0)==(0|0);
   if ($20) {
    $replacement$0$i = $match;
   } else {
    $21 = (_strpbrk($match,$19)|0);
    $22 = ($21|0)!=(0|0);
    $phitmp$i = $22 ? $mtype : 0;
    $23 = ($phitmp$i|0)!=(0);
    $24 = HEAP32[29184>>2]|0;
    $25 = ($24|0)!=(0|0);
    $or$cond5$i = $25 & $23;
    if ($or$cond5$i) {
     $26 = (FUNCTION_TABLE_iiii[$24 & 511]($match,$phitmp$i,$qc)|0);
     $replacement$0$i = $26;
    } else {
     $replacement$0$i = $match;
    }
   }
  }
 } else {
  $replacement$0$i = $match;
 }
 $27 = ($replacement$0$i|0)==(0|0);
 if ($27) {
  return;
 }
 $28 = (_strlen(($replacement$0$i|0))|0);
 if ($0) {
  $29 = HEAP8[$qc>>0]|0;
  $30 = ($29<<24>>24)!=(0);
  $31 = ($start|0)!=(0);
  $or$cond = $31 & $30;
  if ($or$cond) {
   $32 = (($start) + -1)|0;
   $33 = HEAP32[13632>>2]|0;
   $34 = (($33) + ($32)|0);
   $35 = HEAP8[$34>>0]|0;
   $36 = ($35<<24>>24)==($29<<24>>24);
   if ($36) {
    $37 = HEAP8[$replacement$0$i>>0]|0;
    $38 = ($37<<24>>24)==($29<<24>>24);
    if ($38) {
     $$0$ph = $32;
    } else {
     label = 18;
    }
   } else {
    label = 18;
   }
  } else {
   label = 18;
  }
  if ((label|0) == 18) {
   $39 = ($29<<24>>24)!=($40<<24>>24);
   $or$cond3 = $31 & $39;
   if ($or$cond3) {
    $41 = (($start) + -1)|0;
    $42 = HEAP32[13632>>2]|0;
    $43 = (($42) + ($41)|0);
    $44 = HEAP8[$43>>0]|0;
    $45 = ($44<<24>>24)==($40<<24>>24);
    if ($45) {
     $46 = HEAP8[$replacement$0$i>>0]|0;
     $47 = ($46<<24>>24)==($40<<24>>24);
     $start$ = $47 ? $start : $41;
     $$0$ph = $start$;
    } else {
     $$0$ph = $start;
    }
   } else {
    $$0$ph = $start;
   }
  }
  $50 = HEAP32[13784>>2]|0;
  $51 = (($50) + -1)|0;
  $52 = ($51|0)!=(0);
  $or$cond5 = $30 & $52;
  if ($or$cond5) {
   $53 = HEAP32[13632>>2]|0;
   $54 = (($53) + ($50)|0);
   $55 = HEAP8[$54>>0]|0;
   $56 = ($55<<24>>24)==($29<<24>>24);
   if ($56) {
    $57 = (($28) + -1)|0;
    $58 = (($replacement$0$i) + ($57)|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = ($59<<24>>24)==($29<<24>>24);
    $$ = $60 ? $50 : $51;
    $$08 = $$0$ph;$end$0 = $$;
   } else {
    $$08 = $$0$ph;$end$0 = $51;
   }
  } else {
   $$08 = $$0$ph;$end$0 = $51;
  }
 } else {
  $48 = HEAP32[13784>>2]|0;
  $49 = (($48) + -1)|0;
  $$08 = $start;$end$0 = $49;
 }
 $61 = HEAP32[28984>>2]|0;
 $62 = ($61|0)==(0);
 if ($62) {
  (__rl_replace_text($replacement$0$i,$$08,$end$0)|0);
 } else {
  $63 = HEAP32[13768>>2]|0;
  $64 = ($$08|0)<($63|0);
  L37: do {
   if ($64) {
    $65 = HEAP32[13632>>2]|0;
    $$111 = $$08;$r$010 = $replacement$0$i;
    while(1) {
     $66 = HEAP8[$r$010>>0]|0;
     $67 = ($66<<24>>24)==(0);
     if ($67) {
      $$1$lcssa = $$111;$r$0$lcssa = $r$010;
      break L37;
     }
     $68 = (($65) + ($$111)|0);
     $69 = HEAP8[$68>>0]|0;
     $70 = ($69<<24>>24)==($66<<24>>24);
     if (!($70)) {
      $$1$lcssa = $$111;$r$0$lcssa = $r$010;
      break L37;
     }
     $71 = (($$111) + 1)|0;
     $72 = ((($r$010)) + 1|0);
     $73 = ($71|0)<($63|0);
     if ($73) {
      $$111 = $71;$r$010 = $72;
     } else {
      $$1$lcssa = $71;$r$0$lcssa = $72;
      break;
     }
    }
   } else {
    $$1$lcssa = $$08;$r$0$lcssa = $replacement$0$i;
   }
  } while(0);
  $74 = ($$1$lcssa|0)>($end$0|0);
  if ($74) {
   $75 = HEAP8[$r$0$lcssa>>0]|0;
   $76 = ($75<<24>>24)==(0);
   if (!($76)) {
    label = 33;
   }
  } else {
   label = 33;
  }
  if ((label|0) == 33) {
   (__rl_replace_text($r$0$lcssa,$$1$lcssa,$end$0)|0);
  }
  $77 = (_strlen(($r$0$lcssa|0))|0);
  $78 = (($77) + ($$1$lcssa))|0;
  HEAP32[13784>>2] = $78;
 }
 $79 = ($replacement$0$i|0)==($match|0);
 if ($79) {
  return;
 }
 _xfree($replacement$0$i);
 return;
}
function _display_matches($matches) {
 $matches = $matches|0;
 var $$0$i = 0, $$0$i8 = 0, $$lcssa = 0, $$lcssa49 = 0, $$max$0 = 0, $$max$0$lcssa = 0, $$pn$i = 0, $$pn$i$lcssa = 0, $$pn$i1 = 0, $$pn$i1$lcssa = 0, $$pre$i12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $9 = 0, $i$022 = 0, $i$022$lcssa = 0, $max$021 = 0;
 var $or$cond = 0, $or$cond2$i = 0, $or$cond9$i = 0, $phitmp1$i = 0, $phitmp1$i6 = 0, $pos$0$be$i = 0, $pos$03$i = 0, $ps$i = 0, $vararg_buffer = 0, $wc$i = 0, $width$0$be$i = 0, $width$0$lcssa$i = 0, $width$04$i = 0, $x$0$i = 0, $x$0$i2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 8|0;
 $ps$i = sp;
 $wc$i = sp + 12|0;
 $0 = HEAP32[32296>>2]|0;
 __rl_move_vert($0);
 $1 = ((($matches)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $4 = HEAP32[$matches>>2]|0;
  $5 = HEAP32[29160>>2]|0;
  $6 = ($5|0)==(0);
  L3: do {
   if ($6) {
    $$0$i = $4;
   } else {
    $7 = (_strrchr($4,47)|0);
    $8 = ($7|0)==(0|0);
    if ($8) {
     $$0$i = $4;
    } else {
     $9 = HEAP8[$7>>0]|0;
     $10 = ($9<<24>>24)==(0);
     if ($10) {
      $$0$i = $4;
     } else {
      $11 = ((($7)) + 1|0);
      $12 = HEAP8[$11>>0]|0;
      $13 = ($12<<24>>24)==(0);
      if ($13) {
       $$pn$i = $7;
       while(1) {
        $x$0$i = ((($$pn$i)) + -1|0);
        $14 = ($x$0$i>>>0)>($4>>>0);
        $15 = HEAP8[$x$0$i>>0]|0;
        $16 = ($15<<24>>24)==(47);
        if (!($14)) {
         $$lcssa = $16;$$pn$i$lcssa = $$pn$i;
         break;
        }
        if ($16) {
         $$0$i = $$pn$i;
         break L3;
        } else {
         $$pn$i = $x$0$i;
        }
       }
       $phitmp1$i = $$lcssa ? $$pn$i$lcssa : $4;
       $$0$i = $phitmp1$i;
      } else {
       $$0$i = $11;
      }
     }
    }
   }
  } while(0);
  (_rl_crlf()|0);
  $17 = HEAP32[$matches>>2]|0;
  (_print_filename($$0$i,$17,0)|0);
  (_rl_crlf()|0);
  (_rl_forced_update_display()|0);
  HEAP32[32256>>2] = 1;
  STACKTOP = sp;return;
 }
 $20 = $2;$i$022 = 1;$max$021 = 0;
 while(1) {
  $18 = HEAP32[29160>>2]|0;
  $19 = ($18|0)==(0);
  L16: do {
   if ($19) {
    $$0$i8 = $20;
   } else {
    $21 = (_strrchr($20,47)|0);
    $22 = ($21|0)==(0|0);
    if ($22) {
     $$0$i8 = $20;
    } else {
     $23 = HEAP8[$21>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $$0$i8 = $20;
     } else {
      $25 = ((($21)) + 1|0);
      $26 = HEAP8[$25>>0]|0;
      $27 = ($26<<24>>24)==(0);
      if ($27) {
       $$pn$i1 = $21;
       while(1) {
        $x$0$i2 = ((($$pn$i1)) + -1|0);
        $28 = ($x$0$i2>>>0)>($20>>>0);
        $29 = HEAP8[$x$0$i2>>0]|0;
        $30 = ($29<<24>>24)==(47);
        if (!($28)) {
         $$lcssa49 = $30;$$pn$i1$lcssa = $$pn$i1;
         break;
        }
        if ($30) {
         $$0$i8 = $$pn$i1;
         break L16;
        } else {
         $$pn$i1 = $x$0$i2;
        }
       }
       $phitmp1$i6 = $$lcssa49 ? $$pn$i1$lcssa : $20;
       $$0$i8 = $phitmp1$i6;
      } else {
       $$0$i8 = $25;
      }
     }
    }
   }
  } while(0);
  $31 = (_strlen(($$0$i8|0))|0);
  $32 = (($31) + 1)|0;
  $33 = $ps$i;
  $34 = $33;
  HEAP32[$34>>2] = 0;
  $35 = (($33) + 4)|0;
  $36 = $35;
  HEAP32[$36>>2] = 0;
  $37 = HEAP8[$$0$i8>>0]|0;
  $38 = ($37<<24>>24)==(0);
  L25: do {
   if ($38) {
    $width$0$lcssa$i = 0;
   } else {
    $40 = $37;$45 = $$0$i8;$pos$03$i = 0;$width$04$i = 0;
    while(1) {
     $39 = ($40&255)<(32);
     $41 = ($40<<24>>24)==(127);
     $or$cond2$i = $39 | $41;
     do {
      if ($or$cond2$i) {
       $42 = (($width$04$i) + 2)|0;
       $43 = (($pos$03$i) + 1)|0;
       $pos$0$be$i = $43;$width$0$be$i = $42;
      } else {
       $44 = (($32) - ($pos$03$i))|0;
       $46 = (_mbrtowc($wc$i,$45,$44,$ps$i)|0);
       $47 = ($46>>>0)>(4294967293);
       if ($47) {
        $48 = (($width$04$i) + 1)|0;
        $49 = (($pos$03$i) + 1)|0;
        $50 = $ps$i;
        $51 = $50;
        HEAP32[$51>>2] = 0;
        $52 = (($50) + 4)|0;
        $53 = $52;
        HEAP32[$53>>2] = 0;
        $pos$0$be$i = $49;$width$0$be$i = $48;
        break;
       }
       $57 = ($46|0)==(0);
       if ($57) {
        $width$0$lcssa$i = $width$04$i;
        break L25;
       }
       $58 = (($46) + ($pos$03$i))|0;
       $59 = HEAP32[$wc$i>>2]|0;
       $60 = (_wcwidth($59)|0);
       $61 = ($60|0)>(-1);
       $62 = $61 ? $60 : 1;
       $63 = (($62) + ($width$04$i))|0;
       $pos$0$be$i = $58;$width$0$be$i = $63;
      }
     } while(0);
     $54 = (($$0$i8) + ($pos$0$be$i)|0);
     $55 = HEAP8[$54>>0]|0;
     $56 = ($55<<24>>24)==(0);
     if ($56) {
      $width$0$lcssa$i = $width$0$be$i;
      break;
     } else {
      $40 = $55;$45 = $54;$pos$03$i = $pos$0$be$i;$width$04$i = $width$0$be$i;
     }
    }
   }
  } while(0);
  $64 = ($width$0$lcssa$i|0)>($max$021|0);
  $$max$0 = $64 ? $width$0$lcssa$i : $max$021;
  $65 = (($i$022) + 1)|0;
  $66 = (($matches) + ($65<<2)|0);
  $67 = HEAP32[$66>>2]|0;
  $68 = ($67|0)==(0|0);
  if ($68) {
   $$max$0$lcssa = $$max$0;$i$022$lcssa = $i$022;
   break;
  } else {
   $20 = $67;$i$022 = $65;$max$021 = $$max$0;
  }
 }
 $69 = HEAP32[28888>>2]|0;
 $70 = ($69|0)==(0|0);
 if (!($70)) {
  FUNCTION_TABLE_viii[$69 & 0]($matches,$i$022$lcssa,$$max$0$lcssa);
  STACKTOP = sp;return;
 }
 $71 = HEAP32[29080>>2]|0;
 $72 = ($71|0)>(0);
 $73 = ($i$022$lcssa|0)>=($71|0);
 $or$cond = $72 & $73;
 L42: do {
  if ($or$cond) {
   (_rl_crlf()|0);
   $74 = HEAP32[13512>>2]|0;
   HEAP32[$vararg_buffer>>2] = $i$022$lcssa;
   (_fprintf(($74|0),(29592|0),($vararg_buffer|0))|0);
   $75 = HEAP32[13512>>2]|0;
   (_fflush(($75|0))|0);
   $76 = HEAP32[13488>>2]|0;
   $77 = $76 & 524288;
   $78 = ($77|0)==(0);
   if ($78) {
    $80 = $76;
    L44: while(1) {
     $79 = $80 | 64;
     HEAP32[13488>>2] = $79;
     $81 = (_rl_read_key()|0);
     $82 = HEAP32[13488>>2]|0;
     $83 = $82 & -65;
     HEAP32[13488>>2] = $83;
     switch ($81|0) {
     case 78: case 110: case 127:  {
      break L44;
      break;
     }
     case 32: case 89: case 121:  {
      break L42;
      break;
     }
     default: {
     }
     }
     $84 = ($81|0)==(7);
     $85 = ($81|0)<(0);
     $or$cond9$i = $84 | $85;
     if ($or$cond9$i) {
      label = 33;
      break;
     }
     (_rl_ding()|0);
     $$pre$i12 = HEAP32[13488>>2]|0;
     $80 = $$pre$i12;
    }
    if ((label|0) == 33) {
     (__rl_abort_internal()|0);
     // unreachable;
    }
    (_rl_crlf()|0);
    (_rl_forced_update_display()|0);
    HEAP32[32256>>2] = 1;
    STACKTOP = sp;return;
   }
  }
 } while(0);
 _rl_display_match_list($matches,$i$022$lcssa,$$max$0$lcssa);
 (_rl_forced_update_display()|0);
 HEAP32[32256>>2] = 1;
 STACKTOP = sp;return;
}
function _append_to_match($text,$delimiter,$quote_char,$nontrivial_match) {
 $text = $text|0;
 $delimiter = $delimiter|0;
 $quote_char = $quote_char|0;
 $nontrivial_match = $nontrivial_match|0;
 var $$pre = 0, $$pre1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $filename$0 = 0, $finfo = 0, $finfo$i = 0, $fn = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $temp_string = 0;
 var $temp_string_index$0 = 0, $temp_string_index$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $finfo$i = sp + 80|0;
 $temp_string = sp + 156|0;
 $fn = sp + 76|0;
 $finfo = sp;
 $0 = ($quote_char|0)!=(0);
 $1 = HEAP32[13784>>2]|0;
 $2 = ($1|0)!=(0);
 $or$cond = $0 & $2;
 $3 = HEAP32[29224>>2]|0;
 $4 = ($3|0)==(0);
 $or$cond3 = $or$cond & $4;
 if ($or$cond3) {
  $5 = (($1) + -1)|0;
  $6 = HEAP32[13632>>2]|0;
  $7 = (($6) + ($5)|0);
  $8 = HEAP8[$7>>0]|0;
  $9 = $8 << 24 >> 24;
  $10 = ($9|0)==($quote_char|0);
  if ($10) {
   $temp_string_index$0 = 0;
  } else {
   $11 = $quote_char&255;
   HEAP8[$temp_string>>0] = $11;
   $temp_string_index$0 = 1;
  }
 } else {
  $temp_string_index$0 = 0;
 }
 $12 = ($delimiter|0)==(0);
 if ($12) {
  $16 = HEAP32[29208>>2]|0;
  $17 = ($16|0)==(0);
  $18 = HEAP32[29216>>2]|0;
  $19 = ($18|0)!=(0);
  $or$cond5 = $17 & $19;
  if ($or$cond5) {
   $20 = $18&255;
   $21 = (($temp_string_index$0) + 1)|0;
   $22 = (($temp_string) + ($temp_string_index$0)|0);
   HEAP8[$22>>0] = $20;
   $temp_string_index$1 = $21;
  } else {
   $temp_string_index$1 = $temp_string_index$0;
  }
 } else {
  $13 = $delimiter&255;
  $14 = (($temp_string_index$0) + 1)|0;
  $15 = (($temp_string) + ($temp_string_index$0)|0);
  HEAP8[$15>>0] = $13;
  $temp_string_index$1 = $14;
 }
 $23 = (($temp_string) + ($temp_string_index$1)|0);
 HEAP8[$23>>0] = 0;
 $24 = HEAP32[29160>>2]|0;
 $25 = ($24|0)==(0);
 if ($25) {
  $67 = HEAP32[13768>>2]|0;
  $68 = ($1|0)==($67|0);
  if (!($68)) {
   STACKTOP = sp;return;
  }
  (_rl_insert_text($temp_string)|0);
  STACKTOP = sp;return;
 }
 $26 = (_tilde_expand($text)|0);
 $27 = HEAP32[29016>>2]|0;
 $28 = ($27|0)==(0|0);
 if ($28) {
  $filename$0 = $26;
 } else {
  $29 = (_strlen(($26|0))|0);
  $30 = (($29) + 1)|0;
  $31 = (_xmalloc($30)|0);
  $32 = (_strcpy(($31|0),($26|0))|0);
  HEAP32[$fn>>2] = $32;
  $33 = HEAP32[29016>>2]|0;
  (FUNCTION_TABLE_ii[$33 & 511]($fn)|0);
  _xfree($26);
  $34 = HEAP32[$fn>>2]|0;
  $filename$0 = $34;
 }
 $35 = ($nontrivial_match|0)!=(0);
 $36 = HEAP32[29280>>2]|0;
 $37 = ($36|0)==(0);
 $or$cond7 = $35 & $37;
 if ($or$cond7) {
  $38 = (_lstat(($filename$0|0),($finfo|0))|0);
  $41 = $38;
 } else {
  $39 = (_stat(($filename$0|0),($finfo|0))|0);
  $41 = $39;
 }
 $40 = ($41|0)==(0);
 do {
  if ($40) {
   $42 = ((($finfo)) + 12|0);
   $43 = HEAP32[$42>>2]|0;
   $44 = $43 & 61440;
   if ((($44|0) == 40960)) {
    $58 = (_stat(($filename$0|0),($finfo$i|0))|0);
    $59 = ($58|0)==(0);
    if ($59) {
     $60 = ((($finfo$i)) + 12|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = $61 & 61440;
     $63 = ($62|0)==(16384);
     if ($63) {
      break;
     } else {
      label = 26;
      break;
     }
    } else {
     label = 26;
     break;
    }
   } else if (!((($44|0) == 16384))) {
    label = 26;
    break;
   }
   $45 = HEAP32[28912>>2]|0;
   $46 = ($45|0)==(0);
   if (!($46)) {
    $47 = HEAP32[13784>>2]|0;
    $48 = ($47|0)==(0);
    $$pre = HEAP32[13632>>2]|0;
    if ($48) {
     $$pre1 = HEAP8[$$pre>>0]|0;
     $57 = $$pre1;
     label = 21;
    } else {
     $49 = (($$pre) + ($47)|0);
     $50 = HEAP8[$49>>0]|0;
     $51 = ($50<<24>>24)==(0);
     if ($51) {
      $52 = (($47) + -1)|0;
      $53 = (($$pre) + ($52)|0);
      $54 = HEAP8[$53>>0]|0;
      $55 = ($54<<24>>24)==(47);
      if ($55) {
       break;
      }
     } else {
      $57 = $50;
      label = 21;
     }
    }
    if ((label|0) == 21) {
     $56 = ($57<<24>>24)==(47);
     if ($56) {
      break;
     }
    }
    (_rl_insert_text(29576)|0);
   }
  } else {
   label = 26;
  }
 } while(0);
 if ((label|0) == 26) {
  $64 = HEAP32[13784>>2]|0;
  $65 = HEAP32[13768>>2]|0;
  $66 = ($64|0)==($65|0);
  if ($66) {
   (_rl_insert_text($temp_string)|0);
  }
 }
 _xfree($filename$0);
 STACKTOP = sp;return;
}
function __rl_complete_sigcleanup($sig,$ptr) {
 $sig = $sig|0;
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($sig|0)==(2);
 if (!($0)) {
  return;
 }
 $1 = ($ptr|0)==(0|0);
 if ($1) {
  return;
 }
 $2 = HEAP32[$ptr>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = $2;$i$01$i = 0;
  while(1) {
   _xfree($4);
   $5 = (($i$01$i) + 1)|0;
   $6 = (($ptr) + ($5<<2)|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    break;
   } else {
    $4 = $7;$i$01$i = $5;
   }
  }
 }
 _xfree($ptr);
 return;
}
function _print_filename($to_print,$full_pathname,$prefix_bytes) {
 $to_print = $to_print|0;
 $full_pathname = $full_pathname|0;
 $prefix_bytes = $prefix_bytes|0;
 var $$pr = 0, $$pre = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $dn = 0, $extension_char$0 = 0, $extension_char$1 = 0, $extension_char$2 = 0, $finfo$i = 0, $finfo$i9 = 0, $new_full_pathname$0 = 0, $new_full_pathname$1 = 0, $or$cond = 0;
 var $or$cond7 = 0, $phitmp = 0, $phitmp11 = 0, $printed_len$0 = 0, $printed_len$1 = 0, $printed_len$2 = 0, $printed_len$3 = 0, $s = 0, $slen$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $finfo$i9 = sp + 84|0;
 $finfo$i = sp + 8|0;
 $s = sp + 4|0;
 $dn = sp;
 $0 = HEAP32[28976>>2]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[29160>>2]|0;
 $3 = ($2|0)==(0);
 $or$cond = $1 | $3;
 if ($or$cond) {
  $4 = (_fnprint($to_print,$prefix_bytes)|0);
  $$pr = HEAP32[29160>>2]|0;
  $6 = $$pr;$printed_len$0 = $4;
 } else {
  $6 = $2;$printed_len$0 = 0;
 }
 $5 = ($6|0)==(0);
 if ($5) {
  $printed_len$3 = $printed_len$0;
  STACKTOP = sp;return ($printed_len$3|0);
 }
 $7 = HEAP32[28968>>2]|0;
 $8 = HEAP32[28976>>2]|0;
 $9 = $8 | $7;
 $10 = HEAP32[28912>>2]|0;
 $11 = $9 | $10;
 $12 = ($11|0)==(0);
 if ($12) {
  $printed_len$3 = $printed_len$0;
  STACKTOP = sp;return ($printed_len$3|0);
 }
 $13 = ($to_print|0)==($full_pathname|0);
 if ($13) {
  $66 = (_tilde_expand($to_print)|0);
  HEAP32[$s>>2] = $66;
  $67 = HEAP32[28968>>2]|0;
  $68 = ($67|0)==(0);
  if ($68) {
   $70 = HEAP32[28912>>2]|0;
   $71 = ($70|0)==(0);
   if ($71) {
    $extension_char$1 = 0;
   } else {
    $72 = (_stat(($66|0),($finfo$i9|0))|0);
    $73 = ($72|0)==(0);
    if ($73) {
     $74 = ((($finfo$i9)) + 12|0);
     $75 = HEAP32[$74>>2]|0;
     $76 = $75 & 61440;
     $77 = ($76|0)==(16384);
     $phitmp11 = $77 ? 47 : 0;
     $87 = $phitmp11;
    } else {
     $87 = 0;
    }
    $extension_char$1 = $87;
   }
  } else {
   $69 = (_stat_char($66)|0);
   $extension_char$1 = $69;
  }
  $78 = HEAP32[28976>>2]|0;
  $79 = ($78|0)==(0);
  if ($79) {
   $extension_char$2 = $extension_char$1;$printed_len$2 = $printed_len$0;
  } else {
   $80 = HEAP32[$s>>2]|0;
   __rl_set_normal_color();
   (__rl_print_color_indicator($80)|0);
   $81 = (_fnprint($to_print,$prefix_bytes)|0);
   __rl_prep_non_filename_text();
   __rl_put_indicator((36552));
   $extension_char$2 = $extension_char$1;$printed_len$2 = $81;
  }
 } else {
  $14 = ((($to_print)) + -1|0);
  $15 = HEAP8[$14>>0]|0;
  HEAP8[$14>>0] = 0;
  $16 = ($full_pathname|0)==(0|0);
  do {
   if ($16) {
    label = 8;
   } else {
    $17 = HEAP8[$full_pathname>>0]|0;
    if ((($17<<24>>24) == 0)) {
     label = 8;
     break;
    } else if (!((($17<<24>>24) == 47))) {
     HEAP32[$dn>>2] = $full_pathname;
     $23 = $full_pathname;
     break;
    }
    $18 = ((($full_pathname)) + 1|0);
    $19 = HEAP8[$18>>0]|0;
    if ((($19<<24>>24) == 47)) {
     label = 12;
    } else if ((($19<<24>>24) == 0)) {
     HEAP32[$dn>>2] = 29584;
     $23 = 29584;
     break;
    }
    if ((label|0) == 12) {
     $20 = ((($full_pathname)) + 2|0);
     $21 = HEAP8[$20>>0]|0;
     $22 = ($21<<24>>24)==(0);
     if ($22) {
      HEAP32[$dn>>2] = 29576;
      $23 = 29576;
      break;
     }
    }
    HEAP32[$dn>>2] = $full_pathname;
    $23 = $full_pathname;
   }
  } while(0);
  if ((label|0) == 8) {
   HEAP32[$dn>>2] = 29576;
   $23 = 29576;
  }
  $24 = (_tilde_expand($23)|0);
  HEAP32[$s>>2] = $24;
  $25 = HEAP32[29000>>2]|0;
  $26 = ($25|0)==(0|0);
  if ($26) {
   $27 = $24;
  } else {
   (FUNCTION_TABLE_ii[$25 & 511]($s)|0);
   $$pre = HEAP32[$s>>2]|0;
   $27 = $$pre;
  }
  $28 = (_strlen(($27|0))|0);
  $29 = (_strlen(($to_print|0))|0);
  $30 = (($28) + 2)|0;
  $31 = (($30) + ($29))|0;
  $32 = (_xmalloc($31)|0);
  $33 = HEAP32[$s>>2]|0;
  (_strcpy(($32|0),($33|0))|0);
  $34 = (($28) + -1)|0;
  $35 = HEAP32[$s>>2]|0;
  $36 = (($35) + ($34)|0);
  $37 = HEAP8[$36>>0]|0;
  $38 = ($37<<24>>24)==(47);
  if ($38) {
   $slen$0 = $34;
  } else {
   $39 = (($32) + ($28)|0);
   HEAP8[$39>>0] = 47;
   $slen$0 = $28;
  }
  $40 = (($32) + ($slen$0)|0);
  HEAP8[$40>>0] = 47;
  $$sum = (($slen$0) + 1)|0;
  $41 = (($32) + ($$sum)|0);
  (_strcpy(($41|0),($to_print|0))|0);
  $42 = HEAP32[28968>>2]|0;
  $43 = ($42|0)==(0);
  if ($43) {
   $45 = HEAP32[28912>>2]|0;
   $46 = ($45|0)==(0);
   if ($46) {
    $extension_char$0 = 0;$new_full_pathname$1 = $32;
   } else {
    HEAP32[$dn>>2] = 0;
    $47 = HEAP32[29000>>2]|0;
    $48 = ($47|0)==(0|0);
    $49 = HEAP32[29016>>2]|0;
    $50 = ($49|0)!=(0|0);
    $or$cond7 = $48 & $50;
    if ($or$cond7) {
     $51 = (_strlen(($32|0))|0);
     $52 = (($51) + 1)|0;
     $53 = (_xmalloc($52)|0);
     $54 = (_strcpy(($53|0),($32|0))|0);
     HEAP32[$dn>>2] = $54;
     $55 = HEAP32[29016>>2]|0;
     (FUNCTION_TABLE_ii[$55 & 511]($dn)|0);
     _free($32);
     $56 = HEAP32[$dn>>2]|0;
     $new_full_pathname$0 = $56;
    } else {
     $new_full_pathname$0 = $32;
    }
    $57 = (_stat(($new_full_pathname$0|0),($finfo$i|0))|0);
    $58 = ($57|0)==(0);
    if ($58) {
     $59 = ((($finfo$i)) + 12|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = $60 & 61440;
     $62 = ($61|0)==(16384);
     $phitmp = $62 ? 47 : 0;
     $86 = $phitmp;
    } else {
     $86 = 0;
    }
    $extension_char$0 = $86;$new_full_pathname$1 = $new_full_pathname$0;
   }
  } else {
   $44 = (_stat_char($32)|0);
   $extension_char$0 = $44;$new_full_pathname$1 = $32;
  }
  $63 = HEAP32[28976>>2]|0;
  $64 = ($63|0)==(0);
  if ($64) {
   $printed_len$1 = $printed_len$0;
  } else {
   __rl_set_normal_color();
   (__rl_print_color_indicator($new_full_pathname$1)|0);
   $65 = (_fnprint($to_print,$prefix_bytes)|0);
   __rl_prep_non_filename_text();
   __rl_put_indicator((36552));
   $printed_len$1 = $65;
  }
  _xfree($new_full_pathname$1);
  HEAP8[$14>>0] = $15;
  $extension_char$2 = $extension_char$0;$printed_len$2 = $printed_len$1;
 }
 $82 = HEAP32[$s>>2]|0;
 _xfree($82);
 $83 = ($extension_char$2|0)==(0);
 if ($83) {
  $printed_len$3 = $printed_len$2;
  STACKTOP = sp;return ($printed_len$3|0);
 }
 $84 = HEAP32[13512>>2]|0;
 (_putc(($extension_char$2|0),($84|0))|0);
 $85 = (($printed_len$2) + 1)|0;
 $printed_len$3 = $85;
 STACKTOP = sp;return ($printed_len$3|0);
}
function _compute_lcd_of_matches($match_list,$matches,$text) {
 $match_list = $match_list|0;
 $matches = $matches|0;
 $text = $text|0;
 var $$015 = 0, $$lcssa = 0, $$phi$trans$insert = 0, $$phi$trans$insert31 = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre28 = 0, $$pre30 = 0, $$pre32 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $dtext$0 = 0, $exitcond = 0, $i$018 = 0, $i$18 = 0, $low$0$lcssa34 = 0, $low$017 = 0, $or$cond10 = 0, $or$cond12 = 0, $or$cond14 = 0, $or$cond8 = 0, $ps1 = 0, $ps2 = 0, $ps_back = 0, $si$0 = 0, $si$1 = 0, $si$29 = 0, $si$3 = 0, $si$4 = 0, $si$4$low$0 = 0, $si$4$low$0$lcssa = 0;
 var $wc1 = 0, $wc2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps1 = sp + 16|0;
 $ps2 = sp + 8|0;
 $wc1 = sp + 28|0;
 $wc2 = sp + 24|0;
 $ps_back = sp;
 $0 = ($matches|0)==(1);
 if ($0) {
  $2 = ((($match_list)) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  HEAP32[$match_list>>2] = $3;
  HEAP32[$2>>2] = 0;
  STACKTOP = sp;return;
 }
 $1 = ($matches|0)>(1);
 if ($1) {
  $i$018 = 1;$low$017 = 100000;
  while(1) {
   $4 = HEAP32[36240>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    $6 = $ps1;
    $7 = $6;
    HEAP32[$7>>2] = 0;
    $8 = (($6) + 4)|0;
    $9 = $8;
    HEAP32[$9>>2] = 0;
    $10 = $ps2;
    $11 = $10;
    HEAP32[$11>>2] = 0;
    $12 = (($10) + 4)|0;
    $13 = $12;
    HEAP32[$13>>2] = 0;
   }
   $14 = HEAP32[28928>>2]|0;
   $15 = ($14|0)==(0);
   L11: do {
    if ($15) {
     $19 = (($i$018) + 1)|0;
     $20 = (($match_list) + ($19<<2)|0);
     $21 = (($match_list) + ($i$018<<2)|0);
     $22 = HEAP32[$21>>2]|0;
     $23 = HEAP8[$22>>0]|0;
     $24 = ($23<<24>>24)==(0);
     if ($24) {
      $$pre$phiZ2D = $19;$si$4 = 0;
     } else {
      $104 = $23;$94 = $22;$si$29 = 0;
      while(1) {
       $78 = HEAP32[$20>>2]|0;
       $79 = (($78) + ($si$29)|0);
       $80 = HEAP8[$79>>0]|0;
       $81 = ($80<<24>>24)==(0);
       if ($81) {
        $$pre$phiZ2D = $19;$si$4 = $si$29;
        break L11;
       }
       $82 = HEAP32[36240>>2]|0;
       $83 = ($82|0)==(0);
       if ($83) {
        $84 = $ps1;
        $85 = $84;
        $86 = HEAP32[$85>>2]|0;
        $87 = (($84) + 4)|0;
        $88 = $87;
        $89 = HEAP32[$88>>2]|0;
        $90 = $ps_back;
        $91 = $90;
        HEAP32[$91>>2] = $86;
        $92 = (($90) + 4)|0;
        $93 = $92;
        HEAP32[$93>>2] = $89;
        $95 = (__rl_compare_chars($94,$si$29,$ps1,$78,$si$29,$ps2)|0);
        $96 = ($95|0)==(0);
        if ($96) {
         $$pre$phiZ2D = $19;$si$4 = $si$29;
         break L11;
        }
        $97 = HEAP32[$21>>2]|0;
        $98 = (($97) + ($si$29)|0);
        $99 = (__rl_get_char_len($98,$ps_back)|0);
        $100 = ($99|0)>(1);
        if ($100) {
         $101 = (($si$29) + -1)|0;
         $102 = (($101) + ($99))|0;
         $si$3 = $102;
        } else {
         $si$3 = $si$29;
        }
       } else {
        $103 = ($104<<24>>24)==($80<<24>>24);
        if ($103) {
         $si$3 = $si$29;
        } else {
         $$pre$phiZ2D = $19;$si$4 = $si$29;
         break L11;
        }
       }
       $105 = (($si$3) + 1)|0;
       $106 = HEAP32[$21>>2]|0;
       $107 = (($106) + ($105)|0);
       $108 = HEAP8[$107>>0]|0;
       $109 = ($108<<24>>24)==(0);
       if ($109) {
        $$pre$phiZ2D = $19;$si$4 = $105;
        break;
       } else {
        $104 = $108;$94 = $106;$si$29 = $105;
       }
      }
     }
    } else {
     $16 = (($match_list) + ($i$018<<2)|0);
     $17 = (($i$018) + 1)|0;
     $18 = (($match_list) + ($17<<2)|0);
     $si$0 = 0;
     while(1) {
      $25 = HEAP32[$16>>2]|0;
      $26 = (($25) + ($si$0)|0);
      $27 = HEAP8[$26>>0]|0;
      $28 = $27&255;
      $29 = $27 << 24 >> 24;
      $30 = ($28|0)==($29|0);
      if ($30) {
       $31 = (_isupper($28)|0);
       $32 = ($31|0)==(0);
       $$pre = HEAP32[$16>>2]|0;
       $$phi$trans$insert = (($$pre) + ($si$0)|0);
       $$pre28 = HEAP8[$$phi$trans$insert>>0]|0;
       if ($32) {
        $36 = $$pre28;
        label = 12;
       } else {
        $33 = $$pre28&255;
        $34 = (_tolower($33)|0);
        $38 = $34;
       }
      } else {
       $36 = $27;
       label = 12;
      }
      if ((label|0) == 12) {
       label = 0;
       $35 = $36 << 24 >> 24;
       $38 = $35;
      }
      $37 = ($38|0)==(0);
      if ($37) {
       $$pre$phiZ2D = $17;$si$4 = $si$0;
       break L11;
      }
      $39 = HEAP32[$18>>2]|0;
      $40 = (($39) + ($si$0)|0);
      $41 = HEAP8[$40>>0]|0;
      $42 = $41&255;
      $43 = $41 << 24 >> 24;
      $44 = ($42|0)==($43|0);
      if ($44) {
       $45 = (_isupper($42)|0);
       $46 = ($45|0)==(0);
       $$pre30 = HEAP32[$18>>2]|0;
       $$phi$trans$insert31 = (($$pre30) + ($si$0)|0);
       $$pre32 = HEAP8[$$phi$trans$insert31>>0]|0;
       if ($46) {
        $50 = $$pre32;
        label = 17;
       } else {
        $47 = $$pre32&255;
        $48 = (_tolower($47)|0);
        $52 = $48;
       }
      } else {
       $50 = $41;
       label = 17;
      }
      if ((label|0) == 17) {
       label = 0;
       $49 = $50 << 24 >> 24;
       $52 = $49;
      }
      $51 = ($52|0)==(0);
      if ($51) {
       $$pre$phiZ2D = $17;$si$4 = $si$0;
       break L11;
      }
      $53 = HEAP32[36240>>2]|0;
      $54 = ($53|0)==(0);
      do {
       if ($54) {
        $55 = HEAP32[$16>>2]|0;
        $56 = (($55) + ($si$0)|0);
        $57 = (_strlen(($56|0))|0);
        $58 = (_mbrtowc($wc1,$56,$57,$ps1)|0);
        $59 = HEAP32[$18>>2]|0;
        $60 = (($59) + ($si$0)|0);
        $61 = (_strlen(($60|0))|0);
        $62 = (_mbrtowc($wc2,$60,$61,$ps2)|0);
        $63 = ($58>>>0)>(4294967293);
        $64 = ($62>>>0)>(4294967293);
        $65 = $63 | $64;
        if ($65) {
         $66 = ($38|0)==($52|0);
         if ($66) {
          $si$1 = $si$0;
          break;
         } else {
          $$pre$phiZ2D = $17;$si$4 = $si$0;
          break L11;
         }
        }
        $67 = HEAP32[$wc1>>2]|0;
        $68 = (_towlower($67)|0);
        HEAP32[$wc1>>2] = $68;
        $69 = HEAP32[$wc2>>2]|0;
        $70 = (_towlower($69)|0);
        HEAP32[$wc2>>2] = $70;
        $71 = HEAP32[$wc1>>2]|0;
        $72 = ($71|0)==($70|0);
        if (!($72)) {
         $$pre$phiZ2D = $17;$si$4 = $si$0;
         break L11;
        }
        $73 = ($58>>>0)>(1);
        if ($73) {
         $74 = (($si$0) + -1)|0;
         $75 = (($74) + ($58))|0;
         $si$1 = $75;
        } else {
         $si$1 = $si$0;
        }
       } else {
        $76 = ($38|0)==($52|0);
        if ($76) {
         $si$1 = $si$0;
        } else {
         $$pre$phiZ2D = $17;$si$4 = $si$0;
         break L11;
        }
       }
      } while(0);
      $77 = (($si$1) + 1)|0;
      $si$0 = $77;
     }
    }
   } while(0);
   $110 = ($low$017|0)>($si$4|0);
   $si$4$low$0 = $110 ? $si$4 : $low$017;
   $exitcond = ($$pre$phiZ2D|0)==($matches|0);
   if ($exitcond) {
    $si$4$low$0$lcssa = $si$4$low$0;
    break;
   } else {
    $i$018 = $$pre$phiZ2D;$low$017 = $si$4$low$0;
   }
  }
  $111 = ($si$4$low$0$lcssa|0)==(0);
  $112 = ($text|0)!=(0|0);
  $or$cond8 = $112 & $111;
  if ($or$cond8) {
   $113 = HEAP8[$text>>0]|0;
   $114 = ($113<<24>>24)==(0);
   if ($114) {
    $low$0$lcssa34 = $si$4$low$0$lcssa;
   } else {
    $115 = (_strlen(($text|0))|0);
    $116 = (($115) + 1)|0;
    $117 = (_xmalloc($116)|0);
    HEAP32[$match_list>>2] = $117;
    (_strcpy(($117|0),($text|0))|0);
    STACKTOP = sp;return;
   }
  } else {
   $low$0$lcssa34 = $si$4$low$0$lcssa;
  }
 } else {
  $low$0$lcssa34 = 100000;
 }
 $118 = (($low$0$lcssa34) + 1)|0;
 $119 = (_xmalloc($118)|0);
 HEAP32[$match_list>>2] = $119;
 $120 = HEAP32[28928>>2]|0;
 $121 = ($120|0)==(0);
 if ($121) {
  $147 = ((($match_list)) + 4|0);
  $148 = HEAP32[$147>>2]|0;
  (_strncpy(($119|0),($148|0),($low$0$lcssa34|0))|0);
 } else {
  $122 = HEAP32[29160>>2]|0;
  $123 = ($122|0)!=(0);
  $124 = HEAP32[29192>>2]|0;
  $125 = ($124|0)!=(0|0);
  $or$cond10 = $123 & $125;
  $126 = HEAP32[29256>>2]|0;
  $127 = ($126|0)!=(0);
  $or$cond12 = $or$cond10 & $127;
  $128 = HEAP32[29168>>2]|0;
  $129 = ($128|0)!=(0);
  $or$cond14 = $or$cond12 & $129;
  if ($or$cond14) {
   $130 = HEAP32[29264>>2]|0;
   $131 = (FUNCTION_TABLE_iii[$124 & 511]($text,$130)|0);
   $$015 = $131;$dtext$0 = $131;
  } else {
   $$015 = $text;$dtext$0 = 0;
  }
  $132 = ((($match_list)) + 4|0);
  _qsort($132,$matches,4,364);
  $133 = (_strlen(($$015|0))|0);
  $134 = ($133|0)<=($low$0$lcssa34|0);
  $135 = $134 ? $133 : $low$0$lcssa34;
  $136 = ($matches|0)<(1);
  L60: do {
   if ($136) {
    label = 45;
   } else {
    $i$18 = 1;
    while(1) {
     $139 = (($match_list) + ($i$18<<2)|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = (_strncmp($140,$$015,$135)|0);
     $142 = ($141|0)==(0);
     if ($142) {
      $$lcssa = $140;
      break;
     }
     $137 = (($i$18) + 1)|0;
     $138 = ($i$18|0)<($matches|0);
     if ($138) {
      $i$18 = $137;
     } else {
      label = 45;
      break L60;
     }
    }
    $143 = HEAP32[$match_list>>2]|0;
    (_strncpy(($143|0),($$lcssa|0),($low$0$lcssa34|0))|0);
   }
  } while(0);
  if ((label|0) == 45) {
   $144 = HEAP32[$match_list>>2]|0;
   $145 = HEAP32[$132>>2]|0;
   (_strncpy(($144|0),($145|0),($low$0$lcssa34|0))|0);
  }
  $146 = ($dtext$0|0)==(0|0);
  if (!($146)) {
   _free($dtext$0);
  }
 }
 $149 = HEAP32[$match_list>>2]|0;
 $150 = (($149) + ($low$0$lcssa34)|0);
 HEAP8[$150>>0] = 0;
 STACKTOP = sp;return;
}
function _rl_quote_filename($s,$rtype,$qcp) {
 $s = $s|0;
 $rtype = $rtype|0;
 $qcp = $qcp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (($0) + 2)|0;
 $2 = (_xmalloc($1)|0);
 $3 = HEAP32[29128>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 HEAP8[$2>>0] = $4;
 $5 = ((($2)) + 1|0);
 (_strcpy(($5|0),($s|0))|0);
 $6 = ($qcp|0)==(0|0);
 if ($6) {
  return ($2|0);
 }
 $7 = HEAP32[29128>>2]|0;
 $8 = HEAP8[$7>>0]|0;
 HEAP8[$qcp>>0] = $8;
 return ($2|0);
}
function _fnprint($to_print,$prefix_bytes) {
 $to_print = $to_print|0;
 $prefix_bytes = $prefix_bytes|0;
 var $$pre = 0, $$pre12 = 0, $$prefix_bytes = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $8 = 0, $9 = 0, $printed_len$0 = 0, $printed_len$1$be = 0, $printed_len$1$lcssa = 0, $printed_len$14 = 0, $ps = 0, $s$0$be = 0;
 var $s$02 = 0, $tlen$0 = 0, $wc = 0, $width$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps = sp;
 $wc = sp + 8|0;
 $0 = (_strlen(($to_print|0))|0);
 $$sum = (($0) + 1)|0;
 $1 = (($to_print) + ($$sum)|0);
 $2 = $ps;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (($2) + 4)|0;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($to_print) + ($prefix_bytes)|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(0);
 $$prefix_bytes = $8 ? 0 : $prefix_bytes;
 $9 = ($$prefix_bytes|0)==(0);
 $$pre12 = (($to_print) + ($$prefix_bytes)|0);
 if ($9) {
  $printed_len$0 = 0;
 } else {
  $10 = HEAP8[$$pre12>>0]|0;
  $11 = ($10<<24>>24)==(46);
  $12 = $11 ? 95 : 46;
  $13 = HEAP32[13512>>2]|0;
  (_putc(($12|0),($13|0))|0);
  $14 = HEAP32[13512>>2]|0;
  (_putc(($12|0),($14|0))|0);
  $15 = HEAP32[13512>>2]|0;
  (_putc(($12|0),($15|0))|0);
  $printed_len$0 = 3;
 }
 $16 = HEAP8[$$pre12>>0]|0;
 $17 = ($16<<24>>24)==(0);
 if ($17) {
  $printed_len$1$lcssa = $printed_len$0;
  STACKTOP = sp;return ($printed_len$1$lcssa|0);
 }
 $18 = $1;
 $20 = $16;$printed_len$14 = $printed_len$0;$s$02 = $$pre12;
 L7: while(1) {
  $19 = ($20&255)<(32);
  do {
   if ($19) {
    $21 = HEAP32[13512>>2]|0;
    (_putc(94,($21|0))|0);
    $22 = HEAP8[$s$02>>0]|0;
    $23 = $22 << 24 >> 24;
    $24 = $23 | 64;
    $25 = $24 & 255;
    $26 = ($25|0)==($24|0);
    if ($26) {
     $27 = (_islower($24)|0);
     $28 = ($27|0)==(0);
     $$pre = HEAP8[$s$02>>0]|0;
     if ($28) {
      $33 = $$pre;
      label = 9;
     } else {
      $29 = $$pre&255;
      $30 = $29 | 64;
      $31 = (_toupper($30)|0);
      $36 = $31;
     }
    } else {
     $33 = $22;
     label = 9;
    }
    if ((label|0) == 9) {
     label = 0;
     $32 = $33 << 24 >> 24;
     $34 = $32 | 64;
     $36 = $34;
    }
    $35 = HEAP32[13512>>2]|0;
    (_putc(($36|0),($35|0))|0);
    $37 = (($printed_len$14) + 2)|0;
    $38 = ((($s$02)) + 1|0);
    $39 = $ps;
    $40 = $39;
    HEAP32[$40>>2] = 0;
    $41 = (($39) + 4)|0;
    $42 = $41;
    HEAP32[$42>>2] = 0;
    $printed_len$1$be = $37;$s$0$be = $38;
   } else {
    $43 = ($20<<24>>24)==(127);
    if ($43) {
     $44 = HEAP32[13512>>2]|0;
     (_putc(94,($44|0))|0);
     $45 = HEAP32[13512>>2]|0;
     (_putc(63,($45|0))|0);
     $46 = (($printed_len$14) + 2)|0;
     $47 = ((($s$02)) + 1|0);
     $48 = $ps;
     $49 = $48;
     HEAP32[$49>>2] = 0;
     $50 = (($48) + 4)|0;
     $51 = $50;
     HEAP32[$51>>2] = 0;
     $printed_len$1$be = $46;$s$0$be = $47;
     break;
    }
    $54 = $s$02;
    $55 = (($18) - ($54))|0;
    $56 = (_mbrtowc($wc,$s$02,$55,$ps)|0);
    $57 = ($56>>>0)>(4294967293);
    if ($57) {
     $58 = $ps;
     $59 = $58;
     HEAP32[$59>>2] = 0;
     $60 = (($58) + 4)|0;
     $61 = $60;
     HEAP32[$61>>2] = 0;
     $tlen$0 = 1;$width$0 = 1;
    } else {
     $62 = ($56|0)==(0);
     if ($62) {
      $printed_len$1$lcssa = $printed_len$14;
      label = 19;
      break L7;
     }
     $63 = HEAP32[$wc>>2]|0;
     $64 = (_wcwidth($63)|0);
     $65 = ($64|0)>(-1);
     $66 = $65 ? $64 : 1;
     $tlen$0 = $56;$width$0 = $66;
    }
    $67 = HEAP32[13512>>2]|0;
    (_fwrite(($s$02|0),1,($tlen$0|0),($67|0))|0);
    $68 = (($s$02) + ($tlen$0)|0);
    $69 = (($width$0) + ($printed_len$14))|0;
    $printed_len$1$be = $69;$s$0$be = $68;
   }
  } while(0);
  $52 = HEAP8[$s$0$be>>0]|0;
  $53 = ($52<<24>>24)==(0);
  if ($53) {
   $printed_len$1$lcssa = $printed_len$1$be;
   label = 19;
   break;
  } else {
   $20 = $52;$printed_len$14 = $printed_len$1$be;$s$02 = $s$0$be;
  }
 }
 if ((label|0) == 19) {
  STACKTOP = sp;return ($printed_len$1$lcssa|0);
 }
 return (0)|0;
}
function _stat_char($filename) {
 $filename = $filename|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $character$0 = 0;
 var $f = 0, $finfo = 0, $fn$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $finfo = sp + 4|0;
 $f = sp;
 HEAP32[$f>>2] = 0;
 $0 = HEAP32[29016>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $fn$0 = $filename;
 } else {
  $2 = (_strlen(($filename|0))|0);
  $3 = (($2) + 1)|0;
  $4 = (_xmalloc($3)|0);
  $5 = (_strcpy(($4|0),($filename|0))|0);
  HEAP32[$f>>2] = $5;
  $6 = HEAP32[29016>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 511]($f)|0);
  $7 = HEAP32[$f>>2]|0;
  $fn$0 = $7;
 }
 $8 = (_lstat(($fn$0|0),($finfo|0))|0);
 $9 = ($8|0)==(-1);
 if ($9) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $10 = ((($finfo)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 $12 = $11 & 61440;
 if ((($12|0) == 16384)) {
  $character$0 = 47;
 } else if ((($12|0) == 8192)) {
  $character$0 = 37;
 } else if ((($12|0) == 4096)) {
  $character$0 = 124;
 } else if ((($12|0) == 40960)) {
  $character$0 = 64;
 } else if ((($12|0) == 49152)) {
  $character$0 = 61;
 } else if ((($12|0) == 24576)) {
  $character$0 = 35;
 } else {
  $13 = ($12|0)==(32768);
  if ($13) {
   $14 = (_access(($filename|0),1)|0);
   $15 = ($14|0)==(0);
   $$ = $15 ? 42 : 0;
   $character$0 = $$;
  } else {
   $character$0 = 0;
  }
 }
 $16 = HEAP32[$f>>2]|0;
 _free($16);
 $$0 = $character$0;
 STACKTOP = sp;return ($$0|0);
}
function _rl_bind_key_in_map($key,$function,$map) {
 $key = $key|0;
 $function = $function|0;
 $map = $map|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond3$i = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[3358]|0;
 HEAP32[13432>>2] = $map;
 $1 = ($key|0)<(0);
 if ($1) {
  $$0$i = $key;
  HEAP32[3358] = $0;
  return ($$0$i|0);
 }
 $2 = $key & -128;
 $3 = ($2|0)==(128);
 $4 = HEAP32[13688>>2]|0;
 $5 = ($4|0)!=(0);
 $or$cond3$i = $3 & $5;
 if (!($or$cond3$i)) {
  $14 = (($map) + ($key<<3)|0);
  HEAP8[$14>>0] = 0;
  $15 = (((($map) + ($key<<3)|0)) + 4|0);
  HEAP32[$15>>2] = $function;
  $16 = HEAP32[3358]|0;
  HEAP32[29632>>2] = $16;
  $$0$i = 0;
  HEAP32[3358] = $0;
  return ($$0$i|0);
 }
 $6 = ((($map)) + 216|0);
 $7 = HEAP8[$6>>0]|0;
 $8 = ($7<<24>>24)==(1);
 if (!($8)) {
  $$0$i = $key;
  HEAP32[3358] = $0;
  return ($$0$i|0);
 }
 $9 = ((($map)) + 220|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = $key & -129;
 $12 = (($10) + ($11<<3)|0);
 HEAP8[$12>>0] = 0;
 $13 = (((($10) + ($11<<3)|0)) + 4|0);
 HEAP32[$13>>2] = $function;
 $$0$i = 0;
 HEAP32[3358] = $0;
 return ($$0$i|0);
}
function _rl_bind_keyseq_if_unbound_in_map($keyseq,$default_func,$kmap) {
 $keyseq = $keyseq|0;
 $default_func = $default_func|0;
 $kmap = $kmap|0;
 var $$0 = 0, $$0$i = 0, $$0$i$in = 0, $$114$i23 = 0, $$114$us$i2165 = 0, $$2$i = 0, $$2$lcssa$i = 0, $$2$lcssa7$i = 0, $$lcssa12$i = 0, $$lcssa8$i = 0, $$lcssa9$i = 0, $$map$i = 0, $$pre84$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0;
 var $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$015$i22 = 0, $ic$0$i = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($keyseq|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = ($kmap|0)==(0|0);
 $2 = HEAP32[13432>>2]|0;
 $$map$i = $1 ? $2 : $kmap;
 $3 = HEAP32[13688>>2]|0;
 $4 = ($3|0)==(0);
 $$pre84$i = HEAP8[$keyseq>>0]|0;
 $5 = ($$pre84$i<<24>>24)==(0);
 L4: do {
  if ($4) {
   if (!($5)) {
    $6 = $$pre84$i&255;
    $7 = (($$map$i) + ($6<<3)|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = ($8<<24>>24)==(1);
    $10 = ((($keyseq)) + 1|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = ($11<<24>>24)==(0);
    if ($9) {
     $$114$us$i2165 = $$map$i;$14 = $6;$17 = $11;$22 = 1;$52 = $12;
     while(1) {
      if ($52) {
       $$2$lcssa7$i = $$114$us$i2165;$$lcssa9$i = $14;
       label = 13;
       break L4;
      }
      $13 = (((($$114$us$i2165) + ($14<<3)|0)) + 4|0);
      $15 = HEAP32[$13>>2]|0;
      $16 = $17&255;
      $18 = (($15) + ($16<<3)|0);
      $19 = HEAP8[$18>>0]|0;
      $20 = ($19<<24>>24)==(1);
      $21 = (($22) + 1)|0;
      $23 = (($keyseq) + ($21)|0);
      $24 = HEAP8[$23>>0]|0;
      $25 = ($24<<24>>24)==(0);
      if ($20) {
       $$114$us$i2165 = $15;$14 = $16;$17 = $24;$22 = $21;$52 = $25;
      } else {
       $$2$lcssa$i = $15;$$lcssa12$i = $25;$$lcssa8$i = $16;
       label = 15;
       break;
      }
     }
    } else {
     $$2$lcssa$i = $$map$i;$$lcssa12$i = $12;$$lcssa8$i = $6;
     label = 15;
    }
   }
  } else {
   if (!($5)) {
    $$114$i23 = $$map$i;$27 = $$pre84$i;$i$015$i22 = 0;
    while(1) {
     $26 = $27&255;
     $28 = ($27<<24>>24)>(-1);
     if ($28) {
      $$2$i = $$114$i23;$ic$0$i = $27;
     } else {
      $29 = ((($$114$i23)) + 216|0);
      $30 = HEAP8[$29>>0]|0;
      $31 = ($30<<24>>24)==(1);
      $32 = ((($$114$i23)) + 220|0);
      if (!($31)) {
       $$0$i$in = $32;
       label = 17;
       break L4;
      }
      $33 = HEAP32[$32>>2]|0;
      $34 = $26 & 127;
      $35 = $34&255;
      $$2$i = $33;$ic$0$i = $35;
     }
     $36 = $ic$0$i&255;
     $37 = (($$2$i) + ($36<<3)|0);
     $38 = HEAP8[$37>>0]|0;
     $39 = ($38<<24>>24)==(1);
     $40 = (($i$015$i22) + 1)|0;
     $41 = (($keyseq) + ($40)|0);
     $42 = HEAP8[$41>>0]|0;
     $43 = ($42<<24>>24)==(0);
     if (!($39)) {
      $$2$lcssa$i = $$2$i;$$lcssa12$i = $43;$$lcssa8$i = $36;
      label = 15;
      break L4;
     }
     if ($43) {
      $$2$lcssa7$i = $$2$i;$$lcssa9$i = $36;
      label = 13;
      break L4;
     }
     $45 = (((($$2$i) + ($36<<3)|0)) + 4|0);
     $46 = HEAP32[$45>>2]|0;
     $$114$i23 = $46;$27 = $42;$i$015$i22 = $40;
    }
   }
  }
 } while(0);
 if ((label|0) == 13) {
  $44 = (((($$2$lcssa7$i) + ($$lcssa9$i<<3)|0)) + 4|0);
  $$0$i$in = $44;
  label = 17;
 }
 else if ((label|0) == 15) {
  if ($$lcssa12$i) {
   $47 = (((($$2$lcssa$i) + ($$lcssa8$i<<3)|0)) + 4|0);
   $$0$i$in = $47;
   label = 17;
  }
 }
 if ((label|0) == 17) {
  $$0$i = HEAP32[$$0$i$in>>2]|0;
  $48 = ($$0$i|0)==(0|0);
  $49 = ($$0$i|0)==(173|0);
  $or$cond = $48 | $49;
  $50 = ($$0$i|0)==(261|0);
  $or$cond3 = $50 | $or$cond;
  if (!($or$cond3)) {
   $$0 = 1;
   return ($$0|0);
  }
 }
 $51 = (_rl_generic_bind(0,$keyseq,$default_func,$kmap)|0);
 $$0 = $51;
 return ($$0|0);
}
function _rl_generic_bind($type,$keyseq,$data,$map) {
 $type = $type|0;
 $keyseq = $keyseq|0;
 $data = $data|0;
 $map = $map|0;
 var $$$09 = 0, $$0 = 0, $$01014 = 0, $$01014$ph = 0, $$1$ph = 0, $$111 = 0, $$111$lcssa = 0, $$111$lcssa76 = 0, $$212$ph = 0, $$lcssa = 0, $$lcssa84 = 0, $$lcssa88 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0;
 var $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0;
 var $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $i$016 = 0, $i$016$ph = 0, $ic$0 = 0, $ic$0$lcssa = 0, $ic$0$lcssa79 = 0, $ic$1$ph = 0, $k$sroa$0$018$ph = 0, $k$sroa$0$1 = 0, $k$sroa$4 = 0, $k$sroa$48$017$ph = 0, $k$sroa$48$1 = 0, $k$sroa$48$2$ph = 0, $keys_len = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond13 = 0, $or$cond5 = 0;
 var $or$cond7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $keys_len = sp;
 $k$sroa$4 = sp + 4|0;
 $0 = ($keyseq|0)==(0|0);
 if (!($0)) {
  $1 = HEAP8[$keyseq>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if (!($2)) {
   $4 = (_strlen(($keyseq|0))|0);
   $5 = $4 << 1;
   $6 = $5 | 1;
   $7 = (_xmalloc($6)|0);
   (_rl_translate_keyseq($keyseq,$7,$keys_len)|0);
   $8 = HEAP32[$keys_len>>2]|0;
   $9 = ($8|0)>(0);
   L4: do {
    if ($9) {
     $10 = $type&255;
     $11 = ($type|0)==(0);
     $$01014$ph = $map;$i$016$ph = 0;$k$sroa$0$018$ph = 0;$k$sroa$48$017$ph = 0;
     L6: while(1) {
      $$01014 = $$01014$ph;$i$016 = $i$016$ph;
      while(1) {
       $12 = (($7) + ($i$016)|0);
       $13 = HEAP8[$12>>0]|0;
       $14 = $13&255;
       $15 = ($13<<24>>24)<(0);
       $16 = HEAP32[13688>>2]|0;
       $17 = ($16|0)!=(0);
       $or$cond5 = $15 & $17;
       if ($or$cond5) {
        $18 = $14 & 127;
        $19 = ((($$01014)) + 216|0);
        $20 = HEAP8[$19>>0]|0;
        $21 = ($20<<24>>24)==(1);
        if ($21) {
         $22 = ((($$01014)) + 220|0);
         $23 = HEAP32[$22>>2]|0;
         $$111 = $23;$ic$0 = $18;
        } else {
         $$111 = $$01014;$ic$0 = $18;
        }
       } else {
        $$111 = $$01014;$ic$0 = $14;
       }
       $24 = (($i$016) + 1)|0;
       $25 = ($24|0)<($8|0);
       $26 = (($$111) + ($ic$0<<3)|0);
       $27 = HEAP8[$26>>0]|0;
       if ($25) {
        $$111$lcssa = $$111;$$lcssa = $24;$$lcssa84 = $26;$$lcssa88 = $27;$ic$0$lcssa = $ic$0;
        break;
       }
       if ((($27<<24>>24) == 1)) {
        $$111$lcssa76 = $$111;$ic$0$lcssa79 = $ic$0;
        label = 19;
        break L6;
       } else if (!((($27<<24>>24) == 2))) {
        $$1$ph = $data;$$212$ph = $$111;$ic$1$ph = $ic$0;
        break L6;
       }
       $44 = (((($$111) + ($ic$0<<3)|0)) + 4|0);
       $45 = HEAP32[$44>>2]|0;
       _xfree($45);
       $46 = (((($$111) + ($ic$0<<3)|0)) + 4|0);
       HEAP32[$46>>2] = $data;
       $47 = (($$111) + ($ic$0<<3)|0);
       HEAP8[$47>>0] = $10;
       HEAP32[29632>>2] = $$111;
       if ($25) {
        $$01014 = $$111;$i$016 = $24;
       } else {
        break L4;
       }
      }
      $28 = ($$lcssa88<<24>>24)==(1);
      if ($28) {
       $$phi$trans$insert = (((($$111$lcssa) + ($ic$0$lcssa<<3)|0)) + 4|0);
       $$pre = HEAP32[$$phi$trans$insert>>2]|0;
       $36 = $$pre;$k$sroa$0$1 = $k$sroa$0$018$ph;$k$sroa$48$1 = $k$sroa$48$017$ph;
      } else {
       $29 = ((($$lcssa84)) + 1|0);
       ;HEAP8[$k$sroa$4>>0]=HEAP8[$29>>0]|0;HEAP8[$k$sroa$4+1>>0]=HEAP8[$29+1>>0]|0;HEAP8[$k$sroa$4+2>>0]=HEAP8[$29+2>>0]|0;
       $30 = (((($$111$lcssa) + ($ic$0$lcssa<<3)|0)) + 4|0);
       $31 = HEAP32[$30>>2]|0;
       HEAP8[$$lcssa84>>0] = 1;
       $32 = (_rl_make_bare_keymap()|0);
       HEAP32[$30>>2] = $32;
       $36 = $32;$k$sroa$0$1 = $$lcssa88;$k$sroa$48$1 = $31;
      }
      $33 = ($k$sroa$48$1|0)==(0|0);
      if ($33) {
       $k$sroa$48$2$ph = 0;
      } else {
       $notlhs = ($k$sroa$0$1<<24>>24)==(0);
       $notrhs = ($k$sroa$48$1|0)!=(173|0);
       $or$cond$not = $notrhs & $notlhs;
       $34 = ($k$sroa$0$1<<24>>24)==(2);
       $or$cond13 = $34 | $or$cond$not;
       if ($or$cond13) {
        $35 = ((($36)) + 2048|0);
        HEAP8[$35>>0] = $k$sroa$0$1;
        $37 = ((($36)) + 2049|0);
        ;HEAP8[$37>>0]=HEAP8[$k$sroa$4>>0]|0;HEAP8[$37+1>>0]=HEAP8[$k$sroa$4+1>>0]|0;HEAP8[$37+2>>0]=HEAP8[$k$sroa$4+2>>0]|0;
        $38 = ((($36)) + 2052|0);
        HEAP32[$38>>2] = $k$sroa$48$1;
        $k$sroa$48$2$ph = 0;
       } else {
        $k$sroa$48$2$ph = $k$sroa$48$1;
       }
      }
      HEAP32[29632>>2] = $36;
      $$01014$ph = $36;$i$016$ph = $$lcssa;$k$sroa$0$018$ph = $k$sroa$0$1;$k$sroa$48$017$ph = $k$sroa$48$2$ph;
     }
     if ((label|0) == 19) {
      $39 = (((($$111$lcssa76) + ($ic$0$lcssa79<<3)|0)) + 4|0);
      $40 = HEAP32[$39>>2]|0;
      $41 = ($data|0)==(0|0);
      $or$cond7 = $11 & $41;
      $$$09 = $or$cond7 ? 367 : $data;
      $$1$ph = $$$09;$$212$ph = $40;$ic$1$ph = 256;
     }
     $42 = (((($$212$ph) + ($ic$1$ph<<3)|0)) + 4|0);
     HEAP32[$42>>2] = $$1$ph;
     $43 = (($$212$ph) + ($ic$1$ph<<3)|0);
     HEAP8[$43>>0] = $10;
     HEAP32[29632>>2] = $$212$ph;
    }
   } while(0);
   _xfree($7);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $3 = ($type|0)==(2);
 if (!($3)) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 _xfree($data);
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _rl_bind_keyseq_in_map($keyseq,$function,$map) {
 $keyseq = $keyseq|0;
 $function = $function|0;
 $map = $map|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_generic_bind(0,$keyseq,$function,$map)|0);
 return ($0|0);
}
function _rl_bind_keyseq_if_unbound($keyseq,$default_func) {
 $keyseq = $keyseq|0;
 $default_func = $default_func|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13432>>2]|0;
 $1 = (_rl_bind_keyseq_if_unbound_in_map($keyseq,$default_func,$0)|0);
 return ($1|0);
}
function _rl_translate_keyseq($seq,$array,$len) {
 $seq = $seq|0;
 $array = $array|0;
 $len = $len|0;
 var $$ = 0, $$off = 0, $$off7 = 0, $$pre = 0, $$pre34 = 0, $$pre36 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0;
 var $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0;
 var $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0;
 var $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $c$0$lcssa = 0, $c$021 = 0, $c$1$lcssa = 0, $c$110 = 0, $i$0 = 0, $i$1$lcssa = 0, $i$120 = 0, $i$2$lcssa = 0, $i$29 = 0, $i$3 = 0, $l$0 = 0, $l$0$lcssa = 0, $l$1 = 0, $or$cond$not = 0, $or$cond$not18 = 0, $or$cond4 = 0, $temp$022 = 0, $temp$111 = 0, $temp$2 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $i$0 = 0;$l$0 = 0;
 L1: while(1) {
  $0 = (($seq) + ($i$0)|0);
  $1 = HEAP8[$0>>0]|0;
  L3: do {
   if ((($1<<24>>24) == 0)) {
    $l$0$lcssa = $l$0;
    label = 59;
    break L1;
   } else if ((($1<<24>>24) == 92)) {
    $2 = (($i$0) + 1)|0;
    $3 = (($seq) + ($2)|0);
    $4 = HEAP8[$3>>0]|0;
    $5 = $4 << 24 >> 24;
    if ((($4<<24>>24) == 0)) {
     $l$0$lcssa = $l$0;
     label = 59;
     break L1;
    } else if ((($4<<24>>24) == 67) | (($4<<24>>24) == 77)) {
     $6 = (($i$0) + 2)|0;
     $7 = (($seq) + ($6)|0);
     $8 = HEAP8[$7>>0]|0;
     $9 = ($8<<24>>24)==(45);
     if ($9) {
      $10 = (_strncmp($3,29648,5)|0);
      $11 = ($10|0)==(0);
      if ($11) {
       $12 = (($l$0) + 1)|0;
       $13 = (($array) + ($l$0)|0);
       HEAP8[$13>>0] = 27;
       $14 = (($i$0) + 6)|0;
       $15 = (($seq) + ($14)|0);
       $16 = HEAP8[$15>>0]|0;
       $17 = $16&255;
       $18 = $16 << 24 >> 24;
       $19 = ($17|0)==($18|0);
       if ($19) {
        $20 = (_islower($17)|0);
        $21 = ($20|0)==(0);
        $$pre36 = HEAP8[$15>>0]|0;
        if ($21) {
         $25 = $$pre36;
         label = 9;
        } else {
         $22 = $$pre36&255;
         $23 = (_toupper($22)|0);
         $27 = $23;
        }
       } else {
        $25 = $16;
        label = 9;
       }
       if ((label|0) == 9) {
        label = 0;
        $24 = $25 << 24 >> 24;
        $27 = $24;
       }
       $26 = $27 & 31;
       $28 = $26&255;
       $29 = (($l$0) + 2)|0;
       $30 = (($array) + ($12)|0);
       HEAP8[$30>>0] = $28;
       $31 = HEAP8[$15>>0]|0;
       $32 = ($31<<24>>24)==(0);
       $33 = (($i$0) + 5)|0;
       $$ = $32 ? $33 : $14;
       $i$3 = $$;$l$1 = $29;
       break;
      }
      if ((($4<<24>>24) == 67)) {
       $79 = (($i$0) + 3)|0;
       $80 = (($seq) + ($79)|0);
       $81 = HEAP8[$80>>0]|0;
       $82 = $81 << 24 >> 24;
       $83 = ($81<<24>>24)==(63);
       if ($83) {
        $95 = 127;
       } else {
        $84 = $81&255;
        $85 = ($84|0)==($82|0);
        if ($85) {
         $86 = (_islower($82)|0);
         $87 = ($86|0)==(0);
         $$pre = HEAP8[$80>>0]|0;
         if ($87) {
          $91 = $$pre;
          label = 30;
         } else {
          $88 = $$pre&255;
          $89 = (_toupper($88)|0);
          $93 = $89;
         }
        } else {
         $91 = $81;
         label = 30;
        }
        if ((label|0) == 30) {
         label = 0;
         $90 = $91 << 24 >> 24;
         $93 = $90;
        }
        $92 = $93 & 31;
        $95 = $92;
       }
       $94 = $95&255;
       $96 = (($l$0) + 1)|0;
       $97 = (($array) + ($l$0)|0);
       HEAP8[$97>>0] = $94;
       $i$3 = $79;$l$1 = $96;
       break;
      } else if (!((($4<<24>>24) == 77))) {
       $i$3 = $2;$l$1 = $l$0;
       break;
      }
      $34 = HEAP32[13688>>2]|0;
      $35 = ($34|0)==(0);
      if (!($35)) {
       $36 = HEAP32[13432>>2]|0;
       $37 = ((($36)) + 216|0);
       $38 = HEAP8[$37>>0]|0;
       $39 = ($38<<24>>24)==(1);
       if ($39) {
        $40 = (($l$0) + 1)|0;
        $41 = (($array) + ($l$0)|0);
        HEAP8[$41>>0] = 27;
        $i$3 = $6;$l$1 = $40;
        break;
       }
      }
      $42 = (($i$0) + 3)|0;
      $43 = (($seq) + ($42)|0);
      $44 = HEAP8[$43>>0]|0;
      $45 = ($44<<24>>24)==(92);
      if ($45) {
       $46 = (($i$0) + 4)|0;
       $47 = (($seq) + ($46)|0);
       $48 = HEAP8[$47>>0]|0;
       $49 = ($48<<24>>24)==(67);
       if ($49) {
        $50 = (($i$0) + 5)|0;
        $51 = (($seq) + ($50)|0);
        $52 = HEAP8[$51>>0]|0;
        $53 = ($52<<24>>24)==(45);
        if ($53) {
         $54 = (($i$0) + 6)|0;
         $55 = (($seq) + ($54)|0);
         $56 = HEAP8[$55>>0]|0;
         $57 = $56 << 24 >> 24;
         $58 = ($56<<24>>24)==(63);
         if ($58) {
          $70 = 127;
         } else {
          $59 = $56&255;
          $60 = ($59|0)==($57|0);
          if ($60) {
           $61 = (_islower($57)|0);
           $62 = ($61|0)==(0);
           $$pre34 = HEAP8[$55>>0]|0;
           if ($62) {
            $66 = $$pre34;
            label = 22;
           } else {
            $63 = $$pre34&255;
            $64 = (_toupper($63)|0);
            $68 = $64;
           }
          } else {
           $66 = $56;
           label = 22;
          }
          if ((label|0) == 22) {
           label = 0;
           $65 = $66 << 24 >> 24;
           $68 = $65;
          }
          $67 = $68 & 31;
          $70 = $67;
         }
         $69 = $70 | 128;
         $71 = $69&255;
         $72 = (($l$0) + 1)|0;
         $73 = (($array) + ($l$0)|0);
         HEAP8[$73>>0] = $71;
         $i$3 = $54;$l$1 = $72;
         break;
        }
       }
      }
      $74 = $44&255;
      $75 = $74 | 128;
      $76 = $75&255;
      $77 = (($l$0) + 1)|0;
      $78 = (($array) + ($l$0)|0);
      HEAP8[$78>>0] = $76;
      $i$3 = $42;$l$1 = $77;
      break;
     }
    }
    do {
     switch ($5|0) {
     case 98:  {
      $100 = (($l$0) + 1)|0;
      $101 = (($array) + ($l$0)|0);
      HEAP8[$101>>0] = 8;
      $i$3 = $2;$l$1 = $100;
      break L3;
      break;
     }
     case 97:  {
      $98 = (($l$0) + 1)|0;
      $99 = (($array) + ($l$0)|0);
      HEAP8[$99>>0] = 7;
      $i$3 = $2;$l$1 = $98;
      break L3;
      break;
     }
     case 116:  {
      $112 = (($l$0) + 1)|0;
      $113 = (($array) + ($l$0)|0);
      HEAP8[$113>>0] = 9;
      $i$3 = $2;$l$1 = $112;
      break L3;
      break;
     }
     case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
      $118 = (($i$0) + 2)|0;
      $119 = (($5) + -48)|0;
      $120 = (($seq) + ($118)|0);
      $121 = HEAP8[$120>>0]|0;
      $122 = $121 & -8;
      $or$cond$not18 = ($122<<24>>24)==(48);
      if ($or$cond$not18) {
       $124 = $121;$c$021 = $119;$i$120 = $118;$temp$022 = 2;
       while(1) {
        $123 = $124 << 24 >> 24;
        $125 = (($temp$022) + -1)|0;
        $126 = $c$021 << 3;
        $127 = (($126) + -48)|0;
        $128 = (($127) + ($123))|0;
        $129 = (($i$120) + 1)|0;
        $130 = (($seq) + ($129)|0);
        $131 = HEAP8[$130>>0]|0;
        $132 = $131 & -8;
        $or$cond$not = ($132<<24>>24)!=(48);
        $133 = ($125|0)==(0);
        $or$cond4 = $133 | $or$cond$not;
        if ($or$cond4) {
         $c$0$lcssa = $128;$i$1$lcssa = $129;
         break;
        } else {
         $124 = $131;$c$021 = $128;$i$120 = $129;$temp$022 = $125;
        }
       }
      } else {
       $c$0$lcssa = $119;$i$1$lcssa = $118;
      }
      $134 = (($i$1$lcssa) + -1)|0;
      $135 = $c$0$lcssa&255;
      $136 = (($l$0) + 1)|0;
      $137 = (($array) + ($l$0)|0);
      HEAP8[$137>>0] = $135;
      $i$3 = $134;$l$1 = $136;
      break L3;
      break;
     }
     case 101:  {
      $104 = (($l$0) + 1)|0;
      $105 = (($array) + ($l$0)|0);
      HEAP8[$105>>0] = 27;
      $i$3 = $2;$l$1 = $104;
      break L3;
      break;
     }
     case 120:  {
      $138 = (($i$0) + 2)|0;
      $139 = (($seq) + ($138)|0);
      $140 = HEAP8[$139>>0]|0;
      $141 = $140&255;
      $142 = (_isxdigit($141)|0);
      $143 = ($142|0)==(0);
      L59: do {
       if ($143) {
        $c$1$lcssa = 0;$i$2$lcssa = $138;$temp$2 = 2;
       } else {
        $148 = $139;$c$110 = 0;$i$29 = $138;$temp$111 = 2;
        while(1) {
         $144 = (($temp$111) + -1)|0;
         $145 = ($temp$111|0)==(0);
         if ($145) {
          $c$1$lcssa = $c$110;$i$2$lcssa = $i$29;$temp$2 = $144;
          break L59;
         }
         $146 = $c$110 << 4;
         $147 = HEAP8[$148>>0]|0;
         $149 = $147 << 24 >> 24;
         $$off = (($147) + -97)<<24>>24;
         $150 = ($$off&255)<(6);
         do {
          if ($150) {
           $151 = (($149) + -87)|0;
           $156 = $151;
          } else {
           $$off7 = (($147) + -65)<<24>>24;
           $152 = ($$off7&255)<(6);
           if ($152) {
            $153 = (($149) + -55)|0;
            $156 = $153;
            break;
           } else {
            $154 = (($149) + -48)|0;
            $156 = $154;
            break;
           }
          }
         } while(0);
         $155 = (($156) + ($146))|0;
         $157 = (($i$29) + 1)|0;
         $158 = (($seq) + ($157)|0);
         $159 = HEAP8[$158>>0]|0;
         $160 = $159&255;
         $161 = (_isxdigit($160)|0);
         $162 = ($161|0)==(0);
         if ($162) {
          $c$1$lcssa = $155;$i$2$lcssa = $157;$temp$2 = $144;
          break;
         } else {
          $148 = $158;$c$110 = $155;$i$29 = $157;$temp$111 = $144;
         }
        }
       }
      } while(0);
      $163 = ($temp$2|0)==(2);
      $164 = (($i$2$lcssa) + -1)|0;
      $165 = $c$1$lcssa&255;
      $166 = $163 ? 120 : $165;
      $167 = (($l$0) + 1)|0;
      $168 = (($array) + ($l$0)|0);
      HEAP8[$168>>0] = $166;
      $i$3 = $164;$l$1 = $167;
      break L3;
      break;
     }
     case 92:  {
      $116 = (($l$0) + 1)|0;
      $117 = (($array) + ($l$0)|0);
      HEAP8[$117>>0] = 92;
      $i$3 = $2;$l$1 = $116;
      break L3;
      break;
     }
     case 110:  {
      $108 = (($l$0) + 1)|0;
      $109 = (($array) + ($l$0)|0);
      HEAP8[$109>>0] = 10;
      $i$3 = $2;$l$1 = $108;
      break L3;
      break;
     }
     case 100:  {
      $102 = (($l$0) + 1)|0;
      $103 = (($array) + ($l$0)|0);
      HEAP8[$103>>0] = 127;
      $i$3 = $2;$l$1 = $102;
      break L3;
      break;
     }
     case 102:  {
      $106 = (($l$0) + 1)|0;
      $107 = (($array) + ($l$0)|0);
      HEAP8[$107>>0] = 12;
      $i$3 = $2;$l$1 = $106;
      break L3;
      break;
     }
     case 114:  {
      $110 = (($l$0) + 1)|0;
      $111 = (($array) + ($l$0)|0);
      HEAP8[$111>>0] = 13;
      $i$3 = $2;$l$1 = $110;
      break L3;
      break;
     }
     case 118:  {
      $114 = (($l$0) + 1)|0;
      $115 = (($array) + ($l$0)|0);
      HEAP8[$115>>0] = 11;
      $i$3 = $2;$l$1 = $114;
      break L3;
      break;
     }
     default: {
      $169 = (($l$0) + 1)|0;
      $170 = (($array) + ($l$0)|0);
      HEAP8[$170>>0] = $4;
      $i$3 = $2;$l$1 = $169;
      break L3;
     }
     }
    } while(0);
   } else {
    $171 = (($l$0) + 1)|0;
    $172 = (($array) + ($l$0)|0);
    HEAP8[$172>>0] = $1;
    $i$3 = $i$0;$l$1 = $171;
   }
  } while(0);
  $173 = (($i$3) + 1)|0;
  $i$0 = $173;$l$0 = $l$1;
 }
 if ((label|0) == 59) {
  HEAP32[$len>>2] = $l$0$lcssa;
  $174 = (($array) + ($l$0$lcssa)|0);
  HEAP8[$174>>0] = 0;
  return 0;
 }
 return (0)|0;
}
function __rl_untranslate_macro_value($seq,$use_escapes) {
 $seq = $seq|0;
 $use_escapes = $use_escapes|0;
 var $$off$i = 0, $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0 = 0, $c$1 = 0;
 var $or$cond = 0, $or$cond6 = 0, $r$0$lcssa = 0, $r$07 = 0, $r$1 = 0, $r$2 = 0, $s$08 = 0, $switch$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($seq|0))|0);
 $1 = ($0*7)|0;
 $2 = (($1) + 1)|0;
 $3 = (_xmalloc($2)|0);
 $4 = HEAP8[$seq>>0]|0;
 $5 = ($4<<24>>24)==(0);
 if ($5) {
  $r$0$lcssa = $3;
  HEAP8[$r$0$lcssa>>0] = 0;
  return ($3|0);
 }
 $6 = ($use_escapes|0)!=(0);
 $8 = $4;$r$07 = $3;$s$08 = $seq;
 while(1) {
  $7 = $8 << 24 >> 24;
  $9 = ($8<<24>>24)==(27);
  L6: do {
   if ($9) {
    $10 = ((($r$07)) + 1|0);
    HEAP8[$r$07>>0] = 92;
    $c$1 = 101;$r$2 = $10;
   } else {
    $11 = ($8<<24>>24)<(32);
    $12 = $7 & 128;
    $13 = ($12|0)==(0);
    $or$cond = $11 & $13;
    L8: do {
     if ($or$cond) {
      $14 = ((($r$07)) + 1|0);
      HEAP8[$r$07>>0] = 92;
      $$off$i = (($7) + -7)|0;
      $switch$i = ($$off$i>>>0)<(7);
      $or$cond6 = $6 & $switch$i;
      if ($or$cond6) {
       switch ($7|0) {
       case 9:  {
        $c$1 = 116;$r$2 = $14;
        break L6;
        break;
       }
       case 8:  {
        $c$1 = 98;$r$2 = $14;
        break L6;
        break;
       }
       case 13:  {
        $c$1 = 114;$r$2 = $14;
        break L6;
        break;
       }
       case 12:  {
        $c$1 = 102;$r$2 = $14;
        break L6;
        break;
       }
       case 7:  {
        $c$1 = 97;$r$2 = $14;
        break L6;
        break;
       }
       case 10:  {
        $c$1 = 110;$r$2 = $14;
        break L6;
        break;
       }
       case 11:  {
        $c$1 = 118;$r$2 = $14;
        break L6;
        break;
       }
       default: {
        $c$0 = $7;$r$1 = $14;
        break L8;
       }
       }
      }
      $15 = ((($r$07)) + 2|0);
      HEAP8[$14>>0] = 67;
      $16 = ((($r$07)) + 3|0);
      HEAP8[$15>>0] = 45;
      $17 = $7 | 64;
      $18 = $17 & 255;
      $19 = ($18|0)==($17|0);
      if ($19) {
       $20 = (_islower($17)|0);
       $21 = ($20|0)==(0);
       if ($21) {
        $$ph = $17;
       } else {
        $22 = (_toupper($17)|0);
        $$ph = $22;
       }
       $23 = $$ph & 255;
       $24 = (_islower($17)|0);
       $25 = ($24|0)==(0);
       if ($25) {
        $28 = $23;$29 = $17;
       } else {
        $26 = (_toupper($17)|0);
        $28 = $23;$29 = $26;
       }
      } else {
       $28 = $18;$29 = $17;
      }
      $27 = ($28|0)==($29|0);
      if ($27) {
       if ($19) {
        $30 = (_islower($17)|0);
        $31 = ($30|0)==(0);
        if ($31) {
         $33 = $17;
        } else {
         $32 = (_toupper($17)|0);
         $33 = $32;
        }
       } else {
        $33 = $17;
       }
       $34 = (_isupper($33)|0);
       $35 = ($34|0)==(0);
       if (!($35)) {
        if ($19) {
         $36 = (_islower($17)|0);
         $37 = ($36|0)==(0);
         if ($37) {
          $40 = $17;
         } else {
          $38 = (_toupper($17)|0);
          $40 = $38;
         }
        } else {
         $40 = $17;
        }
        $39 = $40 & 255;
        $41 = (_tolower($39)|0);
        $c$0 = $41;$r$1 = $16;
        break;
       }
      }
      if ($19) {
       $42 = (_islower($17)|0);
       $43 = ($42|0)==(0);
       if ($43) {
        $c$0 = $17;$r$1 = $16;
       } else {
        $44 = (_toupper($17)|0);
        $c$0 = $44;$r$1 = $16;
       }
      } else {
       $c$0 = $17;$r$1 = $16;
      }
     } else {
      $45 = ($8<<24>>24)==(127);
      if ($45) {
       $46 = ((($r$07)) + 1|0);
       HEAP8[$r$07>>0] = 92;
       $47 = ((($r$07)) + 2|0);
       HEAP8[$46>>0] = 67;
       $48 = ((($r$07)) + 3|0);
       HEAP8[$47>>0] = 45;
       $c$1 = 63;$r$2 = $48;
       break L6;
      } else {
       $c$0 = $7;$r$1 = $r$07;
      }
     }
    } while(0);
    if ((($c$0|0) == 34) | (($c$0|0) == 92)) {
     $50 = ((($r$1)) + 1|0);
     HEAP8[$r$1>>0] = 92;
     $c$1 = $c$0;$r$2 = $50;
     break;
    } else if ((($c$0|0) == 27)) {
     $49 = ((($r$1)) + 1|0);
     HEAP8[$r$1>>0] = 92;
     $c$1 = 101;$r$2 = $49;
     break;
    } else {
     $c$1 = $c$0;$r$2 = $r$1;
     break;
    }
   }
  } while(0);
  $51 = $c$1&255;
  $52 = ((($r$2)) + 1|0);
  HEAP8[$r$2>>0] = $51;
  $53 = ((($s$08)) + 1|0);
  $54 = HEAP8[$53>>0]|0;
  $55 = ($54<<24>>24)==(0);
  if ($55) {
   $r$0$lcssa = $52;
   break;
  } else {
   $8 = $54;$r$07 = $52;$s$08 = $53;
  }
 }
 HEAP8[$r$0$lcssa>>0] = 0;
 return ($3|0);
}
function _rl_re_read_init_file($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$01$i = 0, $$12$i = 0, $$2$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[29656>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $2 = (_sh_get_env_value(29664)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   label = 4;
  } else {
   $$12$i = $2;
   label = 3;
  }
 } else {
  $$12$i = $0;
  label = 3;
 }
 if ((label|0) == 3) {
  $4 = HEAP8[$$12$i>>0]|0;
  $5 = ($4<<24>>24)==(0);
  if ($5) {
   label = 4;
  } else {
   $$2$i = $$12$i;
   label = 5;
  }
 }
 if ((label|0) == 4) {
  $6 = (__rl_read_init_file(29672,0)|0);
  $7 = ($6|0)==(0);
  if ($7) {
   $$01$i = 0;
  } else {
   $$2$i = 29688;
   label = 5;
  }
 }
 if ((label|0) == 5) {
  $8 = (__rl_read_init_file($$2$i,0)|0);
  $$01$i = $8;
 }
 $9 = HEAP32[13440>>2]|0;
 if ((($9|0) == 1)) {
  HEAP32[13432>>2] = 22352;
  return ($$01$i|0);
 } else if ((($9|0) == 0)) {
  HEAP32[13432>>2] = 26464;
  return ($$01$i|0);
 } else {
  return ($$01$i|0);
 }
 return (0)|0;
}
function _rl_read_init_file($filename) {
 $filename = $filename|0;
 var $$01 = 0, $$12 = 0, $$2 = 0, $$filename = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($filename|0)==(0|0);
 $1 = HEAP32[29656>>2]|0;
 $$filename = $0 ? $1 : $filename;
 $2 = ($$filename|0)==(0|0);
 if ($2) {
  $3 = (_sh_get_env_value(29664)|0);
  $4 = ($3|0)==(0|0);
  if ($4) {
   label = 4;
  } else {
   $$12 = $3;
   label = 3;
  }
 } else {
  $$12 = $$filename;
  label = 3;
 }
 if ((label|0) == 3) {
  $5 = HEAP8[$$12>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if ($6) {
   label = 4;
  } else {
   $$2 = $$12;
  }
 }
 if ((label|0) == 4) {
  $7 = (__rl_read_init_file(29672,0)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $$01 = 0;
   return ($$01|0);
  } else {
   $$2 = 29688;
  }
 }
 $9 = (__rl_read_init_file($$2,0)|0);
 $$01 = $9;
 return ($$01|0);
}
function _rl_set_keymap_from_edit_mode() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13440>>2]|0;
 if ((($0|0) == 0)) {
  HEAP32[13432>>2] = 26464;
  return;
 } else if ((($0|0) == 1)) {
  HEAP32[13432>>2] = 22352;
  return;
 } else {
  return;
 }
}
function _rl_parse_and_bind($string) {
 $string = $string|0;
 var $$0 = 0, $$0$i39 = 0, $$0$i40 = 0, $$0$i49 = 0, $$01$i44 = 0, $$011103 = 0, $$011103$lcssa = 0, $$011103$lcssa267 = 0, $$21 = 0, $$lcssa = 0, $$lcssa244 = 0, $$lcssa245 = 0, $$lcssa247 = 0, $$lcssa249 = 0, $$lcssa253 = 0, $$lcssa255 = 0, $$lcssa258 = 0, $$lcssa260 = 0, $$lcssa262 = 0, $$lcssa264 = 0;
 var $$lcssa265 = 0, $$lcssa268 = 0, $$phi$trans$insert$i = 0, $$pre$i = 0, $$pre$pre = 0, $$pre146$pre = 0, $$pre147 = 0, $$sum = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum56 = 0, $$sum57 = 0, $$sum58 = 0, $$sum59 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $cond102 = 0, $e$0$lcssa = 0, $e$092 = 0, $i$0 = 0, $i$0$i = 0, $i$0$i$lcssa = 0, $i$0$lcssa = 0, $i$0$lcssa$i30 = 0, $i$0$lcssa$i36 = 0, $i$0$lcssa257 = 0, $i$01$i = 0, $i$01$i$lcssa = 0, $i$01$i25 = 0;
 var $i$01$i25$lcssa = 0, $i$01$i28 = 0, $i$01$i34 = 0, $i$02$i = 0, $i$02$i47 = 0, $i$02$lcssa$i = 0, $i$1$i = 0, $i$1$i$lcssa263 = 0, $i$2 = 0, $i$2$i = 0, $i$3 = 0, $i$3$lcssa250 = 0, $i$311$lcssa$i = 0, $i$3251 = 0, $i$4 = 0, $i$4$ph = 0, $j$095 = 0, $k$0$lcssa = 0, $k$096 = 0, $k$1 = 0;
 var $key$0 = 0, $key$0$ = 0, $kname$0 = 0, $macro_keys_len$i = 0, $macro_keys_len$i46 = 0, $not$ = 0, $or$cond = 0, $or$cond24 = 0, $or$cond3$i = 0, $passc$02$i = 0, $passc$02$i27 = 0, $passc$02$i33 = 0, $passc$097 = 0, $passc$1 = 0, $passc$1$i = 0, $passc$1$i29 = 0, $passc$1$i35 = 0, $seq1 = 0, $useq = 0, $value$0 = 0;
 var $value$0$lcssa243 = 0, $value$1 = 0, $value$1$lcssa = 0, $value$2 = 0, $var$0 = 0, $var$0$lcssa = 0, $vararg_buffer = 0, $vararg_buffer11 = 0, $vararg_buffer3 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr10 = 0, $vararg_ptr2 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 64|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer11 = sp + 40|0;
 $vararg_buffer6 = sp + 24|0;
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $macro_keys_len$i46 = sp + 48|0;
 $macro_keys_len$i = sp + 44|0;
 $useq = sp + 54|0;
 $seq1 = sp + 52|0;
 $cond102 = ($string|0)==(0|0);
 if ($cond102) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$011103 = $string;
 }
 L3: while(1) {
  $0 = HEAP8[$$011103>>0]|0;
  switch ($0<<24>>24) {
  case 36:  {
   $$011103$lcssa267 = $$011103;
   label = 3;
   break L3;
   break;
  }
  case 35: case 0:  {
   $$0 = 0;
   label = 133;
   break L3;
   break;
  }
  case 9: case 32:  {
   break;
  }
  default: {
   $$011103$lcssa = $$011103;$$lcssa268 = $0;
   label = 19;
   break L3;
  }
  }
  $1 = ((($$011103)) + 1|0);
  $$011103 = $1;
 }
 if ((label|0) == 3) {
  $i$0$i = 0;
  while(1) {
   $$sum56 = (($i$0$i) + 1)|0;
   $2 = (($$011103$lcssa267) + ($$sum56)|0);
   $3 = HEAP8[$2>>0]|0;
   if ((($3<<24>>24) == 9) | (($3<<24>>24) == 32)) {
    $i$0$i = $$sum56;
   } else {
    $$lcssa264 = $2;$$lcssa265 = $3;$i$0$i$lcssa = $i$0$i;
    break;
   }
  }
  $268 = $$lcssa265;$i$1$i = $i$0$i$lcssa;
  while(1) {
   if ((($268<<24>>24) == 0)) {
    $i$2$i = $i$1$i;
    break;
   } else if ((($268<<24>>24) == 32) | (($268<<24>>24) == 9)) {
    $i$1$i$lcssa263 = $i$1$i;
    label = 9;
    break;
   }
   $4 = (($i$1$i) + 1)|0;
   $$sum59 = (($i$1$i) + 2)|0;
   $$phi$trans$insert$i = (($$011103$lcssa267) + ($$sum59)|0);
   $$pre$i = HEAP8[$$phi$trans$insert$i>>0]|0;
   $268 = $$pre$i;$i$1$i = $4;
  }
  if ((label|0) == 9) {
   $$sum57 = (($i$1$i$lcssa263) + 1)|0;
   $5 = (($$011103$lcssa267) + ($$sum57)|0);
   HEAP8[$5>>0] = 0;
   $i$2$i = $$sum57;
  }
  while(1) {
   $$sum58 = (($i$2$i) + 1)|0;
   $6 = (($$011103$lcssa267) + ($$sum58)|0);
   $7 = HEAP8[$6>>0]|0;
   if ((($7<<24>>24) == 32) | (($7<<24>>24) == 9)) {
    $i$2$i = $$sum58;
   } else {
    $$lcssa262 = $6;
    break;
   }
  }
  $8 = (_strcasecmp($$lcssa264,29704)|0);
  $9 = ($8|0)==(0);
  if ($9) {
   $i$311$lcssa$i = 0;
  } else {
   $12 = (_strcasecmp($$lcssa264,29752)|0);
   $13 = ($12|0)==(0);
   if ($13) {
    $i$311$lcssa$i = 1;
   } else {
    $16 = (_strcasecmp($$lcssa264,29832)|0);
    $17 = ($16|0)==(0);
    if ($17) {
     $i$311$lcssa$i = 2;
    } else {
     $18 = (_strcasecmp($$lcssa264,29840)|0);
     $19 = ($18|0)==(0);
     if ($19) {
      $i$311$lcssa$i = 3;
     } else {
      $20 = HEAP32[29848>>2]|0;
      $21 = ($20|0)==(0);
      if ($21) {
       HEAP32[$vararg_buffer3>>2] = 29800;
       __rl_errmsg(34480,$vararg_buffer3);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      } else {
       $14 = HEAP32[29760>>2]|0;
       $15 = HEAP32[29768>>2]|0;
       HEAP32[$vararg_buffer>>2] = $14;
       $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
       HEAP32[$vararg_ptr1>>2] = $15;
       $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
       HEAP32[$vararg_ptr2>>2] = 29800;
       __rl_errmsg(29776,$vararg_buffer);
       $$0 = 0;
       STACKTOP = sp;return ($$0|0);
      }
     }
    }
   }
  }
  $10 = (((29712 + ($i$311$lcssa$i<<3)|0)) + 4|0);
  $11 = HEAP32[$10>>2]|0;
  (FUNCTION_TABLE_ii[$11 & 511]($$lcssa262)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 19) {
  $22 = HEAP8[13680>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if (!($23)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $24 = ($$lcssa268<<24>>24)==(34);
  L36: do {
   if ($24) {
    $25 = ((($$011103$lcssa)) + 1|0);
    $26 = HEAP8[$25>>0]|0;
    $27 = ($26<<24>>24)==(0);
    L38: do {
     if (!($27)) {
      $28 = $26 << 24 >> 24;
      $$pre$pre = $26;$32 = $28;$i$01$i = 1;$passc$02$i = 0;
      while(1) {
       $29 = ($passc$02$i|0)==(0);
       if ($29) {
        $30 = ($$pre$pre<<24>>24)==(92);
        if ($30) {
         $passc$1$i = 1;
        } else {
         $31 = ($32|0)==(34);
         if ($31) {
          $i$01$i$lcssa = $i$01$i;
          break;
         } else {
          $passc$1$i = 0;
         }
        }
       } else {
        $passc$1$i = 0;
       }
       $33 = (($i$01$i) + 1)|0;
       $34 = (($$011103$lcssa) + ($33)|0);
       $35 = HEAP8[$34>>0]|0;
       $36 = $35 << 24 >> 24;
       $37 = ($35<<24>>24)==(0);
       if ($37) {
        break L38;
       } else {
        $$pre$pre = $35;$32 = $36;$i$01$i = $33;$passc$02$i = $passc$1$i;
       }
      }
      $42 = (($i$01$i$lcssa) + 1)|0;
      $i$0 = $42;
      break L36;
     }
    } while(0);
    $38 = HEAP32[29848>>2]|0;
    $39 = ($38|0)==(0);
    if ($39) {
     HEAP32[$vararg_buffer11>>2] = 29856;
     __rl_errmsg(34480,$vararg_buffer11);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    } else {
     $40 = HEAP32[29760>>2]|0;
     $41 = HEAP32[29768>>2]|0;
     HEAP32[$vararg_buffer6>>2] = $40;
     $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
     HEAP32[$vararg_ptr9>>2] = $41;
     $vararg_ptr10 = ((($vararg_buffer6)) + 8|0);
     HEAP32[$vararg_ptr10>>2] = 29856;
     __rl_errmsg(29776,$vararg_buffer6);
     $$0 = 1;
     STACKTOP = sp;return ($$0|0);
    }
   } else {
    $i$0 = 0;
   }
  } while(0);
  while(1) {
   $43 = (($$011103$lcssa) + ($i$0)|0);
   $44 = HEAP8[$43>>0]|0;
   if ((($44<<24>>24) == 32) | (($44<<24>>24) == 9)) {
    $$lcssa260 = $43;$i$0$lcssa257 = $i$0;
    label = 33;
    break;
   } else if ((($44<<24>>24) == 58)) {
    $$lcssa258 = $43;$i$0$lcssa = $i$0;
    label = 34;
    break;
   } else if ((($44<<24>>24) == 0)) {
    $269 = 0;$i$2 = $i$0;
    break;
   }
   $45 = (($i$0) + 1)|0;
   $i$0 = $45;
  }
  if ((label|0) == 33) {
   $46 = (($i$0$lcssa257) + 1)|0;
   HEAP8[$$lcssa260>>0] = 0;
   $269 = 0;$i$2 = $46;
  }
  else if ((label|0) == 34) {
   $47 = (($i$0$lcssa) + 1)|0;
   $48 = (($$011103$lcssa) + ($47)|0);
   $49 = HEAP8[$48>>0]|0;
   $50 = ($49<<24>>24)==(61);
   $51 = (($i$0$lcssa) + 1)|0;
   HEAP8[$$lcssa258>>0] = 0;
   if ($50) {
    $52 = (($i$0$lcssa) + 2)|0;
    $53 = (($$011103$lcssa) + ($51)|0);
    HEAP8[$53>>0] = 0;
    $269 = 1;$i$2 = $52;
   } else {
    $269 = 0;$i$2 = $51;
   }
  }
  $54 = (_strcasecmp($$011103$lcssa,29888)|0);
  $55 = ($54|0)==(0);
  if ($55) {
   $56 = (($$011103$lcssa) + ($i$2)|0);
   $var$0 = $56;
   while(1) {
    $57 = HEAP8[$var$0>>0]|0;
    if (!((($57<<24>>24) == 32) | (($57<<24>>24) == 9))) {
     $$lcssa244 = $57;$var$0$lcssa = $var$0;
     break;
    }
    $58 = ((($var$0)) + 1|0);
    $var$0 = $58;
   }
   $270 = $$lcssa244;$value$0 = $var$0$lcssa;
   while(1) {
    if ((($270<<24>>24) == 9) | (($270<<24>>24) == 32)) {
     $value$0$lcssa243 = $value$0;
     label = 43;
     break;
    } else if ((($270<<24>>24) == 0)) {
     $value$1 = $value$0;
     break;
    }
    $59 = ((($value$0)) + 1|0);
    $$pre147 = HEAP8[$59>>0]|0;
    $270 = $$pre147;$value$0 = $59;
   }
   if ((label|0) == 43) {
    $60 = ((($value$0$lcssa243)) + 1|0);
    HEAP8[$value$0$lcssa243>>0] = 0;
    $value$1 = $60;
   }
   while(1) {
    $61 = HEAP8[$value$1>>0]|0;
    if (!((($61<<24>>24) == 32) | (($61<<24>>24) == 9))) {
     $$lcssa = $61;$value$1$lcssa = $value$1;
     break;
    }
    $62 = ((($value$1)) + 1|0);
    $value$1 = $62;
   }
   $i$01$i25 = 0;
   while(1) {
    $63 = (29896 + (($i$01$i25*12)|0)|0);
    $64 = HEAP32[$63>>2]|0;
    $65 = (_strcasecmp($var$0$lcssa,$64)|0);
    $66 = ($65|0)==(0);
    if ($66) {
     $i$01$i25$lcssa = $i$01$i25;
     label = 49;
     break;
    }
    $67 = (($i$01$i25) + 1)|0;
    $68 = ($67|0)==(31);
    if ($68) {
     label = 55;
     break;
    } else {
     $i$01$i25 = $67;
    }
   }
   if ((label|0) == 49) {
    $69 = ($i$01$i25$lcssa|0)>(-1);
    if ($69) {
     label = 50;
    } else {
     label = 55;
    }
   }
   if ((label|0) == 55) {
    $80 = (_find_string_var($var$0$lcssa)|0);
    $81 = ($80|0)>(-1);
    if ($81) {
     $82 = ($$lcssa<<24>>24)==(34);
     if ($82) {
      $83 = ((($value$1$lcssa)) + 1|0);
      $84 = HEAP8[$83>>0]|0;
      $85 = ($84<<24>>24)==(0);
      L85: do {
       if ($85) {
        $i$0$lcssa$i30 = 1;
       } else {
        $86 = $84 << 24 >> 24;
        $89 = $84;$91 = $86;$i$01$i28 = 1;$passc$02$i27 = 0;
        while(1) {
         $87 = ($passc$02$i27|0)==(0);
         if ($87) {
          $88 = ($89<<24>>24)==(92);
          if ($88) {
           $passc$1$i29 = 1;
          } else {
           $90 = ($91|0)==(34);
           if ($90) {
            $i$0$lcssa$i30 = $i$01$i28;
            break L85;
           } else {
            $passc$1$i29 = 0;
           }
          }
         } else {
          $passc$1$i29 = 0;
         }
         $92 = (($i$01$i28) + 1)|0;
         $93 = (($value$1$lcssa) + ($92)|0);
         $94 = HEAP8[$93>>0]|0;
         $95 = $94 << 24 >> 24;
         $96 = ($94<<24>>24)==(0);
         if ($96) {
          $i$0$lcssa$i30 = $92;
          break;
         } else {
          $89 = $94;$91 = $95;$i$01$i28 = $92;$passc$02$i27 = $passc$1$i29;
         }
        }
       }
      } while(0);
      $97 = (($value$1$lcssa) + ($i$0$lcssa$i30)|0);
      HEAP8[$97>>0] = 0;
      $value$2 = $83;
     } else {
      label = 50;
     }
    } else {
     $value$2 = $value$1$lcssa;
    }
   }
   if ((label|0) == 50) {
    $70 = (_strlen(($value$1$lcssa|0))|0);
    $$sum15 = (($70) + -1)|0;
    $71 = (($value$1$lcssa) + ($$sum15)|0);
    $72 = ($$sum15|0)<(0);
    L96: do {
     if ($72) {
      $e$0$lcssa = $71;
     } else {
      $e$092 = $71;
      while(1) {
       $73 = HEAP8[$e$092>>0]|0;
       if (!((($73<<24>>24) == 9) | (($73<<24>>24) == 32))) {
        $e$0$lcssa = $e$092;
        break L96;
       }
       $74 = ((($e$092)) + -1|0);
       $75 = ($74>>>0)<($value$1$lcssa>>>0);
       if ($75) {
        $e$0$lcssa = $74;
        break;
       } else {
        $e$092 = $74;
       }
      }
     }
    } while(0);
    $76 = ((($e$0$lcssa)) + 1|0);
    $77 = HEAP8[$76>>0]|0;
    $78 = ($77<<24>>24)==(0);
    $79 = ($76>>>0)<($value$1$lcssa>>>0);
    $or$cond = $79 | $78;
    if ($or$cond) {
     $value$2 = $value$1$lcssa;
    } else {
     HEAP8[$76>>0] = 0;
     $value$2 = $value$1$lcssa;
    }
   }
   (_rl_variable_bind($var$0$lcssa,$value$2)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$3 = $i$2;
  }
  while(1) {
   $98 = (($$011103$lcssa) + ($i$3)|0);
   $99 = HEAP8[$98>>0]|0;
   if ((($99<<24>>24) == 34) | (($99<<24>>24) == 39)) {
    $$lcssa253 = $98;$$lcssa255 = $99;$i$3$lcssa250 = $i$3;
    label = 67;
    break;
   } else if (!((($99<<24>>24) == 32) | (($99<<24>>24) == 9))) {
    $143 = $98;$i$3251 = $i$3;$i$4$ph = $i$3;
    break;
   }
   $100 = (($i$3) + 1)|0;
   $i$3 = $100;
  }
  if ((label|0) == 67) {
   $101 = (($i$3$lcssa250) + 1)|0;
   $102 = $$lcssa255 << 24 >> 24;
   $103 = (($$011103$lcssa) + ($101)|0);
   $104 = HEAP8[$103>>0]|0;
   $105 = ($104<<24>>24)==(0);
   L109: do {
    if ($105) {
     $116 = 0;$i$0$lcssa$i36 = $101;
    } else {
     $106 = $104 << 24 >> 24;
     $$pre146$pre = $104;$110 = $106;$i$01$i34 = $101;$passc$02$i33 = 0;
     while(1) {
      $107 = ($passc$02$i33|0)==(0);
      if ($107) {
       $108 = ($$pre146$pre<<24>>24)==(92);
       if ($108) {
        $passc$1$i35 = 1;
       } else {
        $109 = ($110|0)==($102|0);
        if ($109) {
         $116 = $$pre146$pre;$i$0$lcssa$i36 = $i$01$i34;
         break L109;
        } else {
         $passc$1$i35 = 0;
        }
       }
      } else {
       $passc$1$i35 = 0;
      }
      $111 = (($i$01$i34) + 1)|0;
      $112 = (($$011103$lcssa) + ($111)|0);
      $113 = HEAP8[$112>>0]|0;
      $114 = $113 << 24 >> 24;
      $115 = ($113<<24>>24)==(0);
      if ($115) {
       $116 = 0;$i$0$lcssa$i36 = $111;
       break;
      } else {
       $$pre146$pre = $113;$110 = $114;$i$01$i34 = $111;$passc$02$i33 = $passc$1$i35;
      }
     }
    }
   } while(0);
   $not$ = ($116<<24>>24)!=(0);
   $117 = $not$&1;
   $$21 = (($117) + ($i$0$lcssa$i36))|0;
   $143 = $$lcssa253;$i$3251 = $i$3$lcssa250;$i$4$ph = $$21;
  }
  $i$4 = $i$4$ph;
  while(1) {
   $118 = (($$011103$lcssa) + ($i$4)|0);
   $119 = HEAP8[$118>>0]|0;
   if ((($119<<24>>24) == 9) | (($119<<24>>24) == 32) | (($119<<24>>24) == 0)) {
    $$lcssa249 = $118;
    break;
   }
   $120 = (($i$4) + 1)|0;
   $i$4 = $120;
  }
  HEAP8[$$lcssa249>>0] = 0;
  if ($269) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $121 = HEAP8[$$011103$lcssa>>0]|0;
  $122 = ($121<<24>>24)==(34);
  if ($122) {
   $123 = (_strlen(($$011103$lcssa|0))|0);
   $124 = (($123) + 1)|0;
   $125 = (_xmalloc($124)|0);
   $126 = ((($$011103$lcssa)) + 1|0);
   $127 = HEAP8[$126>>0]|0;
   $128 = ($127<<24>>24)==(0);
   L128: do {
    if ($128) {
     $k$0$lcssa = 0;
    } else {
     $131 = $127;$j$095 = 1;$k$096 = 0;$passc$097 = 0;
     while(1) {
      $129 = ($passc$097|0)!=(0);
      $130 = ($131<<24>>24)==(92);
      $or$cond24 = $129 | $130;
      if ($or$cond24) {
       $132 = (($125) + ($k$096)|0);
       HEAP8[$132>>0] = $131;
       $133 = $129&1;
       $134 = $133 ^ 1;
       $passc$1 = $134;
      } else {
       $135 = ($131<<24>>24)==(34);
       if ($135) {
        $k$0$lcssa = $k$096;
        break L128;
       }
       $136 = (($125) + ($k$096)|0);
       HEAP8[$136>>0] = $131;
       $passc$1 = 0;
      }
      $k$1 = (($k$096) + 1)|0;
      $137 = (($j$095) + 1)|0;
      $138 = (($$011103$lcssa) + ($137)|0);
      $139 = HEAP8[$138>>0]|0;
      $140 = ($139<<24>>24)==(0);
      if ($140) {
       $k$0$lcssa = $k$1;
       break;
      } else {
       $131 = $139;$j$095 = $137;$k$096 = $k$1;$passc$097 = $passc$1;
      }
     }
    }
   } while(0);
   $141 = (($125) + ($k$0$lcssa)|0);
   HEAP8[$141>>0] = 0;
   $142 = HEAP8[$143>>0]|0;
   if ((($142<<24>>24) == 34) | (($142<<24>>24) == 39)) {
    $144 = (_strlen(($143|0))|0);
    $145 = ($144|0)==(0);
    if (!($145)) {
     $146 = (($i$3251) + -1)|0;
     $$sum14 = (($146) + ($144))|0;
     $147 = (($$011103$lcssa) + ($$sum14)|0);
     $148 = HEAP8[$147>>0]|0;
     $149 = ($148<<24>>24)==($142<<24>>24);
     if ($149) {
      HEAP8[$147>>0] = 0;
     }
    }
    $$sum13 = (($i$3251) + 1)|0;
    $150 = (($$011103$lcssa) + ($$sum13)|0);
    $151 = HEAP32[13432>>2]|0;
    $152 = (_strlen(($150|0))|0);
    $153 = $152 << 1;
    $154 = $153 | 1;
    $155 = (_xmalloc($154)|0);
    (_rl_translate_keyseq($150,$155,$macro_keys_len$i)|0);
    (_rl_generic_bind(2,$125,$155,$151)|0);
   } else {
    _rl_initialize_funmap();
    $156 = HEAP32[14520>>2]|0;
    $157 = HEAP32[$156>>2]|0;
    $158 = ($157|0)==(0|0);
    L144: do {
     if ($158) {
      $$0$i39 = 0;
     } else {
      $164 = $157;$i$02$i = 0;
      while(1) {
       $163 = HEAP32[$164>>2]|0;
       $165 = (_strcasecmp($163,$143)|0);
       $166 = ($165|0)==(0);
       $160 = (($i$02$i) + 1)|0;
       if ($166) {
        $$lcssa245 = $164;
        break;
       }
       $159 = (($156) + ($160<<2)|0);
       $161 = HEAP32[$159>>2]|0;
       $162 = ($161|0)==(0|0);
       if ($162) {
        $$0$i39 = 0;
        break L144;
       } else {
        $164 = $161;$i$02$i = $160;
       }
      }
      $167 = ((($$lcssa245)) + 4|0);
      $168 = HEAP32[$167>>2]|0;
      $$0$i39 = $168;
     }
    } while(0);
    $169 = HEAP32[13432>>2]|0;
    (_rl_generic_bind(0,$125,$$0$i39,$169)|0);
   }
   _xfree($125);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $170 = (_strrchr($$011103$lcssa,45)|0);
  $171 = ($170|0)==(0|0);
  $172 = ((($170)) + 1|0);
  $kname$0 = $171 ? $$011103$lcssa : $172;
  $173 = (_strcasecmp($kname$0,30280)|0);
  $174 = ($173|0)==(0);
  if ($174) {
   $i$02$lcssa$i = 0;
   label = 97;
  } else {
   $177 = (_strcasecmp($kname$0,30384)|0);
   $178 = ($177|0)==(0);
   if ($178) {
    $i$02$lcssa$i = 1;
    label = 97;
   } else {
    $179 = (_strcasecmp($kname$0,30392)|0);
    $180 = ($179|0)==(0);
    if ($180) {
     $i$02$lcssa$i = 2;
     label = 97;
    } else {
     $181 = (_strcasecmp($kname$0,30400)|0);
     $182 = ($181|0)==(0);
     if ($182) {
      $i$02$lcssa$i = 3;
      label = 97;
     } else {
      $183 = (_strcasecmp($kname$0,30408)|0);
      $184 = ($183|0)==(0);
      if ($184) {
       $i$02$lcssa$i = 4;
       label = 97;
      } else {
       $185 = (_strcasecmp($kname$0,30416)|0);
       $186 = ($185|0)==(0);
       if ($186) {
        $i$02$lcssa$i = 5;
        label = 97;
       } else {
        $187 = (_strcasecmp($kname$0,30424)|0);
        $188 = ($187|0)==(0);
        if ($188) {
         $i$02$lcssa$i = 6;
         label = 97;
        } else {
         $189 = (_strcasecmp($kname$0,30432)|0);
         $190 = ($189|0)==(0);
         if ($190) {
          $i$02$lcssa$i = 7;
          label = 97;
         } else {
          $191 = (_strcasecmp($kname$0,30440)|0);
          $192 = ($191|0)==(0);
          if ($192) {
           $i$02$lcssa$i = 8;
           label = 97;
          } else {
           $193 = (_strcasecmp($kname$0,30448)|0);
           $194 = ($193|0)==(0);
           if ($194) {
            $i$02$lcssa$i = 9;
            label = 97;
           } else {
            $195 = (_strcasecmp($kname$0,30456)|0);
            $196 = ($195|0)==(0);
            if ($196) {
             $i$02$lcssa$i = 10;
             label = 97;
            } else {
             $197 = HEAP8[$kname$0>>0]|0;
             $198 = $197&255;
             $$0$i40 = $198;
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
  if ((label|0) == 97) {
   $175 = (((30288 + ($i$02$lcssa$i<<3)|0)) + 4|0);
   $176 = HEAP32[$175>>2]|0;
   $$0$i40 = $176;
  }
  $199 = (__rl_strindex($$011103$lcssa,30464)|0);
  $200 = ($199|0)==(0|0);
  if ($200) {
   $201 = (__rl_strindex($$011103$lcssa,30480)|0);
   $202 = ($201|0)==(0|0);
   if ($202) {
    $266 = (__rl_strindex($$011103$lcssa,30520)|0);
    $267 = ($266|0)==(0|0);
    if ($267) {
     $key$0 = $$0$i40;
    } else {
     label = 111;
    }
   } else {
    label = 111;
   }
  } else {
   label = 111;
  }
  if ((label|0) == 111) {
   $203 = $$0$i40 & 255;
   $204 = ($203|0)==($$0$i40|0);
   if ($204) {
    $205 = (_islower($$0$i40)|0);
    $206 = ($205|0)==(0);
    if ($206) {
     $209 = $$0$i40;
    } else {
     $207 = (_toupper($$0$i40)|0);
     $209 = $207;
    }
   } else {
    $209 = $$0$i40;
   }
   $208 = $209 & 31;
   $key$0 = $208;
  }
  $210 = (__rl_strindex($$011103$lcssa,30488)|0);
  $211 = ($210|0)==(0|0);
  if ($211) {
   $212 = (__rl_strindex($$011103$lcssa,30496)|0);
   $213 = ($212|0)==(0|0);
   $$01$i44 = $213;
  } else {
   $$01$i44 = 0;
  }
  $214 = $key$0 | 128;
  $key$0$ = $$01$i44 ? $key$0 : $214;
  $215 = HEAP8[$143>>0]|0;
  if ((($215<<24>>24) == 34) | (($215<<24>>24) == 39)) {
   $216 = (_strlen(($143|0))|0);
   $217 = $key$0$&255;
   HEAP8[$useq>>0] = $217;
   $218 = ((($useq)) + 1|0);
   HEAP8[$218>>0] = 0;
   $219 = ($216|0)==(0);
   if (!($219)) {
    $220 = (($i$3251) + -1)|0;
    $$sum12 = (($220) + ($216))|0;
    $221 = (($$011103$lcssa) + ($$sum12)|0);
    $222 = HEAP8[$221>>0]|0;
    $223 = HEAP8[$143>>0]|0;
    $224 = ($222<<24>>24)==($223<<24>>24);
    if ($224) {
     HEAP8[$221>>0] = 0;
    }
   }
   $$sum = (($i$3251) + 1)|0;
   $225 = (($$011103$lcssa) + ($$sum)|0);
   $226 = HEAP32[13432>>2]|0;
   $227 = (_strlen(($225|0))|0);
   $228 = $227 << 1;
   $229 = $228 | 1;
   $230 = (_xmalloc($229)|0);
   (_rl_translate_keyseq($225,$230,$macro_keys_len$i46)|0);
   (_rl_generic_bind(2,$useq,$230,$226)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $231 = (_strcasecmp($143,30504)|0);
  $232 = ($231|0)==(0);
  if ($232) {
   $233 = $key$0$&255;
   HEAP8[$seq1>>0] = $233;
   $234 = ((($seq1)) + 1|0);
   HEAP8[$234>>0] = 0;
   $235 = HEAP32[13432>>2]|0;
   (_rl_generic_bind(1,$seq1,20296,$235)|0);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  _rl_initialize_funmap();
  $236 = HEAP32[14520>>2]|0;
  $237 = HEAP32[$236>>2]|0;
  $238 = ($237|0)==(0|0);
  L193: do {
   if ($238) {
    $$0$i49 = 0;
   } else {
    $244 = $237;$i$02$i47 = 0;
    while(1) {
     $243 = HEAP32[$244>>2]|0;
     $245 = (_strcasecmp($243,$143)|0);
     $246 = ($245|0)==(0);
     $240 = (($i$02$i47) + 1)|0;
     if ($246) {
      $$lcssa247 = $244;
      break;
     }
     $239 = (($236) + ($240<<2)|0);
     $241 = HEAP32[$239>>2]|0;
     $242 = ($241|0)==(0|0);
     if ($242) {
      $$0$i49 = 0;
      break L193;
     } else {
      $244 = $241;$i$02$i47 = $240;
     }
    }
    $247 = ((($$lcssa247)) + 4|0);
    $248 = HEAP32[$247>>2]|0;
    $$0$i49 = $248;
   }
  } while(0);
  $249 = ($key$0$|0)<(0);
  if ($249) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $250 = $key$0$ & -128;
  $251 = ($250|0)==(128);
  $252 = HEAP32[13688>>2]|0;
  $253 = ($252|0)!=(0);
  $or$cond3$i = $251 & $253;
  $254 = HEAP32[13432>>2]|0;
  if (!($or$cond3$i)) {
   $263 = (($254) + ($key$0$<<3)|0);
   HEAP8[$263>>0] = 0;
   $264 = (((($254) + ($key$0$<<3)|0)) + 4|0);
   HEAP32[$264>>2] = $$0$i49;
   $265 = HEAP32[3358]|0;
   HEAP32[29632>>2] = $265;
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $255 = ((($254)) + 216|0);
  $256 = HEAP8[$255>>0]|0;
  $257 = ($256<<24>>24)==(1);
  if (!($257)) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
  $258 = ((($254)) + 220|0);
  $259 = HEAP32[$258>>2]|0;
  $260 = $key$0$ & -129;
  $261 = (($259) + ($260<<3)|0);
  HEAP8[$261>>0] = 0;
  $262 = (((($259) + ($260<<3)|0)) + 4|0);
  HEAP32[$262>>2] = $$0$i49;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 133) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _rl_variable_bind($name,$value) {
 $name = $name|0;
 $value = $value|0;
 var $$0 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01$i = 0, $i$01$i$lcssa = 0, $or$cond = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $i$01$i = 0;
 while(1) {
  $0 = (29896 + (($i$01$i*12)|0)|0);
  $1 = HEAP32[$0>>2]|0;
  $2 = (_strcasecmp($name,$1)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $$lcssa = $1;$i$01$i$lcssa = $i$01$i;
   label = 4;
   break;
  }
  $4 = (($i$01$i) + 1)|0;
  $5 = ($4|0)==(31);
  if ($5) {
   break;
  } else {
   $i$01$i = $4;
  }
 }
 if ((label|0) == 4) {
  $6 = ($i$01$i$lcssa|0)>(-1);
  if ($6) {
   $7 = ($value|0)==(0|0);
   if ($7) {
    $17 = 1;
   } else {
    $8 = HEAP8[$value>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $17 = 1;
    } else {
     $10 = (_strcasecmp($value,30528)|0);
     $11 = ($10|0)==(0);
     if ($11) {
      $17 = 1;
     } else {
      $12 = ($8<<24>>24)==(49);
      if ($12) {
       $13 = ((($value)) + 1|0);
       $14 = HEAP8[$13>>0]|0;
       $15 = ($14<<24>>24)==(0);
       $17 = $15;
      } else {
       $17 = 0;
      }
     }
    }
   }
   $16 = $17&1;
   $18 = (((29896 + (($i$01$i$lcssa*12)|0)|0)) + 4|0);
   $19 = HEAP32[$18>>2]|0;
   HEAP32[$19>>2] = $16;
   if (!((($i$01$i$lcssa|0) == 1) | (($i$01$i$lcssa|0) == 23))) {
    $$0 = 0;
    return ($$0|0);
   }
   $20 = (_strcasecmp($$lcssa,30536)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = HEAP32[37200>>2]|0;
    __rl_enable_paren_matching($22);
    $$0 = 0;
    return ($$0|0);
   }
   $23 = (_strcasecmp($$lcssa,30560)|0);
   $24 = ($23|0)==(0);
   if (!($24)) {
    $27 = (_strcasecmp($$lcssa,30592)|0);
    $28 = ($27|0)==(0);
    if (!($28)) {
     $$0 = 0;
     return ($$0|0);
    }
    __rl_reset_prompt();
    $$0 = 0;
    return ($$0|0);
   }
   $25 = HEAP32[30584>>2]|0;
   $26 = ($25|0)==(0);
   if ($26) {
    HEAP32[13616>>2] = 1;
    $$0 = 0;
    return ($$0|0);
   } else {
    HEAP32[13616>>2] = 2;
    $$0 = 0;
    return ($$0|0);
   }
  }
 }
 $29 = (_find_string_var($name)|0);
 $30 = ($29|0)<(0);
 $31 = ($29|0)==(10);
 $or$cond = $30 | $31;
 if ($or$cond) {
  $$0 = 0;
  return ($$0|0);
 }
 $32 = (((30616 + (($29*12)|0)|0)) + 8|0);
 $33 = HEAP32[$32>>2]|0;
 $34 = (FUNCTION_TABLE_ii[$33 & 511]($value)|0);
 $$0 = $34;
 return ($$0|0);
}
function _rl_get_keymap_by_name($name) {
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$lcssa = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcasecmp($name,30760)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $i$02$lcssa = 0;
 } else {
  $4 = (_strcasecmp($name,30840)|0);
  $5 = ($4|0)==(0);
  if ($5) {
   $i$02$lcssa = 1;
  } else {
   $6 = (_strcasecmp($name,30856)|0);
   $7 = ($6|0)==(0);
   if ($7) {
    $i$02$lcssa = 2;
   } else {
    $8 = (_strcasecmp($name,30872)|0);
    $9 = ($8|0)==(0);
    if ($9) {
     $i$02$lcssa = 3;
    } else {
     $10 = (_strcasecmp($name,30888)|0);
     $11 = ($10|0)==(0);
     if ($11) {
      $i$02$lcssa = 4;
     } else {
      $12 = (_strcasecmp($name,30896)|0);
      $13 = ($12|0)==(0);
      if ($13) {
       $i$02$lcssa = 5;
      } else {
       $14 = (_strcasecmp($name,30904)|0);
       $15 = ($14|0)==(0);
       if ($15) {
        $i$02$lcssa = 6;
       } else {
        $16 = (_strcasecmp($name,30920)|0);
        $17 = ($16|0)==(0);
        if ($17) {
         $i$02$lcssa = 7;
        } else {
         $$0 = 0;
         return ($$0|0);
        }
       }
      }
     }
    }
   }
  }
 }
 $2 = (((30768 + ($i$02$lcssa<<3)|0)) + 4|0);
 $3 = HEAP32[$2>>2]|0;
 $$0 = $3;
 return ($$0|0);
}
function _rl_invoking_keyseqs_in_map($function,$map) {
 $function = $function|0;
 $map = $map|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $exitcond = 0, $i$08 = 0, $key$014 = 0, $or$cond3 = 0, $result$013 = 0, $result$1 = 0, $result$2$lcssa = 0, $result$27 = 0, $result$3 = 0, $result$4 = 0, $result$4$lcssa = 0, $result_index$012 = 0, $result_index$1$lcssa = 0, $result_index$16 = 0, $result_index$2 = 0;
 var $result_size$011 = 0, $result_size$1 = 0, $result_size$2$lcssa = 0, $result_size$25 = 0, $result_size$3 = 0, $result_size$4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ((($map)) + 216|0);
 $key$014 = 0;$result$013 = 0;$result_index$012 = 0;$result_size$011 = 0;
 while(1) {
  $1 = (($map) + ($key$014<<3)|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = $2 << 24 >> 24;
  if ((($3|0) == 0) | (($3|0) == 2)) {
   $4 = (((($map) + ($key$014<<3)|0)) + 4|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = ($5|0)==($function|0);
   if ($6) {
    $7 = (__rl_get_keyname($key$014)|0);
    $8 = (($result_index$012) + 2)|0;
    $9 = ($8|0)>($result_size$011|0);
    if ($9) {
     $10 = (($result_size$011) + 10)|0;
     $11 = $10 << 2;
     $12 = (_xrealloc($result$013,$11)|0);
     $result$1 = $12;$result_size$1 = $10;
    } else {
     $result$1 = $result$013;$result_size$1 = $result_size$011;
    }
    $13 = (($result_index$012) + 1)|0;
    $14 = (($result$1) + ($result_index$012<<2)|0);
    HEAP32[$14>>2] = $7;
    $15 = (($result$1) + ($13<<2)|0);
    HEAP32[$15>>2] = 0;
    $result$4 = $result$1;$result_index$2 = $13;$result_size$4 = $result_size$1;
   } else {
    $result$4 = $result$013;$result_index$2 = $result_index$012;$result_size$4 = $result_size$011;
   }
  } else if ((($3|0) == 1)) {
   $16 = (((($map) + ($key$014<<3)|0)) + 4|0);
   $17 = HEAP32[$16>>2]|0;
   $18 = ($17|0)==(0|0);
   if ($18) {
    $result$4 = $result$013;$result_index$2 = $result_index$012;$result_size$4 = $result_size$011;
   } else {
    $19 = (_rl_invoking_keyseqs_in_map($function,$17)|0);
    $20 = ($19|0)==(0|0);
    if ($20) {
     $result$4 = $result$013;$result_index$2 = $result_index$012;$result_size$4 = $result_size$011;
    } else {
     $21 = HEAP32[$19>>2]|0;
     $22 = ($21|0)==(0|0);
     if ($22) {
      $result$2$lcssa = $result$013;$result_index$1$lcssa = $result_index$012;$result_size$2$lcssa = $result_size$011;
     } else {
      $23 = ($key$014|0)==(27);
      $24 = ($key$014|0)<(32);
      $25 = $key$014 & 128;
      $26 = ($25|0)==(0);
      $or$cond3 = $24 & $26;
      $27 = $key$014 | 64;
      $28 = $27 & 255;
      $29 = ($28|0)==($27|0);
      $30 = $key$014&255;
      $31 = $21;$69 = $19;$i$08 = 0;$result$27 = $result$013;$result_index$16 = $result_index$012;$result_size$25 = $result_size$011;
      while(1) {
       $32 = (_strlen(($31|0))|0);
       $33 = (($32) + 6)|0;
       $34 = (_xmalloc($33)|0);
       do {
        if ($23) {
         $35 = HEAP32[13688>>2]|0;
         $36 = ($35|0)==(0);
         if (!($36)) {
          $37 = HEAP8[$0>>0]|0;
          $38 = ($37<<24>>24)==(1);
          if ($38) {
           HEAP8[$34>>0]=2968924&255;HEAP8[$34+1>>0]=(2968924>>8)&255;HEAP8[$34+2>>0]=(2968924>>16)&255;HEAP8[$34+3>>0]=2968924>>24;
           break;
          }
         }
         ;HEAP8[$34>>0]=HEAP8[30936>>0]|0;HEAP8[$34+1>>0]=HEAP8[30936+1>>0]|0;HEAP8[$34+2>>0]=HEAP8[30936+2>>0]|0;
        } else {
         if (!($or$cond3)) {
          if ((($key$014|0) == 127)) {
           ;HEAP8[$34>>0]=HEAP8[30952>>0]|0;HEAP8[$34+1>>0]=HEAP8[30952+1>>0]|0;HEAP8[$34+2>>0]=HEAP8[30952+2>>0]|0;HEAP8[$34+3>>0]=HEAP8[30952+3>>0]|0;HEAP8[$34+4>>0]=HEAP8[30952+4>>0]|0;
           break;
          } else if ((($key$014|0) == 34) | (($key$014|0) == 92)) {
           HEAP8[$34>>0] = 92;
           $65 = ((($34)) + 1|0);
           HEAP8[$65>>0] = $30;
           $66 = ((($34)) + 2|0);
           HEAP8[$66>>0] = 0;
           break;
          } else {
           HEAP8[$34>>0] = $30;
           $67 = ((($34)) + 1|0);
           HEAP8[$67>>0] = 0;
           break;
          }
         }
         if ($29) {
          $39 = (_islower($27)|0);
          $40 = ($39|0)==(0);
          if ($40) {
           $$ph = $27;
          } else {
           $41 = (_toupper($27)|0);
           $$ph = $41;
          }
          $42 = $$ph & 255;
          $43 = (_islower($27)|0);
          $44 = ($43|0)==(0);
          if ($44) {
           $47 = $42;$48 = $27;
          } else {
           $45 = (_toupper($27)|0);
           $47 = $42;$48 = $45;
          }
         } else {
          $47 = $28;$48 = $27;
         }
         $46 = ($47|0)==($48|0);
         if ($46) {
          if ($29) {
           $49 = (_islower($27)|0);
           $50 = ($49|0)==(0);
           if ($50) {
            $52 = $27;
           } else {
            $51 = (_toupper($27)|0);
            $52 = $51;
           }
          } else {
           $52 = $27;
          }
          $53 = (_isupper($52)|0);
          $54 = ($53|0)==(0);
          if ($54) {
           label = 31;
          } else {
           if ($29) {
            $55 = (_islower($27)|0);
            $56 = ($55|0)==(0);
            if ($56) {
             $59 = $27;
            } else {
             $57 = (_toupper($27)|0);
             $59 = $57;
            }
           } else {
            $59 = $27;
           }
           $58 = $59 & 255;
           $60 = (_tolower($58)|0);
           $64 = $60;
          }
         } else {
          label = 31;
         }
         if ((label|0) == 31) {
          label = 0;
          if ($29) {
           $61 = (_islower($27)|0);
           $62 = ($61|0)==(0);
           if ($62) {
            $64 = $27;
           } else {
            $63 = (_toupper($27)|0);
            $64 = $63;
           }
          } else {
           $64 = $27;
          }
         }
         HEAP32[$vararg_buffer>>2] = $64;
         (_sprintf($34,30944,$vararg_buffer)|0);
        }
       } while(0);
       $68 = HEAP32[$69>>2]|0;
       (_strcat(($34|0),($68|0))|0);
       $70 = HEAP32[$69>>2]|0;
       _xfree($70);
       $71 = (($result_index$16) + 2)|0;
       $72 = ($71|0)>($result_size$25|0);
       if ($72) {
        $73 = (($result_size$25) + 10)|0;
        $74 = $73 << 2;
        $75 = (_xrealloc($result$27,$74)|0);
        $result$3 = $75;$result_size$3 = $73;
       } else {
        $result$3 = $result$27;$result_size$3 = $result_size$25;
       }
       $76 = (($result_index$16) + 1)|0;
       $77 = (($result$3) + ($result_index$16<<2)|0);
       HEAP32[$77>>2] = $34;
       $78 = (($result$3) + ($76<<2)|0);
       HEAP32[$78>>2] = 0;
       $79 = (($i$08) + 1)|0;
       $80 = (($19) + ($79<<2)|0);
       $81 = HEAP32[$80>>2]|0;
       $82 = ($81|0)==(0|0);
       if ($82) {
        $result$2$lcssa = $result$3;$result_index$1$lcssa = $76;$result_size$2$lcssa = $result_size$3;
        break;
       } else {
        $31 = $81;$69 = $80;$i$08 = $79;$result$27 = $result$3;$result_index$16 = $76;$result_size$25 = $result_size$3;
       }
      }
     }
     _xfree($19);
     $result$4 = $result$2$lcssa;$result_index$2 = $result_index$1$lcssa;$result_size$4 = $result_size$2$lcssa;
    }
   }
  } else {
   $result$4 = $result$013;$result_index$2 = $result_index$012;$result_size$4 = $result_size$011;
  }
  $83 = (($key$014) + 1)|0;
  $exitcond = ($83|0)==(257);
  if ($exitcond) {
   $result$4$lcssa = $result$4;
   break;
  } else {
   $key$014 = $83;$result$013 = $result$4;$result_index$012 = $result_index$2;$result_size$011 = $result_size$4;
  }
 }
 STACKTOP = sp;return ($result$4$lcssa|0);
}
function _rl_function_dumper($print_readably) {
 $print_readably = $print_readably|0;
 var $$0$i = 0, $$lcssa = 0, $$lcssa34 = 0, $$lcssa35 = 0, $$not = 0, $$not1 = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge = 0, $i$014 = 0, $i$02$i = 0, $j$05 = 0, $j1$06 = 0, $j1$111 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer11 = 0, $vararg_buffer5 = 0, $vararg_buffer8 = 0, $vararg_ptr14 = 0, $vararg_ptr4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer11 = sp + 32|0;
 $vararg_buffer8 = sp + 24|0;
 $vararg_buffer5 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_rl_funmap_names()|0);
 $1 = HEAP32[13512>>2]|0;
 (_fputc(10,($1|0))|0);
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  _xfree($0);
  STACKTOP = sp;return;
 }
 $4 = ($print_readably|0)==(0);
 $14 = $2;$i$014 = 0;
 while(1) {
  _rl_initialize_funmap();
  $5 = HEAP32[14520>>2]|0;
  $6 = HEAP32[$5>>2]|0;
  $7 = ($6|0)==(0|0);
  L6: do {
   if ($7) {
    $$0$i = 0;
   } else {
    $13 = $6;$i$02$i = 0;
    while(1) {
     $12 = HEAP32[$13>>2]|0;
     $15 = (_strcasecmp($12,$14)|0);
     $16 = ($15|0)==(0);
     $9 = (($i$02$i) + 1)|0;
     if ($16) {
      $$lcssa = $13;
      break;
     }
     $8 = (($5) + ($9<<2)|0);
     $10 = HEAP32[$8>>2]|0;
     $11 = ($10|0)==(0|0);
     if ($11) {
      $$0$i = 0;
      break L6;
     } else {
      $13 = $10;$i$02$i = $9;
     }
    }
    $17 = ((($$lcssa)) + 4|0);
    $18 = HEAP32[$17>>2]|0;
    $$0$i = $18;
   }
  } while(0);
  $19 = HEAP32[13432>>2]|0;
  $20 = (_rl_invoking_keyseqs_in_map($$0$i,$19)|0);
  $21 = ($20|0)!=(0|0);
  do {
   if ($4) {
    $33 = HEAP32[13512>>2]|0;
    if (!($21)) {
     HEAP32[$vararg_buffer5>>2] = $14;
     (_fprintf(($33|0),(31000|0),($vararg_buffer5|0))|0);
     break;
    }
    HEAP32[$vararg_buffer8>>2] = $14;
    (_fprintf(($33|0),(31032|0),($vararg_buffer8|0))|0);
    $34 = HEAP32[$20>>2]|0;
    $35 = ($34|0)==(0|0);
    if (!($35)) {
     $42 = $34;$j1$06 = 0;
     while(1) {
      $36 = HEAP32[13512>>2]|0;
      $37 = (($j1$06) + 1)|0;
      $38 = (($20) + ($37<<2)|0);
      $39 = HEAP32[$38>>2]|0;
      $40 = ($39|0)!=(0|0);
      $41 = $40 ? 31056 : 31064;
      HEAP32[$vararg_buffer11>>2] = $42;
      $vararg_ptr14 = ((($vararg_buffer11)) + 4|0);
      HEAP32[$vararg_ptr14>>2] = $41;
      (_fprintf(($36|0),(31072|0),($vararg_buffer11|0))|0);
      $43 = HEAP32[$38>>2]|0;
      $44 = ($43|0)!=(0|0);
      $45 = ($37|0)<(5);
      $46 = $45 & $44;
      if ($46) {
       $42 = $43;$j1$06 = $37;
      } else {
       $$lcssa34 = $37;$$lcssa35 = $44;
       break;
      }
     }
     $$not = ($$lcssa34|0)!=(5);
     $$not1 = $$lcssa35 ^ 1;
     $brmerge = $$not | $$not1;
     if (!($brmerge)) {
      $47 = HEAP32[13512>>2]|0;
      (_fwrite((31080|0),4,1,($47|0))|0);
     }
     $$pr = HEAP32[$20>>2]|0;
     $48 = ($$pr|0)==(0|0);
     if (!($48)) {
      $49 = $$pr;$j1$111 = 0;
      while(1) {
       _xfree($49);
       $50 = (($j1$111) + 1)|0;
       $51 = (($20) + ($50<<2)|0);
       $52 = HEAP32[$51>>2]|0;
       $53 = ($52|0)==(0|0);
       if ($53) {
        break;
       } else {
        $49 = $52;$j1$111 = $50;
       }
      }
     }
    }
    _xfree($20);
   } else {
    if (!($21)) {
     $24 = HEAP32[13512>>2]|0;
     HEAP32[$vararg_buffer>>2] = $14;
     (_fprintf(($24|0),(30960|0),($vararg_buffer|0))|0);
     break;
    }
    $22 = HEAP32[$20>>2]|0;
    $23 = ($22|0)==(0|0);
    if (!($23)) {
     $26 = $22;$28 = $20;$j$05 = 0;
     while(1) {
      $25 = HEAP32[13512>>2]|0;
      HEAP32[$vararg_buffer1>>2] = $26;
      $vararg_ptr4 = ((($vararg_buffer1)) + 4|0);
      HEAP32[$vararg_ptr4>>2] = $14;
      (_fprintf(($25|0),(30984|0),($vararg_buffer1|0))|0);
      $27 = HEAP32[$28>>2]|0;
      _xfree($27);
      $29 = (($j$05) + 1)|0;
      $30 = (($20) + ($29<<2)|0);
      $31 = HEAP32[$30>>2]|0;
      $32 = ($31|0)==(0|0);
      if ($32) {
       break;
      } else {
       $26 = $31;$28 = $30;$j$05 = $29;
      }
     }
    }
    _xfree($20);
   }
  } while(0);
  $54 = (($i$014) + 1)|0;
  $55 = (($0) + ($54<<2)|0);
  $56 = HEAP32[$55>>2]|0;
  $57 = ($56|0)==(0|0);
  if ($57) {
   break;
  } else {
   $14 = $56;$i$014 = $54;
  }
 }
 _xfree($0);
 STACKTOP = sp;return;
}
function _rl_dump_functions($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13984>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = HEAP32[13512>>2]|0;
  (_fwrite((31088|0),2,1,($2|0))|0);
 }
 $3 = HEAP32[13472>>2]|0;
 _rl_function_dumper($3);
 (_rl_on_new_line()|0);
 return 0;
}
function _rl_dump_macros($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13984>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = HEAP32[13512>>2]|0;
  (_fwrite((31088|0),2,1,($2|0))|0);
 }
 $3 = HEAP32[13472>>2]|0;
 $4 = HEAP32[13432>>2]|0;
 __rl_macro_dumper_internal($3,$4,0);
 (_rl_on_new_line()|0);
 return 0;
}
function _rl_variable_dumper($print_readably) {
 $print_readably = $print_readably|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$02 = 0, $i$11 = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer2 = 0, $vararg_buffer6 = 0, $vararg_ptr1 = 0, $vararg_ptr13 = 0, $vararg_ptr5 = 0, $vararg_ptr9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer10 = sp + 24|0;
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer2 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = ($print_readably|0)==(0);
 $7 = 31096;$i$02 = 0;
 while(1) {
  $1 = HEAP32[13512>>2]|0;
  $2 = (((29896 + (($i$02*12)|0)|0)) + 4|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)!=(0);
  $6 = $5 ? 30528 : 30752;
  if ($0) {
   HEAP32[$vararg_buffer2>>2] = $7;
   $vararg_ptr5 = ((($vararg_buffer2)) + 4|0);
   HEAP32[$vararg_ptr5>>2] = $6;
   (_fprintf(($1|0),(31136|0),($vararg_buffer2|0))|0);
  } else {
   HEAP32[$vararg_buffer>>2] = $7;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $6;
   (_fprintf(($1|0),(31120|0),($vararg_buffer|0))|0);
  }
  $8 = (($i$02) + 1)|0;
  $9 = (29896 + (($8*12)|0)|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($8|0)==(31);
  if ($11) {
   $13 = 30616;$i$11 = 0;
   break;
  } else {
   $7 = $10;$i$02 = $8;
  }
 }
 while(1) {
  $12 = HEAP32[$13>>2]|0;
  $14 = (__rl_get_string_variable_value($12)|0);
  $15 = ($14|0)==(0|0);
  do {
   if (!($15)) {
    $16 = HEAP32[13512>>2]|0;
    $17 = HEAP32[$13>>2]|0;
    if ($0) {
     HEAP32[$vararg_buffer10>>2] = $17;
     $vararg_ptr13 = ((($vararg_buffer10)) + 4|0);
     HEAP32[$vararg_ptr13>>2] = $14;
     (_fprintf(($16|0),(31136|0),($vararg_buffer10|0))|0);
     break;
    } else {
     HEAP32[$vararg_buffer6>>2] = $17;
     $vararg_ptr9 = ((($vararg_buffer6)) + 4|0);
     HEAP32[$vararg_ptr9>>2] = $14;
     (_fprintf(($16|0),(31120|0),($vararg_buffer6|0))|0);
     break;
    }
   }
  } while(0);
  $18 = (($i$11) + 1)|0;
  $19 = (30616 + (($18*12)|0)|0);
  $20 = ($18|0)==(10);
  if ($20) {
   break;
  } else {
   $13 = $19;$i$11 = $18;
  }
 }
 STACKTOP = sp;return;
}
function _rl_dump_variables($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13984>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = HEAP32[13512>>2]|0;
  (_fwrite((31088|0),2,1,($2|0))|0);
 }
 $3 = HEAP32[13472>>2]|0;
 _rl_variable_dumper($3);
 (_rl_on_new_line()|0);
 return 0;
}
function __rl_read_init_file($filename,$include_level) {
 $filename = $filename|0;
 $include_level = $include_level|0;
 var $$0 = 0, $$0$i = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $finfo$i = 0, $i$0$lcssa = 0, $i$06 = 0, $i$1 = 0, $i$1$lcssa = 0, $i$138 = 0, $line$011 = 0, $line$1 = 0;
 var $line$1$lcssa = 0, $line$140 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $finfo$i = sp + 4|0;
 HEAP32[29760>>2] = $filename;
 HEAP32[32056>>2] = $include_level;
 $0 = (_tilde_expand($filename)|0);
 $1 = (_stat(($0|0),($finfo$i|0))|0);
 $2 = ($1|0)<(0);
 do {
  if ($2) {
   $$0$i = 0;$32 = 0;
  } else {
   HEAP32[$vararg_buffer>>2] = 438;
   $3 = (_open(($0|0),0,($vararg_buffer|0))|0);
   $4 = ($3|0)<(0);
   if ($4) {
    $$0$i = 0;$32 = 0;
   } else {
    $5 = ((($finfo$i)) + 36|0);
    $6 = HEAP32[$5>>2]|0;
    $7 = ($6|0)==(-1);
    if ($7) {
     (_close(($3|0))|0);
     $8 = (___errno_location()|0);
     HEAP32[$8>>2] = 27;
     $$0$i = 0;$32 = 0;
     break;
    }
    $9 = (($6) + 1)|0;
    $10 = (_xmalloc($9)|0);
    $11 = (_read(($3|0),($10|0),($6|0))|0);
    (_close(($3|0))|0);
    $12 = ($11|0)<(0);
    if ($12) {
     _xfree($10);
     $$0$i = 0;$32 = 0;
     break;
    }
    $13 = HEAP32[32656>>2]|0;
    $14 = ($13|0)==(0);
    if (!($14)) {
     $15 = HEAP32[32656>>2]|0;
     __rl_signal_handler($15);
    }
    $16 = (($10) + ($11)|0);
    HEAP8[$16>>0] = 0;
    $$0$i = $10;$32 = $11;
   }
  }
 } while(0);
 _xfree($0);
 $17 = HEAP32[32656>>2]|0;
 $18 = ($17|0)==(0);
 if (!($18)) {
  $19 = HEAP32[32656>>2]|0;
  __rl_signal_handler($19);
 }
 $20 = ($$0$i|0)==(0|0);
 if ($20) {
  $21 = (___errno_location()|0);
  $22 = HEAP32[$21>>2]|0;
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 }
 $23 = ($include_level|0)==(0);
 if ($23) {
  $24 = HEAP32[29656>>2]|0;
  $25 = ($24|0)==($filename|0);
  if (!($25)) {
   $26 = ($24|0)==(0|0);
   if (!($26)) {
    _free($24);
   }
   $27 = (_strlen(($filename|0))|0);
   $28 = (($27) + 1)|0;
   $29 = (_xmalloc($28)|0);
   $30 = (_strcpy(($29|0),($filename|0))|0);
   HEAP32[29656>>2] = $30;
  }
 }
 HEAP32[29848>>2] = 1;
 HEAP32[29768>>2] = 1;
 $31 = (($$0$i) + ($32)|0);
 $33 = ($32|0)>(0);
 if ($33) {
  $line$011 = $$0$i;
  while(1) {
   $34 = ($line$011|0)==($31|0);
   L31: do {
    if ($34) {
     $$lcssa = $31;$i$0$lcssa = 0;
    } else {
     $36 = $line$011;$i$06 = 0;
     while(1) {
      $35 = HEAP8[$36>>0]|0;
      $37 = ($35<<24>>24)==(10);
      if ($37) {
       $$lcssa = $36;$i$0$lcssa = $i$06;
       break L31;
      }
      $38 = (($i$06) + 1)|0;
      $39 = (($line$011) + ($38)|0);
      $40 = ($39|0)==($31|0);
      if ($40) {
       $$lcssa = $31;$i$0$lcssa = $38;
       break;
      } else {
       $36 = $39;$i$06 = $38;
      }
     }
    }
   } while(0);
   HEAP8[$$lcssa>>0] = 0;
   $i$1 = $i$0$lcssa;$line$1 = $line$011;
   while(1) {
    $41 = HEAP8[$line$1>>0]|0;
    if ((($41<<24>>24) == 35) | (($41<<24>>24) == 0)) {
     $i$138 = $i$1;$line$140 = $line$1;
     break;
    } else if (!((($41<<24>>24) == 9) | (($41<<24>>24) == 32))) {
     $i$1$lcssa = $i$1;$line$1$lcssa = $line$1;
     label = 26;
     break;
    }
    $42 = ((($line$1)) + 1|0);
    $43 = (($i$1) + -1)|0;
    $i$1 = $43;$line$1 = $42;
   }
   if ((label|0) == 26) {
    label = 0;
    (_rl_parse_and_bind($line$1$lcssa)|0);
    $i$138 = $i$1$lcssa;$line$140 = $line$1$lcssa;
   }
   $44 = (($i$138) + 1)|0;
   $45 = (($line$140) + ($44)|0);
   $46 = HEAP32[29768>>2]|0;
   $47 = (($46) + 1)|0;
   HEAP32[29768>>2] = $47;
   $48 = ($45>>>0)<($31>>>0);
   if ($48) {
    $line$011 = $45;
   } else {
    break;
   }
  }
 }
 _xfree($$0$i);
 HEAP32[29848>>2] = 0;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _find_string_var($name) {
 $name = $name|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcasecmp($name,31208)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $$0 = 0;
 } else {
  $2 = (_strcasecmp($name,31240)|0);
  $3 = ($2|0)==(0);
  if ($3) {
   $$0 = 1;
  } else {
   $4 = (_strcasecmp($name,31256)|0);
   $5 = ($4|0)==(0);
   if ($5) {
    $$0 = 2;
   } else {
    $6 = (_strcasecmp($name,31320)|0);
    $7 = ($6|0)==(0);
    if ($7) {
     $$0 = 3;
    } else {
     $8 = (_strcasecmp($name,31360)|0);
     $9 = ($8|0)==(0);
     if ($9) {
      $$0 = 4;
     } else {
      $10 = (_strcasecmp($name,31384)|0);
      $11 = ($10|0)==(0);
      if ($11) {
       $$0 = 5;
      } else {
       $12 = (_strcasecmp($name,31400)|0);
       $13 = ($12|0)==(0);
       if ($13) {
        $$0 = 6;
       } else {
        $14 = (_strcasecmp($name,31416)|0);
        $15 = ($14|0)==(0);
        if ($15) {
         $$0 = 7;
        } else {
         $16 = (_strcasecmp($name,31440)|0);
         $17 = ($16|0)==(0);
         if ($17) {
          $$0 = 8;
         } else {
          $18 = (_strcasecmp($name,31448)|0);
          $19 = ($18|0)==(0);
          $$ = $19 ? 9 : -1;
          return ($$|0);
         }
        }
       }
      }
     }
    }
   }
  }
 }
 return ($$0|0);
}
function __rl_get_string_variable_value($name) {
 $name = $name|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $switch$select = 0, $switch$select$i = 0, $switch$select$i4 = 0, $switch$select2 = 0, $switch$select2$i = 0, $switch$select2$i6 = 0, $switch$selectcmp = 0, $switch$selectcmp$i = 0, $switch$selectcmp$i3 = 0, $switch$selectcmp1 = 0, $switch$selectcmp1$i = 0, $switch$selectcmp1$i5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer10 = 0;
 var $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = (_strcasecmp($name,31208)|0);
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $2 = HEAP32[13616>>2]|0;
   $switch$selectcmp = ($2|0)==(2);
   $switch$select = $switch$selectcmp ? 31224 : 31232;
   $switch$selectcmp1 = ($2|0)==(0);
   $switch$select2 = $switch$selectcmp1 ? 38280 : $switch$select;
   $$0 = $switch$select2;
  } else {
   $3 = (_strcasecmp($name,31240)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    $5 = HEAP32[13992>>2]|0;
    $6 = ($5|0)!=(0|0);
    $7 = $6 ? $5 : 35968;
    $$0 = $7;
    break;
   }
   $8 = (_strcasecmp($name,31256)|0);
   $9 = ($8|0)==(0);
   if ($9) {
    $10 = HEAP32[28960>>2]|0;
    HEAP32[$vararg_buffer>>2] = $10;
    (_sprintf(31288,37288,$vararg_buffer)|0);
    $$0 = 31288;
    break;
   }
   $11 = (_strcasecmp($name,31320)|0);
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = HEAP32[28952>>2]|0;
    HEAP32[$vararg_buffer1>>2] = $13;
    (_sprintf(31288,37288,$vararg_buffer1)|0);
    $$0 = 31288;
    break;
   }
   $14 = (_strcasecmp($name,31360)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = HEAP32[29080>>2]|0;
    HEAP32[$vararg_buffer4>>2] = $16;
    (_sprintf(31288,37288,$vararg_buffer4)|0);
    $$0 = 31288;
    break;
   }
   $17 = (_strcasecmp($name,31384)|0);
   $18 = ($17|0)==(0);
   if ($18) {
    $19 = HEAP32[13440>>2]|0;
    $switch$selectcmp$i = ($19|0)==(0);
    $switch$select$i = $switch$selectcmp$i ? 30888 : 38280;
    $switch$selectcmp1$i = ($19|0)==(1);
    $switch$select2$i = $switch$selectcmp1$i ? 30760 : $switch$select$i;
    $$0 = $switch$select2$i;
    break;
   }
   $20 = (_strcasecmp($name,31400)|0);
   $21 = ($20|0)==(0);
   if ($21) {
    $22 = (_history_is_stifled()|0);
    $23 = ($22|0)!=(0);
    $24 = HEAP32[36104>>2]|0;
    $25 = $23 ? $24 : 0;
    HEAP32[$vararg_buffer7>>2] = $25;
    (_sprintf(31288,37288,$vararg_buffer7)|0);
    $$0 = 31288;
    break;
   }
   $26 = (_strcasecmp($name,31416)|0);
   $27 = ($26|0)==(0);
   if ($27) {
    $28 = HEAP32[32176>>2]|0;
    $29 = ($28|0)==(0|0);
    if ($29) {
     $$0 = 0;
     break;
    }
    $30 = (__rl_untranslate_macro_value($28,0)|0);
    $31 = ($30|0)==(0|0);
    if ($31) {
     HEAP8[31288>>0] = 0;
     $$0 = 31288;
     break;
    } else {
     (_strncpy((31288|0),($30|0),31)|0);
     _xfree($30);
     HEAP8[(31319)>>0] = 0;
     $$0 = 31288;
     break;
    }
   }
   $32 = (_strcasecmp($name,31440)|0);
   $33 = ($32|0)==(0);
   if (!($33)) {
    $41 = (_strcasecmp($name,31448)|0);
    $42 = ($41|0)==(0);
    if (!($42)) {
     $$0 = 0;
     break;
    }
    $43 = HEAP32[13672>>2]|0;
    HEAP32[$vararg_buffer10>>2] = $43;
    (_sprintf(31288,37288,$vararg_buffer10)|0);
    $$0 = 31288;
    break;
   }
   $34 = HEAP32[13432>>2]|0;
   $35 = ($34|0)==(22352|0);
   if ($35) {
    $$0 = 30760;
   } else {
    $36 = ($34|0)==(20296|0);
    if ($36) {
     $$0 = 30856;
    } else {
     $37 = ($34|0)==(18240|0);
     if ($37) {
      $$0 = 30872;
     } else {
      $38 = ($34|0)==(24408|0);
      if ($38) {
       $$0 = 30888;
      } else {
       $39 = ($34|0)==(26464|0);
       if ($39) {
        $$0 = 30920;
       } else {
        $40 = HEAP32[13440>>2]|0;
        $switch$selectcmp$i3 = ($40|0)==(0);
        $switch$select$i4 = $switch$selectcmp$i3 ? 30888 : 38280;
        $switch$selectcmp1$i5 = ($40|0)==(1);
        $switch$select2$i6 = $switch$selectcmp1$i5 ? 30760 : $switch$select$i4;
        $$0 = $switch$select2$i6;
       }
      }
     }
    }
   }
  }
 } while(0);
 STACKTOP = sp;return ($$0|0);
}
function __rl_get_keyname($key) {
 $key = $key|0;
 var $$ph = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $c$0 = 0, $c$1 = 0, $i$0 = 0, $i$1 = 0, $i$2 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(8)|0);
 if ((($key|0) == 27)) {
  HEAP8[$0>>0] = 92;
  $1 = ((($0)) + 1|0);
  HEAP8[$1>>0] = 101;
  $2 = ((($0)) + 2|0);
  HEAP8[$2>>0] = 0;
  return ($0|0);
 } else if ((($key|0) == 127)) {
  HEAP8[$0>>0] = 92;
  $3 = ((($0)) + 1|0);
  HEAP8[$3>>0] = 67;
  $4 = ((($0)) + 2|0);
  HEAP8[$4>>0] = 45;
  $5 = ((($0)) + 3|0);
  HEAP8[$5>>0] = 63;
  $6 = ((($0)) + 4|0);
  HEAP8[$6>>0] = 0;
  return ($0|0);
 } else {
  $7 = ($key|0)<(32);
  $8 = $key & 128;
  $9 = ($8|0)==(0);
  $or$cond = $7 & $9;
  do {
   if ($or$cond) {
    HEAP8[$0>>0] = 92;
    $10 = ((($0)) + 1|0);
    HEAP8[$10>>0] = 67;
    $11 = ((($0)) + 2|0);
    HEAP8[$11>>0] = 45;
    $12 = $key | 64;
    $13 = $12 & 255;
    $14 = ($13|0)==($12|0);
    if ($14) {
     $15 = (_islower($12)|0);
     $16 = ($15|0)==(0);
     if ($16) {
      $$ph = $12;
     } else {
      $17 = (_toupper($12)|0);
      $$ph = $17;
     }
     $18 = $$ph & 255;
     $19 = (_islower($12)|0);
     $20 = ($19|0)==(0);
     if ($20) {
      $23 = $18;$24 = $12;
     } else {
      $21 = (_toupper($12)|0);
      $23 = $18;$24 = $21;
     }
    } else {
     $23 = $13;$24 = $12;
    }
    $22 = ($23|0)==($24|0);
    if ($22) {
     if ($14) {
      $25 = (_islower($12)|0);
      $26 = ($25|0)==(0);
      if ($26) {
       $28 = $12;
      } else {
       $27 = (_toupper($12)|0);
       $28 = $27;
      }
     } else {
      $28 = $12;
     }
     $29 = (_isupper($28)|0);
     $30 = ($29|0)==(0);
     if (!($30)) {
      if ($14) {
       $31 = (_islower($12)|0);
       $32 = ($31|0)==(0);
       if ($32) {
        $35 = $12;
       } else {
        $33 = (_toupper($12)|0);
        $35 = $33;
       }
      } else {
       $35 = $12;
      }
      $34 = $35 & 255;
      $36 = (_tolower($34)|0);
      $c$0 = $36;$i$0 = 3;
      break;
     }
    }
    if ($14) {
     $37 = (_islower($12)|0);
     $38 = ($37|0)==(0);
     if ($38) {
      $c$0 = $12;$i$0 = 3;
     } else {
      $39 = (_toupper($12)|0);
      $c$0 = $39;$i$0 = 3;
     }
    } else {
     $c$0 = $12;$i$0 = 3;
    }
   } else {
    $c$0 = $key;$i$0 = 0;
   }
  } while(0);
  $40 = $c$0 & -32;
  $41 = ($40|0)==(128);
  if ($41) {
   $42 = (($i$0) + 1)|0;
   $43 = (($0) + ($i$0)|0);
   HEAP8[$43>>0] = 92;
   $44 = (($i$0) + 2)|0;
   $45 = (($0) + ($42)|0);
   HEAP8[$45>>0] = 50;
   $46 = (($c$0) + -128)|0;
   $47 = (($46|0) / 8)&-1;
   $48 = (($47) + 48)|0;
   $49 = $48&255;
   $50 = (($i$0) + 3)|0;
   $51 = (($0) + ($44)|0);
   HEAP8[$51>>0] = $49;
   $52 = (($46|0) % 8)&-1;
   $53 = (($52) + 48)|0;
   $c$1 = $53;$i$1 = $50;
  } else {
   $c$1 = $c$0;$i$1 = $i$0;
  }
  if ((($c$1|0) == 34) | (($c$1|0) == 92)) {
   $54 = (($i$1) + 1)|0;
   $55 = (($0) + ($i$1)|0);
   HEAP8[$55>>0] = 92;
   $i$2 = $54;
  } else {
   $i$2 = $i$1;
  }
  $56 = $c$1&255;
  $57 = (($i$2) + 1)|0;
  $58 = (($0) + ($i$2)|0);
  HEAP8[$58>>0] = $56;
  $59 = (($0) + ($57)|0);
  HEAP8[$59>>0] = 0;
  return ($0|0);
 }
 return (0)|0;
}
function __rl_macro_dumper_internal($print_readably,$map,$prefix) {
 $print_readably = $print_readably|0;
 $map = $map|0;
 $prefix = $prefix|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $key$01 = 0, $keyname$0 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, $vararg_ptr6 = 0;
 var $vararg_ptr7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $0 = ($print_readably|0)==(0);
 $1 = ($prefix|0)!=(0|0);
 $2 = $1 ? $prefix : 37352;
 $key$01 = 0;
 while(1) {
  $3 = (($map) + ($key$01<<3)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = $4 << 24 >> 24;
  if ((($5|0) == 2)) {
   $6 = (__rl_get_keyname($key$01)|0);
   $7 = (((($map) + ($key$01<<3)|0)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = (__rl_untranslate_macro_value($8,0)|0);
   $10 = HEAP32[13512>>2]|0;
   $11 = ($9|0)!=(0|0);
   $12 = $11 ? $9 : 37352;
   if ($0) {
    HEAP32[$vararg_buffer3>>2] = $2;
    $vararg_ptr6 = ((($vararg_buffer3)) + 4|0);
    HEAP32[$vararg_ptr6>>2] = $6;
    $vararg_ptr7 = ((($vararg_buffer3)) + 8|0);
    HEAP32[$vararg_ptr7>>2] = $12;
    (_fprintf(($10|0),(31184|0),($vararg_buffer3|0))|0);
   } else {
    HEAP32[$vararg_buffer>>2] = $2;
    $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
    HEAP32[$vararg_ptr1>>2] = $6;
    $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
    HEAP32[$vararg_ptr2>>2] = $12;
    (_fprintf(($10|0),(31168|0),($vararg_buffer|0))|0);
   }
   _xfree($6);
   _xfree($9);
  } else if ((($5|0) == 1)) {
   if ($1) {
    $13 = (_strlen(($prefix|0))|0);
    $16 = $13;
   } else {
    $16 = 0;
   }
   $14 = ($key$01|0)==(27);
   if ($14) {
    $15 = (($16) + 3)|0;
    $17 = (_xmalloc($15)|0);
    if ($1) {
     (_strcpy(($17|0),($prefix|0))|0);
    }
    $18 = (($17) + ($16)|0);
    HEAP8[$18>>0] = 92;
    $19 = (($16) + 1)|0;
    $20 = (($17) + ($19)|0);
    HEAP8[$20>>0] = 101;
    $21 = (($16) + 2)|0;
    $22 = (($17) + ($21)|0);
    HEAP8[$22>>0] = 0;
    $keyname$0 = $17;
   } else {
    $23 = (__rl_get_keyname($key$01)|0);
    if ($1) {
     $24 = (_strlen(($23|0))|0);
     $25 = (($16) + 1)|0;
     $26 = (($25) + ($24))|0;
     $27 = (_xmalloc($26)|0);
     (_strcpy(($27|0),($prefix|0))|0);
     $28 = (($27) + ($16)|0);
     (_strcpy(($28|0),($23|0))|0);
     _xfree($23);
     $keyname$0 = $27;
    } else {
     $keyname$0 = $23;
    }
   }
   $29 = (((($map) + ($key$01<<3)|0)) + 4|0);
   $30 = HEAP32[$29>>2]|0;
   __rl_macro_dumper_internal($print_readably,$30,$keyname$0);
   _xfree($keyname$0);
  }
  $31 = (($key$01) + 1)|0;
  $exitcond = ($31|0)==(257);
  if ($exitcond) {
   break;
  } else {
   $key$01 = $31;
  }
 }
 STACKTOP = sp;return;
}
function _sv_bell_style($value) {
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if (!($0)) {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if (!($2)) {
   $3 = (_strcasecmp($value,38280)|0);
   $4 = ($3|0)==(0);
   if (!($4)) {
    $5 = (_strcasecmp($value,30752)|0);
    $6 = ($5|0)==(0);
    if (!($6)) {
     $7 = (_strcasecmp($value,31232)|0);
     $8 = ($7|0)==(0);
     if (!($8)) {
      $9 = (_strcasecmp($value,30528)|0);
      $10 = ($9|0)==(0);
      if (!($10)) {
       $11 = (_strcasecmp($value,31224)|0);
       $12 = ($11|0)==(0);
       if (!($12)) {
        $$0 = 1;
        return ($$0|0);
       }
       HEAP32[13616>>2] = 2;
       $$0 = 0;
       return ($$0|0);
      }
     }
     HEAP32[13616>>2] = 1;
     $$0 = 0;
     return ($$0|0);
    }
   }
   HEAP32[13616>>2] = 0;
   $$0 = 0;
   return ($$0|0);
  }
 }
 HEAP32[13616>>2] = 1;
 $$0 = 0;
 return ($$0|0);
}
function _sv_combegin($value) {
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 1;
  return ($$0|0);
 }
 $1 = HEAP8[$value>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 1;
  return ($$0|0);
 }
 $3 = HEAP32[13992>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  _free($3);
 }
 $5 = (_strlen(($value|0))|0);
 $6 = (($5) + 1)|0;
 $7 = (_xmalloc($6)|0);
 $8 = (_strcpy(($7|0),($value|0))|0);
 HEAP32[13992>>2] = $8;
 $$0 = 0;
 return ($$0|0);
}
function _sv_compwidth($value) {
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $nval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $nval$0 = -1;
 } else {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $nval$0 = -1;
  } else {
   $3 = (_atoi($value)|0);
   $nval$0 = $3;
  }
 }
 HEAP32[28960>>2] = $nval$0;
 return 0;
}
function _sv_dispprefix($value) {
 $value = $value|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $nval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $nval$0 = 0;
 } else {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $nval$0 = 0;
  } else {
   $3 = (_atoi($value)|0);
   $4 = ($3|0)<(0);
   $$ = $4 ? 0 : $3;
   $nval$0 = $$;
  }
 }
 HEAP32[28952>>2] = $nval$0;
 return 0;
}
function _sv_compquery($value) {
 $value = $value|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $nval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $nval$0 = 100;
 } else {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $nval$0 = 100;
  } else {
   $3 = (_atoi($value)|0);
   $4 = ($3|0)<(0);
   $$ = $4 ? 0 : $3;
   $nval$0 = $$;
  }
 }
 HEAP32[29080>>2] = $nval$0;
 return 0;
}
function _sv_editmode($value) {
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strncasecmp($value,30888,2)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP32[13432>>2] = 26464;
  HEAP32[13440>>2] = 0;
  $$0 = 0;
  return ($$0|0);
 }
 $2 = (_strncasecmp($value,30760,5)|0);
 $3 = ($2|0)==(0);
 if (!($3)) {
  $$0 = 1;
  return ($$0|0);
 }
 HEAP32[13432>>2] = 22352;
 HEAP32[13440>>2] = 1;
 $$0 = 0;
 return ($$0|0);
}
function _sv_histsize($value) {
 $value = $value|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $nval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $nval$0 = 500;
 } else {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $nval$0 = 500;
  } else {
   $3 = (_atoi($value)|0);
   $4 = ($3|0)<(0);
   if ($4) {
    (_unstifle_history()|0);
    return 0;
   } else {
    $nval$0 = $3;
   }
  }
 }
 _stifle_history($nval$0);
 return 0;
}
function _sv_isrchterm($value) {
 $value = $value|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $beg$0 = 0, $end = 0, $or$cond = 0, $storemerge = 0, $storemerge1 = 0, $storemerge3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $end = sp;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = (_strlen(($value|0))|0);
 $2 = (($1) + 1)|0;
 $3 = (_xmalloc($2)|0);
 $4 = (_strcpy(($3|0),($value|0))|0);
 $5 = HEAP32[32176>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _free($5);
 }
 $7 = HEAP8[$4>>0]|0;
 L7: do {
  if ((($7<<24>>24) == 39) | (($7<<24>>24) == 34)) {
   $storemerge1 = 1;
   while(1) {
    $8 = (($4) + ($storemerge1)|0);
    $9 = HEAP8[$8>>0]|0;
    $10 = ($9<<24>>24)==(0);
    $11 = ($9<<24>>24)==($7<<24>>24);
    $or$cond = $10 | $11;
    $12 = (($storemerge1) + 1)|0;
    if ($or$cond) {
     $beg$0 = 1;$storemerge3 = $storemerge1;
     break;
    } else {
     $storemerge1 = $12;
    }
   }
  } else {
   $23 = $7;$storemerge = 0;
   while(1) {
    if ((($23<<24>>24) == 9) | (($23<<24>>24) == 32)) {
     $beg$0 = 0;$storemerge3 = $storemerge;
     break L7;
    }
    $13 = (($storemerge) + 1)|0;
    $$phi$trans$insert = (($4) + ($13)|0);
    $$pre = HEAP8[$$phi$trans$insert>>0]|0;
    $23 = $$pre;$storemerge = $13;
   }
  }
 } while(0);
 HEAP32[$end>>2] = $storemerge3;
 $14 = (($4) + ($storemerge3)|0);
 HEAP8[$14>>0] = 0;
 $15 = (_strlen(($4|0))|0);
 $16 = $15 << 1;
 $17 = $16 | 1;
 $18 = (_xmalloc($17)|0);
 HEAP32[32176>>2] = $18;
 $19 = (($4) + ($beg$0)|0);
 (_rl_translate_keyseq($19,$18,$end)|0);
 $20 = HEAP32[$end>>2]|0;
 $21 = HEAP32[32176>>2]|0;
 $22 = (($21) + ($20)|0);
 HEAP8[$22>>0] = 0;
 _xfree($4);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function _sv_keymap($value) {
 $value = $value|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_get_keymap_by_name($value)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 1;
  return ($$0|0);
 }
 HEAP32[13432>>2] = $0;
 $$0 = 0;
 return ($$0|0);
}
function _sv_seqtimeout($value) {
 $value = $value|0;
 var $$ = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $nval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($value|0)==(0|0);
 if ($0) {
  $nval$0 = 0;
 } else {
  $1 = HEAP8[$value>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $nval$0 = 0;
  } else {
   $3 = (_atoi($value)|0);
   $4 = ($3|0)<(0);
   $$ = $4 ? 0 : $3;
   $nval$0 = $$;
  }
 }
 HEAP32[13672>>2] = $nval$0;
 return 0;
}
function _parser_if($args) {
 $args = $args|0;
 var $$ = 0, $$lcssa7 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $mode$0 = 0, $not$ = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32064>>2]|0;
 $1 = (($0) + 1)|0;
 $2 = HEAP32[32152>>2]|0;
 $3 = ($1|0)<($2|0);
 $$pre = HEAP32[32072>>2]|0;
 do {
  if ($3) {
   $12 = $$pre;
  } else {
   $4 = ($$pre|0)==(0|0);
   if ($4) {
    HEAP32[32152>>2] = 20;
    $5 = (_xmalloc(20)|0);
    HEAP32[32072>>2] = $5;
    $12 = $5;
    break;
   } else {
    $6 = (($2) + 20)|0;
    HEAP32[32152>>2] = $6;
    $7 = (_xrealloc($$pre,$6)|0);
    HEAP32[32072>>2] = $7;
    $12 = $7;
    break;
   }
  }
 } while(0);
 $8 = HEAP8[13680>>0]|0;
 $9 = HEAP32[32064>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[32064>>2] = $10;
 $11 = (($12) + ($9)|0);
 HEAP8[$11>>0] = $8;
 $13 = HEAP8[13680>>0]|0;
 $14 = ($13<<24>>24)==(0);
 if ($14) {
  $i$0 = 0;
 } else {
  return 0;
 }
 while(1) {
  $15 = (($args) + ($i$0)|0);
  $16 = HEAP8[$15>>0]|0;
  if ((($16<<24>>24) == 0)) {
   break;
  } else if ((($16<<24>>24) == 32) | (($16<<24>>24) == 9)) {
   $$lcssa7 = $15;
   label = 8;
   break;
  }
  $17 = (($i$0) + 1)|0;
  $i$0 = $17;
 }
 if ((label|0) == 8) {
  HEAP8[$$lcssa7>>0] = 0;
 }
 $18 = HEAP32[13592>>2]|0;
 $19 = ($18|0)==(0|0);
 if (!($19)) {
  $20 = (_strncasecmp($args,32160,5)|0);
  $21 = ($20|0)==(0);
  if ($21) {
   $22 = (_strlen(($18|0))|0);
   $23 = (($22) + 1)|0;
   $24 = (_xmalloc($23)|0);
   $25 = HEAP32[13592>>2]|0;
   $26 = (_strcpy(($24|0),($25|0))|0);
   $27 = (_strchr($26,45)|0);
   $28 = ($27|0)==(0|0);
   if (!($28)) {
    HEAP8[$27>>0] = 0;
   }
   $29 = ((($args)) + 5|0);
   $30 = (_strcasecmp($29,$26)|0);
   $31 = ($30|0)==(0);
   if ($31) {
    $35 = 0;
   } else {
    $32 = HEAP32[13592>>2]|0;
    $33 = (_strcasecmp($29,$32)|0);
    $34 = ($33|0)!=(0);
    $phitmp = $34&1;
    $35 = $phitmp;
   }
   HEAP8[13680>>0] = $35;
   _xfree($26);
   return 0;
  }
 }
 $36 = (_strncasecmp($args,32168,5)|0);
 $37 = ($36|0)==(0);
 if ($37) {
  $38 = ((($args)) + 5|0);
  $39 = (_strcasecmp($38,30760)|0);
  $40 = ($39|0)==(0);
  if ($40) {
   $mode$0 = 1;
  } else {
   $41 = (_strcasecmp($38,30888)|0);
   $not$ = ($41|0)!=(0);
   $$ = $not$ << 31 >> 31;
   $mode$0 = $$;
  }
  $42 = HEAP32[13440>>2]|0;
  $43 = ($mode$0|0)!=($42|0);
  $44 = $43&1;
  HEAP8[13680>>0] = $44;
  return 0;
 }
 $45 = HEAP32[29640>>2]|0;
 $46 = (_strcasecmp($args,$45)|0);
 $47 = ($46|0)==(0);
 if ($47) {
  HEAP8[13680>>0] = 0;
  return 0;
 } else {
  HEAP8[13680>>0] = 1;
  return 0;
 }
 return (0)|0;
}
function _parser_endif($args) {
 $args = $args|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0, $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[32064>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (($0) + -1)|0;
  HEAP32[32064>>2] = $2;
  $3 = HEAP32[32072>>2]|0;
  $4 = (($3) + ($2)|0);
  $5 = HEAP8[$4>>0]|0;
  HEAP8[13680>>0] = $5;
  STACKTOP = sp;return 0;
 }
 $6 = HEAP32[29848>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  HEAP32[$vararg_buffer3>>2] = 32120;
  __rl_errmsg(34480,$vararg_buffer3);
  STACKTOP = sp;return 0;
 } else {
  $8 = HEAP32[29760>>2]|0;
  $9 = HEAP32[29768>>2]|0;
  HEAP32[$vararg_buffer>>2] = $8;
  $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
  HEAP32[$vararg_ptr1>>2] = $9;
  $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
  HEAP32[$vararg_ptr2>>2] = 32120;
  __rl_errmsg(29776,$vararg_buffer);
  STACKTOP = sp;return 0;
 }
 return (0)|0;
}
function _parser_else($args) {
 $args = $args|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, $vararg_buffer = 0, $vararg_buffer3 = 0, $vararg_ptr1 = 0;
 var $vararg_ptr2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer3 = sp + 16|0;
 $vararg_buffer = sp;
 $0 = HEAP32[32064>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $4 = HEAP32[29848>>2]|0;
  $5 = ($4|0)==(0);
  if ($5) {
   HEAP32[$vararg_buffer3>>2] = 32080;
   __rl_errmsg(34480,$vararg_buffer3);
   STACKTOP = sp;return 0;
  } else {
   $6 = HEAP32[29760>>2]|0;
   $7 = HEAP32[29768>>2]|0;
   HEAP32[$vararg_buffer>>2] = $6;
   $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
   HEAP32[$vararg_ptr1>>2] = $7;
   $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
   HEAP32[$vararg_ptr2>>2] = 32080;
   __rl_errmsg(29776,$vararg_buffer);
   STACKTOP = sp;return 0;
  }
 }
 $2 = ($0|0)>(0);
 L9: do {
  if ($2) {
   $3 = HEAP32[32072>>2]|0;
   $i$01 = 0;
   while(1) {
    $10 = (($3) + ($i$01)|0);
    $11 = HEAP8[$10>>0]|0;
    $12 = ($11<<24>>24)==(1);
    $9 = (($i$01) + 1)|0;
    if ($12) {
     break;
    }
    $8 = ($9|0)<($0|0);
    if ($8) {
     $i$01 = $9;
    } else {
     break L9;
    }
   }
   STACKTOP = sp;return 0;
  }
 } while(0);
 $13 = HEAP8[13680>>0]|0;
 $14 = ($13<<24>>24)==(0);
 $15 = $14&1;
 HEAP8[13680>>0] = $15;
 STACKTOP = sp;return 0;
}
function _parser_include($args) {
 $args = $args|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[13680>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = HEAP32[29760>>2]|0;
 $3 = HEAP32[29768>>2]|0;
 $4 = HEAP32[32056>>2]|0;
 $5 = (_strchr($args,10)|0);
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  HEAP8[$5>>0] = 0;
 }
 $7 = (($4) + 1)|0;
 $8 = (__rl_read_init_file($args,$7)|0);
 HEAP32[29760>>2] = $2;
 HEAP32[29768>>2] = $3;
 HEAP32[32056>>2] = $4;
 $$0 = $8;
 return ($$0|0);
}
function __rl_scxt_alloc($type,$flags) {
 $type = $type|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(132)|0);
 HEAP32[$0>>2] = $type;
 $1 = ((($0)) + 4|0);
 HEAP32[$1>>2] = $flags;
 $2 = ((($0)) + 8|0);
 ;HEAP32[$2>>2]=0|0;HEAP32[$2+4>>2]=0|0;HEAP32[$2+8>>2]=0|0;HEAP32[$2+12>>2]=0|0;HEAP32[$2+16>>2]=0|0;HEAP32[$2+20>>2]=0|0;HEAP32[$2+24>>2]=0|0;
 $3 = HEAP32[13784>>2]|0;
 $4 = ((($0)) + 36|0);
 HEAP32[$4>>2] = $3;
 $5 = HEAP32[13952>>2]|0;
 $6 = ((($0)) + 40|0);
 HEAP32[$6>>2] = $5;
 $7 = (_where_history()|0);
 $8 = ((($0)) + 44|0);
 HEAP32[$8>>2] = $7;
 $9 = ((($0)) + 48|0);
 HEAP32[$9>>2] = $7;
 $10 = ((($0)) + 52|0);
 HEAP32[$10>>2] = 0;
 $11 = ((($0)) + 56|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[3358]|0;
 $13 = ((($0)) + 60|0);
 HEAP32[$13>>2] = $12;
 $14 = HEAP32[3358]|0;
 $15 = ((($0)) + 64|0);
 HEAP32[$15>>2] = $14;
 $16 = ((($0)) + 68|0);
 $17 = ((($0)) + 116|0);
 ;HEAP32[$16>>2]=0|0;HEAP32[$16+4>>2]=0|0;HEAP32[$16+8>>2]=0|0;HEAP32[$16+12>>2]=0|0;
 ;HEAP32[$17>>2]=0|0;HEAP32[$17+4>>2]=0|0;HEAP32[$17+8>>2]=0|0;HEAP32[$17+12>>2]=0|0;
 return ($0|0);
}
function __rl_scxt_dispose($cxt,$flags) {
 $cxt = $cxt|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($cxt)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  _free($1);
 }
 $3 = ((($cxt)) + 24|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _free($4);
 }
 $6 = ((($cxt)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if ($8) {
  _xfree($cxt);
  return;
 }
 _free($7);
 _xfree($cxt);
 return;
}
function _rl_reverse_search_history($sign,$key) {
 $sign = $sign|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (0 - ($sign))|0;
 $1 = (_rl_search_history($0)|0);
 return ($1|0);
}
function _rl_forward_search_history($sign,$key) {
 $sign = $sign|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_search_history($sign)|0);
 return ($0|0);
}
function __rl_search_getchar($cxt) {
 $cxt = $cxt|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 $2 = (_rl_read_key()|0);
 $3 = ((($cxt)) + 80|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[13488>>2]|0;
 $5 = $4 & -65;
 HEAP32[13488>>2] = $5;
 $6 = HEAP32[36240>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  $8 = HEAP32[$3>>2]|0;
  $9 = ((($cxt)) + 84|0);
  $10 = (__rl_read_mbstring($8,$9,16)|0);
  HEAP32[$3>>2] = $10;
  $c$0 = $10;
 } else {
  $c$0 = $2;
 }
 $11 = HEAP32[32656>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  return ($c$0|0);
 }
 $13 = HEAP32[32656>>2]|0;
 __rl_signal_handler($13);
 return ($c$0|0);
}
function __rl_isearch_dispatch($cxt,$c) {
 $cxt = $cxt|0;
 $c = $c|0;
 var $$ = 0, $$0 = 0, $$lcssa = 0, $$old = 0, $$phi$trans$insert = 0, $$phi$trans$insert60 = 0, $$phi$trans$insert65 = 0, $$pr32 = 0, $$pr3286 = 0, $$pr3287 = 0, $$pre = 0, $$pre$phi73Z2D = 0, $$pre$phi84Z2D = 0, $$pre$phi85Z2D = 0, $$pre$phiZ2D = 0, $$pre59 = 0, $$pre61 = 0, $$pre62 = 0, $$pre63 = 0, $$pre66 = 0;
 var $$pre67 = 0, $$pre68 = 0, $$pre69 = 0, $$pre70 = 0, $$pre71 = 0, $$pre75 = 0, $$sink = 0, $$sink42 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0;
 var $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0;
 var $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0;
 var $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0;
 var $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0;
 var $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0;
 var $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0;
 var $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0;
 var $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0;
 var $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0;
 var $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0;
 var $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0;
 var $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0;
 var $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0;
 var $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0;
 var $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0;
 var $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0;
 var $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0;
 var $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond57 = 0, $exitcond95 = 0, $f$0 = 0, $n$0$be = 0, $n$0$lcssa = 0;
 var $n$0$ph = 0, $n$047 = 0, $n$153 = 0, $or$cond = 0, $or$cond11 = 0, $or$cond16 = 0, $or$cond19 = 0, $or$cond22 = 0, $or$cond3 = 0, $or$cond34 = 0, $or$cond35 = 0, $or$cond36 = 0, $or$cond5 = 0, $or$cond7 = 0, $or$cond92 = 0, $wstart$045 = 0, dest = 0, label = 0, sp = 0, src = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = ($c|0)<(0);
 if ($0) {
  $1 = ((($cxt)) + 4|0);
  $2 = HEAP32[$1>>2]|0;
  $3 = $2 | 4;
  HEAP32[$1>>2] = $3;
  $4 = ((($cxt)) + 48|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ((($cxt)) + 68|0);
  HEAP32[$6>>2] = $5;
  $$0 = -1;
  return ($$0|0);
 }
 $7 = ((($cxt)) + 60|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = (($8) + ($c<<3)|0);
 $10 = HEAP8[$9>>0]|0;
 $11 = ($10<<24>>24)==(1);
 do {
  if ($11) {
   $12 = ((($cxt)) + 128|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ((($cxt)) + 80|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = (_strchr($13,$15)|0);
   $17 = ($16|0)==(0|0);
   if ($17) {
    $18 = HEAP32[13672>>2]|0;
    $19 = ($18|0)>(0);
    if ($19) {
     $20 = HEAP32[13488>>2]|0;
     $21 = $20 & 655360;
     $22 = ($21|0)==(0);
     if ($22) {
      $23 = (__rl_pushed_input_available()|0);
      $24 = ($23|0)==(0);
      if ($24) {
       $25 = HEAP32[$7>>2]|0;
       $26 = (((($25) + ($c<<3)|0)) + 4|0);
       $27 = HEAP32[$26>>2]|0;
       $28 = ((($27)) + 2052|0);
       $29 = HEAP32[$28>>2]|0;
       $30 = ($29|0)==(0|0);
       if (!($30)) {
        $31 = HEAP32[13672>>2]|0;
        $32 = ($31*1000)|0;
        $33 = (__rl_input_queued($32)|0);
        $34 = ($33|0)==(0);
        if ($34) {
         $$pre = HEAP32[$7>>2]|0;
         $$phi$trans$insert = (($$pre) + ($c<<3)|0);
         $$pre59 = HEAP8[$$phi$trans$insert>>0]|0;
         $55 = $$pre59;$57 = $$pre;
         label = 15;
         break;
        }
       }
      }
     }
    }
    $35 = HEAP32[$7>>2]|0;
    $36 = ((($cxt)) + 64|0);
    HEAP32[$36>>2] = $35;
    $37 = $35;
    $38 = (((($37) + ($c<<3)|0)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$7>>2] = $39;
    $40 = ((($cxt)) + 4|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = $41 | 8;
    HEAP32[$40>>2] = $42;
    $43 = ((($cxt)) + 76|0);
    HEAP32[$43>>2] = $c;
    $44 = HEAP32[36240>>2]|0;
    $45 = ($44|0)==(0);
    if (!($45)) {
     $$0 = 1;
     return ($$0|0);
    }
    $46 = ((($cxt)) + 85|0);
    $47 = HEAP8[$46>>0]|0;
    $48 = ($47<<24>>24)==(0);
    if ($48) {
     $49 = $c&255;
     $50 = ((($cxt)) + 100|0);
     HEAP8[$50>>0] = $49;
     $51 = ((($cxt)) + 101|0);
     HEAP8[$51>>0] = 0;
     $$0 = 1;
     return ($$0|0);
    } else {
     $52 = ((($cxt)) + 100|0);
     $53 = ((($cxt)) + 84|0);
     dest=$52; src=$53; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
     $$0 = 1;
     return ($$0|0);
    }
   } else {
    $f$0 = 0;
   }
  } else {
   $55 = $10;$57 = $8;
   label = 15;
  }
 } while(0);
 do {
  if ((label|0) == 15) {
   $54 = ($55<<24>>24)==(0);
   if ($54) {
    $56 = (((($57) + ($c<<3)|0)) + 4|0);
    $58 = HEAP32[$56>>2]|0;
    $59 = ($58|0)==(213|0);
    if ($59) {
     $60 = ((($cxt)) + 4|0);
     $61 = HEAP32[$60>>2]|0;
     $62 = $61 | -2;
     $63 = ((($cxt)) + 80|0);
     HEAP32[$63>>2] = $62;
     $f$0 = 213;
     break;
    }
    $64 = ($58|0)==(186|0);
    if ($64) {
     $65 = ((($cxt)) + 4|0);
     $66 = HEAP32[$65>>2]|0;
     $67 = $66 | -2;
     $68 = $67 ^ 1;
     $69 = ((($cxt)) + 80|0);
     HEAP32[$69>>2] = $68;
     $f$0 = 186;
     break;
    }
    $70 = ($58|0)==(154|0);
    if ($70) {
     $71 = ((($cxt)) + 80|0);
     HEAP32[$71>>2] = -3;
     $f$0 = 154;
     break;
    }
    $72 = ($c|0)==(7);
    $73 = ($58|0)==(149|0);
    $or$cond = $72 | $73;
    if ($or$cond) {
     $74 = ((($cxt)) + 80|0);
     HEAP32[$74>>2] = -4;
     $f$0 = $58;
     break;
    }
    $75 = ($c|0)==(23);
    $76 = ($58|0)==(228|0);
    $or$cond3 = $75 | $76;
    if ($or$cond3) {
     $77 = ((($cxt)) + 80|0);
     HEAP32[$77>>2] = -5;
     $f$0 = $58;
     break;
    }
    $78 = ($c|0)==(25);
    $79 = ($58|0)==(230|0);
    $or$cond5 = $78 | $79;
    if ($or$cond5) {
     $80 = ((($cxt)) + 80|0);
     HEAP32[$80>>2] = -6;
     $f$0 = $58;
    } else {
     $f$0 = $58;
    }
   } else {
    $f$0 = 0;
   }
  }
 } while(0);
 $81 = ((($cxt)) + 4|0);
 $82 = HEAP32[$81>>2]|0;
 $83 = $82 & 8;
 $84 = ($83|0)==(0);
 do {
  if ($84) {
   $$phi$trans$insert60 = ((($cxt)) + 80|0);
   $$pre61 = HEAP32[$$phi$trans$insert60>>2]|0;
   $$pr32 = $$pre61;$$pre$phiZ2D = $$phi$trans$insert60;
   label = 45;
  } else {
   $85 = ((($cxt)) + 64|0);
   $86 = HEAP32[$85>>2]|0;
   HEAP32[$7>>2] = $86;
   $87 = $82 & -9;
   HEAP32[$81>>2] = $87;
   $88 = ((($cxt)) + 80|0);
   $89 = HEAP32[$88>>2]|0;
   $90 = ($89|0)>(0);
   $91 = $86;
   if ($90) {
    $92 = ((($cxt)) + 76|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)<(32);
    $95 = $93 & 128;
    $96 = ($95|0)==(0);
    $or$cond16 = $94 & $96;
    if ($or$cond16) {
     label = 33;
    } else {
     $97 = $93 & -128;
     $98 = ($97|0)==(128);
     $99 = ($93|0)==(127);
     $or$cond34 = $99 | $98;
     if ($or$cond34) {
      label = 33;
     } else {
      $102 = ($93|0)>(0);
      if (!($102)) {
       $$pr3286 = $89;$$pre$phi85Z2D = $88;
       label = 46;
       break;
      }
     }
    }
    if ((label|0) == 33) {
     $100 = ($93|0)==(7);
     if (!($100)) {
      (_rl_stuff_char($89)|0);
      $101 = HEAP32[$92>>2]|0;
      (_rl_execute_next($101)|0);
      $$0 = 0;
      return ($$0|0);
     }
    }
    $103 = (($91) + ($93<<3)|0);
    $104 = HEAP8[$103>>0]|0;
    $105 = ($104<<24>>24)==(1);
    if ($105) {
     $106 = ($f$0|0)==(0|0);
     $107 = ($f$0|0)==(215|0);
     $or$cond7 = $106 | $107;
     if ($or$cond7) {
      (_rl_execute_next($89)|0);
      $108 = HEAP32[$92>>2]|0;
      HEAP32[$88>>2] = $108;
      $109 = HEAP32[36240>>2]|0;
      $110 = ($109|0)==(0);
      do {
       if ($110) {
        $111 = ((($cxt)) + 101|0);
        $112 = HEAP8[$111>>0]|0;
        $113 = ($112<<24>>24)==(0);
        if ($113) {
         $114 = $108&255;
         $115 = ((($cxt)) + 84|0);
         HEAP8[$115>>0] = $114;
         $116 = ((($cxt)) + 85|0);
         HEAP8[$116>>0] = 0;
         break;
        } else {
         $117 = ((($cxt)) + 84|0);
         $118 = ((($cxt)) + 100|0);
         dest=$117; src=$118; stop=dest+16|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
         break;
        }
       }
      } while(0);
      HEAP32[$92>>2] = 0;
      $$pr32 = $108;$$pre$phiZ2D = $88;
      label = 45;
      break;
     }
    }
    $119 = ($f$0|0)!=(0|0);
    $120 = ($f$0|0)!=(215|0);
    $or$cond11 = $120 & $119;
    if ($or$cond11) {
     (_rl_stuff_char($89)|0);
     $121 = HEAP32[$92>>2]|0;
     (_rl_execute_next($121)|0);
     $$0 = 0;
     return ($$0|0);
    } else {
     $$pr32 = $89;$$pre$phiZ2D = $88;
     label = 45;
    }
   } else {
    $$pr3287 = $89;$$pre$phi84Z2D = $88;
   }
  }
 } while(0);
 if ((label|0) == 45) {
  $122 = ($$pr32|0)>(0);
  if ($122) {
   $$pr3286 = $$pr32;$$pre$phi85Z2D = $$pre$phiZ2D;
   label = 46;
  } else {
   $$pr3287 = $$pr32;$$pre$phi84Z2D = $$pre$phiZ2D;
  }
 }
 if ((label|0) == 46) {
  $123 = ((($cxt)) + 128|0);
  $124 = HEAP32[$123>>2]|0;
  $125 = (_strchr($124,$$pr3286)|0);
  $126 = ($125|0)==(0|0);
  if ($126) {
   $$pr3287 = $$pr3286;$$pre$phi84Z2D = $$pre$phi85Z2D;
  } else {
   $127 = ($$pr3286|0)==(27);
   if (!($127)) {
    $$0 = 0;
    return ($$0|0);
   }
   $128 = (__rl_pushed_input_available()|0);
   $129 = ($128|0)==(0);
   if ($129) {
    $130 = (__rl_input_available()|0);
    $131 = ($130|0)==(0);
    if ($131) {
     $$0 = 0;
     return ($$0|0);
    }
   }
   (_rl_execute_next(27)|0);
   $$0 = 0;
   return ($$0|0);
  }
 }
 $132 = HEAP32[36240>>2]|0;
 $133 = ($132|0)==(0);
 $134 = ($$pr3287|0)>(-1);
 do {
  if ($133) {
   if ($134) {
    $135 = ((($cxt)) + 84|0);
    $136 = HEAP8[$135>>0]|0;
    $137 = ($136<<24>>24)==(0);
    if ($137) {
     label = 64;
    } else {
     $138 = ((($cxt)) + 85|0);
     $139 = HEAP8[$138>>0]|0;
     $140 = ($139<<24>>24)==(0);
     if ($140) {
      $141 = ($$pr3287|0)<(32);
      $142 = $$pr3287 & 128;
      $143 = ($142|0)==(0);
      $or$cond19 = $141 & $143;
      if (!($or$cond19)) {
       $144 = $$pr3287 & -128;
       $145 = ($144|0)==(128);
       $146 = ($$pr3287|0)==(127);
       $or$cond35 = $146 | $145;
       if (!($or$cond35)) {
        label = 64;
        break;
       }
      }
      $147 = ($$pr3287|0)==(7);
      if ($147) {
       label = 105;
      } else {
       (_rl_execute_next($$pr3287)|0);
       $$0 = 0;
       return ($$0|0);
      }
     } else {
      label = 64;
     }
    }
   } else {
    label = 64;
   }
  } else {
   if ($134) {
    $148 = ($$pr3287|0)<(32);
    $149 = $$pr3287 & 128;
    $150 = ($149|0)==(0);
    $or$cond22 = $148 & $150;
    if (!($or$cond22)) {
     $151 = $$pr3287 & -128;
     $152 = ($151|0)==(128);
     $153 = ($$pr3287|0)==(127);
     $or$cond36 = $153 | $152;
     if (!($or$cond36)) {
      label = 64;
      break;
     }
    }
    $154 = ($$pr3287|0)==(7);
    if ($154) {
     label = 105;
    } else {
     (_rl_execute_next($$pr3287)|0);
     $$0 = 0;
     return ($$0|0);
    }
   } else {
    label = 64;
   }
  }
 } while(0);
 L98: do {
  if ((label|0) == 64) {
   switch ($$pr3287|0) {
   case -4:  {
    $194 = ((($cxt)) + 44|0);
    $195 = HEAP32[$194>>2]|0;
    $196 = ((($cxt)) + 20|0);
    $197 = HEAP32[$196>>2]|0;
    $198 = (($197) + ($195<<2)|0);
    $199 = HEAP32[$198>>2]|0;
    _rl_replace_line($199,0);
    $200 = ((($cxt)) + 36|0);
    $201 = HEAP32[$200>>2]|0;
    HEAP32[13784>>2] = $201;
    $202 = ((($cxt)) + 40|0);
    $203 = HEAP32[$202>>2]|0;
    HEAP32[13952>>2] = $203;
    _rl_restore_prompt();
    (_rl_clear_message()|0);
    $$0 = -1;
    return ($$0|0);
    break;
   }
   case -6:  {
    $256 = HEAP32[13784>>2]|0;
    $257 = ((($cxt)) + 12|0);
    $258 = HEAP32[$257>>2]|0;
    $259 = (($258) + ($256))|0;
    $260 = HEAP32[13768>>2]|0;
    $261 = ($260|0)>($259|0);
    if (!($261)) {
     (_rl_ding()|0);
     break L98;
    }
    $262 = (($260) - ($259))|0;
    $263 = (($258) + 2)|0;
    $264 = (($263) + ($262))|0;
    $265 = ((($cxt)) + 16|0);
    $266 = HEAP32[$265>>2]|0;
    $267 = ($264|0)<($266|0);
    if ($267) {
     $274 = $260;
    } else {
     $268 = (($262) + 2)|0;
     $269 = (($268) + ($266))|0;
     HEAP32[$265>>2] = $269;
     $270 = ((($cxt)) + 8|0);
     $271 = HEAP32[$270>>2]|0;
     $272 = (_xrealloc($271,$269)|0);
     HEAP32[$270>>2] = $272;
     $$pre62 = HEAP32[13768>>2]|0;
     $274 = $$pre62;
    }
    $273 = ($259|0)<($274|0);
    $275 = ((($cxt)) + 8|0);
    if ($273) {
     $n$153 = $259;
     while(1) {
      $276 = HEAP32[13632>>2]|0;
      $277 = (($276) + ($n$153)|0);
      $278 = HEAP8[$277>>0]|0;
      $279 = HEAP32[$257>>2]|0;
      $280 = (($279) + 1)|0;
      HEAP32[$257>>2] = $280;
      $281 = HEAP32[$275>>2]|0;
      $282 = (($281) + ($279)|0);
      HEAP8[$282>>0] = $278;
      $283 = (($n$153) + 1)|0;
      $284 = HEAP32[13768>>2]|0;
      $285 = ($283|0)<($284|0);
      if ($285) {
       $n$153 = $283;
      } else {
       break;
      }
     }
    }
    $286 = HEAP32[$257>>2]|0;
    $287 = HEAP32[$275>>2]|0;
    $288 = (($287) + ($286)|0);
    HEAP8[$288>>0] = 0;
    break L98;
    break;
   }
   case -2:  {
    $180 = ((($cxt)) + 72|0);
    $181 = HEAP32[$180>>2]|0;
    $182 = (0 - ($181))|0;
    HEAP32[$180>>2] = $182;
    $183 = ($181|0)>(0);
    $184 = HEAP32[$81>>2]|0;
    if ($183) {
     $185 = $184 | 1;
     HEAP32[$81>>2] = $185;
     break L98;
    } else {
     $186 = $184 & -2;
     HEAP32[$81>>2] = $186;
     break L98;
    }
    break;
   }
   case -1:  {
    $155 = ((($cxt)) + 12|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($156|0)==(0);
    if ($157) {
     $158 = HEAP32[32192>>2]|0;
     $159 = ($158|0)==(0|0);
     if ($159) {
      $$0 = 1;
      return ($$0|0);
     } else {
      $160 = HEAP32[32200>>2]|0;
      $161 = (($160) + 64)|0;
      $162 = ((($cxt)) + 16|0);
      HEAP32[$162>>2] = $161;
      $163 = ((($cxt)) + 8|0);
      $164 = HEAP32[$163>>2]|0;
      $165 = (_xrealloc($164,$161)|0);
      HEAP32[$163>>2] = $165;
      $166 = HEAP32[32192>>2]|0;
      (_strcpy(($165|0),($166|0))|0);
      $167 = HEAP32[32200>>2]|0;
      HEAP32[$155>>2] = $167;
      $168 = HEAP32[$163>>2]|0;
      $169 = HEAP32[$81>>2]|0;
      _rl_display_search($168,$169);
      break L98;
     }
    }
    $170 = HEAP32[$81>>2]|0;
    $171 = $170 & 1;
    $172 = ($171|0)==(0);
    $173 = ((($cxt)) + 124|0);
    $174 = HEAP32[$173>>2]|0;
    if (!($172)) {
     $175 = (($174) + -1)|0;
     HEAP32[$173>>2] = $175;
     break L98;
    }
    $176 = ((($cxt)) + 120|0);
    $177 = HEAP32[$176>>2]|0;
    $178 = ($174|0)==($177|0);
    if ($178) {
     (_rl_ding()|0);
     break L98;
    } else {
     $179 = (($174) + 1)|0;
     HEAP32[$173>>2] = $179;
     break L98;
    }
    break;
   }
   case -3:  {
    $187 = ((($cxt)) + 12|0);
    $188 = HEAP32[$187>>2]|0;
    $189 = ($188|0)==(0);
    if ($189) {
     (_rl_ding()|0);
     break L98;
    } else {
     $190 = (($188) + -1)|0;
     HEAP32[$187>>2] = $190;
     $191 = ((($cxt)) + 8|0);
     $192 = HEAP32[$191>>2]|0;
     $193 = (($192) + ($190)|0);
     HEAP8[$193>>0] = 0;
     break L98;
    }
    break;
   }
   case -5:  {
    $204 = HEAP32[13784>>2]|0;
    $205 = ((($cxt)) + 12|0);
    $206 = HEAP32[$205>>2]|0;
    $207 = (($206) + ($204))|0;
    $208 = HEAP32[13768>>2]|0;
    $209 = ($207|0)<($208|0);
    if (!($209)) {
     (_rl_ding()|0);
     break L98;
    }
    $210 = HEAP32[13632>>2]|0;
    $211 = (__rl_char_value($210,$207)|0);
    $212 = (__rl_walphabetic($211)|0);
    $213 = ($212|0)==(0);
    if ($213) {
     (_rl_ding()|0);
     break L98;
    }
    $214 = HEAP32[36240>>2]|0;
    $215 = ($214|0)==(0);
    if ($215) {
     $216 = HEAP32[13632>>2]|0;
     $217 = (__rl_find_next_mbchar($216,$207,1,1)|0);
     $n$0$ph = $217;
    } else {
     $218 = (($207) + 1)|0;
     $n$0$ph = $218;
    }
    $219 = HEAP32[13768>>2]|0;
    $220 = ($n$0$ph|0)<($219|0);
    L146: do {
     if ($220) {
      $n$047 = $n$0$ph;
      while(1) {
       $221 = HEAP32[13632>>2]|0;
       $222 = (__rl_char_value($221,$n$047)|0);
       $223 = (__rl_walphabetic($222)|0);
       $224 = ($223|0)==(0);
       if ($224) {
        $n$0$lcssa = $n$047;
        break L146;
       }
       $225 = HEAP32[36240>>2]|0;
       $226 = ($225|0)==(0);
       if ($226) {
        $227 = HEAP32[13632>>2]|0;
        $228 = (__rl_find_next_mbchar($227,$n$047,1,1)|0);
        $n$0$be = $228;
       } else {
        $229 = (($n$047) + 1)|0;
        $n$0$be = $229;
       }
       $230 = HEAP32[13768>>2]|0;
       $231 = ($n$0$be|0)<($230|0);
       if ($231) {
        $n$047 = $n$0$be;
       } else {
        $n$0$lcssa = $n$0$be;
        break;
       }
      }
     } else {
      $n$0$lcssa = $n$0$ph;
     }
    } while(0);
    $232 = (($n$0$lcssa) - ($207))|0;
    $233 = HEAP32[$205>>2]|0;
    $234 = (($232) + 2)|0;
    $235 = (($234) + ($233))|0;
    $236 = ((($cxt)) + 16|0);
    $237 = HEAP32[$236>>2]|0;
    $238 = ($235|0)<($237|0);
    if (!($238)) {
     $239 = (($234) + ($237))|0;
     HEAP32[$236>>2] = $239;
     $240 = ((($cxt)) + 8|0);
     $241 = HEAP32[$240>>2]|0;
     $242 = (_xrealloc($241,$239)|0);
     HEAP32[$240>>2] = $242;
    }
    $243 = ($n$0$lcssa|0)>($207|0);
    $244 = ((($cxt)) + 8|0);
    if ($243) {
     $wstart$045 = $207;
     while(1) {
      $245 = HEAP32[13632>>2]|0;
      $246 = (($245) + ($wstart$045)|0);
      $247 = HEAP8[$246>>0]|0;
      $248 = HEAP32[$205>>2]|0;
      $249 = (($248) + 1)|0;
      HEAP32[$205>>2] = $249;
      $250 = HEAP32[$244>>2]|0;
      $251 = (($250) + ($248)|0);
      HEAP8[$251>>0] = $247;
      $252 = (($wstart$045) + 1)|0;
      $exitcond57 = ($252|0)==($n$0$lcssa|0);
      if ($exitcond57) {
       break;
      } else {
       $wstart$045 = $252;
      }
     }
    }
    $253 = HEAP32[$205>>2]|0;
    $254 = HEAP32[$244>>2]|0;
    $255 = (($254) + ($253)|0);
    HEAP8[$255>>0] = 0;
    break L98;
    break;
   }
   default: {
    label = 105;
    break L98;
   }
   }
  }
 } while(0);
 if ((label|0) == 105) {
  $289 = ((($cxt)) + 12|0);
  $290 = HEAP32[$289>>2]|0;
  $291 = (($290) + 2)|0;
  $292 = ((($cxt)) + 16|0);
  $293 = HEAP32[$292>>2]|0;
  $294 = ($291|0)<($293|0);
  if ($294) {
   $300 = $132;
  } else {
   $295 = (($293) + 128)|0;
   HEAP32[$292>>2] = $295;
   $296 = ((($cxt)) + 8|0);
   $297 = HEAP32[$296>>2]|0;
   $298 = (_xrealloc($297,$295)|0);
   HEAP32[$296>>2] = $298;
   $$pre63 = HEAP32[36240>>2]|0;
   $300 = $$pre63;
  }
  $299 = ($300|0)==(0);
  L167: do {
   if ($299) {
    $301 = ((($cxt)) + 84|0);
    $302 = HEAP8[$301>>0]|0;
    $303 = ($302<<24>>24)==(0);
    if (!($303)) {
     $304 = ((($cxt)) + 85|0);
     $305 = HEAP8[$304>>0]|0;
     $306 = ($305<<24>>24)==(0);
     if (!($306)) {
      $312 = ((($cxt)) + 86|0);
      $313 = HEAP8[$312>>0]|0;
      $314 = ($313<<24>>24)==(0);
      if ($314) {
       $322 = 2;
      } else {
       $315 = (_strlen(($301|0))|0);
       $316 = ($315|0)>(0);
       if ($316) {
        $322 = $315;
       } else {
        $$pre75 = ((($cxt)) + 8|0);
        $$pre$phi73Z2D = $$pre75;
        break;
       }
      }
      $317 = ((($cxt)) + 8|0);
      $318 = HEAP32[$289>>2]|0;
      $319 = (($318) + 1)|0;
      HEAP32[$289>>2] = $319;
      $320 = HEAP32[$317>>2]|0;
      $321 = (($320) + ($318)|0);
      HEAP8[$321>>0] = $302;
      $exitcond95 = ($322|0)==(1);
      if ($exitcond95) {
       $$pre$phi73Z2D = $317;
       break;
      } else {
       $323 = 1;
      }
      while(1) {
       $$phi$trans$insert65 = (((($cxt)) + 84|0) + ($323)|0);
       $$pre66 = HEAP8[$$phi$trans$insert65>>0]|0;
       $324 = (($323) + 1)|0;
       $325 = HEAP32[$289>>2]|0;
       $326 = (($325) + 1)|0;
       HEAP32[$289>>2] = $326;
       $327 = HEAP32[$317>>2]|0;
       $328 = (($327) + ($325)|0);
       HEAP8[$328>>0] = $$pre66;
       $exitcond = ($324|0)==($322|0);
       if ($exitcond) {
        $$pre$phi73Z2D = $317;
        break L167;
       } else {
        $323 = $324;
       }
      }
     }
    }
    $307 = HEAP32[$289>>2]|0;
    $308 = (($307) + 1)|0;
    HEAP32[$289>>2] = $308;
    $309 = ((($cxt)) + 8|0);
    $310 = HEAP32[$309>>2]|0;
    $311 = (($310) + ($307)|0);
    HEAP8[$311>>0] = $302;
    $$pre$phi73Z2D = $309;
   } else {
    $329 = HEAP32[$$pre$phi84Z2D>>2]|0;
    $330 = $329&255;
    $331 = HEAP32[$289>>2]|0;
    $332 = (($331) + 1)|0;
    HEAP32[$289>>2] = $332;
    $333 = ((($cxt)) + 8|0);
    $334 = HEAP32[$333>>2]|0;
    $335 = (($334) + ($331)|0);
    HEAP8[$335>>0] = $330;
    $$pre$phi73Z2D = $333;
   }
  } while(0);
  $336 = HEAP32[$289>>2]|0;
  $337 = HEAP32[$$pre$phi73Z2D>>2]|0;
  $338 = (($337) + ($336)|0);
  HEAP8[$338>>0] = 0;
 }
 $339 = HEAP32[$81>>2]|0;
 $340 = $339 & -7;
 HEAP32[$81>>2] = $340;
 $341 = ((($cxt)) + 120|0);
 $342 = ((($cxt)) + 12|0);
 $343 = ((($cxt)) + 124|0);
 $344 = ((($cxt)) + 72|0);
 $345 = ((($cxt)) + 68|0);
 $346 = ((($cxt)) + 28|0);
 $347 = ((($cxt)) + 20|0);
 $348 = ((($cxt)) + 116|0);
 $349 = ((($cxt)) + 52|0);
 $350 = ((($cxt)) + 8|0);
 $$pre67 = HEAP32[$341>>2]|0;
 $$pre68 = HEAP32[$342>>2]|0;
 $$pre69 = HEAP32[$343>>2]|0;
 $351 = ($$pre68|0)==(0);
 $353 = $$pre67;$356 = $340;$359 = $$pre69;
 while(1) {
  $352 = (($353) + 1)|0;
  $354 = (($352) - ($$pre68))|0;
  $355 = $356 & 1;
  $357 = ($355|0)!=(0);
  $358 = ($359|0)>(-1);
  $360 = ($359|0)<($354|0);
  $$sink42 = $357 ? $358 : $360;
  L184: do {
   if ($$sink42) {
    $365 = $359;
    while(1) {
     if ($351) {
      break;
     }
     $361 = HEAP32[$350>>2]|0;
     $362 = HEAP8[$361>>0]|0;
     $363 = HEAP32[$348>>2]|0;
     $364 = (($363) + ($365)|0);
     $366 = HEAP8[$364>>0]|0;
     $367 = ($362<<24>>24)==($366<<24>>24);
     if ($367) {
      $368 = (_strncmp($361,$364,$$pre68)|0);
      $369 = ($368|0)==(0);
      if ($369) {
       break;
      }
     }
     $371 = HEAP32[$344>>2]|0;
     $372 = (($365) + ($371))|0;
     HEAP32[$343>>2] = $372;
     $373 = ($372|0)>(-1);
     $374 = ($372|0)<($354|0);
     $$sink = $357 ? $373 : $374;
     if ($$sink) {
      $365 = $372;
     } else {
      $376 = $356;
      break L184;
     }
    }
    $370 = $356 | 2;
    HEAP32[$81>>2] = $370;
    $376 = $370;
   } else {
    $376 = $356;
   }
  } while(0);
  $375 = $376 & 2;
  $377 = ($375|0)==(0);
  if (!($377)) {
   $407 = $376;
   break;
  }
  $$pre70 = HEAP32[$344>>2]|0;
  $$pre71 = HEAP32[$345>>2]|0;
  $378 = $376 & 1;
  $379 = ($378|0)==(0);
  $381 = $$pre71;$425 = $353;
  while(1) {
   $380 = (($381) + ($$pre70))|0;
   HEAP32[$345>>2] = $380;
   if ($379) {
    $383 = HEAP32[$346>>2]|0;
    $384 = ($380|0)==($383|0);
    if ($384) {
     $$lcssa = $425;
     label = 130;
     break;
    }
   } else {
    $382 = ($380|0)<(0);
    if ($382) {
     $$lcssa = $425;
     label = 130;
     break;
    }
   }
   $386 = HEAP32[$347>>2]|0;
   $387 = (($386) + ($380<<2)|0);
   $388 = HEAP32[$387>>2]|0;
   HEAP32[$348>>2] = $388;
   $389 = (_strlen(($388|0))|0);
   HEAP32[$341>>2] = $389;
   $390 = HEAP32[$349>>2]|0;
   $391 = ($390|0)==(0|0);
   if (!($391)) {
    $392 = HEAP8[$390>>0]|0;
    $393 = HEAP32[$387>>2]|0;
    $394 = HEAP8[$393>>0]|0;
    $395 = ($392<<24>>24)==($394<<24>>24);
    if ($395) {
     $396 = (_strcmp($390,$393)|0);
     $397 = ($396|0)==(0);
     $398 = ($$pre68|0)>($389|0);
     $or$cond92 = $397 | $398;
     if ($or$cond92) {
      $381 = $380;$425 = $389;
      continue;
     } else {
      $400 = $376;$405 = $389;
      break;
     }
    }
   }
   $$old = ($$pre68|0)>($389|0);
   if ($$old) {
    $381 = $380;$425 = $389;
   } else {
    $400 = $376;$405 = $389;
    break;
   }
  }
  if ((label|0) == 130) {
   label = 0;
   $385 = $376 | 4;
   HEAP32[$81>>2] = $385;
   $400 = $385;$405 = $$lcssa;
  }
  $399 = $400 & 4;
  $401 = ($399|0)==(0);
  if (!($401)) {
   $407 = $400;
   break;
  }
  $402 = $400 & 1;
  $403 = ($402|0)==(0);
  $404 = (($405) - ($$pre68))|0;
  $$ = $403 ? 0 : $404;
  HEAP32[$343>>2] = $$;
  $353 = $405;$356 = $400;$359 = $$;
 }
 $406 = $407 & 4;
 $408 = ($406|0)==(0);
 if (!($408)) {
  (_rl_ding()|0);
  $409 = ((($cxt)) + 48|0);
  $410 = HEAP32[$409>>2]|0;
  HEAP32[$345>>2] = $410;
  $411 = HEAP32[$350>>2]|0;
  $412 = HEAP32[$81>>2]|0;
  _rl_display_search($411,$412);
  $$0 = 1;
  return ($$0|0);
 }
 $413 = $407 & 2;
 $414 = ($413|0)==(0);
 if ($414) {
  $$0 = 1;
  return ($$0|0);
 }
 $415 = HEAP32[$345>>2]|0;
 $416 = HEAP32[$347>>2]|0;
 $417 = (($416) + ($415<<2)|0);
 $418 = HEAP32[$417>>2]|0;
 HEAP32[$349>>2] = $418;
 $419 = HEAP32[$417>>2]|0;
 _rl_replace_line($419,0);
 $420 = HEAP32[$343>>2]|0;
 HEAP32[13784>>2] = $420;
 $421 = HEAP32[$345>>2]|0;
 $422 = ((($cxt)) + 48|0);
 HEAP32[$422>>2] = $421;
 $423 = HEAP32[$350>>2]|0;
 $424 = HEAP32[$81>>2]|0;
 _rl_display_search($423,$424);
 $$0 = 1;
 return ($$0|0);
}
function _rl_search_history($direction) {
 $direction = $direction|0;
 var $$0 = 0, $$lcssa = 0, $$pre = 0, $$pre$i = 0, $$pre3$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0;
 var $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $i$0$i = 0, $i$1$i = 0, $i$2$lcssa$i = 0, $smax$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 128;
 HEAP32[13488>>2] = $1;
 $2 = (_xmalloc(132)|0);
 HEAP32[$2>>2] = 1;
 $3 = ((($2)) + 4|0);
 $4 = ((($2)) + 8|0);
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;HEAP32[$3+16>>2]=0|0;HEAP32[$3+20>>2]=0|0;HEAP32[$3+24>>2]=0|0;HEAP32[$3+28>>2]=0|0;
 $5 = HEAP32[13784>>2]|0;
 $6 = ((($2)) + 36|0);
 HEAP32[$6>>2] = $5;
 $7 = HEAP32[13952>>2]|0;
 $8 = ((($2)) + 40|0);
 HEAP32[$8>>2] = $7;
 $9 = (_where_history()|0);
 $10 = ((($2)) + 44|0);
 HEAP32[$10>>2] = $9;
 $11 = ((($2)) + 48|0);
 HEAP32[$11>>2] = $9;
 $12 = ((($2)) + 52|0);
 HEAP32[$12>>2] = 0;
 $13 = ((($2)) + 56|0);
 HEAP32[$13>>2] = 0;
 $14 = HEAP32[3358]|0;
 $15 = ((($2)) + 60|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[3358]|0;
 $17 = ((($2)) + 64|0);
 HEAP32[$17>>2] = $16;
 $18 = ((($2)) + 68|0);
 $19 = ((($2)) + 116|0);
 ;HEAP32[$18>>2]=0|0;HEAP32[$18+4>>2]=0|0;HEAP32[$18+8>>2]=0|0;HEAP32[$18+12>>2]=0|0;
 ;HEAP32[$19>>2]=0|0;HEAP32[$19+4>>2]=0|0;HEAP32[$19+8>>2]=0|0;HEAP32[$19+12>>2]=0|0;
 $20 = ($direction|0)<(0);
 if ($20) {
  $21 = HEAP32[$3>>2]|0;
  $22 = $21 | 1;
  HEAP32[$3>>2] = $22;
 }
 $23 = HEAP32[32176>>2]|0;
 $24 = ($23|0)!=(0|0);
 $25 = $24 ? $23 : 32240;
 $26 = ((($2)) + 128|0);
 HEAP32[$26>>2] = $25;
 $27 = (_history_list()|0);
 (_rl_maybe_replace_line()|0);
 $28 = ($27|0)==(0|0);
 if ($28) {
  $i$1$i = 0;
 } else {
  $i$0$i = 0;
  while(1) {
   $29 = (($27) + ($i$0$i<<2)|0);
   $30 = HEAP32[$29>>2]|0;
   $31 = ($30|0)==(0|0);
   $32 = (($i$0$i) + 1)|0;
   if ($31) {
    $i$1$i = $i$0$i;
    break;
   } else {
    $i$0$i = $32;
   }
  }
 }
 $33 = ((($2)) + 28|0);
 HEAP32[$33>>2] = $i$1$i;
 $34 = $i$1$i << 2;
 $35 = (($34) + 4)|0;
 $36 = (_xmalloc($35)|0);
 $37 = ((($2)) + 20|0);
 HEAP32[$37>>2] = $36;
 $38 = HEAP32[$33>>2]|0;
 $39 = ($38|0)>(0);
 if ($39) {
  $40 = ($38|0)>(1);
  $41 = HEAP32[$27>>2]|0;
  $42 = HEAP32[$41>>2]|0;
  HEAP32[$36>>2] = $42;
  if ($40) {
   $44 = 1;
   while(1) {
    $$pre$i = HEAP32[$37>>2]|0;
    $43 = (($27) + ($44<<2)|0);
    $45 = HEAP32[$43>>2]|0;
    $46 = HEAP32[$45>>2]|0;
    $47 = (($$pre$i) + ($44<<2)|0);
    HEAP32[$47>>2] = $46;
    $48 = (($44) + 1)|0;
    $exitcond = ($48|0)==($38|0);
    if ($exitcond) {
     break;
    } else {
     $44 = $48;
    }
   }
  }
  $smax$i = $40 ? $38 : 1;
  $i$2$lcssa$i = $smax$i;
 } else {
  $i$2$lcssa$i = 0;
 }
 $49 = HEAP32[36056>>2]|0;
 $50 = ($49|0)==(0|0);
 if ($50) {
  $54 = HEAP32[13632>>2]|0;
  $55 = (_strlen(($54|0))|0);
  $56 = (($55) + 1)|0;
  $57 = (_xmalloc($56)|0);
  $58 = ((($2)) + 24|0);
  HEAP32[$58>>2] = $57;
  $59 = HEAP32[13632>>2]|0;
  (_strcpy(($57|0),($59|0))|0);
  $60 = HEAP32[$58>>2]|0;
  $61 = HEAP32[$37>>2]|0;
  $62 = (($61) + ($i$2$lcssa$i<<2)|0);
  HEAP32[$62>>2] = $60;
  $$pre3$i = HEAP32[$33>>2]|0;
  $64 = $$pre3$i;
 } else {
  $51 = HEAP32[$49>>2]|0;
  $52 = HEAP32[$37>>2]|0;
  $53 = (($52) + ($i$2$lcssa$i<<2)|0);
  HEAP32[$53>>2] = $51;
  $64 = $38;
 }
 $63 = (($64) + 1)|0;
 HEAP32[$33>>2] = $63;
 $65 = HEAP32[$10>>2]|0;
 HEAP32[$18>>2] = $65;
 _rl_save_prompt();
 $66 = ((($2)) + 16|0);
 HEAP32[$66>>2] = 128;
 $67 = (_xmalloc(128)|0);
 HEAP32[$4>>2] = $67;
 $68 = ((($2)) + 12|0);
 HEAP32[$68>>2] = 0;
 HEAP8[$67>>0] = 0;
 $69 = $direction >> 31;
 $70 = $69 | 1;
 $71 = ((($2)) + 72|0);
 HEAP32[$71>>2] = $70;
 $72 = HEAP32[13632>>2]|0;
 HEAP32[$19>>2] = $72;
 $73 = (_strlen(($72|0))|0);
 $74 = ((($2)) + 120|0);
 HEAP32[$74>>2] = $73;
 $75 = HEAP32[13784>>2]|0;
 $76 = ((($2)) + 124|0);
 HEAP32[$76>>2] = $75;
 HEAP32[32184>>2] = $2;
 $77 = HEAP32[$4>>2]|0;
 $78 = HEAP32[$3>>2]|0;
 _rl_display_search($77,$78);
 $79 = HEAP32[13488>>2]|0;
 $80 = $79 & 524288;
 $81 = ($80|0)==(0);
 if (!($81)) {
  $$0 = 0;
  return ($$0|0);
 }
 $82 = ((($2)) + 80|0);
 $83 = ((($2)) + 84|0);
 $85 = $79;
 while(1) {
  $84 = $85 | 64;
  HEAP32[13488>>2] = $84;
  $86 = (_rl_read_key()|0);
  HEAP32[$82>>2] = $86;
  $87 = HEAP32[13488>>2]|0;
  $88 = $87 & -65;
  HEAP32[13488>>2] = $88;
  $89 = HEAP32[36240>>2]|0;
  $90 = ($89|0)==(0);
  if ($90) {
   $91 = HEAP32[$82>>2]|0;
   $92 = (__rl_read_mbstring($91,$83,16)|0);
   HEAP32[$82>>2] = $92;
  }
  $93 = HEAP32[32656>>2]|0;
  $94 = ($93|0)==(0);
  if (!($94)) {
   $95 = HEAP32[32656>>2]|0;
   __rl_signal_handler($95);
  }
  $96 = HEAP32[$82>>2]|0;
  $97 = (__rl_isearch_dispatch($2,$96)|0);
  $98 = ($97|0)<(1);
  if ($98) {
   $$lcssa = $97;
   break;
  }
  $$pre = HEAP32[13488>>2]|0;
  $85 = $$pre;
 }
 $99 = (__rl_isearch_cleanup($2,$$lcssa)|0);
 $$0 = $99;
 return ($$0|0);
}
function _rl_display_search($search_string,$flags) {
 $search_string = $search_string|0;
 $flags = $flags|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $msglen$0 = 0, $msglen$1 = 0, $msglen$2 = 0, $vararg_buffer = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = ($search_string|0)!=(0|0);
 if ($0) {
  $1 = HEAP8[$search_string>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $5 = 0;
  } else {
   $3 = (_strlen(($search_string|0))|0);
   $5 = $3;
  }
 } else {
  $5 = 0;
 }
 $4 = (($5) + 64)|0;
 $6 = (_xmalloc($4)|0);
 HEAP8[$6>>0] = 40;
 $7 = $flags & 4;
 $8 = ($7|0)==(0);
 if ($8) {
  $msglen$0 = 1;
 } else {
  $9 = ((($6)) + 1|0);
  $10 = $9;
  $11 = $10;
  HEAP8[$11>>0]=1818845542&255;HEAP8[$11+1>>0]=(1818845542>>8)&255;HEAP8[$11+2>>0]=(1818845542>>16)&255;HEAP8[$11+3>>0]=1818845542>>24;
  $12 = (($10) + 4)|0;
  $13 = $12;
  HEAP8[$13>>0]=2122853&255;HEAP8[$13+1>>0]=(2122853>>8)&255;HEAP8[$13+2>>0]=(2122853>>16)&255;HEAP8[$13+3>>0]=2122853>>24;
  $msglen$0 = 8;
 }
 $14 = $flags & 1;
 $15 = ($14|0)==(0);
 if ($15) {
  $msglen$1 = $msglen$0;
 } else {
  $16 = (($6) + ($msglen$0)|0);
  dest=$16; src=32208; stop=dest+9|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
  $17 = (($msglen$0) + 8)|0;
  $msglen$1 = $17;
 }
 $18 = (($6) + ($msglen$1)|0);
 dest=$18; src=32224; stop=dest+11|0; do { HEAP8[dest>>0]=HEAP8[src>>0]|0; dest=dest+1|0; src=src+1|0; } while ((dest|0) < (stop|0));
 $19 = (($msglen$1) + 10)|0;
 if ($0) {
  $20 = (($6) + ($19)|0);
  (_strcpy(($20|0),($search_string|0))|0);
  $21 = (($19) + ($5))|0;
  $msglen$2 = $21;
 } else {
  $msglen$2 = $19;
 }
 $22 = (($6) + ($msglen$2)|0);
 HEAP8[$22>>0]=2112039&255;HEAP8[$22+1>>0]=(2112039>>8)&255;HEAP8[$22+2>>0]=(2112039>>16)&255;HEAP8[$22+3>>0]=2112039>>24;
 HEAP32[$vararg_buffer>>2] = $6;
 (_rl_message(34480,$vararg_buffer)|0);
 _xfree($6);
 $23 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$23 & 511]();
 STACKTOP = sp;return;
}
function __rl_isearch_cleanup($cxt,$r) {
 $cxt = $cxt|0;
 $r = $r|0;
 var $$pre = 0, $$pre$i = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($r|0)>(-1);
 if ($0) {
  $1 = HEAP32[13632>>2]|0;
  $2 = ((($cxt)) + 44|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ((($cxt)) + 20|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = (($5) + ($3<<2)|0);
  $7 = HEAP32[$6>>2]|0;
  (_strcpy(($1|0),($7|0))|0);
  _rl_restore_prompt();
  $8 = HEAP32[32192>>2]|0;
  $9 = ($8|0)==(0|0);
  if (!($9)) {
   _free($8);
  }
  $10 = ((($cxt)) + 8|0);
  $11 = HEAP32[$10>>2]|0;
  HEAP32[32192>>2] = $11;
  $12 = ((($cxt)) + 12|0);
  $13 = HEAP32[$12>>2]|0;
  HEAP32[32200>>2] = $13;
  HEAP32[$10>>2] = 0;
  $14 = ((($cxt)) + 48|0);
  $15 = HEAP32[$14>>2]|0;
  $16 = HEAP32[$2>>2]|0;
  $17 = ($15|0)<($16|0);
  if ($17) {
   $18 = (($16) - ($15))|0;
   (_rl_get_previous_history($18,0)|0);
  } else {
   $19 = (($15) - ($16))|0;
   (_rl_get_next_history($19,0)|0);
  }
  $20 = ((($cxt)) + 124|0);
  $21 = HEAP32[$20>>2]|0;
  $22 = ($21|0)<(0);
  if ($22) {
   $23 = HEAP32[$14>>2]|0;
   $24 = HEAP32[$2>>2]|0;
   $25 = ($23|0)==($24|0);
   if ($25) {
    $26 = ((($cxt)) + 36|0);
    $27 = HEAP32[$26>>2]|0;
    $storemerge$i = $27;
   } else {
    $28 = HEAP32[13632>>2]|0;
    $29 = (_strlen(($28|0))|0);
    $storemerge$i = $29;
   }
   HEAP32[$20>>2] = $storemerge$i;
   $30 = ((($cxt)) + 40|0);
   $31 = HEAP32[$30>>2]|0;
   HEAP32[13952>>2] = $31;
   $$pre$i = HEAP32[$20>>2]|0;
   $32 = $$pre$i;
  } else {
   $32 = $21;
  }
  HEAP32[13784>>2] = $32;
  (_rl_clear_message()|0);
  $$pre$phiZ2D = $10;
 } else {
  $$pre = ((($cxt)) + 8|0);
  $$pre$phiZ2D = $$pre;
 }
 $33 = HEAP32[$$pre$phiZ2D>>2]|0;
 $34 = ($33|0)==(0|0);
 if (!($34)) {
  _free($33);
 }
 $35 = ((($cxt)) + 24|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ($36|0)==(0|0);
 if (!($37)) {
  _free($36);
 }
 $38 = ((($cxt)) + 20|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ($39|0)==(0|0);
 if ($40) {
  _xfree($cxt);
  HEAP32[32184>>2] = 0;
  $41 = HEAP32[13488>>2]|0;
  $42 = $41 & -129;
  HEAP32[13488>>2] = $42;
  $43 = ($r|0)!=(0);
  $44 = $43&1;
  return ($44|0);
 }
 _free($39);
 _xfree($cxt);
 HEAP32[32184>>2] = 0;
 $41 = HEAP32[13488>>2]|0;
 $42 = $41 & -129;
 HEAP32[13488>>2] = $42;
 $43 = ($r|0)!=(0);
 $44 = $43&1;
 return ($44|0);
}
function _rl_redisplay() {
 var $$ = 0, $$$ = 0, $$103 = 0, $$104 = 0, $$lcssa = 0, $$lcssa279 = 0, $$neg134 = 0, $$old20 = 0, $$op = 0, $$pn = 0, $$pn216 = 0, $$pre = 0, $$pre$i = 0, $$pre$i105 = 0, $$pre$i119 = 0, $$pre235 = 0, $$pre236 = 0, $$pre237 = 0, $$pre238 = 0, $$pre239 = 0;
 var $$pre240 = 0, $$pre241 = 0, $$pre242$pre = 0, $$pre243 = 0, $$pre244 = 0, $$pre245 = 0, $$pre246 = 0, $$pre247 = 0, $$pre248 = 0, $$pre249 = 0, $$pre251 = 0, $$pre252 = 0, $$pre253 = 0, $$pre255 = 0, $$pre256 = 0, $$pre257 = 0, $$pre258 = 0, $$pre261 = 0, $$pre262 = 0, $$pre265 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0;
 var $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0;
 var $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0;
 var $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0;
 var $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0;
 var $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0;
 var $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0;
 var $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0;
 var $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0;
 var $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0;
 var $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0;
 var $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0;
 var $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0;
 var $783 = 0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0;
 var $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0;
 var $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0;
 var $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0;
 var $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0;
 var $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0;
 var $891 = 0, $892 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $_rl_wrapped_multicolumn$0181 = 0, $_rl_wrapped_multicolumn$1151 = 0, $_rl_wrapped_multicolumn$2 = 0, $_rl_wrapped_multicolumn$3 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0;
 var $exitcond$i$i107 = 0, $exitcond$i$i124 = 0, $exitcond$i113 = 0, $exitcond230 = 0, $exitcond231 = 0, $i$01$i$i = 0, $i$01$i$i106 = 0, $i$01$i$i123 = 0, $i$0154 = 0, $i$03$i = 0, $i$03$i112 = 0, $i$1161 = 0, $i$2168 = 0, $in$0$be = 0, $in$0188 = 0, $lb_linenum$0$lcssa = 0, $lb_linenum$0184 = 0, $lb_linenum$1 = 0, $lb_linenum$2 = 0, $lb_linenum$3 = 0;
 var $lb_linenum$4 = 0, $line$0 = 0, $line$1 = 0, $line$2 = 0, $line$3 = 0, $line$4$lcssa = 0, $line$4185 = 0, $line$5 = 0, $linenum$0$lcssa = 0, $linenum$0149 = 0, $linenum$1147 = 0, $lmargin$0 = 0, $lmargin$0128 = 0, $lpos$0$be = 0, $lpos$0$lcssa = 0, $lpos$0209 = 0, $lpos$1182 = 0, $lpos$2 = 0, $lpos$3 = 0, $lpos$4152 = 0;
 var $lpos$5 = 0, $lpos$5$lcssa = 0, $lpos$6 = 0, $lpos$7166 = 0, $lpos$8 = 0, $lpos$9 = 0, $n0$0207 = 0, $n0$1 = 0, $newlines$0$lcssa = 0, $newlines$0210 = 0, $newlines$1$lcssa = 0, $newlines$1183 = 0, $newlines$2 = 0, $newlines$3 = 0, $newlines$4153 = 0, $newlines$5 = 0, $newlines$5$lcssa = 0, $newlines$6 = 0, $newlines$7167 = 0, $newlines$8 = 0;
 var $newlines$9 = 0, $nleft$0 = 0, $notlhs = 0, $notrhs = 0, $num$0208 = 0, $num$1201 = 0, $num$1201$lcssa = 0, $num$3 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond100 = 0, $or$cond102 = 0, $or$cond15 = 0, $or$cond17 = 0, $or$cond19 = 0, $or$cond24 = 0, $or$cond269 = 0, $or$cond27 = 0, $or$cond271 = 0, $or$cond272 = 0;
 var $or$cond3 = 0, $or$cond45 = 0, $or$cond48 = 0, $or$cond5 = 0, $or$cond51 = 0, $or$cond54 = 0, $or$cond57 = 0, $or$cond60 = 0, $or$cond63 = 0, $or$cond66 = 0, $or$cond69$not = 0, $or$cond7 = 0, $or$cond78 = 0, $or$cond81 = 0, $or$cond84 = 0, $or$cond86 = 0, $or$cond88 = 0, $or$cond9 = 0, $or$cond90 = 0, $or$cond92 = 0;
 var $or$cond93 = 0, $or$cond94 = 0, $or$cond96 = 0, $or$cond98 = 0, $out$0 = 0, $out$1 = 0, $out$10 = 0, $out$2 = 0, $out$3$lcssa = 0, $out$3186 = 0, $out$6155 = 0, $out$7 = 0, $out$8$lcssa = 0, $out$8162 = 0, $out$9 = 0, $prompt_this_line$0 = 0, $ps = 0, $scevgep = 0, $scevgep234 = 0, $storemerge = 0;
 var $storemerge82 = 0, $temp$0 = 0, $tx$0 = 0, $vararg_buffer = 0, $wc = 0, $wc_bytes$0$be = 0, $wc_bytes$0$ph = 0, $wc_bytes$0179 = 0, $wc_bytes$1 = 0, $wc_width$0180 = 0, $wc_width$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp + 8|0;
 $wc = sp + 12|0;
 $ps = sp;
 $0 = HEAP32[13520>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 __rl_block_sigint();
 $2 = HEAP32[13488>>2]|0;
 $3 = $2 | 8388608;
 HEAP32[13488>>2] = $3;
 $4 = HEAP32[32272>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  HEAP32[32272>>2] = 37352;
 }
 $6 = HEAP32[32304>>2]|0;
 $7 = ($6|0)==(0);
 if ($7) {
  _init_line_structures(0);
  $8 = HEAP32[32312>>2]|0;
  $9 = HEAP32[$8>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $12 = $8;
  } else {
   HEAP8[$9>>0] = 0;
   $$pre$i = HEAP32[32312>>2]|0;
   $12 = $$pre$i;
  }
  HEAP32[32288>>2] = 0;
  HEAP32[32280>>2] = 0;
  HEAP32[32320>>2] = 0;
  HEAP32[32296>>2] = 0;
  $11 = ((($12)) + 4|0);
  $13 = HEAP32[$11>>2]|0;
  $14 = ($13|0)==(0|0);
  if (!($14)) {
   $15 = ((($13)) + 4|0);
   HEAP32[$15>>2] = 0;
   HEAP32[$13>>2] = 0;
  }
  HEAP32[32328>>2] = 0;
 }
 HEAP32[32336>>2] = -1;
 $16 = HEAP32[32344>>2]|0;
 $17 = HEAP32[32352>>2]|0;
 $18 = (($16) - ($17))|0;
 HEAP32[32360>>2] = $18;
 $19 = HEAP32[32368>>2]|0;
 $20 = HEAP32[$19>>2]|0;
 HEAP32[32376>>2] = 0;
 $21 = HEAP32[13608>>2]|0;
 $22 = ($21|0)==(0);
 if ($22) {
  $out$0 = 0;
 } else {
  $23 = (_current_history()|0);
  $24 = ($23|0)!=(0|0);
  $25 = HEAP32[34424>>2]|0;
  $26 = ($25|0)!=(0|0);
  $or$cond = $24 & $26;
  if ($or$cond) {
   HEAP8[$20>>0] = 42;
   $27 = ((($20)) + 1|0);
   HEAP8[$27>>0] = 0;
   HEAP32[32376>>2] = 1;
   $out$0 = 1;
  } else {
   $out$0 = 0;
  }
 }
 $28 = HEAP32[32312>>2]|0;
 $29 = HEAP32[$28>>2]|0;
 $30 = HEAP8[$29>>0]|0;
 $31 = HEAP32[32368>>2]|0;
 $32 = HEAP32[$31>>2]|0;
 $33 = HEAP8[$32>>0]|0;
 $34 = ($30<<24>>24)==($33<<24>>24);
 if (!($34)) {
  HEAP32[32256>>2] = 0;
 }
 $35 = HEAP32[32272>>2]|0;
 $36 = HEAP32[13528>>2]|0;
 $37 = ($35|0)==($36|0);
 $38 = HEAP32[32384>>2]|0;
 $39 = ($38|0)!=(0|0);
 $or$cond3 = $37 | $39;
 if ($or$cond3) {
  $40 = HEAP32[32392>>2]|0;
  $41 = ($40|0)!=(0|0);
  $42 = HEAP32[32400>>2]|0;
  $43 = ($42|0)!=(0);
  $or$cond5 = $41 & $43;
  if ($or$cond5) {
   $44 = (_strlen(($40|0))|0);
   __rl_output_some_chars($40,$44);
  }
  $45 = HEAP32[32408>>2]|0;
  $46 = ($45|0)>(0);
  if ($46) {
   $47 = (($45) + ($out$0))|0;
   $48 = (($47) + 2)|0;
   $49 = HEAP32[32416>>2]|0;
   $50 = ($48|0)<($49|0);
   if ($50) {
    $65 = $45;$line$0 = $20;
   } else {
    $51 = (($47) + 1026)|0;
    $52 = (($48|0) % 1024)&-1;
    $53 = (($51) - ($52))|0;
    HEAP32[32416>>2] = $53;
    $54 = HEAP32[32312>>2]|0;
    $55 = HEAP32[$54>>2]|0;
    $56 = (_xrealloc($55,$53)|0);
    $57 = HEAP32[32312>>2]|0;
    HEAP32[$57>>2] = $56;
    $58 = HEAP32[32368>>2]|0;
    $59 = HEAP32[$58>>2]|0;
    $60 = HEAP32[32416>>2]|0;
    $61 = (_xrealloc($59,$60)|0);
    $62 = HEAP32[32368>>2]|0;
    HEAP32[$62>>2] = $61;
    $$pre = HEAP32[32408>>2]|0;
    $65 = $$pre;$line$0 = $61;
   }
   $63 = (($line$0) + ($out$0)|0);
   $64 = HEAP32[32384>>2]|0;
   (_strncpy(($63|0),($64|0),($65|0))|0);
   $66 = HEAP32[32408>>2]|0;
   $67 = (($66) + ($out$0))|0;
   $line$1 = $line$0;$out$1 = $67;
  } else {
   $line$1 = $20;$out$1 = $out$0;
  }
  $68 = (($line$1) + ($out$1)|0);
  HEAP8[$68>>0] = 0;
  $69 = HEAP32[32408>>2]|0;
  $70 = HEAP32[32344>>2]|0;
  $71 = (($69) - ($70))|0;
  $line$3 = $line$1;$out$2 = $out$1;$storemerge = $71;
 } else {
  $72 = (_strrchr($35,10)|0);
  $73 = ($72|0)==(0|0);
  do {
   if ($73) {
    $prompt_this_line$0 = $35;
   } else {
    $74 = ((($72)) + 1|0);
    $75 = $74;
    $76 = $35;
    $77 = (($75) - ($76))|0;
    $78 = HEAP32[32400>>2]|0;
    $79 = ($78|0)==(0);
    if ($79) {
     $prompt_this_line$0 = $74;
    } else {
     __rl_output_some_chars($35,$77);
     $80 = ($77|0)<(2);
     if (!($80)) {
      $81 = ((($72)) + -1|0);
      $82 = HEAP8[$81>>0]|0;
      $83 = ($82<<24>>24)==(13);
      if ($83) {
       $prompt_this_line$0 = $74;
       break;
      }
     }
     $84 = HEAP32[35144>>2]|0;
     $85 = ($84|0)==(0|0);
     if ($85) {
      $prompt_this_line$0 = $74;
     } else {
      (_tputs($84,1,368)|0);
      HEAP32[32280>>2] = 0;
      $prompt_this_line$0 = $74;
     }
    }
   }
  } while(0);
  $86 = (_strlen(($prompt_this_line$0|0))|0);
  HEAP32[32352>>2] = $86;
  $87 = (($86) + ($out$0))|0;
  $88 = (($87) + 2)|0;
  $89 = HEAP32[32416>>2]|0;
  $90 = ($88|0)<($89|0);
  if ($90) {
   $line$2 = $20;
  } else {
   $91 = (($87) + 1026)|0;
   $92 = (($88|0) % 1024)&-1;
   $93 = (($91) - ($92))|0;
   HEAP32[32416>>2] = $93;
   $94 = HEAP32[32312>>2]|0;
   $95 = HEAP32[$94>>2]|0;
   $96 = (_xrealloc($95,$93)|0);
   $97 = HEAP32[32312>>2]|0;
   HEAP32[$97>>2] = $96;
   $98 = HEAP32[32368>>2]|0;
   $99 = HEAP32[$98>>2]|0;
   $100 = HEAP32[32416>>2]|0;
   $101 = (_xrealloc($99,$100)|0);
   $102 = HEAP32[32368>>2]|0;
   HEAP32[$102>>2] = $101;
   $line$2 = $101;
  }
  $103 = (($line$2) + ($out$0)|0);
  (_strncpy(($103|0),($prompt_this_line$0|0),($86|0))|0);
  $104 = (($line$2) + ($87)|0);
  HEAP8[$104>>0] = 0;
  HEAP32[32424>>2] = 0;
  $line$3 = $line$2;$out$2 = $87;$storemerge = 0;
 }
 HEAP32[32432>>2] = $storemerge;
 $105 = HEAP32[32368>>2]|0;
 $106 = ((($105)) + 4|0);
 $107 = HEAP32[$106>>2]|0;
 HEAP32[$107>>2] = 0;
 $108 = HEAP32[32352>>2]|0;
 $109 = HEAP32[32376>>2]|0;
 $110 = (($109) + ($108))|0;
 $111 = ((($105)) + 12|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = ((($105)) + 16|0);
 $114 = HEAP32[$113>>2]|0;
 $115 = $114 << 2;
 _memset(($112|0),0,($115|0))|0;
 $116 = HEAP32[35112>>2]|0;
 $117 = (($110|0) / ($116|0))&-1;
 $118 = ($110|0)<($116|0);
 if ($118) {
  $lpos$0$lcssa = $110;$newlines$0$lcssa = 0;
 } else {
  $136 = $116;$lpos$0209 = $110;$n0$0207 = 0;$newlines$0210 = 0;$num$0208 = 0;
  while(1) {
   $119 = HEAP32[36240>>2]|0;
   $120 = ($119|0)==(0);
   $121 = HEAP32[32360>>2]|0;
   $122 = ($121|0)>(0);
   $or$cond7 = $120 & $122;
   L50: do {
    if ($or$cond7) {
     $123 = HEAP32[32408>>2]|0;
     $124 = ($num$0208|0)<($123|0);
     if ($124) {
      $num$1201 = $num$0208;
      while(1) {
       $125 = HEAP32[32384>>2]|0;
       $126 = (__rl_col_width($125,$num$0208,$num$1201,1)|0);
       $127 = HEAP32[35112>>2]|0;
       $128 = ($126|0)>($127|0);
       if ($128) {
        $num$1201$lcssa = $num$1201;
        break;
       }
       $131 = ($126|0)==($127|0);
       if ($131) {
        $n0$1 = $num$0208;$num$3 = $num$1201;$temp$0 = $num$1201;
        break L50;
       }
       $132 = (($num$1201) + 1)|0;
       $133 = ($132|0)<($123|0);
       if ($133) {
        $num$1201 = $132;
       } else {
        $n0$1 = $num$0208;$num$3 = $132;$temp$0 = $132;
        break L50;
       }
      }
      $129 = HEAP32[32384>>2]|0;
      $130 = (__rl_find_prev_mbchar($129,$num$1201$lcssa,0)|0);
      $n0$1 = $num$0208;$num$3 = $130;$temp$0 = $130;
     } else {
      $n0$1 = $num$0208;$num$3 = $num$0208;$temp$0 = $num$0208;
     }
    } else {
     $134 = (($newlines$0210) + 1)|0;
     $135 = Math_imul($134, $136)|0;
     $n0$1 = $n0$0207;$num$3 = $num$0208;$temp$0 = $135;
    }
   } while(0);
   $137 = ($newlines$0210|0)==(0);
   if ($137) {
    $138 = HEAP32[32424>>2]|0;
    $144 = $138;
   } else {
    $139 = ($newlines$0210|0)==($117|0);
    $140 = HEAP32[32432>>2]|0;
    $141 = HEAP32[32424>>2]|0;
    $142 = $139 ? $140 : $141;
    $144 = $142;
   }
   $143 = (($144) + ($temp$0))|0;
   $145 = (($newlines$0210) + 1)|0;
   $146 = HEAP32[32368>>2]|0;
   $147 = ((($146)) + 4|0);
   $148 = HEAP32[$147>>2]|0;
   $149 = (($148) + ($145<<2)|0);
   HEAP32[$149>>2] = $143;
   $150 = HEAP32[36240>>2]|0;
   $151 = ($150|0)==(0);
   $152 = HEAP32[32360>>2]|0;
   $153 = ($152|0)>(0);
   $or$cond9 = $151 & $153;
   if ($or$cond9) {
    $154 = HEAP32[32384>>2]|0;
    $155 = (__rl_col_width($154,$n0$1,$num$3,1)|0);
    $$pre235 = HEAP32[35112>>2]|0;
    $$pn216 = $155;$158 = $$pre235;
   } else {
    $156 = HEAP32[35112>>2]|0;
    $$pn216 = $156;$158 = $156;
   }
   $lpos$0$be = (($lpos$0209) - ($$pn216))|0;
   $157 = ($lpos$0$be|0)<($158|0);
   if ($157) {
    $lpos$0$lcssa = $lpos$0$be;$newlines$0$lcssa = $145;
    break;
   } else {
    $136 = $158;$lpos$0209 = $lpos$0$be;$n0$0207 = $n0$1;$newlines$0210 = $145;$num$0208 = $num$3;
   }
  }
 }
 HEAP32[32440>>2] = $newlines$0$lcssa;
 $159 = HEAP32[36240>>2]|0;
 $160 = ($159|0)==(0);
 if ($160) {
  $161 = $ps;
  $162 = $161;
  HEAP32[$162>>2] = 0;
  $163 = (($161) + 4)|0;
  $164 = $163;
  HEAP32[$164>>2] = 0;
  $165 = HEAP32[13632>>2]|0;
  $166 = HEAP32[13768>>2]|0;
  $167 = (_mbrtowc($wc,$165,$166,$ps)|0);
  $wc_bytes$0$ph = $167;
 } else {
  $wc_bytes$0$ph = 1;
 }
 $168 = HEAP32[13768>>2]|0;
 $169 = ($168|0)>(0);
 L71: do {
  if ($169) {
   $_rl_wrapped_multicolumn$0181 = 0;$in$0188 = 0;$lb_linenum$0184 = 0;$line$4185 = $line$3;$lpos$1182 = $lpos$0$lcssa;$newlines$1183 = $newlines$0$lcssa;$out$3186 = $out$2;$wc_bytes$0179 = $wc_bytes$0$ph;$wc_width$0180 = 0;
   while(1) {
    $170 = HEAP32[13632>>2]|0;
    $171 = (($170) + ($in$0188)|0);
    $172 = HEAP8[$171>>0]|0;
    $173 = $172&255;
    $174 = HEAP32[36240>>2]|0;
    $175 = ($174|0)==(0);
    do {
     if ($175) {
      $176 = ($wc_bytes$0179>>>0)>(4294967293);
      if ($176) {
       $177 = $ps;
       $178 = $177;
       HEAP32[$178>>2] = 0;
       $179 = (($177) + 4)|0;
       $180 = $179;
       HEAP32[$180>>2] = 0;
       $wc_bytes$1 = 1;$wc_width$1 = 1;
       break;
      }
      $181 = ($wc_bytes$0179|0)==(0);
      if ($181) {
       $lb_linenum$0$lcssa = $lb_linenum$0184;$line$4$lcssa = $line$4185;$newlines$1$lcssa = $newlines$1183;$out$3$lcssa = $out$3186;
       break L71;
      }
      $182 = HEAP32[$wc>>2]|0;
      $183 = (_wcwidth($182)|0);
      $184 = ($183|0)>(-1);
      $185 = $184 ? $183 : 1;
      $wc_bytes$1 = $wc_bytes$0179;$wc_width$1 = $185;
     } else {
      $wc_bytes$1 = $wc_bytes$0179;$wc_width$1 = $wc_width$0180;
     }
    } while(0);
    $186 = (($out$3186) + 8)|0;
    $187 = HEAP32[32416>>2]|0;
    $188 = ($186|0)<($187|0);
    if ($188) {
     $line$5 = $line$4185;
    } else {
     $189 = $187 << 1;
     HEAP32[32416>>2] = $189;
     $190 = HEAP32[32312>>2]|0;
     $191 = HEAP32[$190>>2]|0;
     $192 = (_xrealloc($191,$189)|0);
     $193 = HEAP32[32312>>2]|0;
     HEAP32[$193>>2] = $192;
     $194 = HEAP32[32368>>2]|0;
     $195 = HEAP32[$194>>2]|0;
     $196 = HEAP32[32416>>2]|0;
     $197 = (_xrealloc($195,$196)|0);
     $198 = HEAP32[32368>>2]|0;
     HEAP32[$198>>2] = $197;
     $199 = HEAP32[32368>>2]|0;
     $200 = HEAP32[$199>>2]|0;
     $line$5 = $200;
    }
    $201 = HEAP32[13784>>2]|0;
    $202 = ($in$0188|0)==($201|0);
    if ($202) {
     HEAP32[32336>>2] = $out$3186;
     $lb_linenum$1 = $newlines$1183;
    } else {
     $lb_linenum$1 = $lb_linenum$0184;
    }
    $203 = ($172<<24>>24)<(0);
    $204 = HEAP32[13696>>2]|0;
    $205 = ($204|0)==(0);
    $or$cond15 = $203 & $205;
    do {
     if ($or$cond15) {
      $206 = (($line$5) + ($out$3186)|0);
      HEAP32[$vararg_buffer>>2] = $173;
      (_sprintf($206,32448,$vararg_buffer)|0);
      $207 = (($lpos$1182) + 4)|0;
      $208 = HEAP32[35112>>2]|0;
      $209 = ($207|0)<($208|0);
      if ($209) {
       $lpos$2 = $207;$newlines$2 = $newlines$1183;
      } else {
       $210 = (($208) - ($lpos$1182))|0;
       $211 = HEAP32[32368>>2]|0;
       $212 = ((($211)) + 8|0);
       $213 = HEAP32[$212>>2]|0;
       $214 = (($213) + -2)|0;
       $215 = ($newlines$1183|0)<($214|0);
       if ($215) {
        $226 = $211;
       } else {
        $216 = $213 << 1;
        HEAP32[$212>>2] = $216;
        $217 = ((($211)) + 4|0);
        $218 = HEAP32[$217>>2]|0;
        $219 = $213 << 3;
        $220 = (_xrealloc($218,$219)|0);
        $221 = HEAP32[32368>>2]|0;
        $222 = ((($221)) + 4|0);
        HEAP32[$222>>2] = $220;
        $$pre251 = HEAP32[32368>>2]|0;
        $226 = $$pre251;
       }
       $223 = (($210) + ($out$3186))|0;
       $224 = (($newlines$1183) + 1)|0;
       $225 = ((($226)) + 4|0);
       $227 = HEAP32[$225>>2]|0;
       $228 = (($227) + ($224<<2)|0);
       HEAP32[$228>>2] = $223;
       $229 = (4 - ($210))|0;
       $lpos$2 = $229;$newlines$2 = $224;
      }
      $230 = (($out$3186) + 4)|0;
      $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $lpos$2;$newlines$9 = $newlines$2;$out$9 = $230;
     } else {
      $231 = ($172<<24>>24)==(9);
      if ($231) {
       $232 = (($lpos$1182|0) % 8)&-1;
       $233 = (($186) - ($232))|0;
       $234 = (($233) - ($out$3186))|0;
       $235 = (($234) + ($lpos$1182))|0;
       $236 = HEAP32[35112>>2]|0;
       $237 = ($235|0)<($236|0);
       if ($237) {
        $238 = ($233|0)>($out$3186|0);
        if (!($238)) {
         $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $235;$newlines$9 = $newlines$1183;$out$9 = $out$3186;
         break;
        }
        $scevgep234 = (($line$5) + ($out$3186)|0);
        $239 = (8 - ($232))|0;
        _memset(($scevgep234|0),32,($239|0))|0;
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $235;$newlines$9 = $newlines$1183;$out$9 = $233;
        break;
       }
       $240 = (($236) - ($lpos$1182))|0;
       $241 = HEAP32[32368>>2]|0;
       $242 = ((($241)) + 8|0);
       $243 = HEAP32[$242>>2]|0;
       $244 = (($243) + -2)|0;
       $245 = ($newlines$1183|0)<($244|0);
       if ($245) {
        $256 = $241;
       } else {
        $246 = $243 << 1;
        HEAP32[$242>>2] = $246;
        $247 = ((($241)) + 4|0);
        $248 = HEAP32[$247>>2]|0;
        $249 = $243 << 3;
        $250 = (_xrealloc($248,$249)|0);
        $251 = HEAP32[32368>>2]|0;
        $252 = ((($251)) + 4|0);
        HEAP32[$252>>2] = $250;
        $$pre249 = HEAP32[32368>>2]|0;
        $256 = $$pre249;
       }
       $253 = (($240) + ($out$3186))|0;
       $254 = (($newlines$1183) + 1)|0;
       $255 = ((($256)) + 4|0);
       $257 = HEAP32[$255>>2]|0;
       $258 = (($257) + ($254<<2)|0);
       HEAP32[$258>>2] = $253;
       $259 = (($234) - ($240))|0;
       $260 = ($233|0)>($out$3186|0);
       if (!($260)) {
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $259;$newlines$9 = $254;$out$9 = $out$3186;
        break;
       }
       $scevgep = (($line$5) + ($out$3186)|0);
       $261 = (8 - ($232))|0;
       _memset(($scevgep|0),32,($261|0))|0;
       $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $259;$newlines$9 = $254;$out$9 = $233;
       break;
      }
      $262 = ($172<<24>>24)==(10);
      $263 = HEAP32[13600>>2]|0;
      $264 = ($263|0)==(0);
      $or$cond17 = $262 & $264;
      $265 = HEAP32[35208>>2]|0;
      $266 = ($265|0)!=(0|0);
      $or$cond19 = $or$cond17 & $266;
      if ($or$cond19) {
       $267 = HEAP8[$265>>0]|0;
       $268 = ($267<<24>>24)==(0);
       if (!($268)) {
        $269 = (($out$3186) + 1)|0;
        $270 = (($line$5) + ($out$3186)|0);
        HEAP8[$270>>0] = 0;
        $271 = HEAP32[32368>>2]|0;
        $272 = ((($271)) + 8|0);
        $273 = HEAP32[$272>>2]|0;
        $274 = (($273) + -2)|0;
        $275 = ($newlines$1183|0)<($274|0);
        if ($275) {
         $285 = $271;
        } else {
         $276 = $273 << 1;
         HEAP32[$272>>2] = $276;
         $277 = ((($271)) + 4|0);
         $278 = HEAP32[$277>>2]|0;
         $279 = $273 << 3;
         $280 = (_xrealloc($278,$279)|0);
         $281 = HEAP32[32368>>2]|0;
         $282 = ((($281)) + 4|0);
         HEAP32[$282>>2] = $280;
         $$pre236 = HEAP32[32368>>2]|0;
         $285 = $$pre236;
        }
        $283 = (($newlines$1183) + 1)|0;
        $284 = ((($285)) + 4|0);
        $286 = HEAP32[$284>>2]|0;
        $287 = (($286) + ($283<<2)|0);
        HEAP32[$287>>2] = $269;
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = 0;$newlines$9 = $283;$out$9 = $269;
        break;
       }
      }
      $288 = ($172&255)<(32);
      if ($288) {
       $289 = $173 & 128;
       $290 = ($289|0)==(0);
       if ($290) {
        label = 81;
       }
      } else {
       $$old20 = ($172<<24>>24)==(127);
       if ($$old20) {
        label = 81;
       }
      }
      if ((label|0) == 81) {
       label = 0;
       $291 = (($out$3186) + 1)|0;
       $292 = (($line$5) + ($out$3186)|0);
       HEAP8[$292>>0] = 94;
       $293 = (($lpos$1182) + 1)|0;
       $294 = HEAP32[35112>>2]|0;
       $295 = ($293|0)<($294|0);
       if ($295) {
        $lpos$3 = $293;$newlines$3 = $newlines$1183;
       } else {
        $296 = HEAP32[32368>>2]|0;
        $297 = ((($296)) + 8|0);
        $298 = HEAP32[$297>>2]|0;
        $299 = (($298) + -2)|0;
        $300 = ($newlines$1183|0)<($299|0);
        if ($300) {
         $310 = $296;
        } else {
         $301 = $298 << 1;
         HEAP32[$297>>2] = $301;
         $302 = ((($296)) + 4|0);
         $303 = HEAP32[$302>>2]|0;
         $304 = $298 << 3;
         $305 = (_xrealloc($303,$304)|0);
         $306 = HEAP32[32368>>2]|0;
         $307 = ((($306)) + 4|0);
         HEAP32[$307>>2] = $305;
         $$pre245 = HEAP32[32368>>2]|0;
         $310 = $$pre245;
        }
        $308 = (($newlines$1183) + 1)|0;
        $309 = ((($310)) + 4|0);
        $311 = HEAP32[$309>>2]|0;
        $312 = (($311) + ($308<<2)|0);
        HEAP32[$312>>2] = $291;
        $313 = ((($310)) + 16|0);
        $314 = HEAP32[$313>>2]|0;
        $315 = (($314) + -1)|0;
        $316 = ($308|0)<($315|0);
        if ($316) {
         $325 = $310;
        } else {
         $317 = $314 << 1;
         HEAP32[$313>>2] = $317;
         $318 = ((($310)) + 12|0);
         $319 = HEAP32[$318>>2]|0;
         $320 = $314 << 3;
         $321 = (_xrealloc($319,$320)|0);
         $322 = HEAP32[32368>>2]|0;
         $323 = ((($322)) + 12|0);
         HEAP32[$323>>2] = $321;
         $$pre246 = HEAP32[32368>>2]|0;
         $325 = $$pre246;
        }
        $324 = ((($325)) + 12|0);
        $326 = HEAP32[$324>>2]|0;
        $327 = (($326) + ($308<<2)|0);
        HEAP32[$327>>2] = $_rl_wrapped_multicolumn$0181;
        $lpos$3 = 0;$newlines$3 = $308;
       }
       $328 = $173 & 128;
       $329 = ($328|0)==(0);
       $or$cond84 = $288 & $329;
       do {
        if ($or$cond84) {
         $330 = $173 | 64;
         $331 = (_islower($330)|0);
         $332 = ($331|0)==(0);
         if ($332) {
          $335 = $330;
          break;
         }
         $333 = (_toupper($330)|0);
         $335 = $333;
        } else {
         $335 = 63;
        }
       } while(0);
       $334 = $335&255;
       $336 = (($out$3186) + 2)|0;
       $337 = (($line$5) + ($291)|0);
       HEAP8[$337>>0] = $334;
       $338 = (($lpos$3) + 1)|0;
       $339 = HEAP32[35112>>2]|0;
       $340 = ($338|0)<($339|0);
       if ($340) {
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $338;$newlines$9 = $newlines$3;$out$9 = $336;
        break;
       }
       $341 = HEAP32[32368>>2]|0;
       $342 = ((($341)) + 8|0);
       $343 = HEAP32[$342>>2]|0;
       $344 = (($343) + -2)|0;
       $345 = ($newlines$3|0)<($344|0);
       if ($345) {
        $355 = $341;
       } else {
        $346 = $343 << 1;
        HEAP32[$342>>2] = $346;
        $347 = ((($341)) + 4|0);
        $348 = HEAP32[$347>>2]|0;
        $349 = $343 << 3;
        $350 = (_xrealloc($348,$349)|0);
        $351 = HEAP32[32368>>2]|0;
        $352 = ((($351)) + 4|0);
        HEAP32[$352>>2] = $350;
        $$pre247 = HEAP32[32368>>2]|0;
        $355 = $$pre247;
       }
       $353 = (($newlines$3) + 1)|0;
       $354 = ((($355)) + 4|0);
       $356 = HEAP32[$354>>2]|0;
       $357 = (($356) + ($353<<2)|0);
       HEAP32[$357>>2] = $336;
       $358 = ((($355)) + 16|0);
       $359 = HEAP32[$358>>2]|0;
       $360 = (($359) + -1)|0;
       $361 = ($353|0)<($360|0);
       if ($361) {
        $370 = $355;
       } else {
        $362 = $359 << 1;
        HEAP32[$358>>2] = $362;
        $363 = ((($355)) + 12|0);
        $364 = HEAP32[$363>>2]|0;
        $365 = $359 << 3;
        $366 = (_xrealloc($364,$365)|0);
        $367 = HEAP32[32368>>2]|0;
        $368 = ((($367)) + 12|0);
        HEAP32[$368>>2] = $366;
        $$pre248 = HEAP32[32368>>2]|0;
        $370 = $$pre248;
       }
       $369 = ((($370)) + 12|0);
       $371 = HEAP32[$369>>2]|0;
       $372 = (($371) + ($353<<2)|0);
       HEAP32[$372>>2] = $_rl_wrapped_multicolumn$0181;
       $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = 0;$newlines$9 = $353;$out$9 = $336;
       break;
      }
      $373 = HEAP32[36240>>2]|0;
      $374 = ($373|0)==(0);
      if (!($374)) {
       $468 = (($out$3186) + 1)|0;
       $469 = (($line$5) + ($out$3186)|0);
       HEAP8[$469>>0] = $172;
       $470 = (($lpos$1182) + 1)|0;
       $471 = HEAP32[35112>>2]|0;
       $472 = ($470|0)<($471|0);
       if ($472) {
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = $470;$newlines$9 = $newlines$1183;$out$9 = $468;
        break;
       }
       $473 = HEAP32[32368>>2]|0;
       $474 = ((($473)) + 8|0);
       $475 = HEAP32[$474>>2]|0;
       $476 = (($475) + -2)|0;
       $477 = ($newlines$1183|0)<($476|0);
       if ($477) {
        $487 = $473;
       } else {
        $478 = $475 << 1;
        HEAP32[$474>>2] = $478;
        $479 = ((($473)) + 4|0);
        $480 = HEAP32[$479>>2]|0;
        $481 = $475 << 3;
        $482 = (_xrealloc($480,$481)|0);
        $483 = HEAP32[32368>>2]|0;
        $484 = ((($483)) + 4|0);
        HEAP32[$484>>2] = $482;
        $$pre237 = HEAP32[32368>>2]|0;
        $487 = $$pre237;
       }
       $485 = (($newlines$1183) + 1)|0;
       $486 = ((($487)) + 4|0);
       $488 = HEAP32[$486>>2]|0;
       $489 = (($488) + ($485<<2)|0);
       HEAP32[$489>>2] = $468;
       $490 = ((($487)) + 16|0);
       $491 = HEAP32[$490>>2]|0;
       $492 = (($491) + -1)|0;
       $493 = ($485|0)<($492|0);
       if ($493) {
        $502 = $487;
       } else {
        $494 = $491 << 1;
        HEAP32[$490>>2] = $494;
        $495 = ((($487)) + 12|0);
        $496 = HEAP32[$495>>2]|0;
        $497 = $491 << 3;
        $498 = (_xrealloc($496,$497)|0);
        $499 = HEAP32[32368>>2]|0;
        $500 = ((($499)) + 12|0);
        HEAP32[$500>>2] = $498;
        $$pre238 = HEAP32[32368>>2]|0;
        $502 = $$pre238;
       }
       $501 = ((($502)) + 12|0);
       $503 = HEAP32[$501>>2]|0;
       $504 = (($503) + ($485<<2)|0);
       HEAP32[$504>>2] = $_rl_wrapped_multicolumn$0181;
       $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$0181;$lb_linenum$3 = $lb_linenum$1;$lpos$9 = 0;$newlines$9 = $485;$out$9 = $468;
       break;
      }
      $375 = HEAP32[35112>>2]|0;
      $376 = (($wc_width$1) + ($lpos$1182))|0;
      $377 = ($375|0)<($376|0);
      $378 = ($lpos$1182|0)<($375|0);
      $or$cond269 = $377 & $378;
      if ($or$cond269) {
       $_rl_wrapped_multicolumn$1151 = 0;$i$0154 = $lpos$1182;$lpos$4152 = $lpos$1182;$newlines$4153 = $newlines$1183;$out$6155 = $out$3186;
       while(1) {
        $379 = (($out$6155) + 1)|0;
        $380 = (($line$5) + ($out$6155)|0);
        HEAP8[$380>>0] = 32;
        $381 = (($_rl_wrapped_multicolumn$1151) + 1)|0;
        $382 = (($lpos$4152) + 1)|0;
        $383 = HEAP32[35112>>2]|0;
        $384 = ($382|0)<($383|0);
        if ($384) {
         $419 = $383;$lpos$5 = $382;$newlines$5 = $newlines$4153;
        } else {
         $385 = HEAP32[32368>>2]|0;
         $386 = ((($385)) + 8|0);
         $387 = HEAP32[$386>>2]|0;
         $388 = (($387) + -2)|0;
         $389 = ($newlines$4153|0)<($388|0);
         if ($389) {
          $399 = $385;
         } else {
          $390 = $387 << 1;
          HEAP32[$386>>2] = $390;
          $391 = ((($385)) + 4|0);
          $392 = HEAP32[$391>>2]|0;
          $393 = $387 << 3;
          $394 = (_xrealloc($392,$393)|0);
          $395 = HEAP32[32368>>2]|0;
          $396 = ((($395)) + 4|0);
          HEAP32[$396>>2] = $394;
          $$pre239 = HEAP32[32368>>2]|0;
          $399 = $$pre239;
         }
         $397 = (($newlines$4153) + 1)|0;
         $398 = ((($399)) + 4|0);
         $400 = HEAP32[$398>>2]|0;
         $401 = (($400) + ($397<<2)|0);
         HEAP32[$401>>2] = $379;
         $402 = ((($399)) + 16|0);
         $403 = HEAP32[$402>>2]|0;
         $404 = (($403) + -1)|0;
         $405 = ($397|0)<($404|0);
         if ($405) {
          $414 = $399;
         } else {
          $406 = $403 << 1;
          HEAP32[$402>>2] = $406;
          $407 = ((($399)) + 12|0);
          $408 = HEAP32[$407>>2]|0;
          $409 = $403 << 3;
          $410 = (_xrealloc($408,$409)|0);
          $411 = HEAP32[32368>>2]|0;
          $412 = ((($411)) + 12|0);
          HEAP32[$412>>2] = $410;
          $$pre240 = HEAP32[32368>>2]|0;
          $414 = $$pre240;
         }
         $413 = ((($414)) + 12|0);
         $415 = HEAP32[$413>>2]|0;
         $416 = (($415) + ($397<<2)|0);
         HEAP32[$416>>2] = $381;
         $$pre241 = HEAP32[35112>>2]|0;
         $419 = $$pre241;$lpos$5 = 0;$newlines$5 = $397;
        }
        $417 = (($i$0154) + 1)|0;
        $418 = ($417|0)<($419|0);
        if ($418) {
         $_rl_wrapped_multicolumn$1151 = $381;$i$0154 = $417;$lpos$4152 = $lpos$5;$newlines$4153 = $newlines$5;$out$6155 = $379;
        } else {
         $$lcssa = $379;$$lcssa279 = $381;$lpos$5$lcssa = $lpos$5;$newlines$5$lcssa = $newlines$5;
         break;
        }
       }
       $$pre242$pre = HEAP32[13784>>2]|0;
       $421 = $$pre242$pre;$_rl_wrapped_multicolumn$2 = $$lcssa279;$lpos$6 = $lpos$5$lcssa;$newlines$6 = $newlines$5$lcssa;$out$7 = $$lcssa;
      } else {
       $421 = $201;$_rl_wrapped_multicolumn$2 = 0;$lpos$6 = $lpos$1182;$newlines$6 = $newlines$1183;$out$7 = $out$3186;
      }
      $420 = ($in$0188|0)==($421|0);
      if ($420) {
       HEAP32[32336>>2] = $out$7;
       $lb_linenum$2 = $newlines$6;
      } else {
       $lb_linenum$2 = $lb_linenum$1;
      }
      $422 = (($wc_bytes$1) + ($in$0188))|0;
      $423 = ($in$0188>>>0)<($422>>>0);
      if ($423) {
       $i$1161 = $in$0188;$out$8162 = $out$7;
       while(1) {
        $426 = HEAP32[13632>>2]|0;
        $427 = (($426) + ($i$1161)|0);
        $428 = HEAP8[$427>>0]|0;
        $429 = (($out$8162) + 1)|0;
        $430 = (($line$5) + ($out$8162)|0);
        HEAP8[$430>>0] = $428;
        $431 = (($i$1161) + 1)|0;
        $exitcond230 = ($431|0)==($422|0);
        if ($exitcond230) {
         break;
        } else {
         $i$1161 = $431;$out$8162 = $429;
        }
       }
       $424 = (($wc_bytes$1) + ($out$7))|0;
       $out$8$lcssa = $424;
      } else {
       $out$8$lcssa = $out$7;
      }
      $425 = ($wc_width$1|0)>(0);
      if ($425) {
       $i$2168 = 0;$lpos$7166 = $lpos$6;$newlines$7167 = $newlines$6;
      } else {
       $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$2;$lb_linenum$3 = $lb_linenum$2;$lpos$9 = $lpos$6;$newlines$9 = $newlines$6;$out$9 = $out$8$lcssa;
       break;
      }
      while(1) {
       $432 = (($lpos$7166) + 1)|0;
       $433 = HEAP32[35112>>2]|0;
       $434 = ($432|0)<($433|0);
       if ($434) {
        $lpos$8 = $432;$newlines$8 = $newlines$7167;
       } else {
        $435 = HEAP32[32368>>2]|0;
        $436 = ((($435)) + 8|0);
        $437 = HEAP32[$436>>2]|0;
        $438 = (($437) + -2)|0;
        $439 = ($newlines$7167|0)<($438|0);
        if ($439) {
         $449 = $435;
        } else {
         $440 = $437 << 1;
         HEAP32[$436>>2] = $440;
         $441 = ((($435)) + 4|0);
         $442 = HEAP32[$441>>2]|0;
         $443 = $437 << 3;
         $444 = (_xrealloc($442,$443)|0);
         $445 = HEAP32[32368>>2]|0;
         $446 = ((($445)) + 4|0);
         HEAP32[$446>>2] = $444;
         $$pre243 = HEAP32[32368>>2]|0;
         $449 = $$pre243;
        }
        $447 = (($newlines$7167) + 1)|0;
        $448 = ((($449)) + 4|0);
        $450 = HEAP32[$448>>2]|0;
        $451 = (($450) + ($447<<2)|0);
        HEAP32[$451>>2] = $out$8$lcssa;
        $452 = ((($449)) + 16|0);
        $453 = HEAP32[$452>>2]|0;
        $454 = (($453) + -1)|0;
        $455 = ($447|0)<($454|0);
        if ($455) {
         $464 = $449;
        } else {
         $456 = $453 << 1;
         HEAP32[$452>>2] = $456;
         $457 = ((($449)) + 12|0);
         $458 = HEAP32[$457>>2]|0;
         $459 = $453 << 3;
         $460 = (_xrealloc($458,$459)|0);
         $461 = HEAP32[32368>>2]|0;
         $462 = ((($461)) + 12|0);
         HEAP32[$462>>2] = $460;
         $$pre244 = HEAP32[32368>>2]|0;
         $464 = $$pre244;
        }
        $463 = ((($464)) + 12|0);
        $465 = HEAP32[$463>>2]|0;
        $466 = (($465) + ($447<<2)|0);
        HEAP32[$466>>2] = $_rl_wrapped_multicolumn$2;
        $lpos$8 = 0;$newlines$8 = $447;
       }
       $467 = (($i$2168) + 1)|0;
       $exitcond231 = ($467|0)==($wc_width$1|0);
       if ($exitcond231) {
        $_rl_wrapped_multicolumn$3 = $_rl_wrapped_multicolumn$2;$lb_linenum$3 = $lb_linenum$2;$lpos$9 = $lpos$8;$newlines$9 = $newlines$8;$out$9 = $out$8$lcssa;
        break;
       } else {
        $i$2168 = $467;$lpos$7166 = $lpos$8;$newlines$7167 = $newlines$8;
       }
      }
     }
    } while(0);
    $505 = HEAP32[36240>>2]|0;
    $506 = ($505|0)==(0);
    if ($506) {
     $507 = (($wc_bytes$1) + ($in$0188))|0;
     $508 = HEAP32[13632>>2]|0;
     $509 = (($508) + ($507)|0);
     $510 = HEAP32[13768>>2]|0;
     $511 = (($510) - ($507))|0;
     $512 = (_mbrtowc($wc,$509,$511,$ps)|0);
     $in$0$be = $507;$wc_bytes$0$be = $512;
    } else {
     $513 = (($in$0188) + 1)|0;
     $in$0$be = $513;$wc_bytes$0$be = $wc_bytes$1;
    }
    $514 = HEAP32[13768>>2]|0;
    $515 = ($in$0$be|0)<($514|0);
    if ($515) {
     $_rl_wrapped_multicolumn$0181 = $_rl_wrapped_multicolumn$3;$in$0188 = $in$0$be;$lb_linenum$0184 = $lb_linenum$3;$line$4185 = $line$5;$lpos$1182 = $lpos$9;$newlines$1183 = $newlines$9;$out$3186 = $out$9;$wc_bytes$0179 = $wc_bytes$0$be;$wc_width$0180 = $wc_width$1;
    } else {
     $lb_linenum$0$lcssa = $lb_linenum$3;$line$4$lcssa = $line$5;$newlines$1$lcssa = $newlines$9;$out$3$lcssa = $out$9;
     break;
    }
   }
  } else {
   $lb_linenum$0$lcssa = 0;$line$4$lcssa = $line$3;$newlines$1$lcssa = $newlines$0$lcssa;$out$3$lcssa = $out$2;
  }
 } while(0);
 $516 = (($line$4$lcssa) + ($out$3$lcssa)|0);
 HEAP8[$516>>0] = 0;
 $517 = HEAP32[32336>>2]|0;
 $518 = ($517|0)<(0);
 if ($518) {
  HEAP32[32336>>2] = $out$3$lcssa;
  $lb_linenum$4 = $newlines$1$lcssa;
 } else {
  $lb_linenum$4 = $lb_linenum$0$lcssa;
 }
 $519 = HEAP32[32368>>2]|0;
 $520 = ((($519)) + 8|0);
 $521 = HEAP32[$520>>2]|0;
 $522 = (($521) + -2)|0;
 $523 = ($newlines$1$lcssa|0)<($522|0);
 if ($523) {
  $533 = $519;
 } else {
  $524 = $521 << 1;
  HEAP32[$520>>2] = $524;
  $525 = ((($519)) + 4|0);
  $526 = HEAP32[$525>>2]|0;
  $527 = $521 << 3;
  $528 = (_xrealloc($526,$527)|0);
  $529 = HEAP32[32368>>2]|0;
  $530 = ((($529)) + 4|0);
  HEAP32[$530>>2] = $528;
  $$pre252 = HEAP32[32368>>2]|0;
  $533 = $$pre252;
 }
 $531 = (($newlines$1$lcssa) + 1)|0;
 $532 = ((($533)) + 4|0);
 $534 = HEAP32[$532>>2]|0;
 $535 = (($534) + ($531<<2)|0);
 HEAP32[$535>>2] = $out$3$lcssa;
 HEAP32[32456>>2] = 1;
 $536 = HEAP32[13600>>2]|0;
 $537 = ($536|0)==(0);
 $538 = HEAP32[35208>>2]|0;
 $539 = ($538|0)!=(0|0);
 $or$cond24 = $537 & $539;
 do {
  if ($or$cond24) {
   $540 = HEAP8[$538>>0]|0;
   $541 = ($540<<24>>24)==(0);
   if ($541) {
    label = 223;
   } else {
    $542 = HEAP32[32256>>2]|0;
    $543 = ($542|0)==(0);
    $544 = HEAP32[32400>>2]|0;
    $545 = ($544|0)!=(0);
    $or$cond27 = $543 | $545;
    if ($or$cond27) {
     HEAP32[32400>>2] = 0;
     $546 = HEAP32[35128>>2]|0;
     $547 = ($out$3$lcssa|0)<($546|0);
     do {
      if ($547) {
       $out$10 = $out$3$lcssa;
      } else {
       $548 = HEAP32[36240>>2]|0;
       $549 = ($548|0)==(0);
       if ($549) {
        $550 = (__rl_find_prev_mbchar($line$4$lcssa,$546,0)|0);
        $out$10 = $550;
        break;
       } else {
        $551 = (($546) + -1)|0;
        $out$10 = $551;
        break;
       }
      }
     } while(0);
     $552 = ($newlines$1$lcssa|0)<(0);
     if ($552) {
      $linenum$0$lcssa = 0;
     } else {
      $553 = ($newlines$1$lcssa|0)>(0);
      $linenum$0149 = 0;
      while(1) {
       $554 = HEAP32[32280>>2]|0;
       HEAP32[32464>>2] = 0;
       $555 = HEAP32[32296>>2]|0;
       $556 = ($linenum$0149|0)>($555|0);
       if ($556) {
        $582 = 37352;
       } else {
        $557 = HEAP32[32312>>2]|0;
        $558 = HEAP32[$557>>2]|0;
        $559 = ((($557)) + 4|0);
        $560 = HEAP32[$559>>2]|0;
        $561 = (($560) + ($linenum$0149<<2)|0);
        $562 = HEAP32[$561>>2]|0;
        $563 = (($558) + ($562)|0);
        $582 = $563;
       }
       $564 = HEAP32[32368>>2]|0;
       $565 = HEAP32[$564>>2]|0;
       $566 = ((($564)) + 4|0);
       $567 = HEAP32[$566>>2]|0;
       $568 = (($567) + ($linenum$0149<<2)|0);
       $569 = HEAP32[$568>>2]|0;
       $570 = (($565) + ($569)|0);
       $$pre265 = (($linenum$0149) + 1)|0;
       if ($556) {
        $583 = 0;
       } else {
        $571 = HEAP32[32312>>2]|0;
        $572 = ((($571)) + 4|0);
        $573 = HEAP32[$572>>2]|0;
        $574 = (($573) + ($$pre265<<2)|0);
        $575 = HEAP32[$574>>2]|0;
        $576 = (($573) + ($linenum$0149<<2)|0);
        $577 = HEAP32[$576>>2]|0;
        $578 = (($575) - ($577))|0;
        $583 = $578;
       }
       $579 = (($567) + ($$pre265<<2)|0);
       $580 = HEAP32[$579>>2]|0;
       $581 = (($580) - ($569))|0;
       _update_line($582,$570,$linenum$0149,$583,$581,$newlines$1$lcssa);
       $584 = ($linenum$0149|0)==(0);
       $585 = HEAP32[36240>>2]|0;
       $586 = $585 | $linenum$0149;
       $587 = HEAP32[32464>>2]|0;
       $588 = $586 | $587;
       $589 = ($588|0)==(0);
       do {
        if ($589) {
         $590 = HEAP32[32280>>2]|0;
         $591 = ($590|0)!=($554|0);
         $592 = HEAP32[32432>>2]|0;
         $593 = ($590|0)>($592|0);
         $or$cond86 = $591 & $593;
         $594 = HEAP32[32472>>2]|0;
         $595 = ($554|0)<($594|0);
         $or$cond88 = $or$cond86 & $595;
         if (!($or$cond88)) {
          label = 149;
          break;
         }
         $596 = HEAP32[32424>>2]|0;
         $597 = (($590) - ($596))|0;
         HEAP32[32280>>2] = $597;
        } else {
         label = 149;
        }
       } while(0);
       do {
        if ((label|0) == 149) {
         label = 0;
         $598 = HEAP32[32440>>2]|0;
         $599 = ($linenum$0149|0)==($598|0);
         if (!($599)) {
          break;
         }
         $600 = HEAP32[32352>>2]|0;
         $601 = HEAP32[35112>>2]|0;
         $602 = ($600|0)>($601|0);
         $603 = $587 | $585;
         $604 = ($603|0)==(0);
         $605 = $602 & $604;
         if (!($605)) {
          break;
         }
         $606 = HEAP32[32280>>2]|0;
         $607 = ($606|0)==($554|0);
         if ($607) {
          break;
         }
         $608 = HEAP32[32472>>2]|0;
         $609 = (($608) - ($601))|0;
         $610 = HEAP32[32424>>2]|0;
         $611 = (($609) - ($610))|0;
         $612 = ($606|0)>($611|0);
         if (!($612)) {
          break;
         }
         $613 = HEAP32[32432>>2]|0;
         $614 = (($610) + ($606))|0;
         $615 = (($614) - ($613))|0;
         HEAP32[32280>>2] = $615;
        }
       } while(0);
       $616 = $linenum$0149 | $newlines$1$lcssa;
       $617 = ($616|0)==(0);
       $618 = HEAP32[32280>>2]|0;
       $619 = ($618|0)==($out$10|0);
       $or$cond271 = $617 & $619;
       do {
        if ($or$cond271) {
         $620 = HEAP32[32432>>2]|0;
         $621 = HEAP32[32328>>2]|0;
         $622 = ($620|0)>($621|0);
         $623 = HEAP32[32480>>2]|0;
         $624 = ($out$10|0)<($623|0);
         $or$cond90 = $622 & $624;
         if (!($or$cond90)) {
          break;
         }
         $625 = ($585|0)==(0);
         $626 = HEAP32[35112>>2]|0;
         $627 = $625 ? 0 : $620;
         $$pn = (($627) + ($626))|0;
         $628 = ($$pn|0)==($out$10|0);
         if ($628) {
          break;
         }
         $nleft$0 = (($$pn) - ($out$10))|0;
         $629 = HEAP32[35136>>2]|0;
         $630 = ($629|0)==(0|0);
         if (!($630)) {
          (_tputs($629,1,368)|0);
          break;
         }
         $631 = ($nleft$0|0)>(0);
         if ($631) {
          $i$01$i$i = 0;
          while(1) {
           $632 = HEAP32[13512>>2]|0;
           (_putc(32,($632|0))|0);
           $633 = (($i$01$i$i) + 1)|0;
           $exitcond$i$i = ($633|0)==($nleft$0|0);
           if ($exitcond$i$i) {
            break;
           } else {
            $i$01$i$i = $633;
           }
          }
          $$pre253 = HEAP32[32280>>2]|0;
          $635 = $$pre253;
         } else {
          $635 = $out$10;
         }
         $634 = (($635) + ($nleft$0))|0;
         HEAP32[32280>>2] = $634;
        }
       } while(0);
       if ($584) {
        if ($553) {
         $636 = HEAP32[32368>>2]|0;
         $637 = ((($636)) + 4|0);
         $638 = HEAP32[$637>>2]|0;
         $639 = ((($638)) + 4|0);
         $640 = HEAP32[$639>>2]|0;
         $643 = $640;
        } else {
         $641 = HEAP32[32432>>2]|0;
         $642 = (($out$10) - ($641))|0;
         $643 = $642;
        }
        HEAP32[32480>>2] = $643;
       }
       $exitcond = ($$pre265|0)==($531|0);
       if ($exitcond) {
        $linenum$0$lcssa = $531;
        break;
       } else {
        $linenum$0149 = $$pre265;
       }
      }
     }
     $644 = HEAP32[32296>>2]|0;
     $645 = ($644|0)<=($newlines$1$lcssa|0);
     $646 = ($linenum$0$lcssa|0)>($644|0);
     $or$cond272 = $645 | $646;
     if (!($or$cond272)) {
      $linenum$1147 = $linenum$0$lcssa;
      while(1) {
       $647 = HEAP32[32312>>2]|0;
       $648 = HEAP32[$647>>2]|0;
       $649 = ((($647)) + 4|0);
       $650 = HEAP32[$649>>2]|0;
       $651 = (($650) + ($linenum$1147<<2)|0);
       $652 = HEAP32[$651>>2]|0;
       $653 = (($648) + ($652)|0);
       $654 = HEAP32[32288>>2]|0;
       $655 = ($linenum$1147|0)==($654|0);
       $656 = HEAP32[35120>>2]|0;
       $657 = ($656|0)<($linenum$1147|0);
       $or$cond$i = $655 | $657;
       if (!($or$cond$i)) {
        $658 = (($linenum$1147) - ($654))|0;
        $659 = ($658|0)>(0);
        do {
         if ($659) {
          $i$03$i = 0;
          while(1) {
           $660 = HEAP32[13512>>2]|0;
           (_putc(10,($660|0))|0);
           $661 = (($i$03$i) + 1)|0;
           $exitcond$i = ($661|0)==($658|0);
           if ($exitcond$i) {
            break;
           } else {
            $i$03$i = $661;
           }
          }
          $662 = HEAP32[35144>>2]|0;
          (_tputs($662,1,368)|0);
          HEAP32[32280>>2] = 0;
         } else {
          $663 = HEAP32[35208>>2]|0;
          $664 = ($663|0)==(0|0);
          if ($664) {
           break;
          }
          $665 = HEAP8[$663>>0]|0;
          $666 = ($665<<24>>24)==(0);
          if ($666) {
           break;
          }
          $667 = (0 - ($658))|0;
          $668 = ($658|0)<(0);
          if (!($668)) {
           break;
          }
          (_tputs($663,1,368)|0);
          $669 = ($658|0)<(-1);
          if ($669) {
           $671 = 1;
          } else {
           break;
          }
          while(1) {
           $$pre$i105 = HEAP32[35208>>2]|0;
           (_tputs($$pre$i105,1,368)|0);
           $670 = (($671) + 1)|0;
           $672 = ($670|0)<($667|0);
           if ($672) {
            $671 = $670;
           } else {
            break;
           }
          }
         }
        } while(0);
        HEAP32[32288>>2] = $linenum$1147;
       }
       __rl_move_cursor_relative(0,$653);
       $673 = HEAP32[32296>>2]|0;
       $674 = ($linenum$1147|0)==($673|0);
       if ($674) {
        $675 = (_strlen(($653|0))|0);
        $680 = $675;
       } else {
        $676 = HEAP32[35112>>2]|0;
        $680 = $676;
       }
       $677 = HEAP32[35136>>2]|0;
       $678 = ($677|0)==(0|0);
       do {
        if ($678) {
         $679 = ($680|0)==(0);
         if ($679) {
          break;
         }
         $681 = ($680|0)>(0);
         if ($681) {
          $i$01$i$i106 = 0;
          while(1) {
           $682 = HEAP32[13512>>2]|0;
           (_putc(32,($682|0))|0);
           $683 = (($i$01$i$i106) + 1)|0;
           $exitcond$i$i107 = ($683|0)==($680|0);
           if ($exitcond$i$i107) {
            break;
           } else {
            $i$01$i$i106 = $683;
           }
          }
         }
         $684 = HEAP32[32280>>2]|0;
         $685 = (($684) + ($680))|0;
         HEAP32[32280>>2] = $685;
        } else {
         (_tputs($677,1,368)|0);
        }
       } while(0);
       $686 = (($linenum$1147) + 1)|0;
       $687 = HEAP32[32296>>2]|0;
       $688 = ($linenum$1147|0)<($687|0);
       if ($688) {
        $linenum$1147 = $686;
       } else {
        break;
       }
      }
     }
     HEAP32[32296>>2] = $newlines$1$lcssa;
     $689 = HEAP32[32288>>2]|0;
     $690 = ($lb_linenum$4|0)==($689|0);
     do {
      if ($690) {
       $$pre255 = HEAP32[32432>>2]|0;
       $717 = $$pre255;
      } else {
       $691 = HEAP32[35120>>2]|0;
       $692 = ($691|0)<($lb_linenum$4|0);
       if (!($692)) {
        $693 = (($lb_linenum$4) - ($689))|0;
        $694 = ($693|0)>(0);
        do {
         if ($694) {
          $i$03$i112 = 0;
          while(1) {
           $695 = HEAP32[13512>>2]|0;
           (_putc(10,($695|0))|0);
           $696 = (($i$03$i112) + 1)|0;
           $exitcond$i113 = ($696|0)==($693|0);
           if ($exitcond$i113) {
            break;
           } else {
            $i$03$i112 = $696;
           }
          }
          $697 = HEAP32[35144>>2]|0;
          (_tputs($697,1,368)|0);
          HEAP32[32280>>2] = 0;
         } else {
          $698 = HEAP32[35208>>2]|0;
          $699 = ($698|0)==(0|0);
          if ($699) {
           break;
          }
          $700 = HEAP8[$698>>0]|0;
          $701 = ($700<<24>>24)==(0);
          if ($701) {
           break;
          }
          $702 = (0 - ($693))|0;
          $703 = ($693|0)<(0);
          if (!($703)) {
           break;
          }
          (_tputs($698,1,368)|0);
          $704 = ($693|0)<(-1);
          if ($704) {
           $706 = 1;
          } else {
           break;
          }
          while(1) {
           $$pre$i119 = HEAP32[35208>>2]|0;
           (_tputs($$pre$i119,1,368)|0);
           $705 = (($706) + 1)|0;
           $707 = ($705|0)<($702|0);
           if ($707) {
            $706 = $705;
           } else {
            break;
           }
          }
         }
        } while(0);
        HEAP32[32288>>2] = $lb_linenum$4;
       }
       $708 = HEAP32[36240>>2]|0;
       $709 = ($708|0)!=(0);
       $710 = ($lb_linenum$4|0)==(0);
       $or$cond45 = $710 & $709;
       $711 = HEAP32[32432>>2]|0;
       $712 = ($711|0)!=(0);
       $or$cond48 = $or$cond45 & $712;
       if (!($or$cond48)) {
        $717 = $711;
        break;
       }
       $713 = HEAP32[32280>>2]|0;
       $714 = (($713) + ($711))|0;
       HEAP32[32280>>2] = $714;
       $717 = $711;
      }
     } while(0);
     $715 = HEAP32[32344>>2]|0;
     $716 = (($717) + ($715))|0;
     $718 = ($lb_linenum$4|0)==(0);
     $719 = ($717|0)>(0);
     $or$cond51 = $718 & $719;
     $720 = HEAP32[32280>>2]|0;
     $721 = ($720|0)>(0);
     $or$cond54 = $or$cond51 & $721;
     do {
      if ($or$cond54) {
       $722 = HEAP32[36240>>2]|0;
       $723 = ($722|0)==(0);
       $724 = HEAP32[32352>>2]|0;
       $725 = HEAP32[32472>>2]|0;
       $726 = (($725) + 1)|0;
       $727 = $723 ? $724 : $726;
       $728 = ($720|0)<($727|0);
       $729 = HEAP32[32384>>2]|0;
       $730 = ($729|0)!=(0|0);
       $or$cond57 = $730 & $728;
       if (!($or$cond57)) {
        $754 = $717;$756 = $720;
        break;
       }
       $731 = HEAP32[35144>>2]|0;
       $732 = ($731|0)==(0|0);
       if (!($732)) {
        (_tputs($731,1,368)|0);
       }
       $733 = HEAP32[32376>>2]|0;
       $734 = ($733|0)==(0);
       if (!($734)) {
        __rl_output_some_chars(32488,1);
       }
       $735 = HEAP32[32384>>2]|0;
       __rl_output_some_chars($735,$716);
       $736 = HEAP32[36240>>2]|0;
       $737 = ($736|0)==(0);
       if ($737) {
        $738 = HEAP32[32384>>2]|0;
        $739 = (__rl_col_width($738,0,$716,1)|0);
        $740 = HEAP32[32432>>2]|0;
        $741 = (($739) - ($740))|0;
        $742 = HEAP32[32376>>2]|0;
        $743 = (($741) + ($742))|0;
        HEAP32[32280>>2] = $743;
        $754 = $740;$756 = $743;
        break;
       } else {
        $744 = HEAP32[32376>>2]|0;
        $745 = (($744) + ($716))|0;
        HEAP32[32280>>2] = $745;
        $$pre256 = HEAP32[32432>>2]|0;
        $754 = $$pre256;$756 = $745;
        break;
       }
      } else {
       $754 = $717;$756 = $720;
      }
     } while(0);
     $746 = HEAP32[32368>>2]|0;
     $747 = ((($746)) + 4|0);
     $748 = HEAP32[$747>>2]|0;
     $749 = (($748) + ($lb_linenum$4<<2)|0);
     $750 = HEAP32[$749>>2]|0;
     $751 = HEAP32[32336>>2]|0;
     $752 = (($751) - ($750))|0;
     $753 = ($754|0)!=(0);
     $or$cond60 = $718 & $753;
     $755 = ($752|0)<($756|0);
     $or$cond92 = $or$cond60 & $755;
     do {
      if ($or$cond92) {
       $757 = HEAP32[36240>>2]|0;
       $758 = ($757|0)==(0);
       if ($758) {
        $759 = HEAP32[32312>>2]|0;
        $760 = HEAP32[$759>>2]|0;
        $761 = (($760) + ($750)|0);
        $762 = (__rl_col_width($761,0,$752,1)|0);
        $763 = HEAP32[32328>>2]|0;
        $764 = (($762) - ($763))|0;
        $tx$0 = $764;
       } else {
        $tx$0 = $752;
       }
       $765 = ($tx$0|0)>(-1);
       if (!($765)) {
        break;
       }
       $766 = HEAP32[32280>>2]|0;
       $767 = ($766|0)>($tx$0|0);
       if (!($767)) {
        break;
       }
       $768 = (($766) - ($tx$0))|0;
       (__rl_backspace($768)|0);
       HEAP32[32280>>2] = $tx$0;
      }
     } while(0);
     $769 = HEAP32[36240>>2]|0;
     $770 = ($769|0)==(0);
     if ($770) {
      $771 = HEAP32[32368>>2]|0;
      $772 = HEAP32[$771>>2]|0;
      $773 = (($772) + ($750)|0);
      __rl_move_cursor_relative($752,$773);
      break;
     }
     $774 = HEAP32[32280>>2]|0;
     $775 = ($752|0)==($774|0);
     if ($775) {
      break;
     }
     $776 = HEAP32[32368>>2]|0;
     $777 = HEAP32[$776>>2]|0;
     $778 = (($777) + ($750)|0);
     __rl_move_cursor_relative($752,$778);
    }
   }
  } else {
   label = 223;
  }
 } while(0);
 if ((label|0) == 223) {
  HEAP32[32288>>2] = 0;
  $779 = HEAP32[32336>>2]|0;
  $780 = HEAP32[32432>>2]|0;
  $781 = HEAP32[32344>>2]|0;
  $782 = (($781) + ($780))|0;
  $783 = HEAP32[32320>>2]|0;
  $784 = ($783|0)!=(0);
  $785 = $784 ? $783 : $780;
  $786 = (($779) - ($785))|0;
  $787 = HEAP32[35112>>2]|0;
  $788 = (($787|0) / 3)&-1;
  $789 = (($787) + -2)|0;
  $790 = ($786|0)>($789|0);
  do {
   if ($790) {
    $791 = $788 << 1;
    $792 = (($779) - ($791))|0;
    $793 = ($792|0)<(0);
    $$ = $793 ? 0 : $792;
    $794 = ($780|0)!=(0);
    $795 = ($$|0)>(0);
    $or$cond63 = $794 & $795;
    $796 = ($$|0)<($782|0);
    $or$cond93 = $796 & $or$cond63;
    $$$ = $or$cond93 ? $782 : $$;
    $lmargin$0 = $$$;
    label = 229;
   } else {
    $797 = (($779) - ($780))|0;
    $798 = ($797|0)<($789|0);
    if ($798) {
     $799 = ($782|0)>(0);
     $800 = $799&1;
     HEAP32[32456>>2] = $800;
     $814 = $780;$817 = $787;$lmargin$0128 = 0;
     break;
    }
    $801 = ($786|0)<(1);
    if ($801) {
     $802 = (($779) + -1)|0;
     $803 = (($802|0) % ($788|0))&-1;
     $804 = (($802) - ($803))|0;
     $805 = ($780|0)!=(0);
     $806 = ($804|0)>(0);
     $or$cond66 = $805 & $806;
     $807 = ($804|0)<($782|0);
     $or$cond94 = $807 & $or$cond66;
     $$104 = $or$cond94 ? $782 : $804;
     $lmargin$0 = $$104;
     label = 229;
    } else {
     $lmargin$0 = $783;
     label = 229;
    }
   }
  } while(0);
  if ((label|0) == 229) {
   $808 = ($lmargin$0|0)<($782|0);
   $809 = $808&1;
   HEAP32[32456>>2] = $809;
   $810 = ($lmargin$0|0)>(0);
   if ($810) {
    $811 = (($line$4$lcssa) + ($lmargin$0)|0);
    HEAP8[$811>>0] = 60;
    $$pre257 = HEAP32[32432>>2]|0;
    $$pre258 = HEAP32[35112>>2]|0;
    $814 = $$pre257;$817 = $$pre258;$lmargin$0128 = $lmargin$0;
   } else {
    $814 = $780;$817 = $787;$lmargin$0128 = $lmargin$0;
   }
  }
  $812 = ($lmargin$0128|0)==(0);
  $813 = $812 ? $814 : 0;
  $815 = (($813) + ($lmargin$0128))|0;
  $816 = (($815) + ($817))|0;
  $818 = ($816|0)<($out$3$lcssa|0);
  if ($818) {
   $819 = (($816) + -1)|0;
   $820 = (($line$4$lcssa) + ($819)|0);
   HEAP8[$820>>0] = 62;
  }
  $821 = HEAP32[32256>>2]|0;
  $822 = HEAP32[32400>>2]|0;
  $notlhs = ($821|0)!=(0);
  $notrhs = ($822|0)==(0);
  $or$cond69$not = $notlhs & $notrhs;
  $823 = HEAP32[32320>>2]|0;
  $824 = ($lmargin$0128|0)==($823|0);
  $or$cond96 = $or$cond69$not & $824;
  if (!($or$cond96)) {
   HEAP32[32400>>2] = 0;
   $825 = HEAP32[32280>>2]|0;
   HEAP32[32464>>2] = 0;
   $826 = HEAP32[32312>>2]|0;
   $827 = HEAP32[$826>>2]|0;
   $828 = (($827) + ($823)|0);
   $829 = HEAP32[32368>>2]|0;
   $830 = HEAP32[$829>>2]|0;
   $831 = (($830) + ($lmargin$0128)|0);
   $832 = HEAP32[35112>>2]|0;
   $833 = HEAP32[32328>>2]|0;
   $834 = (($833) + ($832))|0;
   $835 = ($lmargin$0128|0)!=(0);
   $836 = HEAP32[32432>>2]|0;
   $837 = $835 ? 0 : $836;
   $838 = (($837) + ($832))|0;
   _update_line($828,$831,0,$834,$838,0);
   $839 = HEAP32[36240>>2]|0;
   $840 = HEAP32[32456>>2]|0;
   $841 = ($840|0)!=(0);
   $842 = HEAP32[32464>>2]|0;
   $843 = $842 | $839;
   $844 = ($843|0)==(0);
   $845 = $841 & $844;
   $846 = HEAP32[32280>>2]|0;
   if ($845) {
    $847 = ($846|0)!=($825|0);
    $848 = HEAP32[32432>>2]|0;
    $849 = ($846|0)>($848|0);
    $or$cond98 = $847 & $849;
    $850 = HEAP32[32472>>2]|0;
    $851 = ($825|0)<($850|0);
    $or$cond100 = $or$cond98 & $851;
    if ($or$cond100) {
     $852 = HEAP32[32424>>2]|0;
     $853 = (($846) - ($852))|0;
     HEAP32[32280>>2] = $853;
     $855 = $848;$857 = $853;
    } else {
     $855 = $848;$857 = $846;
    }
   } else {
    $$pre261 = HEAP32[32432>>2]|0;
    $855 = $$pre261;$857 = $846;
   }
   $854 = $812 ? $855 : 0;
   $856 = (($857) - ($854))|0;
   $858 = HEAP32[32328>>2]|0;
   $859 = ($854|0)>($858|0);
   do {
    if ($859) {
     $860 = ($857|0)==($out$3$lcssa|0);
     $or$cond78 = $860 & $841;
     $861 = HEAP32[32480>>2]|0;
     $862 = ($856|0)<($861|0);
     $or$cond102 = $or$cond78 & $862;
     if ($or$cond102) {
      $863 = HEAP32[35112>>2]|0;
      $864 = (($863) - ($856))|0;
      $865 = HEAP32[35136>>2]|0;
      $866 = ($865|0)==(0|0);
      if (!($866)) {
       (_tputs($865,1,368)|0);
       break;
      }
      $867 = ($863|0)==($856|0);
      if ($867) {
       break;
      }
      $868 = ($864|0)>(0);
      if ($868) {
       $i$01$i$i123 = 0;
       while(1) {
        $869 = HEAP32[13512>>2]|0;
        (_putc(32,($869|0))|0);
        $870 = (($i$01$i$i123) + 1)|0;
        $exitcond$i$i124 = ($870|0)==($864|0);
        if ($exitcond$i$i124) {
         break;
        } else {
         $i$01$i$i123 = $870;
        }
       }
       $$pre262 = HEAP32[32280>>2]|0;
       $872 = $$pre262;
      } else {
       $872 = $out$3$lcssa;
      }
      $871 = (($872) + ($864))|0;
      HEAP32[32280>>2] = $871;
     }
    }
   } while(0);
   $873 = (($out$3$lcssa) - ($lmargin$0128))|0;
   $874 = HEAP32[32432>>2]|0;
   $$op = (0 - ($874))|0;
   $$neg134 = $812 ? $$op : 0;
   $875 = (($$neg134) + ($873))|0;
   $876 = HEAP32[35112>>2]|0;
   $877 = ($875|0)>($876|0);
   $$103 = $877 ? $876 : $875;
   HEAP32[32480>>2] = $$103;
   $878 = HEAP32[32336>>2]|0;
   $879 = (($878) - ($lmargin$0128))|0;
   $880 = HEAP32[32368>>2]|0;
   $881 = HEAP32[$880>>2]|0;
   $882 = (($881) + ($lmargin$0128)|0);
   __rl_move_cursor_relative($879,$882);
   HEAP32[32320>>2] = $lmargin$0128;
  }
 }
 $883 = HEAP32[13512>>2]|0;
 (_fflush(($883|0))|0);
 $884 = HEAP32[8078]|0;
 $885 = HEAP32[8092]|0;
 HEAP32[8078] = $885;
 HEAP32[8092] = $884;
 HEAP32[32256>>2] = 0;
 $886 = HEAP32[13600>>2]|0;
 $887 = ($886|0)!=(0);
 $888 = HEAP32[32320>>2]|0;
 $889 = ($888|0)!=(0);
 $or$cond81 = $887 & $889;
 $890 = HEAP32[32432>>2]|0;
 $storemerge82 = $or$cond81 ? 0 : $890;
 HEAP32[32328>>2] = $storemerge82;
 $891 = HEAP32[13488>>2]|0;
 $892 = $891 & -8388609;
 HEAP32[13488>>2] = $892;
 __rl_release_sigint();
 STACKTOP = sp;return;
}
function __rl_strip_prompt($pmt) {
 $pmt = $pmt|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_expand_prompt($pmt,0,0,0,0)|0);
 return ($0|0);
}
function __rl_reset_prompt() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13528>>2]|0;
 $1 = (_rl_expand_prompt($0)|0);
 HEAP32[13536>>2] = $1;
 return;
}
function _rl_expand_prompt($prompt) {
 $prompt = $prompt|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32384>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  _free($0);
 }
 $2 = HEAP32[32392>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 HEAP32[32392>>2] = 0;
 HEAP32[32384>>2] = 0;
 HEAP32[32408>>2] = 0;
 HEAP32[32424>>2] = 0;
 HEAP32[32472>>2] = 0;
 HEAP32[32352>>2] = 0;
 HEAP32[32344>>2] = 0;
 $4 = ($prompt|0)==(0|0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = HEAP8[$prompt>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if ($6) {
  $$0 = 0;
  return ($$0|0);
 }
 $7 = (_strrchr($prompt,10)|0);
 $8 = ($7|0)==(0|0);
 if ($8) {
  $9 = (_expand_prompt($prompt,32344,32472,32424,32352)|0);
  HEAP32[32384>>2] = $9;
  HEAP32[32392>>2] = 0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $12 = 0;
  } else {
   $11 = (_strlen(($9|0))|0);
   $12 = $11;
  }
  HEAP32[32408>>2] = $12;
  $13 = HEAP32[32344>>2]|0;
  $$0 = $13;
  return ($$0|0);
 } else {
  $14 = ((($7)) + 1|0);
  $15 = (_expand_prompt($14,32344,32472,32424,32352)|0);
  HEAP32[32384>>2] = $15;
  $16 = HEAP8[$14>>0]|0;
  HEAP8[$14>>0] = 0;
  $17 = (_expand_prompt($prompt,32496,0,0,0)|0);
  HEAP32[32392>>2] = $17;
  HEAP8[$14>>0] = $16;
  $18 = HEAP32[32384>>2]|0;
  $19 = ($18|0)==(0|0);
  if ($19) {
   $21 = 0;
  } else {
   $20 = (_strlen(($18|0))|0);
   $21 = $20;
  }
  HEAP32[32408>>2] = $21;
  $22 = HEAP32[32496>>2]|0;
  $$0 = $22;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_on_new_line() {
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32312>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = $0;
 } else {
  HEAP8[$1>>0] = 0;
  $$pre = HEAP32[32312>>2]|0;
  $4 = $$pre;
 }
 HEAP32[32288>>2] = 0;
 HEAP32[32280>>2] = 0;
 HEAP32[32320>>2] = 0;
 HEAP32[32296>>2] = 0;
 $3 = ((($4)) + 4|0);
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  HEAP32[32328>>2] = 0;
  return 0;
 }
 $7 = ((($5)) + 4|0);
 HEAP32[$7>>2] = 0;
 HEAP32[$5>>2] = 0;
 HEAP32[32328>>2] = 0;
 return 0;
}
function __rl_clear_to_eol($count) {
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $exitcond$i = 0, $i$01$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35136>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  (_tputs($0,1,368)|0);
  return;
 }
 $2 = ($count|0)==(0);
 if ($2) {
  return;
 }
 $3 = ($count|0)>(0);
 if ($3) {
  $i$01$i = 0;
  while(1) {
   $4 = HEAP32[13512>>2]|0;
   (_putc(32,($4|0))|0);
   $5 = (($i$01$i) + 1)|0;
   $exitcond$i = ($5|0)==($count|0);
   if ($exitcond$i) {
    break;
   } else {
    $i$01$i = $5;
   }
  }
 }
 $6 = HEAP32[32280>>2]|0;
 $7 = (($6) + ($count))|0;
 HEAP32[32280>>2] = $7;
 return;
}
function __rl_move_vert($to) {
 $to = $to|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $exitcond = 0, $i$03 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32288>>2]|0;
 $1 = ($0|0)==($to|0);
 $2 = HEAP32[35120>>2]|0;
 $3 = ($2|0)<($to|0);
 $or$cond = $1 | $3;
 if ($or$cond) {
  return;
 }
 $4 = (($to) - ($0))|0;
 $5 = ($4|0)>(0);
 if ($5) {
  $i$03 = 0;
  while(1) {
   $6 = HEAP32[13512>>2]|0;
   (_putc(10,($6|0))|0);
   $7 = (($i$03) + 1)|0;
   $exitcond = ($7|0)==($4|0);
   if ($exitcond) {
    break;
   } else {
    $i$03 = $7;
   }
  }
  $8 = HEAP32[35144>>2]|0;
  (_tputs($8,1,368)|0);
  HEAP32[32280>>2] = 0;
 } else {
  $9 = HEAP32[35208>>2]|0;
  $10 = ($9|0)==(0|0);
  if (!($10)) {
   $11 = HEAP8[$9>>0]|0;
   $12 = ($11<<24>>24)==(0);
   if (!($12)) {
    $13 = (0 - ($4))|0;
    $14 = ($4|0)<(0);
    if ($14) {
     (_tputs($9,1,368)|0);
     $15 = ($4|0)<(-1);
     if ($15) {
      $17 = 1;
      while(1) {
       $$pre = HEAP32[35208>>2]|0;
       (_tputs($$pre,1,368)|0);
       $16 = (($17) + 1)|0;
       $18 = ($16|0)<($13|0);
       if ($18) {
        $17 = $16;
       } else {
        break;
       }
      }
     }
    }
   }
  }
 }
 HEAP32[32288>>2] = $to;
 return;
}
function __rl_move_cursor_relative($new,$data) {
 $new = $new|0;
 $data = $data|0;
 var $$pre18 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $cpos$0 = 0, $dpos$1 = 0, $exitcond = 0, $exitcond15 = 0, $exitcond1523 = 0, $exitcond16 = 0, $i$0 = 0, $i$210 = 0, $i$313 = 0, $or$cond = 0;
 var $or$cond2 = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32288>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[32432>>2]|0;
  $3 = ($2|0)==(0);
  if ($3) {
   $45 = 0;
  } else {
   $4 = HEAP32[32352>>2]|0;
   $5 = HEAP32[35112>>2]|0;
   $6 = ($4|0)>($5|0);
   $7 = HEAP32[32424>>2]|0;
   $8 = $6 ? $7 : $2;
   $45 = $8;
  }
 } else {
  $9 = HEAP32[32440>>2]|0;
  $10 = ($0|0)==($9|0);
  if ($10) {
   $11 = HEAP32[32432>>2]|0;
   $12 = HEAP32[32424>>2]|0;
   $13 = (($11) - ($12))|0;
   $45 = $13;
  } else {
   $45 = 0;
  }
 }
 $14 = HEAP32[32280>>2]|0;
 $15 = ($14|0)==(0);
 $16 = ($14|0)==($new|0);
 $or$cond2 = $15 & $16;
 if ($or$cond2) {
  return;
 }
 $17 = HEAP32[36240>>2]|0;
 $18 = ($17|0)==(0);
 do {
  if ($18) {
   $19 = HEAP32[32408>>2]|0;
   $20 = ($19|0)==($new|0);
   $21 = HEAP32[32384>>2]|0;
   if ($20) {
    $22 = (_memcmp($data,$21,$new)|0);
    $23 = ($22|0)==(0);
    if ($23) {
     $24 = HEAP32[32352>>2]|0;
     HEAP32[32464>>2] = 1;
     $dpos$1 = $24;
     break;
    }
   }
   $25 = ($19|0)<($new|0);
   $26 = ($21|0)!=(0|0);
   $or$cond = $25 & $26;
   if ($or$cond) {
    $27 = (_memcmp($data,$21,$19)|0);
    $28 = ($27|0)==(0);
    if ($28) {
     $29 = HEAP32[32352>>2]|0;
     $30 = (__rl_col_width($data,$19,$new,1)|0);
     $31 = (($30) + ($29))|0;
     HEAP32[32464>>2] = 1;
     $dpos$1 = $31;
     break;
    }
   }
   $32 = (__rl_col_width($data,0,$new,1)|0);
   $33 = HEAP32[32456>>2]|0;
   $34 = ($33|0)==(0);
   if ($34) {
    $dpos$1 = $32;
   } else {
    $35 = HEAP32[32472>>2]|0;
    $36 = ($35|0)<($new|0);
    if (!($36)) {
     $37 = HEAP32[32352>>2]|0;
     $38 = HEAP32[35112>>2]|0;
     $39 = ($37|0)<($38|0);
     if ($39) {
      $dpos$1 = $32;
      break;
     }
     $40 = HEAP32[32288>>2]|0;
     $41 = HEAP32[32440>>2]|0;
     $42 = ($40|0)==($41|0);
     if (!($42)) {
      $dpos$1 = $32;
      break;
     }
     $43 = HEAP32[32432>>2]|0;
     $44 = ($43|0)<($45|0);
     $46 = ($32|0)<($45|0);
     $or$cond3 = $46 | $44;
     if ($or$cond3) {
      $dpos$1 = $32;
      break;
     }
     $47 = Math_imul($40, $38)|0;
     $48 = (($35) - ($47))|0;
     $49 = (($48) - ($43))|0;
     $50 = ($49|0)<($new|0);
     if (!($50)) {
      $dpos$1 = $32;
      break;
     }
    }
    $51 = (($32) - ($45))|0;
    HEAP32[32464>>2] = 1;
    $dpos$1 = $51;
   }
  } else {
   $dpos$1 = $new;
  }
 } while(0);
 $52 = ($14|0)==($dpos$1|0);
 if ($52) {
  return;
 }
 $53 = HEAP32[36240>>2]|0;
 $54 = ($53|0)==(0);
 $55 = HEAP32[32280>>2]|0;
 $56 = $54 ? 0 : $45;
 $i$0 = (($55) - ($56))|0;
 $57 = ($dpos$1|0)==(0);
 if ($57) {
  label = 25;
 } else {
  $58 = (($dpos$1) + 1)|0;
  $59 = (($55) - ($dpos$1))|0;
  $60 = ($58|0)<($59|0);
  if ($60) {
   label = 25;
  } else {
   $61 = HEAP32[35096>>2]|0;
   $62 = ($61|0)!=(0);
   $63 = HEAP32[35112>>2]|0;
   $64 = ($i$0|0)==($63|0);
   $or$cond5 = $62 & $64;
   if ($or$cond5) {
    label = 25;
   } else {
    $cpos$0 = $14;
   }
  }
 }
 if ((label|0) == 25) {
  $65 = HEAP32[35144>>2]|0;
  (_tputs($65,1,368)|0);
  HEAP32[32280>>2] = 0;
  $cpos$0 = 0;
 }
 $66 = ($cpos$0|0)<($dpos$1|0);
 L37: do {
  if ($66) {
   $67 = HEAP32[36240>>2]|0;
   $68 = ($67|0)==(0);
   if (!($68)) {
    $69 = ($cpos$0|0)<($new|0);
    if ($69) {
     $i$313 = $cpos$0;
    } else {
     break;
    }
    while(1) {
     $82 = (($data) + ($i$313)|0);
     $83 = HEAP8[$82>>0]|0;
     $84 = $83 << 24 >> 24;
     $85 = HEAP32[13512>>2]|0;
     (_putc(($84|0),($85|0))|0);
     $86 = (($i$313) + 1)|0;
     $exitcond16 = ($86|0)==($new|0);
     if ($exitcond16) {
      break L37;
     } else {
      $i$313 = $86;
     }
    }
   }
   $70 = HEAP32[35216>>2]|0;
   $71 = ($70|0)==(0|0);
   if ($71) {
    $75 = HEAP32[35144>>2]|0;
    (_tputs($75,1,368)|0);
    $76 = ($new|0)>(0);
    if ($76) {
     $i$210 = 0;
    } else {
     break;
    }
    while(1) {
     $77 = (($data) + ($i$210)|0);
     $78 = HEAP8[$77>>0]|0;
     $79 = $78 << 24 >> 24;
     $80 = HEAP32[13512>>2]|0;
     (_putc(($79|0),($80|0))|0);
     $81 = (($i$210) + 1)|0;
     $exitcond = ($81|0)==($new|0);
     if ($exitcond) {
      break;
     } else {
      $i$210 = $81;
     }
    }
   } else {
    (_tputs($70,1,368)|0);
    $72 = (($cpos$0) + 1)|0;
    $exitcond1523 = ($72|0)==($dpos$1|0);
    if ($exitcond1523) {
     break;
    } else {
     $74 = $72;
    }
    while(1) {
     $$pre18 = HEAP32[35216>>2]|0;
     (_tputs($$pre18,1,368)|0);
     $73 = (($74) + 1)|0;
     $exitcond15 = ($73|0)==($dpos$1|0);
     if ($exitcond15) {
      break;
     } else {
      $74 = $73;
     }
    }
   }
  } else {
   $87 = ($cpos$0|0)>($dpos$1|0);
   if ($87) {
    $88 = (($cpos$0) - ($dpos$1))|0;
    (__rl_backspace($88)|0);
   }
  }
 } while(0);
 HEAP32[32280>>2] = $dpos$1;
 return;
}
function _rl_on_new_line_with_prompt() {
 var $$ = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $i$02 = 0, $newlines$0$lcssa = 0, $newlines$01 = 0, $not$ = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13528>>2]|0;
 $1 = (_strlen(($0|0))|0);
 $2 = (($1) + 1)|0;
 _init_line_structures($2);
 $3 = HEAP32[32384>>2]|0;
 $4 = ($3|0)!=(0|0);
 $5 = HEAP32[13528>>2]|0;
 $6 = $4 ? $3 : $5;
 $7 = HEAP32[32312>>2]|0;
 $8 = HEAP32[$7>>2]|0;
 (_strcpy(($8|0),($6|0))|0);
 $9 = HEAP32[32368>>2]|0;
 $10 = HEAP32[$9>>2]|0;
 (_strcpy(($10|0),($6|0))|0);
 $11 = HEAP32[13528>>2]|0;
 $12 = (_strrchr($11,10)|0);
 $13 = ($12|0)==(0|0);
 $$ = $13 ? $11 : $12;
 $14 = (_strlen(($$|0))|0);
 $15 = HEAP32[36240>>2]|0;
 $16 = ($15|0)==(0);
 if ($16) {
  $17 = (__rl_col_width($$,0,$14,1)|0);
  $storemerge = $17;
 } else {
  $storemerge = $14;
 }
 HEAP32[32280>>2] = $storemerge;
 $18 = HEAP32[35112>>2]|0;
 $19 = HEAP32[35096>>2]|0;
 $not$ = ($19|0)==(0);
 $20 = $not$&1;
 $21 = (($20) + ($18))|0;
 $22 = (($14|0) / ($21|0))&-1;
 HEAP32[32288>>2] = $22;
 $23 = ($14|0)>(0);
 if ($23) {
  $24 = (($14|0) % ($21|0))&-1;
  $25 = ($24|0)==(0);
  if ($25) {
   __rl_output_some_chars(37240,1);
  }
  HEAP32[32320>>2] = 0;
 } else {
  HEAP32[32320>>2] = 0;
  $26 = ($14|0)<(0);
  if ($26) {
   $$pre = HEAP32[32312>>2]|0;
   $$phi$trans$insert = ((($$pre)) + 4|0);
   $$pre4 = HEAP32[$$phi$trans$insert>>2]|0;
   $35 = $$pre4;$newlines$0$lcssa = 0;
   $34 = (($35) + ($newlines$0$lcssa<<2)|0);
   HEAP32[$34>>2] = $14;
   HEAP32[32328>>2] = 0;
   $36 = HEAP32[13528>>2]|0;
   HEAP32[32272>>2] = $36;
   return 0;
  }
 }
 $27 = HEAP32[32312>>2]|0;
 $28 = ((($27)) + 4|0);
 $29 = HEAP32[$28>>2]|0;
 $i$02 = 0;$newlines$01 = 0;
 while(1) {
  HEAP32[32296>>2] = $newlines$01;
  $30 = (($newlines$01) + 1)|0;
  $31 = (($29) + ($newlines$01<<2)|0);
  HEAP32[$31>>2] = $i$02;
  $32 = (($i$02) + ($21))|0;
  $33 = ($32|0)>($14|0);
  if ($33) {
   $35 = $29;$newlines$0$lcssa = $30;
   break;
  } else {
   $i$02 = $32;$newlines$01 = $30;
  }
 }
 $34 = (($35) + ($newlines$0$lcssa<<2)|0);
 HEAP32[$34>>2] = $14;
 HEAP32[32328>>2] = 0;
 $36 = HEAP32[13528>>2]|0;
 HEAP32[32272>>2] = $36;
 return 0;
}
function _rl_forced_update_display() {
 var $$pre$i = 0, $$pre$pre = 0, $$pre2$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $temp$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32312>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $11 = $0;
  } else {
   $3 = HEAP8[$1>>0]|0;
   $4 = ($3<<24>>24)==(0);
   if ($4) {
    $9 = $1;
   } else {
    $temp$01 = $1;
    while(1) {
     $5 = ((($temp$01)) + 1|0);
     HEAP8[$temp$01>>0] = 0;
     $6 = HEAP8[$5>>0]|0;
     $7 = ($6<<24>>24)==(0);
     if ($7) {
      break;
     } else {
      $temp$01 = $5;
     }
    }
    $$pre$pre = HEAP32[32312>>2]|0;
    $$pre2$pre = HEAP32[$$pre$pre>>2]|0;
    $8 = ($$pre2$pre|0)==(0|0);
    if ($8) {
     $11 = $$pre$pre;
     break;
    } else {
     $9 = $$pre2$pre;
    }
   }
   HEAP8[$9>>0] = 0;
   $$pre$i = HEAP32[32312>>2]|0;
   $11 = $$pre$i;
  }
 } while(0);
 HEAP32[32288>>2] = 0;
 HEAP32[32280>>2] = 0;
 HEAP32[32320>>2] = 0;
 HEAP32[32296>>2] = 0;
 $10 = ((($11)) + 4|0);
 $12 = HEAP32[$10>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  $14 = ((($12)) + 4|0);
  HEAP32[$14>>2] = 0;
  HEAP32[$12>>2] = 0;
 }
 HEAP32[32328>>2] = 0;
 $15 = HEAP32[32400>>2]|0;
 $16 = (($15) + 1)|0;
 HEAP32[32400>>2] = $16;
 $17 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$17 & 511]();
 return 0;
}
function _rl_character_len($c,$pos) {
 $c = $c|0;
 $pos = $pos|0;
 var $$0 = 0, $$old1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = ($0>>>0)>(127);
 if ($1) {
  $2 = HEAP32[13696>>2]|0;
  $3 = ($2|0)==(0);
  $4 = $3 ? 4 : 1;
  $$0 = $4;
  return ($$0|0);
 }
 $5 = ($0|0)==(9);
 if ($5) {
  $6 = $pos | 7;
  $7 = (1 - ($pos))|0;
  $8 = (($7) + ($6))|0;
  $$0 = $8;
  return ($$0|0);
 }
 $9 = ($c|0)<(32);
 if ($9) {
  $10 = $c & 128;
  $11 = ($10|0)==(0);
  if ($11) {
   $$0 = 2;
   return ($$0|0);
  }
 } else {
  $$old1 = ($c|0)==(127);
  if ($$old1) {
   $$0 = 2;
   return ($$0|0);
  }
 }
 $12 = (_isprint($0)|0);
 $13 = ($12|0)!=(0);
 $14 = $13 ? 1 : 2;
 $$0 = $14;
 return ($$0|0);
}
function _rl_message($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $$cast = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $args = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $args = sp;
 HEAP32[$args>>2] = $varargs;
 $0 = HEAP32[32504>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[32512>>2] = 128;
  $2 = (_xmalloc(128)|0);
  HEAP32[32504>>2] = $2;
  $5 = $2;
 } else {
  $5 = $0;
 }
 $3 = HEAP32[32512>>2]|0;
 $4 = (($3) + -1)|0;
 $6 = (_vsnprintf($5,$4,$format,$args)|0);
 $7 = HEAP32[32512>>2]|0;
 $8 = (($7) + -1)|0;
 $9 = ($6|0)<($8|0);
 if (!($9)) {
  $10 = (($6) + 1)|0;
  HEAP32[32512>>2] = $10;
  $11 = HEAP32[32504>>2]|0;
  $12 = (_xrealloc($11,$10)|0);
  HEAP32[32504>>2] = $12;
  HEAP32[$args>>2] = $varargs;
  $13 = HEAP32[32504>>2]|0;
  $14 = HEAP32[32512>>2]|0;
  $15 = (($14) + -1)|0;
  (_vsnprintf($13,$15,$format,$args)|0);
 }
 $16 = HEAP32[32520>>2]|0;
 $17 = ($16|0)==(0|0);
 if ($17) {
  $18 = HEAP32[32384>>2]|0;
  HEAP32[32520>>2] = $18;
  $19 = HEAP32[32392>>2]|0;
  HEAP32[32528>>2] = $19;
  $20 = HEAP32[32496>>2]|0;
  HEAP32[32536>>2] = $20;
  $21 = HEAP32[32408>>2]|0;
  HEAP32[32544>>2] = $21;
  $22 = HEAP32[32472>>2]|0;
  HEAP32[32552>>2] = $22;
  $23 = HEAP32[32344>>2]|0;
  HEAP32[32560>>2] = $23;
  $24 = HEAP32[32424>>2]|0;
  HEAP32[32568>>2] = $24;
  $25 = HEAP32[32352>>2]|0;
  HEAP32[32576>>2] = $25;
  HEAP32[32392>>2] = 0;
  HEAP32[32384>>2] = 0;
  HEAP32[32408>>2] = 0;
  HEAP32[32496>>2] = 0;
  HEAP32[32344>>2] = 0;
  HEAP32[32472>>2] = 0;
  HEAP32[32352>>2] = 0;
  HEAP32[32424>>2] = 0;
  HEAP32[32584>>2] = 1;
 } else {
  $26 = HEAP32[32384>>2]|0;
  $27 = ($26|0)==($16|0);
  if (!($27)) {
   $28 = ($26|0)==(0|0);
   if (!($28)) {
    _free($26);
   }
   $29 = HEAP32[32392>>2]|0;
   $30 = ($29|0)==(0|0);
   if (!($30)) {
    _free($29);
   }
   HEAP32[32384>>2] = 0;
  }
 }
 $31 = HEAP32[32504>>2]|0;
 HEAP32[32272>>2] = $31;
 $$cast = $31;
 $32 = (_expand_prompt($$cast,32344,32472,32424,32352)|0);
 HEAP32[32384>>2] = $32;
 HEAP32[32392>>2] = 0;
 $33 = ($32|0)==(0|0);
 if ($33) {
  $35 = 0;
  HEAP32[32408>>2] = $35;
  $36 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$36 & 511]();
  STACKTOP = sp;return 0;
 }
 $34 = (_strlen(($32|0))|0);
 $35 = $34;
 HEAP32[32408>>2] = $35;
 $36 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$36 & 511]();
 STACKTOP = sp;return 0;
}
function _rl_save_prompt() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32384>>2]|0;
 HEAP32[32520>>2] = $0;
 $1 = HEAP32[32392>>2]|0;
 HEAP32[32528>>2] = $1;
 $2 = HEAP32[32496>>2]|0;
 HEAP32[32536>>2] = $2;
 $3 = HEAP32[32408>>2]|0;
 HEAP32[32544>>2] = $3;
 $4 = HEAP32[32472>>2]|0;
 HEAP32[32552>>2] = $4;
 $5 = HEAP32[32344>>2]|0;
 HEAP32[32560>>2] = $5;
 $6 = HEAP32[32424>>2]|0;
 HEAP32[32568>>2] = $6;
 $7 = HEAP32[32352>>2]|0;
 HEAP32[32576>>2] = $7;
 HEAP32[32392>>2] = 0;
 HEAP32[32384>>2] = 0;
 HEAP32[32408>>2] = 0;
 HEAP32[32496>>2] = 0;
 HEAP32[32344>>2] = 0;
 HEAP32[32472>>2] = 0;
 HEAP32[32352>>2] = 0;
 HEAP32[32424>>2] = 0;
 return;
}
function _rl_clear_message() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13528>>2]|0;
 HEAP32[32272>>2] = $0;
 $1 = HEAP32[32584>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  $15 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$15 & 511]();
  return 0;
 }
 $3 = HEAP32[32384>>2]|0;
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  _free($3);
 }
 $5 = HEAP32[32392>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _free($5);
 }
 $7 = HEAP32[32520>>2]|0;
 HEAP32[32384>>2] = $7;
 $8 = HEAP32[32528>>2]|0;
 HEAP32[32392>>2] = $8;
 $9 = HEAP32[32544>>2]|0;
 HEAP32[32408>>2] = $9;
 $10 = HEAP32[32536>>2]|0;
 HEAP32[32496>>2] = $10;
 $11 = HEAP32[32552>>2]|0;
 HEAP32[32472>>2] = $11;
 $12 = HEAP32[32560>>2]|0;
 HEAP32[32344>>2] = $12;
 $13 = HEAP32[32568>>2]|0;
 HEAP32[32424>>2] = $13;
 $14 = HEAP32[32576>>2]|0;
 HEAP32[32352>>2] = $14;
 HEAP32[32528>>2] = 0;
 HEAP32[32520>>2] = 0;
 HEAP32[32544>>2] = 0;
 HEAP32[32536>>2] = 0;
 HEAP32[32560>>2] = 0;
 HEAP32[32552>>2] = 0;
 HEAP32[32576>>2] = 0;
 HEAP32[32568>>2] = 0;
 HEAP32[32584>>2] = 0;
 $15 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$15 & 511]();
 return 0;
}
function _rl_restore_prompt() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32384>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  _free($0);
 }
 $2 = HEAP32[32392>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 $4 = HEAP32[32520>>2]|0;
 HEAP32[32384>>2] = $4;
 $5 = HEAP32[32528>>2]|0;
 HEAP32[32392>>2] = $5;
 $6 = HEAP32[32544>>2]|0;
 HEAP32[32408>>2] = $6;
 $7 = HEAP32[32536>>2]|0;
 HEAP32[32496>>2] = $7;
 $8 = HEAP32[32552>>2]|0;
 HEAP32[32472>>2] = $8;
 $9 = HEAP32[32560>>2]|0;
 HEAP32[32344>>2] = $9;
 $10 = HEAP32[32568>>2]|0;
 HEAP32[32424>>2] = $10;
 $11 = HEAP32[32576>>2]|0;
 HEAP32[32352>>2] = $11;
 HEAP32[32528>>2] = 0;
 HEAP32[32520>>2] = 0;
 HEAP32[32544>>2] = 0;
 HEAP32[32536>>2] = 0;
 HEAP32[32560>>2] = 0;
 HEAP32[32552>>2] = 0;
 HEAP32[32576>>2] = 0;
 HEAP32[32568>>2] = 0;
 return;
}
function _rl_reset_line_state() {
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32312>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $4 = $0;
 } else {
  HEAP8[$1>>0] = 0;
  $$pre$i = HEAP32[32312>>2]|0;
  $4 = $$pre$i;
 }
 HEAP32[32288>>2] = 0;
 HEAP32[32280>>2] = 0;
 HEAP32[32320>>2] = 0;
 HEAP32[32296>>2] = 0;
 $3 = ((($4)) + 4|0);
 $5 = HEAP32[$3>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  $7 = ((($5)) + 4|0);
  HEAP32[$7>>2] = 0;
  HEAP32[$5>>2] = 0;
 }
 HEAP32[32328>>2] = 0;
 $8 = HEAP32[13528>>2]|0;
 $9 = ($8|0)!=(0|0);
 $10 = $9 ? $8 : 37352;
 HEAP32[32272>>2] = $10;
 HEAP32[32400>>2] = 1;
 return 0;
}
function __rl_make_prompt_for_search($pchar) {
 $pchar = $pchar|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $pmt$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32384>>2]|0;
 HEAP32[32520>>2] = $0;
 $1 = HEAP32[32392>>2]|0;
 HEAP32[32528>>2] = $1;
 $2 = HEAP32[32496>>2]|0;
 HEAP32[32536>>2] = $2;
 $3 = HEAP32[32408>>2]|0;
 HEAP32[32544>>2] = $3;
 $4 = HEAP32[32472>>2]|0;
 HEAP32[32552>>2] = $4;
 $5 = HEAP32[32344>>2]|0;
 HEAP32[32560>>2] = $5;
 $6 = HEAP32[32424>>2]|0;
 HEAP32[32568>>2] = $6;
 $7 = HEAP32[32352>>2]|0;
 HEAP32[32576>>2] = $7;
 HEAP32[32392>>2] = 0;
 HEAP32[32384>>2] = 0;
 HEAP32[32408>>2] = 0;
 HEAP32[32496>>2] = 0;
 HEAP32[32344>>2] = 0;
 HEAP32[32472>>2] = 0;
 HEAP32[32352>>2] = 0;
 HEAP32[32424>>2] = 0;
 $8 = HEAP32[13528>>2]|0;
 $9 = ($8|0)==(0|0);
 do {
  if ($9) {
   label = 4;
  } else {
   $10 = (_strrchr($8,10)|0);
   $11 = ($10|0)==(0|0);
   if ($11) {
    $12 = HEAP8[$8>>0]|0;
    $13 = ($12<<24>>24)==(0);
    if ($13) {
     label = 4;
     break;
    }
    $15 = (_strlen(($8|0))|0);
    $16 = (($15) + 2)|0;
    $17 = (_xmalloc($16)|0);
    $18 = ($15|0)==(0);
    if ($18) {
     $22 = $17;$23 = 0;
     break;
    }
    $19 = HEAP32[13528>>2]|0;
    (_strcpy(($17|0),($19|0))|0);
    $22 = $17;$23 = $15;
    break;
   }
   $26 = ((($10)) + 1|0);
   $27 = (_strlen(($26|0))|0);
   $28 = (($27) + 2)|0;
   $29 = (_xmalloc($28)|0);
   $30 = ($27|0)==(0);
   if (!($30)) {
    (_strcpy(($29|0),($26|0))|0);
   }
   $31 = $pchar&255;
   $32 = (($29) + ($27)|0);
   HEAP8[$32>>0] = $31;
   $33 = (($27) + 1)|0;
   $34 = (($29) + ($33)|0);
   HEAP8[$34>>0] = 0;
   $pmt$0 = $29;
   $35 = HEAP32[32576>>2]|0;
   $36 = (($35) + 1)|0;
   HEAP32[32352>>2] = $36;
   return ($pmt$0|0);
  }
 } while(0);
 if ((label|0) == 4) {
  $14 = (_xmalloc(2)|0);
  $22 = $14;$23 = 0;
 }
 $20 = $pchar&255;
 $21 = (($22) + ($23)|0);
 HEAP8[$21>>0] = $20;
 $24 = (($23) + 1)|0;
 $25 = (($22) + ($24)|0);
 HEAP8[$25>>0] = 0;
 $pmt$0 = $22;
 $35 = HEAP32[32576>>2]|0;
 $36 = (($35) + 1)|0;
 HEAP32[32352>>2] = $36;
 return ($pmt$0|0);
}
function __rl_erase_at_end_of_line($l) {
 $l = $l|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond6 = 0, $i$02 = 0, $i$11 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (__rl_backspace($l)|0);
 $0 = ($l|0)>(0);
 if ($0) {
  $i$02 = 0;
  while(1) {
   $1 = HEAP32[13512>>2]|0;
   (_putc(32,($1|0))|0);
   $2 = (($i$02) + 1)|0;
   $exitcond6 = ($2|0)==($l|0);
   if ($exitcond6) {
    break;
   } else {
    $i$02 = $2;
   }
  }
  (__rl_backspace($l)|0);
  if ($0) {
   $i$11 = 0;
   while(1) {
    $3 = HEAP32[32280>>2]|0;
    $4 = (($3) + -1)|0;
    HEAP32[32280>>2] = $4;
    $5 = HEAP32[32312>>2]|0;
    $6 = HEAP32[$5>>2]|0;
    $7 = (($6) + ($4)|0);
    HEAP8[$7>>0] = 0;
    $8 = (($i$11) + 1)|0;
    $exitcond = ($8|0)==($l|0);
    if ($exitcond) {
     break;
    } else {
     $i$11 = $8;
    }
   }
  }
 } else {
  (__rl_backspace($l)|0);
 }
 $9 = HEAP32[32256>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[32256>>2] = $10;
 return;
}
function __rl_clear_screen() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35152>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_crlf()|0);
  return;
 } else {
  (_tputs($0,1,368)|0);
  return;
 }
}
function __rl_update_final() {
 var $$pre$i = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0;
 var $61 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $full_lines$0 = 0, $i$03$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32296>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[32280>>2]|0;
 $3 = ($2|0)==(0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  $4 = HEAP32[32312>>2]|0;
  $5 = ((($4)) + 4|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (($6) + ($0<<2)|0);
  $8 = HEAP32[$7>>2]|0;
  $9 = HEAP32[$4>>2]|0;
  $10 = (($9) + ($8)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = ($11<<24>>24)==(0);
  if ($12) {
   $13 = (($0) + -1)|0;
   HEAP32[32296>>2] = $13;
   $16 = $13;$full_lines$0 = 1;
  } else {
   $16 = $0;$full_lines$0 = 0;
  }
 } else {
  $16 = $0;$full_lines$0 = 0;
 }
 $14 = HEAP32[32288>>2]|0;
 $15 = ($16|0)==($14|0);
 $17 = HEAP32[35120>>2]|0;
 $18 = ($17|0)<($16|0);
 $or$cond$i = $15 | $18;
 if (!($or$cond$i)) {
  $19 = (($16) - ($14))|0;
  $20 = ($19|0)>(0);
  if ($20) {
   $i$03$i = 0;
   while(1) {
    $21 = HEAP32[13512>>2]|0;
    (_putc(10,($21|0))|0);
    $22 = (($i$03$i) + 1)|0;
    $exitcond$i = ($22|0)==($19|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$03$i = $22;
    }
   }
   $23 = HEAP32[35144>>2]|0;
   (_tputs($23,1,368)|0);
   HEAP32[32280>>2] = 0;
  } else {
   $24 = HEAP32[35208>>2]|0;
   $25 = ($24|0)==(0|0);
   if (!($25)) {
    $26 = HEAP8[$24>>0]|0;
    $27 = ($26<<24>>24)==(0);
    if (!($27)) {
     $28 = (0 - ($19))|0;
     $29 = ($19|0)<(0);
     if ($29) {
      (_tputs($24,1,368)|0);
      $30 = ($19|0)<(-1);
      if ($30) {
       $32 = 1;
       while(1) {
        $$pre$i = HEAP32[35208>>2]|0;
        (_tputs($$pre$i,1,368)|0);
        $31 = (($32) + 1)|0;
        $33 = ($31|0)<($28|0);
        if ($33) {
         $32 = $31;
        } else {
         break;
        }
       }
      }
     }
    }
   }
  }
  HEAP32[32288>>2] = $16;
 }
 $34 = HEAP32[35096>>2]|0;
 $35 = ($34|0)!=(0);
 $or$cond3 = $full_lines$0 & $35;
 if (!($or$cond3)) {
  HEAP32[32296>>2] = 0;
  (_rl_crlf()|0);
  $59 = HEAP32[13512>>2]|0;
  (_fflush(($59|0))|0);
  $60 = HEAP32[32256>>2]|0;
  $61 = (($60) + 1)|0;
  HEAP32[32256>>2] = $61;
  return;
 }
 $36 = HEAP32[32296>>2]|0;
 $37 = (($36) + 1)|0;
 $38 = HEAP32[32312>>2]|0;
 $39 = ((($38)) + 4|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = (($40) + ($37<<2)|0);
 $42 = HEAP32[$41>>2]|0;
 $43 = (($40) + ($36<<2)|0);
 $44 = HEAP32[$43>>2]|0;
 $45 = (($42) - ($44))|0;
 $46 = HEAP32[35112>>2]|0;
 $47 = ($45|0)==($46|0);
 if (!($47)) {
  HEAP32[32296>>2] = 0;
  (_rl_crlf()|0);
  $59 = HEAP32[13512>>2]|0;
  (_fflush(($59|0))|0);
  $60 = HEAP32[32256>>2]|0;
  $61 = (($60) + 1)|0;
  HEAP32[32256>>2] = $61;
  return;
 }
 $48 = HEAP32[$38>>2]|0;
 $49 = (($48) + ($44)|0);
 HEAP32[32336>>2] = -1;
 $50 = (($45) + -1)|0;
 __rl_move_cursor_relative($50,$49);
 $51 = HEAP32[35136>>2]|0;
 $52 = ($51|0)==(0|0);
 if (!($52)) {
  (_tputs($51,1,368)|0);
 }
 $53 = HEAP32[35112>>2]|0;
 $54 = (($44) + -1)|0;
 $$sum = (($54) + ($53))|0;
 $55 = (($48) + ($$sum)|0);
 $56 = HEAP8[$55>>0]|0;
 $57 = $56 << 24 >> 24;
 $58 = HEAP32[13512>>2]|0;
 (_putc(($57|0),($58|0))|0);
 HEAP32[32296>>2] = 0;
 (_rl_crlf()|0);
 $59 = HEAP32[13512>>2]|0;
 (_fflush(($59|0))|0);
 $60 = HEAP32[32256>>2]|0;
 $61 = (($60) + 1)|0;
 HEAP32[32256>>2] = $61;
 return;
}
function __rl_redisplay_after_sigwinch() {
 var $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i$i$i = 0, $$pre$i12 = 0, $$pre$pre$i = 0, $$pre$pre$i$i = 0, $$pre2$pre$i = 0, $$pre2$pre$i$i = 0, $$pre20 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0;
 var $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0;
 var $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0;
 var $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i1 = 0, $exitcond$i6 = 0, $i$01$i = 0, $i$03$i = 0, $i$03$i5 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond19 = 0, $temp$01$i = 0, $temp$01$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35144>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_crlf()|0);
 } else {
  $2 = HEAP32[32296>>2]|0;
  $3 = HEAP32[32288>>2]|0;
  $4 = ($2|0)==($3|0);
  $5 = HEAP32[35120>>2]|0;
  $6 = ($5|0)<($2|0);
  $or$cond$i = $4 | $6;
  if ($or$cond$i) {
   $22 = $0;
  } else {
   $7 = (($2) - ($3))|0;
   $8 = ($7|0)>(0);
   if ($8) {
    $i$03$i = 0;
    while(1) {
     $9 = HEAP32[13512>>2]|0;
     (_putc(10,($9|0))|0);
     $10 = (($i$03$i) + 1)|0;
     $exitcond$i = ($10|0)==($7|0);
     if ($exitcond$i) {
      break;
     } else {
      $i$03$i = $10;
     }
    }
    $11 = HEAP32[35144>>2]|0;
    (_tputs($11,1,368)|0);
    HEAP32[32280>>2] = 0;
   } else {
    $12 = HEAP32[35208>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     $14 = HEAP8[$12>>0]|0;
     $15 = ($14<<24>>24)==(0);
     if (!($15)) {
      $16 = (0 - ($7))|0;
      $17 = ($7|0)<(0);
      if ($17) {
       (_tputs($12,1,368)|0);
       $18 = ($7|0)<(-1);
       if ($18) {
        $20 = 1;
        while(1) {
         $$pre$i = HEAP32[35208>>2]|0;
         (_tputs($$pre$i,1,368)|0);
         $19 = (($20) + 1)|0;
         $21 = ($19|0)<($16|0);
         if ($21) {
          $20 = $19;
         } else {
          break;
         }
        }
       }
      }
     }
    }
   }
   HEAP32[32288>>2] = $2;
   $$pre = HEAP32[35144>>2]|0;
   $22 = $$pre;
  }
  (_tputs($22,1,368)|0);
  HEAP32[32280>>2] = 0;
  $23 = HEAP32[35136>>2]|0;
  $24 = ($23|0)==(0|0);
  if ($24) {
   $25 = HEAP32[35112>>2]|0;
   $26 = ($25|0)>(0);
   if ($26) {
    $i$01$i = 0;
    while(1) {
     $27 = HEAP32[13512>>2]|0;
     (_putc(32,($27|0))|0);
     $28 = (($i$01$i) + 1)|0;
     $exitcond$i1 = ($28|0)==($25|0);
     if ($exitcond$i1) {
      break;
     } else {
      $i$01$i = $28;
     }
    }
    $$pre20 = HEAP32[32280>>2]|0;
    $30 = $$pre20;
   } else {
    $30 = 0;
   }
   $29 = (($30) + ($25))|0;
   HEAP32[32280>>2] = $29;
   $31 = HEAP32[35144>>2]|0;
   (_tputs($31,1,368)|0);
  } else {
   (_tputs($23,1,368)|0);
  }
  $32 = HEAP32[32288>>2]|0;
  $33 = ($32|0)<(1);
  $34 = HEAP32[35120>>2]|0;
  $35 = ($34|0)<(0);
  $or$cond19 = $33 | $35;
  if (!($or$cond19)) {
   $36 = (0 - ($32))|0;
   $37 = ($36|0)>(0);
   if ($37) {
    $i$03$i5 = 0;
    while(1) {
     $38 = HEAP32[13512>>2]|0;
     (_putc(10,($38|0))|0);
     $39 = (($i$03$i5) + 1)|0;
     $exitcond$i6 = ($39|0)==($36|0);
     if ($exitcond$i6) {
      break;
     } else {
      $i$03$i5 = $39;
     }
    }
    $40 = HEAP32[35144>>2]|0;
    (_tputs($40,1,368)|0);
    HEAP32[32280>>2] = 0;
   } else {
    $41 = HEAP32[35208>>2]|0;
    $42 = ($41|0)==(0|0);
    if (!($42)) {
     $43 = HEAP8[$41>>0]|0;
     $44 = ($43<<24>>24)!=(0);
     $45 = ($36|0)<(0);
     $or$cond = $45 & $44;
     if ($or$cond) {
      (_tputs($41,1,368)|0);
      $46 = ($32|0)>(1);
      if ($46) {
       $48 = 1;
       while(1) {
        $$pre$i12 = HEAP32[35208>>2]|0;
        (_tputs($$pre$i12,1,368)|0);
        $47 = (($48) + 1)|0;
        $exitcond = ($47|0)==($32|0);
        if ($exitcond) {
         break;
        } else {
         $48 = $47;
        }
       }
      }
     }
    }
   }
   HEAP32[32288>>2] = 0;
  }
 }
 $49 = HEAP32[32272>>2]|0;
 $50 = (_strrchr($49,10)|0);
 $51 = ($50|0)==(0|0);
 $52 = $49;
 if ($51) {
  $96 = HEAP32[32312>>2]|0;
  $97 = HEAP32[$96>>2]|0;
  $98 = ($97|0)==(0|0);
  do {
   if ($98) {
    $107 = $96;
   } else {
    $99 = HEAP8[$97>>0]|0;
    $100 = ($99<<24>>24)==(0);
    if ($100) {
     $105 = $97;
    } else {
     $temp$01$i = $97;
     while(1) {
      $101 = ((($temp$01$i)) + 1|0);
      HEAP8[$temp$01$i>>0] = 0;
      $102 = HEAP8[$101>>0]|0;
      $103 = ($102<<24>>24)==(0);
      if ($103) {
       break;
      } else {
       $temp$01$i = $101;
      }
     }
     $$pre$pre$i = HEAP32[32312>>2]|0;
     $$pre2$pre$i = HEAP32[$$pre$pre$i>>2]|0;
     $104 = ($$pre2$pre$i|0)==(0|0);
     if ($104) {
      $107 = $$pre$pre$i;
      break;
     } else {
      $105 = $$pre2$pre$i;
     }
    }
    HEAP8[$105>>0] = 0;
    $$pre$i$i = HEAP32[32312>>2]|0;
    $107 = $$pre$i$i;
   }
  } while(0);
  HEAP32[32288>>2] = 0;
  HEAP32[32280>>2] = 0;
  HEAP32[32320>>2] = 0;
  HEAP32[32296>>2] = 0;
  $106 = ((($107)) + 4|0);
  $108 = HEAP32[$106>>2]|0;
  $109 = ($108|0)==(0|0);
  if (!($109)) {
   $110 = ((($108)) + 4|0);
   HEAP32[$110>>2] = 0;
   HEAP32[$108>>2] = 0;
  }
  HEAP32[32328>>2] = 0;
  $111 = HEAP32[32400>>2]|0;
  $112 = (($111) + 1)|0;
  HEAP32[32400>>2] = $112;
  $113 = HEAP32[32248>>2]|0;
  FUNCTION_TABLE_v[$113 & 511]();
  return;
 }
 $53 = ((($50)) + 1|0);
 $54 = HEAP32[32384>>2]|0;
 HEAP32[32520>>2] = $54;
 $55 = HEAP32[32392>>2]|0;
 HEAP32[32528>>2] = $55;
 $56 = HEAP32[32496>>2]|0;
 HEAP32[32536>>2] = $56;
 $57 = HEAP32[32408>>2]|0;
 HEAP32[32544>>2] = $57;
 $58 = HEAP32[32472>>2]|0;
 HEAP32[32552>>2] = $58;
 $59 = HEAP32[32344>>2]|0;
 HEAP32[32560>>2] = $59;
 $60 = HEAP32[32424>>2]|0;
 HEAP32[32568>>2] = $60;
 $61 = HEAP32[32352>>2]|0;
 HEAP32[32576>>2] = $61;
 HEAP32[32392>>2] = 0;
 HEAP32[32384>>2] = 0;
 HEAP32[32408>>2] = 0;
 HEAP32[32496>>2] = 0;
 HEAP32[32344>>2] = 0;
 HEAP32[32472>>2] = 0;
 HEAP32[32352>>2] = 0;
 HEAP32[32424>>2] = 0;
 HEAP32[32272>>2] = $53;
 $62 = (_expand_prompt($53,32344,32472,32424,32352)|0);
 HEAP32[32384>>2] = $62;
 HEAP32[32392>>2] = 0;
 $63 = ($62|0)==(0|0);
 if ($63) {
  $65 = 0;
 } else {
  $64 = (_strlen(($62|0))|0);
  $65 = $64;
 }
 HEAP32[32408>>2] = $65;
 $66 = HEAP32[32312>>2]|0;
 $67 = HEAP32[$66>>2]|0;
 $68 = ($67|0)==(0|0);
 do {
  if ($68) {
   $77 = $66;
  } else {
   $69 = HEAP8[$67>>0]|0;
   $70 = ($69<<24>>24)==(0);
   if ($70) {
    $75 = $67;
   } else {
    $temp$01$i$i = $67;
    while(1) {
     $71 = ((($temp$01$i$i)) + 1|0);
     HEAP8[$temp$01$i$i>>0] = 0;
     $72 = HEAP8[$71>>0]|0;
     $73 = ($72<<24>>24)==(0);
     if ($73) {
      break;
     } else {
      $temp$01$i$i = $71;
     }
    }
    $$pre$pre$i$i = HEAP32[32312>>2]|0;
    $$pre2$pre$i$i = HEAP32[$$pre$pre$i$i>>2]|0;
    $74 = ($$pre2$pre$i$i|0)==(0|0);
    if ($74) {
     $77 = $$pre$pre$i$i;
     break;
    } else {
     $75 = $$pre2$pre$i$i;
    }
   }
   HEAP8[$75>>0] = 0;
   $$pre$i$i$i = HEAP32[32312>>2]|0;
   $77 = $$pre$i$i$i;
  }
 } while(0);
 HEAP32[32288>>2] = 0;
 HEAP32[32280>>2] = 0;
 HEAP32[32320>>2] = 0;
 HEAP32[32296>>2] = 0;
 $76 = ((($77)) + 4|0);
 $78 = HEAP32[$76>>2]|0;
 $79 = ($78|0)==(0|0);
 if (!($79)) {
  $80 = ((($78)) + 4|0);
  HEAP32[$80>>2] = 0;
  HEAP32[$78>>2] = 0;
 }
 HEAP32[32328>>2] = 0;
 $81 = HEAP32[32400>>2]|0;
 $82 = (($81) + 1)|0;
 HEAP32[32400>>2] = $82;
 $83 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$83 & 511]();
 HEAP32[32272>>2] = $52;
 $84 = HEAP32[32384>>2]|0;
 $85 = ($84|0)==(0|0);
 if (!($85)) {
  _free($84);
 }
 $86 = HEAP32[32392>>2]|0;
 $87 = ($86|0)==(0|0);
 if (!($87)) {
  _free($86);
 }
 $88 = HEAP32[32520>>2]|0;
 HEAP32[32384>>2] = $88;
 $89 = HEAP32[32528>>2]|0;
 HEAP32[32392>>2] = $89;
 $90 = HEAP32[32544>>2]|0;
 HEAP32[32408>>2] = $90;
 $91 = HEAP32[32536>>2]|0;
 HEAP32[32496>>2] = $91;
 $92 = HEAP32[32552>>2]|0;
 HEAP32[32472>>2] = $92;
 $93 = HEAP32[32560>>2]|0;
 HEAP32[32344>>2] = $93;
 $94 = HEAP32[32568>>2]|0;
 HEAP32[32424>>2] = $94;
 $95 = HEAP32[32576>>2]|0;
 HEAP32[32352>>2] = $95;
 HEAP32[32528>>2] = 0;
 HEAP32[32520>>2] = 0;
 HEAP32[32544>>2] = 0;
 HEAP32[32536>>2] = 0;
 HEAP32[32560>>2] = 0;
 HEAP32[32552>>2] = 0;
 HEAP32[32576>>2] = 0;
 HEAP32[32568>>2] = 0;
 return;
}
function __rl_clean_up_for_exit() {
 var $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $i$03$i = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13520>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return;
 }
 $2 = HEAP32[32296>>2]|0;
 $3 = HEAP32[32288>>2]|0;
 $4 = ($2|0)==($3|0);
 $5 = HEAP32[35120>>2]|0;
 $6 = ($5|0)<($2|0);
 $or$cond$i = $4 | $6;
 if (!($or$cond$i)) {
  $7 = (($2) - ($3))|0;
  $8 = ($7|0)>(0);
  if ($8) {
   $i$03$i = 0;
   while(1) {
    $9 = HEAP32[13512>>2]|0;
    (_putc(10,($9|0))|0);
    $10 = (($i$03$i) + 1)|0;
    $exitcond$i = ($10|0)==($7|0);
    if ($exitcond$i) {
     break;
    } else {
     $i$03$i = $10;
    }
   }
   $11 = HEAP32[35144>>2]|0;
   (_tputs($11,1,368)|0);
   HEAP32[32280>>2] = 0;
  } else {
   $12 = HEAP32[35208>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    $14 = HEAP8[$12>>0]|0;
    $15 = ($14<<24>>24)==(0);
    if (!($15)) {
     $16 = (0 - ($7))|0;
     $17 = ($7|0)<(0);
     if ($17) {
      (_tputs($12,1,368)|0);
      $18 = ($7|0)<(-1);
      if ($18) {
       $20 = 1;
       while(1) {
        $$pre$i = HEAP32[35208>>2]|0;
        (_tputs($$pre$i,1,368)|0);
        $19 = (($20) + 1)|0;
        $21 = ($19|0)<($16|0);
        if ($21) {
         $20 = $19;
        } else {
         break;
        }
       }
      }
     }
    }
   }
  }
  HEAP32[32288>>2] = $2;
 }
 HEAP32[32296>>2] = 0;
 $22 = HEAP32[13512>>2]|0;
 (_fflush(($22|0))|0);
 (_rl_restart_output(1,0)|0);
 return;
}
function __rl_erase_entire_line() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35144>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  (_tputs($0,1,368)|0);
  HEAP32[32280>>2] = 0;
 }
 $2 = HEAP32[35136>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  (_tputs($2,1,368)|0);
 }
 $4 = HEAP32[35144>>2]|0;
 $5 = ($4|0)==(0|0);
 if ($5) {
  $6 = HEAP32[13512>>2]|0;
  (_fflush(($6|0))|0);
  return;
 }
 (_tputs($4,1,368)|0);
 HEAP32[32280>>2] = 0;
 $6 = HEAP32[13512>>2]|0;
 (_fflush(($6|0))|0);
 return;
}
function __rl_current_display_line() {
 var $$neg = 0, $$op = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nleft$0 = 0, $ret$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32272>>2]|0;
 $1 = HEAP32[13528>>2]|0;
 $2 = ($0|0)==($1|0);
 $3 = HEAP32[32280>>2]|0;
 $4 = HEAP32[35112>>2]|0;
 $5 = (($3) - ($4))|0;
 $6 = HEAP32[13536>>2]|0;
 $$op = (0 - ($6))|0;
 $$neg = $2 ? $$op : 0;
 $nleft$0 = (($$neg) + ($5))|0;
 $7 = ($nleft$0|0)>(0);
 if (!($7)) {
  $ret$0 = 0;
  return ($ret$0|0);
 }
 $8 = (($nleft$0|0) / ($4|0))&-1;
 $9 = (($8) + 1)|0;
 $ret$0 = $9;
 return ($ret$0|0);
}
function _init_line_structures($minsize) {
 $minsize = $minsize|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $8 = 0, $9 = 0, $minsize$ = 0, $n$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32368>>2]|0;
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = HEAP32[32416>>2]|0;
 $4 = ($3|0)<($minsize|0);
 if ($2) {
  if ($4) {
   HEAP32[32416>>2] = $minsize;
   $5 = $minsize;
  } else {
   $5 = $3;
  }
  $6 = (_xmalloc($5)|0);
  $7 = HEAP32[32312>>2]|0;
  HEAP32[$7>>2] = $6;
  $8 = HEAP32[32416>>2]|0;
  $9 = (_xmalloc($8)|0);
  $10 = HEAP32[32368>>2]|0;
  HEAP32[$10>>2] = $9;
 } else {
  if ($4) {
   $11 = $3 << 1;
   $12 = ($11|0)<($minsize|0);
   $minsize$ = $12 ? $minsize : $11;
   HEAP32[32416>>2] = $minsize$;
   $13 = HEAP32[32312>>2]|0;
   $14 = HEAP32[$13>>2]|0;
   $15 = (_xrealloc($14,$minsize$)|0);
   $16 = HEAP32[32312>>2]|0;
   HEAP32[$16>>2] = $15;
   $17 = HEAP32[32368>>2]|0;
   $18 = HEAP32[$17>>2]|0;
   $19 = HEAP32[32416>>2]|0;
   $20 = (_xrealloc($18,$19)|0);
   $21 = HEAP32[32368>>2]|0;
   HEAP32[$21>>2] = $20;
  }
 }
 $22 = HEAP32[32416>>2]|0;
 $23 = ($22|0)>($minsize|0);
 $24 = HEAP32[32312>>2]|0;
 if ($23) {
  $26 = $24;$n$01 = $minsize;
  while(1) {
   $25 = HEAP32[$26>>2]|0;
   $27 = (($25) + ($n$01)|0);
   HEAP8[$27>>0] = 0;
   $28 = HEAP32[32368>>2]|0;
   $29 = HEAP32[$28>>2]|0;
   $30 = (($29) + ($n$01)|0);
   HEAP8[$30>>0] = 1;
   $31 = (($n$01) + 1)|0;
   $32 = HEAP32[32416>>2]|0;
   $33 = ($31|0)<($32|0);
   $34 = HEAP32[32312>>2]|0;
   if ($33) {
    $26 = $34;$n$01 = $31;
   } else {
    $36 = $34;
    break;
   }
  }
 } else {
  $36 = $24;
 }
 $35 = ((($36)) + 4|0);
 $37 = HEAP32[$35>>2]|0;
 $38 = ($37|0)==(0|0);
 if (!($38)) {
  HEAP32[32304>>2] = 1;
  return;
 }
 $39 = ((($36)) + 8|0);
 HEAP32[$39>>2] = 256;
 $40 = HEAP32[32368>>2]|0;
 $41 = ((($40)) + 8|0);
 HEAP32[$41>>2] = 256;
 $42 = HEAP32[$39>>2]|0;
 $43 = ((($36)) + 16|0);
 HEAP32[$43>>2] = $42;
 $44 = $42 << 2;
 $45 = (_xmalloc($44)|0);
 $46 = HEAP32[32312>>2]|0;
 $47 = ((($46)) + 12|0);
 HEAP32[$47>>2] = $45;
 $48 = HEAP32[32368>>2]|0;
 $49 = ((($48)) + 8|0);
 $50 = HEAP32[$49>>2]|0;
 $51 = ((($48)) + 16|0);
 HEAP32[$51>>2] = $50;
 $52 = $50 << 2;
 $53 = (_xmalloc($52)|0);
 $54 = HEAP32[32368>>2]|0;
 $55 = ((($54)) + 12|0);
 HEAP32[$55>>2] = $53;
 $56 = HEAP32[32368>>2]|0;
 $57 = ((($56)) + 8|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = $58 << 2;
 $60 = (_xmalloc($59)|0);
 $61 = HEAP32[32368>>2]|0;
 $62 = ((($61)) + 4|0);
 HEAP32[$62>>2] = $60;
 $63 = HEAP32[32312>>2]|0;
 $64 = ((($63)) + 8|0);
 $65 = HEAP32[$64>>2]|0;
 $66 = $65 << 2;
 $67 = (_xmalloc($66)|0);
 $68 = HEAP32[32312>>2]|0;
 $69 = ((($68)) + 4|0);
 HEAP32[$69>>2] = $67;
 $70 = HEAP32[32312>>2]|0;
 $71 = ((($70)) + 4|0);
 $72 = HEAP32[$71>>2]|0;
 HEAP32[$72>>2] = 0;
 $73 = HEAP32[32368>>2]|0;
 $74 = ((($73)) + 4|0);
 $75 = HEAP32[$74>>2]|0;
 HEAP32[$75>>2] = 0;
 HEAP32[32304>>2] = 1;
 return;
}
function __rl_col_width($str,$start,$end,$flags) {
 $str = $str|0;
 $start = $start|0;
 $end = $end|0;
 $flags = $flags|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $7 = 0, $8 = 0, $9 = 0, $max$0$be = 0, $max$0$lcssa = 0, $max$021 = 0, $max$1$be = 0, $max$115 = 0, $or$cond = 0, $or$cond7 = 0, $point$0$be = 0, $point$0$lcssa = 0, $point$020 = 0, $point$1$be = 0, $point$1$lcssa = 0, $point$113 = 0;
 var $ps = 0, $wc = 0, $width$0$be = 0, $width$0$lcssa = 0, $width$014 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $wc = sp + 8|0;
 $ps = sp;
 $0 = ($end|0)>($start|0);
 if (!($0)) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[36240>>2]|0;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (($end) - ($start))|0;
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = $ps;
 $5 = $4;
 HEAP32[$5>>2] = 0;
 $6 = (($4) + 4)|0;
 $7 = $6;
 HEAP32[$7>>2] = 0;
 $8 = ($flags|0)!=(0);
 $9 = ($start|0)==(0);
 $or$cond = $9 & $8;
 if ($or$cond) {
  $11 = HEAP32[32408>>2]|0;
  $12 = ($11|0)==($end|0);
  if ($12) {
   $13 = HEAP32[32384>>2]|0;
   $14 = (_memcmp($str,$13,$end)|0);
   $15 = ($14|0)==(0);
   if ($15) {
    $16 = HEAP32[32352>>2]|0;
    $17 = HEAP32[32432>>2]|0;
    $18 = (($17) + ($16))|0;
    $$0 = $18;
    STACKTOP = sp;return ($$0|0);
   }
  }
  $19 = ($11|0)>(0);
  if ($19) {
   $20 = ($11|0)<($end|0);
   $21 = HEAP32[32384>>2]|0;
   $22 = ($21|0)!=(0|0);
   $or$cond7 = $20 & $22;
   if ($or$cond7) {
    $23 = (_memcmp($str,$21,$11)|0);
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = HEAP32[32352>>2]|0;
     $26 = HEAP32[32432>>2]|0;
     $27 = (($26) + ($25))|0;
     $28 = (__rl_col_width($str,$11,$end,$flags)|0);
     $29 = (($27) + ($28))|0;
     $$0 = $29;
     STACKTOP = sp;return ($$0|0);
    }
   }
  }
 }
 $10 = ($start|0)>(0);
 L20: do {
  if ($10) {
   $max$021 = $end;$point$020 = 0;
   while(1) {
    $30 = (($str) + ($point$020)|0);
    $31 = (_mbrlen($30,$max$021,$ps)|0);
    $32 = ($31>>>0)>(4294967293);
    if ($32) {
     $33 = (($point$020) + 1)|0;
     $34 = (($max$021) + -1)|0;
     $35 = $ps;
     $36 = $35;
     HEAP32[$36>>2] = 0;
     $37 = (($35) + 4)|0;
     $38 = $37;
     HEAP32[$38>>2] = 0;
     $max$0$be = $34;$point$0$be = $33;
    } else {
     $39 = ($31|0)==(0);
     if ($39) {
      $max$0$lcssa = $max$021;$point$0$lcssa = $point$020;
      break L20;
     }
     $40 = (($31) + ($point$020))|0;
     $41 = (($max$021) - ($31))|0;
     $max$0$be = $41;$point$0$be = $40;
    }
    $42 = ($point$0$be|0)<($start|0);
    if ($42) {
     $max$021 = $max$0$be;$point$020 = $point$0$be;
    } else {
     $max$0$lcssa = $max$0$be;$point$0$lcssa = $point$0$be;
     break;
    }
   }
  } else {
   $max$0$lcssa = $end;$point$0$lcssa = 0;
  }
 } while(0);
 $43 = (($point$0$lcssa) - ($start))|0;
 $44 = ($point$0$lcssa|0)<($end|0);
 L29: do {
  if ($44) {
   $max$115 = $max$0$lcssa;$point$113 = $point$0$lcssa;$width$014 = $43;
   while(1) {
    $45 = (($str) + ($point$113)|0);
    $46 = (_mbrtowc($wc,$45,$max$115,$ps)|0);
    $47 = ($46>>>0)>(4294967293);
    if ($47) {
     $48 = (($point$113) + 1)|0;
     $49 = (($max$115) + -1)|0;
     $50 = (($width$014) + 1)|0;
     $51 = $ps;
     $52 = $51;
     HEAP32[$52>>2] = 0;
     $53 = (($51) + 4)|0;
     $54 = $53;
     HEAP32[$54>>2] = 0;
     $max$1$be = $49;$point$1$be = $48;$width$0$be = $50;
    } else {
     $55 = ($46|0)==(0);
     if ($55) {
      $point$1$lcssa = $point$113;$width$0$lcssa = $width$014;
      break L29;
     }
     $56 = (($46) + ($point$113))|0;
     $57 = (($max$115) - ($46))|0;
     $58 = HEAP32[$wc>>2]|0;
     $59 = (_wcwidth($58)|0);
     $60 = ($59|0)>(-1);
     $61 = $60 ? $59 : 1;
     $62 = (($61) + ($width$014))|0;
     $max$1$be = $57;$point$1$be = $56;$width$0$be = $62;
    }
    $63 = ($point$1$be|0)<($end|0);
    if ($63) {
     $max$115 = $max$1$be;$point$113 = $point$1$be;$width$014 = $width$0$be;
    } else {
     $point$1$lcssa = $point$1$be;$width$0$lcssa = $width$0$be;
     break;
    }
   }
  } else {
   $point$1$lcssa = $point$0$lcssa;$width$0$lcssa = $43;
  }
 } while(0);
 $64 = (($point$1$lcssa) - ($end))|0;
 $65 = (($64) + ($width$0$lcssa))|0;
 $$0 = $65;
 STACKTOP = sp;return ($$0|0);
}
function _update_line($old,$new,$current_line,$omax,$nmax,$inv_botlin) {
 $old = $old|0;
 $new = $new|0;
 $current_line = $current_line|0;
 $omax = $omax|0;
 $nmax = $nmax|0;
 $inv_botlin = $inv_botlin|0;
 var $$ = 0, $$0 = 0, $$111 = 0, $$97 = 0, $$col_lendiff$1 = 0, $$off = 0, $$old = 0, $$old103 = 0, $$old141 = 0, $$pn155 = 0, $$pn88156 = 0, $$pr = 0, $$pr139 = 0, $$pre = 0, $$pre$i = 0, $$pre$i117 = 0, $$pre$i121 = 0, $$pre$phiZ2D = 0, $$pre246 = 0, $$wsatend$0 = 0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0;
 var $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0;
 var $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0;
 var $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0;
 var $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0;
 var $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0;
 var $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0;
 var $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0;
 var $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0;
 var $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0;
 var $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0;
 var $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0;
 var $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0;
 var $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0;
 var $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0;
 var $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0;
 var $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0;
 var $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0;
 var $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0;
 var $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0;
 var $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0;
 var $495 = 0, $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0;
 var $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0;
 var $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0;
 var $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $col_lendiff$0 = 0, $col_lendiff$1 = 0, $col_lendiff$2 = 0, $col_lendiff$4 = 0, $col_temp$0 = 0, $count$0218 = 0, $exitcond = 0, $exitcond$i = 0, $exitcond$i$i = 0, $exitcond$i$i128 = 0, $exitcond$i124 = 0, $i$01$i = 0, $i$01$i$i = 0, $i$01$i$i127 = 0, $i$02$i = 0, $i$0216 = 0, $i$0216$in = 0, $i$03$i = 0, $lendiff$0 = 0, $nd$0180 = 0;
 var $ne$0$lcssa = 0, $ne$0179 = 0, $new_offset$0192 = 0, $nfd$0191 = 0, $nfd$1204 = 0, $nfd$2 = 0, $nfd$3 = 0, $nfd$3$ph = 0, $nls$0 = 0, $nls$0152 = 0, $nls$0158 = 0, $nls$1 = 0, $nls$1166 = 0, $nls$1170 = 0, $nls$2 = 0, $nls$3 = 0, $not$ = 0, $notlhs = 0, $notlhs143 = 0, $notrhs = 0;
 var $notrhs144 = 0, $od$0185 = 0, $oe$0$lcssa = 0, $oe$0186 = 0, $ofd$0194 = 0, $ofd$1205 = 0, $ofd$2 = 0, $ofd$3 = 0, $ofd$3$ph = 0, $old_offset$0193 = 0, $ols$0 = 0, $ols$0151 = 0, $ols$0157 = 0, $ols$1 = 0, $ols$1165 = 0, $ols$1169 = 0, $ols$2 = 0, $ols$3 = 0, $ols$4 = 0, $or$cond = 0;
 var $or$cond$i115 = 0, $or$cond$i119 = 0, $or$cond$not = 0, $or$cond104 = 0, $or$cond106 = 0, $or$cond108 = 0, $or$cond110 = 0, $or$cond113 = 0, $or$cond16 = 0, $or$cond25 = 0, $or$cond259 = 0, $or$cond27 = 0, $or$cond29$not = 0, $or$cond3 = 0, $or$cond31 = 0, $or$cond33$not = 0, $or$cond37 = 0, $or$cond41 = 0, $or$cond43 = 0, $or$cond45 = 0;
 var $or$cond47 = 0, $or$cond49 = 0, $or$cond53 = 0, $or$cond55 = 0, $or$cond59 = 0, $or$cond61 = 0, $or$cond65 = 0, $or$cond67 = 0, $or$cond69 = 0, $or$cond7 = 0, $or$cond71 = 0, $or$cond73 = 0, $or$cond75 = 0, $or$cond77 = 0, $or$cond79 = 0, $or$cond81 = 0, $or$cond83 = 0, $or$cond85 = 0, $or$cond87 = 0, $or$cond92 = 0;
 var $or$cond92153 = 0, $or$cond93 = 0, $or$cond93167 = 0, $or$cond94 = 0, $or$cond96 = 0, $or$cond99 = 0, $ps = 0, $ps2 = 0, $ps_new = 0, $ps_old = 0, $ret$0133$ph247 = 0, $ret$0133$ph248 = 0, $storemerge = 0, $temp$0 = 0, $tempwidth$0132$ph249 = 0, $tempwidth$0132$ph250 = 0, $wc = 0, $wc1 = 0, $wsatend$0154 = 0, $wsatend$2$ = 0;
 var $wsatend$2168 = 0, $wsatend$4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps_new = sp + 24|0;
 $ps_old = sp + 16|0;
 $wc = sp + 36|0;
 $ps = sp + 8|0;
 $wc1 = sp + 32|0;
 $ps2 = sp;
 $0 = HEAP32[36240>>2]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[32280>>2]|0;
 if ($1) {
  $temp$0 = $2;
 } else {
  $3 = HEAP32[32288>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
   $5 = HEAP32[32328>>2]|0;
   $6 = ($5|0)==(0);
   if ($6) {
    $19 = 0;
   } else {
    $7 = HEAP32[32352>>2]|0;
    $8 = HEAP32[35112>>2]|0;
    $9 = ($7|0)>($8|0);
    $10 = HEAP32[32424>>2]|0;
    $11 = HEAP32[32432>>2]|0;
    $12 = $9 ? $10 : $11;
    $19 = $12;
   }
  } else {
   $13 = HEAP32[32440>>2]|0;
   $14 = ($3|0)==($13|0);
   if ($14) {
    $15 = HEAP32[32432>>2]|0;
    $16 = HEAP32[32424>>2]|0;
    $17 = (($15) - ($16))|0;
    $19 = $17;
   } else {
    $19 = 0;
   }
  }
  $18 = (($2) - ($19))|0;
  $temp$0 = $18;
 }
 $20 = HEAP32[35112>>2]|0;
 $21 = HEAP32[35096>>2]|0;
 $notlhs = ($temp$0|0)!=($20|0);
 $notrhs = ($21|0)==(0);
 $or$cond$not = $notlhs | $notrhs;
 $22 = HEAP32[13600>>2]|0;
 $23 = ($22|0)!=(0);
 $or$cond3 = $or$cond$not | $23;
 L10: do {
  if ($or$cond3) {
   $$0 = $omax;
  } else {
   $24 = HEAP32[32288>>2]|0;
   $25 = (($current_line) + -1)|0;
   $26 = ($24|0)==($25|0);
   if ($26) {
    if (!($1)) {
     $88 = HEAP8[$new>>0]|0;
     $89 = ($88<<24>>24)==(0);
     if ($89) {
      $92 = HEAP32[13512>>2]|0;
      (_putc(32,($92|0))|0);
     } else {
      $90 = $88 << 24 >> 24;
      $91 = HEAP32[13512>>2]|0;
      (_putc(($90|0),($91|0))|0);
     }
     HEAP32[32280>>2] = 1;
     $93 = HEAP32[32288>>2]|0;
     $94 = (($93) + 1)|0;
     HEAP32[32288>>2] = $94;
     $95 = HEAP8[$old>>0]|0;
     $96 = ($95<<24>>24)==(0);
     if ($96) {
      $$0 = $omax;
      break;
     }
     $97 = HEAP8[$new>>0]|0;
     $98 = ($97<<24>>24)==(0);
     if ($98) {
      $$0 = $omax;
      break;
     }
     HEAP8[$old>>0] = $97;
     $$0 = $omax;
     break;
    }
    $27 = HEAP32[32312>>2]|0;
    $28 = ((($27)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)>($current_line|0);
    do {
     if ($30) {
      $31 = ((($27)) + 12|0);
      $32 = HEAP32[$31>>2]|0;
      $33 = (($32) + ($current_line<<2)|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ($34|0)>(0);
      if ($35) {
       $36 = HEAP32[35136>>2]|0;
       $37 = ($36|0)==(0|0);
       if ($37) {
        $i$01$i$i = 0;
       } else {
        (_tputs($36,1,368)|0);
        break;
       }
       while(1) {
        $38 = HEAP32[13512>>2]|0;
        (_putc(32,($38|0))|0);
        $39 = (($i$01$i$i) + 1)|0;
        $exitcond$i$i = ($39|0)==($34|0);
        if ($exitcond$i$i) {
         break;
        } else {
         $i$01$i$i = $39;
        }
       }
       $40 = HEAP32[32280>>2]|0;
       $41 = (($40) + ($34))|0;
       HEAP32[32280>>2] = $41;
      }
     }
    } while(0);
    $42 = $ps;
    $43 = $42;
    HEAP32[$43>>2] = 0;
    $44 = (($42) + 4)|0;
    $45 = $44;
    HEAP32[$45>>2] = 0;
    $46 = (_mbrtowc($wc,$new,4,$ps)|0);
    $47 = ($46>>>0)>(4294967293);
    do {
     if ($47) {
      $ret$0133$ph248 = 1;$tempwidth$0132$ph250 = 1;
      label = 21;
     } else {
      $48 = ($46|0)==(0);
      if (!($48)) {
       $49 = HEAP32[$wc>>2]|0;
       $50 = (_wcwidth($49)|0);
       $51 = ($50|0)>(0);
       if ($51) {
        $52 = ($46|0)>(0);
        if ($52) {
         $ret$0133$ph248 = $46;$tempwidth$0132$ph250 = $50;
         label = 21;
         break;
        } else {
         $ret$0133$ph247 = $46;$tempwidth$0132$ph249 = $50;
         break;
        }
       }
      }
      $81 = HEAP32[13512>>2]|0;
      (_putc(32,($81|0))|0);
      HEAP32[32280>>2] = 1;
      $82 = HEAP32[32288>>2]|0;
      $83 = (($82) + 1)|0;
      HEAP32[32288>>2] = $83;
      $84 = HEAP8[$old>>0]|0;
      $85 = ($84<<24>>24)==(0);
      if ($85) {
       $$0 = $omax;
       break L10;
      }
      $86 = HEAP8[$new>>0]|0;
      $87 = ($86<<24>>24)==(0);
      if ($87) {
       $$0 = $omax;
       break L10;
      }
      HEAP8[$old>>0] = $86;
      $$0 = $omax;
      break L10;
     }
    } while(0);
    if ((label|0) == 21) {
     $count$0218 = 0;
     while(1) {
      $53 = (($new) + ($count$0218)|0);
      $54 = HEAP8[$53>>0]|0;
      $55 = $54 << 24 >> 24;
      $56 = HEAP32[13512>>2]|0;
      (_putc(($55|0),($56|0))|0);
      $57 = (($count$0218) + 1)|0;
      $exitcond = ($57|0)==($ret$0133$ph248|0);
      if ($exitcond) {
       $ret$0133$ph247 = $ret$0133$ph248;$tempwidth$0132$ph249 = $tempwidth$0132$ph250;
       break;
      } else {
       $count$0218 = $57;
      }
     }
    }
    HEAP32[32280>>2] = $tempwidth$0132$ph249;
    $58 = HEAP32[32288>>2]|0;
    $59 = (($58) + 1)|0;
    HEAP32[32288>>2] = $59;
    $60 = $ps;
    $61 = $60;
    HEAP32[$61>>2] = 0;
    $62 = (($60) + 4)|0;
    $63 = $62;
    HEAP32[$63>>2] = 0;
    $64 = (_mbrtowc($wc,$old,4,$ps)|0);
    $65 = ($64|0)!=(0);
    $66 = ($ret$0133$ph247|0)!=(0);
    $or$cond7 = $66 & $65;
    if ($or$cond7) {
     $67 = ($64>>>0)>(4294967293);
     $$ = $67 ? 1 : $64;
     $68 = (($old) + ($ret$0133$ph247)|0);
     $69 = (($old) + ($$)|0);
     $70 = (_strlen(($69|0))|0);
     _memmove(($68|0),($69|0),($70|0))|0;
     _memcpy(($old|0),($new|0),($ret$0133$ph247|0))|0;
     $71 = (($ret$0133$ph247) - ($$))|0;
     $72 = (($71) + ($omax))|0;
     $73 = ($inv_botlin|0)<($current_line|0);
     if ($73) {
      $$0 = $72;
     } else {
      $74 = HEAP32[32312>>2]|0;
      $75 = ((($74)) + 4|0);
      $76 = HEAP32[$75>>2]|0;
      $i$0216$in = $current_line;
      while(1) {
       $i$0216 = (($i$0216$in) + 1)|0;
       $77 = (($76) + ($i$0216<<2)|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = (($78) + ($71))|0;
       HEAP32[$77>>2] = $79;
       $80 = ($i$0216$in|0)<($inv_botlin|0);
       if ($80) {
        $i$0216$in = $i$0216;
       } else {
        $$0 = $72;
        break;
       }
      }
     }
    } else {
     $$0 = $omax;
    }
   } else {
    $$0 = $omax;
   }
  }
 } while(0);
 $99 = HEAP32[36240>>2]|0;
 $100 = ($99|0)==(0);
 L49: do {
  if ($100) {
   $103 = ($$0|0)<($nmax|0);
   $104 = $103 ? $$0 : $nmax;
   $105 = (_memcmp($old,$new,$104)|0);
   $106 = ($105|0)==(0);
   if ($106) {
    $107 = (($old) + ($104)|0);
    $108 = (($new) + ($104)|0);
    $nfd$2 = $108;$ofd$2 = $107;
    break;
   }
   $109 = $ps_new;
   $110 = $109;
   HEAP32[$110>>2] = 0;
   $111 = (($109) + 4)|0;
   $112 = $111;
   HEAP32[$112>>2] = 0;
   $113 = $ps_old;
   $114 = $113;
   HEAP32[$114>>2] = 0;
   $115 = (($113) + 4)|0;
   $116 = $115;
   HEAP32[$116>>2] = 0;
   $117 = ($$0|0)==($nmax|0);
   do {
    if ($117) {
     $119 = ($nmax|0)==(0);
     if (!($119)) {
      $120 = HEAP8[$new>>0]|0;
      $121 = HEAP8[$old>>0]|0;
      $122 = ($120<<24>>24)==($121<<24>>24);
      if (!($122)) {
       break;
      }
      $123 = (_strncmp($new,$old,$nmax)|0);
      $124 = ($123|0)==(0);
      if (!($124)) {
       break;
      }
     }
     $125 = (($old) + ($nmax)|0);
     $126 = (($new) + ($nmax)|0);
     $nfd$2 = $126;$ofd$2 = $125;
     break L49;
    }
   } while(0);
   $118 = ($$0|0)>(0);
   if ($118) {
    $new_offset$0192 = 0;$nfd$0191 = $new;$ofd$0194 = $old;$old_offset$0193 = 0;
    while(1) {
     $127 = HEAP8[$ofd$0194>>0]|0;
     $128 = ($127<<24>>24)==(0);
     if ($128) {
      $nfd$2 = $nfd$0191;$ofd$2 = $ofd$0194;
      break L49;
     }
     $129 = (__rl_compare_chars($old,$old_offset$0193,$ps_old,$new,$new_offset$0192,$ps_new)|0);
     $130 = ($129|0)==(0);
     if ($130) {
      $nfd$2 = $nfd$0191;$ofd$2 = $ofd$0194;
      break L49;
     }
     $131 = (__rl_find_next_mbchar($old,$old_offset$0193,1,0)|0);
     $132 = (__rl_find_next_mbchar($new,$new_offset$0192,1,0)|0);
     $133 = (($old) + ($131)|0);
     $134 = (($new) + ($132)|0);
     $135 = ($131|0)<($$0|0);
     if ($135) {
      $new_offset$0192 = $132;$nfd$0191 = $134;$ofd$0194 = $133;$old_offset$0193 = $131;
     } else {
      $nfd$2 = $134;$ofd$2 = $133;
      break;
     }
    }
   } else {
    $nfd$2 = $new;$ofd$2 = $old;
   }
  } else {
   $101 = $old;
   $102 = ($$0|0)>(0);
   if ($102) {
    $nfd$1204 = $new;$ofd$1205 = $old;
    while(1) {
     $136 = HEAP8[$ofd$1205>>0]|0;
     $137 = ($136<<24>>24)==(0);
     if ($137) {
      $nfd$2 = $nfd$1204;$ofd$2 = $ofd$1205;
      break L49;
     }
     $138 = HEAP8[$nfd$1204>>0]|0;
     $139 = ($136<<24>>24)==($138<<24>>24);
     if (!($139)) {
      $nfd$2 = $nfd$1204;$ofd$2 = $ofd$1205;
      break L49;
     }
     $140 = ((($ofd$1205)) + 1|0);
     $141 = ((($nfd$1204)) + 1|0);
     $142 = $140;
     $143 = (($142) - ($101))|0;
     $144 = ($143|0)<($$0|0);
     if ($144) {
      $nfd$1204 = $141;$ofd$1205 = $140;
     } else {
      $nfd$2 = $141;$ofd$2 = $140;
      break;
     }
    }
   } else {
    $nfd$2 = $new;$ofd$2 = $old;
   }
  }
 } while(0);
 $145 = $ofd$2;
 $146 = $old;
 $147 = (($145) - ($146))|0;
 $148 = ($147|0)<($$0|0);
 L71: do {
  if ($148) {
   $od$0185 = $147;$oe$0186 = $ofd$2;
   while(1) {
    $149 = HEAP8[$oe$0186>>0]|0;
    $150 = ($149<<24>>24)==(0);
    if ($150) {
     $oe$0$lcssa = $oe$0186;
     break L71;
    }
    $151 = ((($oe$0186)) + 1|0);
    $152 = (($od$0185) + 1)|0;
    $153 = ($152|0)<($$0|0);
    if ($153) {
     $od$0185 = $152;$oe$0186 = $151;
    } else {
     $oe$0$lcssa = $151;
     break;
    }
   }
  } else {
   $oe$0$lcssa = $ofd$2;
  }
 } while(0);
 $154 = $nfd$2;
 $155 = $new;
 $156 = (($154) - ($155))|0;
 $157 = ($156|0)<($nmax|0);
 L76: do {
  if ($157) {
   $nd$0180 = $156;$ne$0179 = $nfd$2;
   while(1) {
    $158 = HEAP8[$ne$0179>>0]|0;
    $159 = ($158<<24>>24)==(0);
    if ($159) {
     $ne$0$lcssa = $ne$0179;
     break L76;
    }
    $160 = ((($ne$0179)) + 1|0);
    $161 = (($nd$0180) + 1)|0;
    $162 = ($161|0)<($nmax|0);
    if ($162) {
     $nd$0180 = $161;$ne$0179 = $160;
    } else {
     $ne$0$lcssa = $160;
     break;
    }
   }
  } else {
   $ne$0$lcssa = $nfd$2;
  }
 } while(0);
 $163 = ($ofd$2|0)==($oe$0$lcssa|0);
 $164 = ($nfd$2|0)==($ne$0$lcssa|0);
 $or$cond = $163 & $164;
 if ($or$cond) {
  STACKTOP = sp;return;
 }
 $165 = HEAP32[36240>>2]|0;
 $166 = ($165|0)==(0);
 $167 = HEAP32[36248>>2]|0;
 $168 = ($167|0)!=(0);
 $or$cond16 = $166 & $168;
 if ($or$cond16) {
  $169 = $ps2;
  $170 = $169;
  HEAP32[$170>>2] = 0;
  $171 = (($169) + 4)|0;
  $172 = $171;
  HEAP32[$172>>2] = 0;
  $173 = (_mbrtowc($wc1,$ofd$2,4,$ps2)|0);
  $174 = ($173|0)>(0);
  $175 = HEAP32[$wc1>>2]|0;
  $$off = (($175) + -768)|0;
  $176 = ($$off>>>0)<(112);
  $177 = $174 & $176;
  if ($177) {
   $178 = (_wcwidth($175)|0);
   $179 = ($178|0)==(0);
   if ($179) {
    $180 = (__rl_find_prev_mbchar($old,$147,0)|0);
    $181 = (__rl_find_prev_mbchar($new,$156,0)|0);
    $182 = (($old) + ($180)|0);
    $183 = (($new) + ($181)|0);
    $nfd$3$ph = $183;$ofd$3$ph = $182;
   } else {
    $nfd$3$ph = $nfd$2;$ofd$3$ph = $ofd$2;
   }
  } else {
   $nfd$3$ph = $nfd$2;$ofd$3$ph = $ofd$2;
  }
  $$pr = HEAP32[36240>>2]|0;
  $185 = $$pr;$nfd$3 = $nfd$3$ph;$ofd$3 = $ofd$3$ph;
 } else {
  $185 = $165;$nfd$3 = $nfd$2;$ofd$3 = $ofd$2;
 }
 $184 = ($185|0)==(0);
 L91: do {
  if ($184) {
   $188 = $oe$0$lcssa;
   $189 = (($188) - ($146))|0;
   $190 = (__rl_find_prev_mbchar($old,$189,0)|0);
   $191 = $ne$0$lcssa;
   $192 = (($191) - ($155))|0;
   $193 = (__rl_find_prev_mbchar($new,$192,0)|0);
   $ols$0151 = (($old) + ($190)|0);
   $nls$0152 = (($new) + ($193)|0);
   $194 = ($ols$0151>>>0)>($ofd$3>>>0);
   $195 = ($nls$0152>>>0)>($nfd$3>>>0);
   $or$cond92153 = $195 & $194;
   if ($or$cond92153) {
    $$pn155 = $193;$$pn88156 = $190;$nls$0158 = $nls$0152;$ols$0157 = $ols$0151;$wsatend$0154 = 1;
    while(1) {
     $196 = $ps_old;
     $197 = $196;
     HEAP32[$197>>2] = 0;
     $198 = (($196) + 4)|0;
     $199 = $198;
     HEAP32[$199>>2] = 0;
     $200 = $ps_new;
     $201 = $200;
     HEAP32[$201>>2] = 0;
     $202 = (($200) + 4)|0;
     $203 = $202;
     HEAP32[$203>>2] = 0;
     $204 = (__rl_compare_chars($old,$$pn88156,$ps_old,$new,$$pn155,$ps_new)|0);
     $205 = ($204|0)==(0);
     if ($205) {
      $nls$2 = $nls$0158;$ols$2 = $ols$0157;$wsatend$4 = $wsatend$0154;
      label = 71;
      break L91;
     }
     $206 = HEAP8[$ols$0157>>0]|0;
     $207 = ($206<<24>>24)==(32);
     $$wsatend$0 = $207 ? 0 : $wsatend$0154;
     $208 = (__rl_find_prev_mbchar($old,$$pn88156,0)|0);
     $209 = (__rl_find_prev_mbchar($new,$$pn155,0)|0);
     $ols$0 = (($old) + ($208)|0);
     $nls$0 = (($new) + ($209)|0);
     $210 = ($ols$0>>>0)>($ofd$3>>>0);
     $211 = ($nls$0>>>0)>($nfd$3>>>0);
     $or$cond92 = $211 & $210;
     if ($or$cond92) {
      $$pn155 = $209;$$pn88156 = $208;$nls$0158 = $nls$0;$ols$0157 = $ols$0;$wsatend$0154 = $$wsatend$0;
     } else {
      $nls$2 = $nls$0;$ols$2 = $ols$0;$wsatend$4 = $$wsatend$0;
      label = 71;
      break;
     }
    }
   } else {
    $nls$3 = $ne$0$lcssa;$ols$4 = $oe$0$lcssa;
   }
  } else {
   $ols$1165 = ((($oe$0$lcssa)) + -1|0);
   $nls$1166 = ((($ne$0$lcssa)) + -1|0);
   $186 = ($ols$1165>>>0)>($ofd$3>>>0);
   $187 = ($nls$1166>>>0)>($nfd$3>>>0);
   $or$cond93167 = $187 & $186;
   if ($or$cond93167) {
    $nls$1170 = $nls$1166;$ols$1169 = $ols$1165;$wsatend$2168 = 1;
    while(1) {
     $212 = HEAP8[$ols$1169>>0]|0;
     $213 = HEAP8[$nls$1170>>0]|0;
     $214 = ($212<<24>>24)==($213<<24>>24);
     if (!($214)) {
      $nls$2 = $nls$1170;$ols$2 = $ols$1169;$wsatend$4 = $wsatend$2168;
      label = 71;
      break L91;
     }
     $215 = ($212<<24>>24)==(32);
     $wsatend$2$ = $215 ? $wsatend$2168 : 0;
     $ols$1 = ((($ols$1169)) + -1|0);
     $nls$1 = ((($nls$1170)) + -1|0);
     $216 = ($ols$1>>>0)>($ofd$3>>>0);
     $217 = ($nls$1>>>0)>($nfd$3>>>0);
     $or$cond93 = $217 & $216;
     if ($or$cond93) {
      $nls$1170 = $nls$1;$ols$1169 = $ols$1;$wsatend$2168 = $wsatend$2$;
     } else {
      $nls$2 = $nls$1;$ols$2 = $ols$1;$wsatend$4 = $wsatend$2$;
      label = 71;
      break;
     }
    }
   } else {
    $nls$3 = $ne$0$lcssa;$ols$4 = $oe$0$lcssa;
   }
  }
 } while(0);
 do {
  if ((label|0) == 71) {
   $218 = ($wsatend$4|0)==(0);
   if ($218) {
    $219 = (__rl_compare_chars($ols$2,0,0,$nls$2,0,0)|0);
    $220 = ($219|0)==(0);
    if ($220) {
     $221 = HEAP8[$ols$2>>0]|0;
     $222 = ($221<<24>>24)==(0);
     do {
      if ($222) {
       $ols$3 = $ols$2;
      } else {
       $223 = HEAP32[36240>>2]|0;
       $224 = ($223|0)==(0);
       if ($224) {
        $225 = $ols$2;
        $226 = (($225) - ($146))|0;
        $227 = (__rl_find_next_mbchar($old,$226,1,0)|0);
        $228 = (($old) + ($227)|0);
        $ols$3 = $228;
        break;
       } else {
        $229 = ((($ols$2)) + 1|0);
        $ols$3 = $229;
        break;
       }
      }
     } while(0);
     $230 = HEAP8[$nls$2>>0]|0;
     $231 = ($230<<24>>24)==(0);
     if ($231) {
      $nls$3 = $nls$2;$ols$4 = $ols$3;
     } else {
      $232 = HEAP32[36240>>2]|0;
      $233 = ($232|0)==(0);
      if ($233) {
       $234 = $nls$2;
       $235 = (($234) - ($155))|0;
       $236 = (__rl_find_next_mbchar($new,$235,1,0)|0);
       $237 = (($new) + ($236)|0);
       $nls$3 = $237;$ols$4 = $ols$3;
       break;
      } else {
       $238 = ((($nls$2)) + 1|0);
       $nls$3 = $238;$ols$4 = $ols$3;
       break;
      }
     }
    } else {
     $nls$3 = $nls$2;$ols$4 = $ols$2;
    }
   } else {
    $nls$3 = $ne$0$lcssa;$ols$4 = $oe$0$lcssa;
   }
  }
 } while(0);
 $239 = ($current_line|0)==(0);
 $240 = HEAP32[32432>>2]|0;
 $241 = $239 ? $240 : 0;
 $242 = HEAP32[32288>>2]|0;
 $243 = ($242|0)==($current_line|0);
 if (!($243)) {
  $244 = HEAP32[35120>>2]|0;
  $245 = ($244|0)<($current_line|0);
  if (!($245)) {
   $246 = (($current_line) - ($242))|0;
   $247 = ($246|0)>(0);
   if ($247) {
    $i$03$i = 0;
    while(1) {
     $248 = HEAP32[13512>>2]|0;
     (_putc(10,($248|0))|0);
     $249 = (($i$03$i) + 1)|0;
     $exitcond$i = ($249|0)==($246|0);
     if ($exitcond$i) {
      break;
     } else {
      $i$03$i = $249;
     }
    }
    $250 = HEAP32[35144>>2]|0;
    (_tputs($250,1,368)|0);
    HEAP32[32280>>2] = 0;
   } else {
    $251 = HEAP32[35208>>2]|0;
    $252 = ($251|0)==(0|0);
    if (!($252)) {
     $253 = HEAP8[$251>>0]|0;
     $254 = ($253<<24>>24)==(0);
     if (!($254)) {
      $255 = (0 - ($246))|0;
      $256 = ($246|0)<(0);
      if ($256) {
       (_tputs($251,1,368)|0);
       $257 = ($246|0)<(-1);
       if ($257) {
        $259 = 1;
        while(1) {
         $$pre$i = HEAP32[35208>>2]|0;
         (_tputs($$pre$i,1,368)|0);
         $258 = (($259) + 1)|0;
         $260 = ($258|0)<($255|0);
         if ($260) {
          $259 = $258;
         } else {
          break;
         }
        }
       }
      }
     }
    }
   }
   HEAP32[32288>>2] = $current_line;
  }
  $261 = HEAP32[36240>>2]|0;
  $262 = ($261|0)!=(0);
  $or$cond25 = $239 & $262;
  $263 = HEAP32[32328>>2]|0;
  $264 = ($263|0)!=(0);
  $or$cond27 = $or$cond25 & $264;
  if ($or$cond27) {
   $265 = HEAP32[32280>>2]|0;
   $266 = (($265) + ($263))|0;
   HEAP32[32280>>2] = $266;
  }
 }
 $267 = HEAP32[32408>>2]|0;
 $268 = $ofd$3;
 $269 = (($268) - ($146))|0;
 $270 = HEAP32[13600>>2]|0;
 $271 = $270 | $current_line;
 $or$cond29$not = ($271|0)==(0);
 $272 = HEAP32[35144>>2]|0;
 $273 = ($272|0)!=(0|0);
 $or$cond31 = $or$cond29$not & $273;
 do {
  if ($or$cond31) {
   $274 = HEAP32[32344>>2]|0;
   $275 = HEAP32[32280>>2]|0;
   $notlhs143 = ($267|0)<=($274|0);
   $notrhs144 = ($275|0)<(1);
   $or$cond33$not = $notlhs143 | $notrhs144;
   $276 = ($269|0)<($267|0);
   $or$cond94 = $276 | $or$cond33$not;
   if ($or$cond94) {
    $303 = $275;
   } else {
    $277 = HEAP32[36240>>2]|0;
    $278 = ($277|0)==(0);
    $279 = HEAP32[32352>>2]|0;
    $280 = HEAP32[32472>>2]|0;
    $281 = (($280) + 1)|0;
    $282 = $278 ? $279 : $281;
    $283 = ($275|0)<($282|0);
    if ($283) {
     (_tputs($272,1,368)|0);
     $284 = HEAP32[32376>>2]|0;
     $285 = ($284|0)==(0);
     if (!($285)) {
      __rl_output_some_chars(32488,1);
     }
     $286 = HEAP32[32384>>2]|0;
     __rl_output_some_chars($286,$267);
     $287 = HEAP32[36240>>2]|0;
     $288 = ($287|0)==(0);
     if ($288) {
      $289 = HEAP32[32384>>2]|0;
      $290 = (__rl_col_width($289,0,$267,1)|0);
      $291 = HEAP32[32432>>2]|0;
      $292 = (($290) - ($291))|0;
      $293 = HEAP32[32376>>2]|0;
      $294 = (($292) + ($293))|0;
      HEAP32[32280>>2] = $294;
      HEAP32[32464>>2] = 1;
      $303 = $294;
      break;
     } else {
      $295 = HEAP32[32376>>2]|0;
      $296 = (($295) + ($267))|0;
      HEAP32[32280>>2] = $296;
      $303 = $296;
      break;
     }
    } else {
     $303 = $275;
    }
   }
  } else {
   $$pre = HEAP32[32280>>2]|0;
   $303 = $$pre;
  }
 } while(0);
 __rl_move_cursor_relative($269,$old);
 $297 = HEAP32[36240>>2]|0;
 $298 = $297 | $current_line;
 $299 = ($298|0)==(0);
 if ($299) {
  $300 = HEAP32[32280>>2]|0;
  $301 = ($300|0)>(0);
  $302 = ($303|0)>(0);
  $or$cond37 = $302 | $301;
  $304 = HEAP32[32352>>2]|0;
  $305 = ($300|0)==($304|0);
  $or$cond96 = $or$cond37 & $305;
  if ($or$cond96) {
   HEAP32[32464>>2] = 1;
  }
 }
 $306 = $nls$3;
 $307 = $nfd$3;
 $308 = (($306) - ($307))|0;
 $309 = $ols$4;
 $310 = (($268) - ($309))|0;
 $311 = (($310) + ($308))|0;
 $312 = ($297|0)==(0);
 if ($312) {
  $313 = (($307) - ($155))|0;
  $314 = (($306) - ($155))|0;
  $315 = (__rl_col_width($new,$313,$314,1)|0);
  $316 = (($309) - ($146))|0;
  $317 = (__rl_col_width($old,$269,$316,1)|0);
  $318 = (($315) - ($317))|0;
  $col_lendiff$0 = $318;
 } else {
  $col_lendiff$0 = $311;
 }
 $319 = HEAP32[13600>>2]|0;
 $320 = $319 | $current_line;
 $321 = ($320|0)==(0);
 if ($321) {
  $322 = HEAP32[32328>>2]|0;
  $323 = ($322|0)==($241|0);
  if ($323) {
   $col_lendiff$1 = $col_lendiff$0;$lendiff$0 = $311;
  } else {
   $324 = HEAP32[36240>>2]|0;
   $325 = ($324|0)==(0);
   $326 = (($322) - ($241))|0;
   $327 = (($326) + ($311))|0;
   $328 = (($326) + ($col_lendiff$0))|0;
   $$111 = $325 ? $328 : $327;
   $col_lendiff$1 = $$111;$lendiff$0 = $327;
  }
 } else {
  $col_lendiff$1 = $col_lendiff$0;$lendiff$0 = $311;
 }
 $329 = $ne$0$lcssa;
 $330 = (($329) - ($307))|0;
 $331 = HEAP32[36240>>2]|0;
 $332 = ($331|0)==(0);
 if ($332) {
  $333 = (($307) - ($155))|0;
  $334 = (($329) - ($155))|0;
  $335 = (__rl_col_width($new,$333,$334,1)|0);
  $col_temp$0 = $335;
 } else {
  $col_temp$0 = $330;
 }
 $336 = ($col_lendiff$1|0)>(0);
 if (!($336)) {
  $456 = HEAP32[35200>>2]|0;
  $457 = ($456|0)==(0|0);
  do {
   if ($457) {
    label = 181;
   } else {
    $458 = $col_temp$0 << 1;
    $459 = (0 - ($col_lendiff$1))|0;
    $460 = ($458|0)<($459|0);
    if ($460) {
     label = 181;
    } else {
     $461 = HEAP32[13600>>2]|0;
     $462 = ($461|0)!=(0);
     $463 = HEAP32[32280>>2]|0;
     $464 = ($463|0)==(0);
     $or$cond73 = $462 & $464;
     $465 = HEAP32[32456>>2]|0;
     $466 = ($465|0)!=(0);
     $or$cond75 = $or$cond73 & $466;
     if ($or$cond75) {
      $467 = (0 - ($lendiff$0))|0;
      $468 = HEAP32[32328>>2]|0;
      $469 = ($468|0)==($467|0);
      $$col_lendiff$1 = $469 ? 0 : $col_lendiff$1;
      $col_lendiff$2 = $$col_lendiff$1;
     } else {
      $col_lendiff$2 = $col_lendiff$1;
     }
     $470 = ($465|0)==(0);
     $or$cond77 = $462 & $470;
     $471 = ($col_lendiff$2|0)!=(0);
     $or$cond79 = $471 & $or$cond77;
     do {
      if ($or$cond79) {
       $472 = (0 - ($col_lendiff$2))|0;
       $473 = ($463|0)<($472|0);
       if (!($473)) {
        $$pre$phiZ2D = $472;
        label = 165;
       }
      } else {
       $$old141 = ($col_lendiff$2|0)==(0);
       if ($$old141) {
        break;
       }
       $$pre246 = (0 - ($col_lendiff$2))|0;
       $$pre$phiZ2D = $$pre246;
       label = 165;
      }
     } while(0);
     L171: do {
      if ((label|0) == 165) {
       $474 = HEAP32[35112>>2]|0;
       $475 = ($474|0)<($$pre$phiZ2D|0);
       if ($475) {
        break;
       }
       $476 = HEAP32[35192>>2]|0;
       $477 = ($476|0)==(0|0);
       do {
        if (!($477)) {
         $478 = HEAP8[$476>>0]|0;
         $479 = ($478<<24>>24)==(0);
         if ($479) {
          break;
         }
         $480 = (_tgoto($476,$$pre$phiZ2D,$$pre$phiZ2D)|0);
         (_tputs($480,$$pre$phiZ2D,368)|0);
         break L171;
        }
       } while(0);
       $481 = HEAP8[$456>>0]|0;
       $482 = ($481<<24>>24)==(0);
       $483 = ($col_lendiff$2|0)==(0);
       $or$cond$i119 = $483 | $482;
       if ($or$cond$i119) {
        break;
       }
       (_tputs($456,1,368)|0);
       $484 = ($col_lendiff$2|0)==(-1);
       if ($484) {
        break;
       }
       $485 = $col_lendiff$2 ^ -1;
       $487 = $485;
       while(1) {
        $$pre$i121 = HEAP32[35200>>2]|0;
        $486 = (($487) + -1)|0;
        (_tputs($$pre$i121,1,368)|0);
        $488 = ($486|0)==(0);
        if ($488) {
         break;
        } else {
         $487 = $486;
        }
       }
      }
     } while(0);
     $489 = ($308|0)>(0);
     if (!($489)) {
      STACKTOP = sp;return;
     }
     __rl_output_some_chars($nfd$3,$308);
     $490 = HEAP32[36240>>2]|0;
     $491 = ($490|0)==(0);
     do {
      if ($491) {
       $492 = (__rl_col_width($nfd$3,0,$308,1)|0);
       $493 = HEAP32[32280>>2]|0;
       $494 = (($493) + ($492))|0;
       HEAP32[32280>>2] = $494;
       $495 = HEAP32[32432>>2]|0;
       $496 = ($495|0)!=(0);
       $or$cond81 = $239 & $496;
       $497 = HEAP32[32456>>2]|0;
       $498 = ($497|0)!=(0);
       $or$cond83 = $or$cond81 & $498;
       $499 = ($494|0)>($495|0);
       $or$cond106 = $499 & $or$cond83;
       if (!($or$cond106)) {
        break;
       }
       $500 = (($307) - ($155))|0;
       $501 = HEAP32[32472>>2]|0;
       $502 = ($500|0)>($501|0);
       if ($502) {
        break;
       }
       $503 = (($494) - ($495))|0;
       HEAP32[32280>>2] = $503;
       HEAP32[32464>>2] = 1;
      } else {
       $504 = HEAP32[32280>>2]|0;
       $505 = (($504) + ($308))|0;
       HEAP32[32280>>2] = $505;
      }
     } while(0);
     $506 = HEAP32[13600>>2]|0;
     $507 = ($506|0)==(0);
     if ($507) {
      STACKTOP = sp;return;
     }
     $508 = $oe$0$lcssa;
     $509 = (($508) - ($146))|0;
     $510 = (($329) - ($155))|0;
     $511 = ($509|0)>($510|0);
     if ($511) {
      label = 187;
      break;
     }
     STACKTOP = sp;return;
    }
   }
  } while(0);
  do {
   if ((label|0) == 181) {
    $512 = ($330|0)>(0);
    if ($512) {
     __rl_output_some_chars($nfd$3,$330);
     $513 = HEAP32[32280>>2]|0;
     $514 = (($513) + ($col_temp$0))|0;
     HEAP32[32280>>2] = $514;
     $515 = HEAP32[36240>>2]|0;
     $516 = ($515|0)==(0);
     if (!($516)) {
      $517 = $oe$0$lcssa;
      $518 = (($517) - ($146))|0;
      $519 = (($329) - ($155))|0;
      $537 = $518;$538 = $519;
      label = 189;
      break;
     }
     $520 = HEAP32[32432>>2]|0;
     $521 = ($520|0)!=(0);
     $or$cond85 = $239 & $521;
     $522 = HEAP32[32456>>2]|0;
     $523 = ($522|0)!=(0);
     $or$cond87 = $or$cond85 & $523;
     $524 = ($514|0)>($520|0);
     $or$cond108 = $524 & $or$cond87;
     if (!($or$cond108)) {
      label = 187;
      break;
     }
     $525 = (($307) - ($155))|0;
     $526 = HEAP32[32472>>2]|0;
     $527 = ($525|0)>($526|0);
     if ($527) {
      label = 187;
      break;
     }
     $528 = (($514) - ($520))|0;
     HEAP32[32280>>2] = $528;
     HEAP32[32464>>2] = 1;
     label = 187;
    } else {
     label = 187;
    }
   }
  } while(0);
  if ((label|0) == 187) {
   $$pr139 = HEAP32[36240>>2]|0;
   $529 = $oe$0$lcssa;
   $530 = (($529) - ($146))|0;
   $531 = (($329) - ($155))|0;
   $532 = ($$pr139|0)==(0);
   if ($532) {
    $533 = (__rl_col_width($old,0,$530,1)|0);
    $534 = (__rl_col_width($new,0,$531,1)|0);
    $535 = (($533) - ($534))|0;
    $col_lendiff$4 = $535;
   } else {
    $537 = $530;$538 = $531;
    label = 189;
   }
  }
  if ((label|0) == 189) {
   $536 = (($537) - ($538))|0;
   $col_lendiff$4 = $536;
  }
  $539 = ($col_lendiff$4|0)==(0);
  if ($539) {
   STACKTOP = sp;return;
  }
  $540 = HEAP32[36240>>2]|0;
  $541 = ($540|0)==(0);
  do {
   if ($541) {
    $542 = HEAP32[32280>>2]|0;
    $543 = HEAP32[35112>>2]|0;
    $544 = ($542|0)<($543|0);
    if ($544) {
     break;
    }
    STACKTOP = sp;return;
   }
  } while(0);
  $545 = HEAP32[35096>>2]|0;
  $546 = ($545|0)!=(0);
  $547 = ($current_line|0)<($inv_botlin|0);
  $or$cond110 = $547 & $546;
  if ($or$cond110) {
   $548 = ($col_lendiff$4|0)>(0);
   if ($548) {
    $i$01$i = 0;
    while(1) {
     $549 = HEAP32[13512>>2]|0;
     (_putc(32,($549|0))|0);
     $550 = (($i$01$i) + 1)|0;
     $exitcond$i124 = ($550|0)==($col_lendiff$4|0);
     if ($exitcond$i124) {
      break;
     } else {
      $i$01$i = $550;
     }
    }
   }
   $551 = HEAP32[32280>>2]|0;
   $552 = (($551) + ($col_lendiff$4))|0;
   HEAP32[32280>>2] = $552;
   STACKTOP = sp;return;
  }
  $553 = HEAP32[35136>>2]|0;
  $554 = ($553|0)==(0|0);
  if (!($554)) {
   (_tputs($553,1,368)|0);
   STACKTOP = sp;return;
  }
  $555 = ($col_lendiff$4|0)>(0);
  if ($555) {
   $i$01$i$i127 = 0;
   while(1) {
    $556 = HEAP32[13512>>2]|0;
    (_putc(32,($556|0))|0);
    $557 = (($i$01$i$i127) + 1)|0;
    $exitcond$i$i128 = ($557|0)==($col_lendiff$4|0);
    if ($exitcond$i$i128) {
     break;
    } else {
     $i$01$i$i127 = $557;
    }
   }
  }
  $558 = HEAP32[32280>>2]|0;
  $559 = (($558) + ($col_lendiff$4))|0;
  HEAP32[32280>>2] = $559;
  STACKTOP = sp;return;
 }
 $337 = HEAP32[32296>>2]|0;
 $338 = ($337|0)<($inv_botlin|0);
 $not$ = ($337|0)<=($current_line|0);
 $$97 = $338 & $not$;
 $339 = ($lendiff$0|0)<(0);
 if ($339) {
  __rl_output_some_chars($nfd$3,$330);
  $340 = HEAP32[32280>>2]|0;
  $341 = (($340) + ($col_temp$0))|0;
  HEAP32[32280>>2] = $341;
  $342 = HEAP32[32456>>2]|0;
  $343 = ($342|0)!=(0);
  $or$cond41 = $239 & $343;
  $344 = HEAP32[32432>>2]|0;
  $345 = ($344|0)!=(0);
  $or$cond43 = $or$cond41 & $345;
  if (!($or$cond43)) {
   STACKTOP = sp;return;
  }
  $346 = (($307) - ($155))|0;
  $347 = HEAP32[32472>>2]|0;
  $348 = ($346|0)>($347|0);
  if ($348) {
   STACKTOP = sp;return;
  }
  $349 = (($341) - ($344))|0;
  HEAP32[32280>>2] = $349;
  HEAP32[32464>>2] = 1;
  STACKTOP = sp;return;
 }
 $350 = HEAP32[35088>>2]|0;
 $351 = ($350|0)==(0);
 if (!($351)) {
  $352 = $col_temp$0 << 1;
  $353 = ($352|0)>=($col_lendiff$1|0);
  $354 = HEAP32[35160>>2]|0;
  $355 = ($354|0)!=(0|0);
  $or$cond45 = $353 | $355;
  if ($or$cond45) {
   $356 = HEAP32[35096>>2]|0;
   $357 = ($356|0)!=(0);
   $or$cond47 = $$97 & $357;
   if (!($or$cond47)) {
    $358 = HEAP8[$ols$4>>0]|0;
    $359 = ($358<<24>>24)==(0);
    L249: do {
     if (!($359)) {
      $360 = HEAP32[13600>>2]|0;
      $361 = ($360|0)!=(0);
      $362 = HEAP32[32280>>2]|0;
      $363 = ($362|0)==(0);
      $or$cond49 = $361 & $363;
      $364 = HEAP32[32344>>2]|0;
      $365 = ($lendiff$0|0)>($364|0);
      $or$cond99 = $or$cond49 & $365;
      $366 = ($241|0)>(0);
      $or$cond113 = $366 & $or$cond99;
      if ($or$cond113) {
       break;
      }
      $367 = HEAP32[36240>>2]|0;
      $368 = $367 | $current_line;
      $369 = ($368|0)==(0);
      $370 = HEAP32[32432>>2]|0;
      $371 = ($370|0)!=(0);
      $or$cond53 = $369 & $371;
      do {
       if ($or$cond53) {
        $372 = (($307) - ($155))|0;
        $373 = HEAP32[32472>>2]|0;
        $374 = ($372|0)>($373|0);
        if ($374) {
         label = 126;
         break;
        }
        $375 = ($col_lendiff$1|0)<($364|0);
        $376 = HEAP32[32328>>2]|0;
        $377 = ($376|0)<($241|0);
        $or$cond104 = $375 | $377;
        if ($or$cond104) {
         break L249;
        }
       } else {
        label = 126;
       }
      } while(0);
      if ((label|0) == 126) {
       $$old = HEAP32[32328>>2]|0;
       $$old103 = ($$old|0)<($241|0);
       if ($$old103) {
        break;
       }
      }
      $378 = ($354|0)==(0|0);
      L258: do {
       if ($378) {
        $380 = HEAP32[35184>>2]|0;
        $381 = ($380|0)==(0|0);
        do {
         if (!($381)) {
          $382 = HEAP8[$380>>0]|0;
          $383 = ($382<<24>>24)==(0);
          if ($383) {
           break;
          }
          (_tputs($380,1,368)|0);
          $384 = ($col_lendiff$1|0)==(0);
          if (!($384)) {
           $i$02$i = $col_lendiff$1;
           while(1) {
            $385 = (($i$02$i) + -1)|0;
            (__rl_output_character_function(32)|0);
            $386 = ($385|0)==(0);
            if ($386) {
             break;
            } else {
             $i$02$i = $385;
            }
           }
          }
          $387 = HEAP32[35176>>2]|0;
          $388 = ($387|0)==(0|0);
          do {
           if (!($388)) {
            $389 = HEAP8[$387>>0]|0;
            $390 = ($389<<24>>24)==(0);
            if ($390) {
             break;
            }
            (_tputs($387,1,368)|0);
           }
          } while(0);
          (__rl_backspace($col_lendiff$1)|0);
          break L258;
         }
        } while(0);
        $391 = HEAP32[35168>>2]|0;
        $392 = ($391|0)==(0|0);
        if ($392) {
         break;
        }
        $393 = HEAP8[$391>>0]|0;
        $394 = ($393<<24>>24)==(0);
        $395 = ($col_lendiff$1|0)==(0);
        $or$cond$i115 = $395 | $394;
        if ($or$cond$i115) {
         break;
        }
        $396 = (($col_lendiff$1) + -1)|0;
        (_tputs($391,1,368)|0);
        $397 = ($396|0)==(0);
        if ($397) {
         break;
        } else {
         $399 = $396;
        }
        while(1) {
         $$pre$i117 = HEAP32[35168>>2]|0;
         $398 = (($399) + -1)|0;
         (_tputs($$pre$i117,1,368)|0);
         $400 = ($398|0)==(0);
         if ($400) {
          break;
         } else {
          $399 = $398;
         }
        }
       } else {
        $379 = (_tgoto($354,0,$col_lendiff$1)|0);
        (_tputs($379,1,368)|0);
       }
      } while(0);
      __rl_output_some_chars($nfd$3,$308);
      $401 = HEAP32[36240>>2]|0;
      $402 = ($401|0)==(0);
      if ($402) {
       $403 = (__rl_col_width($nfd$3,0,$308,1)|0);
       $404 = HEAP32[32280>>2]|0;
       $405 = (($404) + ($403))|0;
       $storemerge = $405;
      } else {
       $406 = HEAP32[32280>>2]|0;
       $407 = (($406) + ($308))|0;
       $storemerge = $407;
      }
      HEAP32[32280>>2] = $storemerge;
      $424 = ($308|0)>($lendiff$0|0);
      if (!($424)) {
       STACKTOP = sp;return;
      }
      $425 = HEAP32[36240>>2]|0;
      $426 = $425 | $current_line;
      $427 = ($426|0)==(0);
      $428 = HEAP32[32456>>2]|0;
      $429 = ($428|0)!=(0);
      $or$cond65 = $427 & $429;
      $430 = HEAP32[32432>>2]|0;
      $431 = ($430|0)!=(0);
      $or$cond67 = $or$cond65 & $431;
      if (!($or$cond67)) {
       STACKTOP = sp;return;
      }
      $432 = (($307) - ($155))|0;
      $433 = HEAP32[32472>>2]|0;
      $434 = ($432|0)>($433|0);
      if ($434) {
       STACKTOP = sp;return;
      }
      $435 = (($storemerge) - ($430))|0;
      HEAP32[32280>>2] = $435;
      HEAP32[32464>>2] = 1;
      STACKTOP = sp;return;
     }
    } while(0);
    $408 = HEAP32[36240>>2]|0;
    $409 = ($408|0)!=(0);
    $410 = ($lendiff$0|0)>(0);
    $or$cond55 = $410 & $359;
    $or$cond259 = $409 & $or$cond55;
    __rl_output_some_chars($nfd$3,$330);
    $411 = HEAP32[32280>>2]|0;
    $412 = (($411) + ($col_temp$0))|0;
    HEAP32[32280>>2] = $412;
    if ($or$cond259) {
     STACKTOP = sp;return;
    }
    $413 = HEAP32[36240>>2]|0;
    $414 = $413 | $current_line;
    $415 = ($414|0)==(0);
    $416 = HEAP32[32456>>2]|0;
    $417 = ($416|0)!=(0);
    $or$cond59 = $415 & $417;
    $418 = HEAP32[32432>>2]|0;
    $419 = ($418|0)!=(0);
    $or$cond61 = $or$cond59 & $419;
    if (!($or$cond61)) {
     STACKTOP = sp;return;
    }
    $420 = (($307) - ($155))|0;
    $421 = HEAP32[32472>>2]|0;
    $422 = ($420|0)>($421|0);
    if ($422) {
     STACKTOP = sp;return;
    }
    $423 = (($412) - ($418))|0;
    HEAP32[32280>>2] = $423;
    HEAP32[32464>>2] = 1;
    STACKTOP = sp;return;
   }
  }
 }
 __rl_output_some_chars($nfd$3,$330);
 $436 = HEAP32[32280>>2]|0;
 $437 = (($436) + ($col_temp$0))|0;
 HEAP32[32280>>2] = $437;
 $438 = HEAP32[36240>>2]|0;
 $439 = ($438|0)==(0);
 if (!($439)) {
  STACKTOP = sp;return;
 }
 $440 = HEAP32[32440>>2]|0;
 $441 = ($440|0)==($current_line|0);
 $442 = HEAP32[32432>>2]|0;
 $443 = ($442|0)!=(0);
 $or$cond69 = $441 & $443;
 $444 = HEAP32[32456>>2]|0;
 $445 = ($444|0)!=(0);
 $or$cond71 = $or$cond69 & $445;
 if (!($or$cond71)) {
  STACKTOP = sp;return;
 }
 $446 = HEAP32[32424>>2]|0;
 $447 = ($446|0)==($442|0);
 if ($447) {
  STACKTOP = sp;return;
 }
 $448 = (($307) - ($155))|0;
 $449 = HEAP32[32472>>2]|0;
 $450 = HEAP32[35112>>2]|0;
 $451 = Math_imul($450, $current_line)|0;
 $452 = (($449) - ($451))|0;
 $453 = ($448|0)<($452|0);
 if (!($453)) {
  STACKTOP = sp;return;
 }
 $454 = (($437) - ($442))|0;
 $455 = (($454) + ($446))|0;
 HEAP32[32280>>2] = $455;
 HEAP32[32464>>2] = 1;
 STACKTOP = sp;return;
}
function _expand_prompt($pmt,$lp,$lip,$niflp,$vlp) {
 $pmt = $pmt|0;
 $lp = $lp|0;
 $lip = $lip|0;
 $niflp = $niflp|0;
 $vlp = $vlp|0;
 var $$0 = 0, $$0$i = 0, $$0$i8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $9 = 0, $ignoring$02055 = 0, $ignoring$1 = 0, $igstart$01758 = 0, $igstart$1 = 0, $invfl$0$lcssa = 0, $invfl$0$ninvis$2 = 0, $invfl$02253 = 0, $invfl$1 = 0, $invflset$0$ = 0;
 var $invflset$02352 = 0, $invflset$1 = 0, $l$013 = 0, $last$0$lcssa = 0, $last$01956 = 0, $last$1 = 0, $ninvis$0$invfl$0 = 0, $ninvis$0$lcssa = 0, $ninvis$02154 = 0, $ninvis$1 = 0, $ninvis$2 = 0, $ninvis$3 = 0, $or$cond = 0, $or$cond10 = 0, $or$cond3 = 0, $or$cond4 = 0, $or$cond6 = 0, $p$01659 = 0, $p$1$lcssa = 0, $p$112 = 0;
 var $p$2 = 0, $p$3 = 0, $phitmp = 0, $phitmp11 = 0, $physchars$1$lcssa = 0, $physchars$12550 = 0, $physchars$2 = 0, $physchars$3 = 0, $physchars$4 = 0, $r$0 = 0, $r$2$lcssa = 0, $r$2$ph = 0, $r$22451 = 0, $r$3$lcssa = 0, $r$314 = 0, $r$4 = 0, $r$5 = 0, $rl$1$lcssa = 0, $rl$1$ph = 0, $rl$11857 = 0;
 var $rl$2 = 0, $rl$3 = 0, $rl$4 = 0, $scevgep$sum = 0, $scevgep47 = 0, $scevgep48$sum = 0, $scevgep49 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36240>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (_strchr($pmt,1)|0);
  $3 = ($2|0)==(0|0);
  if ($3) {
   $4 = HEAP32[13528>>2]|0;
   $5 = ($4|0)==($pmt|0);
   $6 = HEAP32[13728>>2]|0;
   $7 = ($6|0)!=(0);
   $or$cond = $5 & $7;
   $8 = (_strlen(($pmt|0))|0);
   if ($or$cond) {
    $9 = (($8) + 2)|0;
    $10 = (_xmalloc($9)|0);
    $11 = HEAP32[13440>>2]|0;
    $12 = ($11|0)==(1);
    if ($12) {
     $$0$i = 64;
    } else {
     $13 = HEAP32[13432>>2]|0;
     $14 = ($13|0)==(26464|0);
     $phitmp11 = $14 ? 43 : 58;
     $$0$i = $phitmp11;
    }
    HEAP8[$10>>0] = $$0$i;
    $15 = ((($10)) + 1|0);
    (_strcpy(($15|0),($pmt|0))|0);
    $r$0 = $10;
   } else {
    $16 = (($8) + 1)|0;
    $17 = (_xmalloc($16)|0);
    $18 = (_strcpy(($17|0),($pmt|0))|0);
    $r$0 = $18;
   }
   $19 = ($lp|0)!=(0|0);
   if ($19) {
    $20 = (_strlen(($r$0|0))|0);
    HEAP32[$lp>>2] = $20;
   }
   $21 = ($lip|0)==(0|0);
   if (!($21)) {
    HEAP32[$lip>>2] = 0;
   }
   $22 = ($niflp|0)==(0|0);
   if (!($22)) {
    HEAP32[$niflp>>2] = 0;
   }
   $23 = ($vlp|0)==(0|0);
   if ($23) {
    $$0 = $r$0;
    return ($$0|0);
   }
   if ($19) {
    $24 = HEAP32[$lp>>2]|0;
    $26 = $24;
   } else {
    $25 = (_strlen(($r$0|0))|0);
    $26 = $25;
   }
   HEAP32[$vlp>>2] = $26;
   $$0 = $r$0;
   return ($$0|0);
  }
 }
 $27 = (_strlen(($pmt|0))|0);
 $28 = (($27) + 2)|0;
 $29 = (_xmalloc($28)|0);
 $30 = HEAP32[13528>>2]|0;
 $31 = ($30|0)==($pmt|0);
 $32 = HEAP32[13728>>2]|0;
 $33 = ($32|0)!=(0);
 $or$cond3 = $31 & $33;
 if ($or$cond3) {
  $34 = HEAP32[13440>>2]|0;
  $35 = ($34|0)==(1);
  if ($35) {
   $$0$i8 = 64;
  } else {
   $36 = HEAP32[13432>>2]|0;
   $37 = ($36|0)==(26464|0);
   $phitmp = $37 ? 43 : 58;
   $$0$i8 = $phitmp;
  }
  $38 = ((($29)) + 1|0);
  HEAP8[$29>>0] = $$0$i8;
  $r$2$ph = $38;$rl$1$ph = 1;
 } else {
  $r$2$ph = $29;$rl$1$ph = 0;
 }
 $39 = ($pmt|0)==(0|0);
 if ($39) {
  $invfl$0$lcssa = 0;$last$0$lcssa = 0;$ninvis$0$lcssa = 0;$physchars$1$lcssa = $rl$1$ph;$r$2$lcssa = $r$2$ph;$rl$1$lcssa = $rl$1$ph;
 } else {
  $40 = $29;
  $41 = $40 ^ -1;
  $42 = $pmt;
  $43 = HEAP8[$pmt>>0]|0;
  $44 = ($43<<24>>24)==(0);
  if ($44) {
   $invfl$0$lcssa = 0;$last$0$lcssa = 0;$ninvis$0$lcssa = 0;$physchars$1$lcssa = $rl$1$ph;$r$2$lcssa = $r$2$ph;$rl$1$lcssa = $rl$1$ph;
  } else {
   $47 = $43;$ignoring$02055 = 0;$igstart$01758 = 0;$invfl$02253 = 0;$invflset$02352 = 0;$last$01956 = 0;$ninvis$02154 = 0;$p$01659 = $pmt;$physchars$12550 = $rl$1$ph;$r$22451 = $r$2$ph;$rl$11857 = $rl$1$ph;
   while(1) {
    $45 = ($ignoring$02055|0)==(0);
    $46 = ($47<<24>>24)==(1);
    $or$cond4 = $45 & $46;
    do {
     if ($or$cond4) {
      $ignoring$1 = 1;$igstart$1 = $p$01659;$invfl$1 = $invfl$02253;$invflset$1 = $invflset$02352;$last$1 = $last$01956;$ninvis$3 = $ninvis$02154;$p$3 = $p$01659;$physchars$4 = $physchars$12550;$r$5 = $r$22451;$rl$4 = $rl$11857;
     } else {
      $48 = ($ignoring$02055|0)!=(0);
      $49 = ($47<<24>>24)==(2);
      $or$cond10 = $48 & $49;
      if ($or$cond10) {
       $50 = ((($igstart$01758)) + 1|0);
       $51 = ($p$01659|0)==($50|0);
       if ($51) {
        $ignoring$1 = 0;$igstart$1 = $igstart$01758;$invfl$1 = $invfl$02253;$invflset$1 = $invflset$02352;$last$1 = $last$01956;$ninvis$3 = $ninvis$02154;$p$3 = $p$01659;$physchars$4 = $physchars$12550;$r$5 = $r$22451;$rl$4 = $rl$11857;
        break;
       }
       $52 = $r$22451;
       $53 = (($52) + ($41))|0;
       $ignoring$1 = 0;$igstart$1 = $igstart$01758;$invfl$1 = $invfl$02253;$invflset$1 = $invflset$02352;$last$1 = $53;$ninvis$3 = $ninvis$02154;$p$3 = $p$01659;$physchars$4 = $physchars$12550;$r$5 = $r$22451;$rl$4 = $rl$11857;
       break;
      }
      $54 = HEAP32[36240>>2]|0;
      $55 = ($54|0)==(0);
      do {
       if ($55) {
        $56 = $p$01659;
        $57 = (($56) - ($42))|0;
        $58 = (__rl_find_next_mbchar($pmt,$57,1,1)|0);
        $59 = (($58) - ($57))|0;
        $60 = ($58|0)==($57|0);
        if ($60) {
         $p$1$lcssa = $p$01659;$r$3$lcssa = $r$22451;
        } else {
         $61 = (($58) - ($56))|0;
         $l$013 = $59;$p$112 = $p$01659;$r$314 = $r$22451;
         while(1) {
          $62 = (($l$013) + -1)|0;
          $63 = ((($p$112)) + 1|0);
          $64 = HEAP8[$p$112>>0]|0;
          $65 = ((($r$314)) + 1|0);
          HEAP8[$r$314>>0] = $64;
          $66 = ($62|0)==(0);
          if ($66) {
           break;
          } else {
           $l$013 = $62;$p$112 = $63;$r$314 = $65;
          }
         }
         $scevgep$sum = (($42) + ($61))|0;
         $scevgep47 = (($r$22451) + ($scevgep$sum)|0);
         $scevgep48$sum = (($42) + ($61))|0;
         $scevgep49 = (($p$01659) + ($scevgep48$sum)|0);
         $p$1$lcssa = $scevgep49;$r$3$lcssa = $scevgep47;
        }
        if ($48) {
         $70 = (($59) + ($ninvis$02154))|0;
         $ninvis$1 = $70;$physchars$2 = $physchars$12550;$rl$2 = $rl$11857;
        } else {
         $67 = (($59) + ($rl$11857))|0;
         $68 = (__rl_col_width($pmt,$57,$58,0)|0);
         $69 = (($68) + ($physchars$12550))|0;
         $ninvis$1 = $ninvis$02154;$physchars$2 = $69;$rl$2 = $67;
        }
        $71 = ((($p$1$lcssa)) + -1|0);
        $ninvis$2 = $ninvis$1;$p$2 = $71;$physchars$3 = $physchars$2;$r$4 = $r$3$lcssa;$rl$3 = $rl$2;
       } else {
        $72 = ((($r$22451)) + 1|0);
        HEAP8[$r$22451>>0] = $47;
        if ($48) {
         $75 = (($ninvis$02154) + 1)|0;
         $ninvis$2 = $75;$p$2 = $p$01659;$physchars$3 = $physchars$12550;$r$4 = $72;$rl$3 = $rl$11857;
         break;
        } else {
         $73 = (($rl$11857) + 1)|0;
         $74 = (($physchars$12550) + 1)|0;
         $ninvis$2 = $ninvis$02154;$p$2 = $p$01659;$physchars$3 = $74;$r$4 = $72;$rl$3 = $73;
         break;
        }
       }
      } while(0);
      $76 = ($invflset$02352|0)!=(0);
      $77 = HEAP32[35112>>2]|0;
      $78 = ($rl$3|0)<($77|0);
      $or$cond6 = $76 | $78;
      $invfl$0$ninvis$2 = $or$cond6 ? $invfl$02253 : $ninvis$2;
      $invflset$0$ = $or$cond6 ? $invflset$02352 : 1;
      $ignoring$1 = $ignoring$02055;$igstart$1 = $igstart$01758;$invfl$1 = $invfl$0$ninvis$2;$invflset$1 = $invflset$0$;$last$1 = $last$01956;$ninvis$3 = $ninvis$2;$p$3 = $p$2;$physchars$4 = $physchars$3;$r$5 = $r$4;$rl$4 = $rl$3;
     }
    } while(0);
    $79 = ((($p$3)) + 1|0);
    $80 = HEAP8[$79>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     $invfl$0$lcssa = $invfl$1;$last$0$lcssa = $last$1;$ninvis$0$lcssa = $ninvis$3;$physchars$1$lcssa = $physchars$4;$r$2$lcssa = $r$5;$rl$1$lcssa = $rl$4;
     break;
    } else {
     $47 = $80;$ignoring$02055 = $ignoring$1;$igstart$01758 = $igstart$1;$invfl$02253 = $invfl$1;$invflset$02352 = $invflset$1;$last$01956 = $last$1;$ninvis$02154 = $ninvis$3;$p$01659 = $79;$physchars$12550 = $physchars$4;$r$22451 = $r$5;$rl$11857 = $rl$4;
    }
   }
  }
 }
 $82 = HEAP32[35112>>2]|0;
 $83 = ($rl$1$lcssa|0)<($82|0);
 $ninvis$0$invfl$0 = $83 ? $ninvis$0$lcssa : $invfl$0$lcssa;
 HEAP8[$r$2$lcssa>>0] = 0;
 $84 = ($lp|0)==(0|0);
 if (!($84)) {
  HEAP32[$lp>>2] = $rl$1$lcssa;
 }
 $85 = ($lip|0)==(0|0);
 if (!($85)) {
  HEAP32[$lip>>2] = $last$0$lcssa;
 }
 $86 = ($niflp|0)==(0|0);
 if (!($86)) {
  HEAP32[$niflp>>2] = $ninvis$0$invfl$0;
 }
 $87 = ($vlp|0)==(0|0);
 if ($87) {
  $$0 = $29;
  return ($$0|0);
 }
 HEAP32[$vlp>>2] = $physchars$1$lcssa;
 $$0 = $29;
 return ($$0|0);
}
function __rl_signal_handler($sig) {
 $sig = $sig|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[32656>>2] = 0;
 $0 = ($sig|0)==(28);
 if (!($0)) {
  __rl_handle_signal($sig);
  return;
 }
 _rl_resize_terminal();
 $1 = HEAP32[34496>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  return;
 }
 (FUNCTION_TABLE_i[$1 & 511]()|0);
 return;
}
function _rl_set_signals() {
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $9 = 0, $act$i = 0, $act$i$i = 0, $act$i$i12 = 0, $act$i$i17 = 0, $act$i$i22 = 0, $act$i$i27 = 0, $act$i$i32 = 0, $act$i$i37 = 0, $act$i$i7 = 0, $dummy = 0, $dummy$i = 0, $dummy$i13 = 0, $dummy$i18 = 0, $dummy$i23 = 0, $dummy$i28 = 0, $dummy$i33 = 0, $dummy$i38 = 0;
 var $dummy$i8 = 0, $magicptr = 0, $old_handler$i = 0, $old_handler$i$i = 0, $old_handler$i$i11 = 0, $old_handler$i$i16 = 0, $old_handler$i$i21 = 0, $old_handler$i$i26 = 0, $old_handler$i$i31 = 0, $old_handler$i$i36 = 0, $old_handler$i$i6 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 3792|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $old_handler$i$i36 = sp + 3640|0;
 $act$i$i37 = sp + 3500|0;
 $dummy$i38 = sp + 3360|0;
 $old_handler$i$i31 = sp + 3220|0;
 $act$i$i32 = sp + 3080|0;
 $dummy$i33 = sp + 2940|0;
 $old_handler$i$i26 = sp + 2800|0;
 $act$i$i27 = sp + 2660|0;
 $dummy$i28 = sp + 2520|0;
 $old_handler$i$i21 = sp + 2380|0;
 $act$i$i22 = sp + 2240|0;
 $dummy$i23 = sp + 2100|0;
 $old_handler$i = sp + 1960|0;
 $act$i = sp + 1820|0;
 $old_handler$i$i16 = sp + 1680|0;
 $act$i$i17 = sp + 1540|0;
 $dummy$i18 = sp + 1400|0;
 $old_handler$i$i11 = sp + 1260|0;
 $act$i$i12 = sp + 1120|0;
 $dummy$i13 = sp + 980|0;
 $old_handler$i$i6 = sp + 840|0;
 $act$i$i7 = sp + 700|0;
 $dummy$i8 = sp + 560|0;
 $old_handler$i$i = sp + 420|0;
 $act$i$i = sp + 280|0;
 $dummy$i = sp + 140|0;
 $dummy = sp;
 $0 = HEAP32[32632>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[32712>>2]|0;
 $3 = ($2|0)==(0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  (_sigemptyset((32720|0))|0);
  (_sigaddset((32720|0),2)|0);
  (_sigaddset((32720|0),15)|0);
  (_sigaddset((32720|0),1)|0);
  (_sigaddset((32720|0),3)|0);
  (_sigaddset((32720|0),14)|0);
  (_sigaddset((32720|0),20)|0);
  (_sigaddset((32720|0),21)|0);
  (_sigaddset((32720|0),22)|0);
  HEAP32[32712>>2] = 1;
  $$pre = HEAP32[32632>>2]|0;
  $5 = $$pre;
 } else {
  $5 = $0;
 }
 $4 = ($5|0)!=(0);
 $6 = HEAP32[32848>>2]|0;
 $7 = ($6|0)==(0);
 $or$cond3 = $4 & $7;
 if ($or$cond3) {
  (_sigemptyset((32856|0))|0);
  (_sigprocmask(0,(32720|0),(32856|0))|0);
  $8 = ((($dummy$i)) + 4|0);
  (_sigemptyset(($8|0))|0);
  $9 = ((($dummy$i)) + 132|0);
  HEAP32[$9>>2] = 0;
  HEAP32[$act$i$i>>2] = 369;
  $10 = ((($act$i$i)) + 132|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($act$i$i)) + 4|0);
  (_sigemptyset(($11|0))|0);
  (_sigemptyset(((32988)|0))|0);
  (_sigaction(2,($act$i$i|0),($old_handler$i$i|0))|0);
  $12 = HEAP32[$old_handler$i$i>>2]|0;
  $13 = ($12|0)==(369|0);
  if (!($13)) {
   _memcpy((32984|0),($old_handler$i$i|0),140)|0;
  }
  $14 = HEAP32[32984>>2]|0;
  $15 = ($14|0)==((1)|0);
  if ($15) {
   (_sigaction(2,(32984|0),($dummy$i|0))|0);
  }
  $16 = ((($dummy$i8)) + 4|0);
  (_sigemptyset(($16|0))|0);
  $17 = ((($dummy$i8)) + 132|0);
  HEAP32[$17>>2] = 0;
  HEAP32[$act$i$i7>>2] = 369;
  $18 = ((($act$i$i7)) + 132|0);
  HEAP32[$18>>2] = 0;
  $19 = ((($act$i$i7)) + 4|0);
  (_sigemptyset(($19|0))|0);
  (_sigemptyset(((33132)|0))|0);
  (_sigaction(15,($act$i$i7|0),($old_handler$i$i6|0))|0);
  $20 = HEAP32[$old_handler$i$i6>>2]|0;
  $21 = ($20|0)==(369|0);
  if (!($21)) {
   _memcpy((33128|0),($old_handler$i$i6|0),140)|0;
  }
  $22 = HEAP32[33128>>2]|0;
  $23 = ($22|0)==((1)|0);
  if ($23) {
   (_sigaction(15,(33128|0),($dummy$i8|0))|0);
  }
  $24 = ((($dummy$i13)) + 4|0);
  (_sigemptyset(($24|0))|0);
  $25 = ((($dummy$i13)) + 132|0);
  HEAP32[$25>>2] = 0;
  HEAP32[$act$i$i12>>2] = 369;
  $26 = ((($act$i$i12)) + 132|0);
  HEAP32[$26>>2] = 0;
  $27 = ((($act$i$i12)) + 4|0);
  (_sigemptyset(($27|0))|0);
  (_sigemptyset(((33276)|0))|0);
  (_sigaction(1,($act$i$i12|0),($old_handler$i$i11|0))|0);
  $28 = HEAP32[$old_handler$i$i11>>2]|0;
  $29 = ($28|0)==(369|0);
  if (!($29)) {
   _memcpy((33272|0),($old_handler$i$i11|0),140)|0;
  }
  $30 = HEAP32[33272>>2]|0;
  $31 = ($30|0)==((1)|0);
  if ($31) {
   (_sigaction(1,(33272|0),($dummy$i13|0))|0);
  }
  $32 = ((($dummy$i18)) + 4|0);
  (_sigemptyset(($32|0))|0);
  $33 = ((($dummy$i18)) + 132|0);
  HEAP32[$33>>2] = 0;
  HEAP32[$act$i$i17>>2] = 369;
  $34 = ((($act$i$i17)) + 132|0);
  HEAP32[$34>>2] = 0;
  $35 = ((($act$i$i17)) + 4|0);
  (_sigemptyset(($35|0))|0);
  (_sigemptyset(((33420)|0))|0);
  (_sigaction(3,($act$i$i17|0),($old_handler$i$i16|0))|0);
  $36 = HEAP32[$old_handler$i$i16>>2]|0;
  $37 = ($36|0)==(369|0);
  if (!($37)) {
   _memcpy((33416|0),($old_handler$i$i16|0),140)|0;
  }
  $38 = HEAP32[33416>>2]|0;
  $39 = ($38|0)==((1)|0);
  if ($39) {
   (_sigaction(3,(33416|0),($dummy$i18|0))|0);
  }
  HEAP32[$act$i>>2] = 369;
  $40 = ((($act$i)) + 132|0);
  HEAP32[$40>>2] = 0;
  $41 = ((($act$i)) + 4|0);
  (_sigemptyset(($41|0))|0);
  (_sigemptyset(((33564)|0))|0);
  (_sigaction(14,($act$i|0),($old_handler$i|0))|0);
  $42 = HEAP32[$old_handler$i>>2]|0;
  $43 = ($42|0)==(369|0);
  if (!($43)) {
   _memcpy((33560|0),($old_handler$i|0),140)|0;
  }
  $44 = HEAP32[33560>>2]|0;
  $magicptr = $44;
  if ((($magicptr|0) == 1)) {
   (_sigaction(14,(33560|0),($dummy|0))|0);
   label = 24;
  } else if (!((($magicptr|0) == 0))) {
   label = 24;
  }
  if ((label|0) == 24) {
   $45 = HEAP32[(33692)>>2]|0;
   $46 = $45 & 268435456;
   $47 = ($46|0)==(0);
   if (!($47)) {
    (_sigaction(14,(33560|0),($dummy|0))|0);
   }
  }
  $48 = ((($dummy$i23)) + 4|0);
  (_sigemptyset(($48|0))|0);
  $49 = ((($dummy$i23)) + 132|0);
  HEAP32[$49>>2] = 0;
  HEAP32[$act$i$i22>>2] = 369;
  $50 = ((($act$i$i22)) + 132|0);
  HEAP32[$50>>2] = 0;
  $51 = ((($act$i$i22)) + 4|0);
  (_sigemptyset(($51|0))|0);
  (_sigemptyset(((33708)|0))|0);
  (_sigaction(20,($act$i$i22|0),($old_handler$i$i21|0))|0);
  $52 = HEAP32[$old_handler$i$i21>>2]|0;
  $53 = ($52|0)==(369|0);
  if (!($53)) {
   _memcpy((33704|0),($old_handler$i$i21|0),140)|0;
  }
  $54 = HEAP32[33704>>2]|0;
  $55 = ($54|0)==((1)|0);
  if ($55) {
   (_sigaction(20,(33704|0),($dummy$i23|0))|0);
  }
  $56 = ((($dummy$i28)) + 4|0);
  (_sigemptyset(($56|0))|0);
  $57 = ((($dummy$i28)) + 132|0);
  HEAP32[$57>>2] = 0;
  HEAP32[$act$i$i27>>2] = 369;
  $58 = ((($act$i$i27)) + 132|0);
  HEAP32[$58>>2] = 0;
  $59 = ((($act$i$i27)) + 4|0);
  (_sigemptyset(($59|0))|0);
  (_sigemptyset(((33852)|0))|0);
  (_sigaction(22,($act$i$i27|0),($old_handler$i$i26|0))|0);
  $60 = HEAP32[$old_handler$i$i26>>2]|0;
  $61 = ($60|0)==(369|0);
  if (!($61)) {
   _memcpy((33848|0),($old_handler$i$i26|0),140)|0;
  }
  $62 = HEAP32[33848>>2]|0;
  $63 = ($62|0)==((1)|0);
  if ($63) {
   (_sigaction(22,(33848|0),($dummy$i28|0))|0);
  }
  $64 = ((($dummy$i33)) + 4|0);
  (_sigemptyset(($64|0))|0);
  $65 = ((($dummy$i33)) + 132|0);
  HEAP32[$65>>2] = 0;
  HEAP32[$act$i$i32>>2] = 369;
  $66 = ((($act$i$i32)) + 132|0);
  HEAP32[$66>>2] = 0;
  $67 = ((($act$i$i32)) + 4|0);
  (_sigemptyset(($67|0))|0);
  (_sigemptyset(((33996)|0))|0);
  (_sigaction(21,($act$i$i32|0),($old_handler$i$i31|0))|0);
  $68 = HEAP32[$old_handler$i$i31>>2]|0;
  $69 = ($68|0)==(369|0);
  if (!($69)) {
   _memcpy((33992|0),($old_handler$i$i31|0),140)|0;
  }
  $70 = HEAP32[33992>>2]|0;
  $71 = ($70|0)==((1)|0);
  if ($71) {
   (_sigaction(21,(33992|0),($dummy$i33|0))|0);
  }
  HEAP32[32848>>2] = 1;
  (_sigprocmask(2,(32856|0),(0|0))|0);
 }
 $72 = HEAP32[32640>>2]|0;
 $73 = ($72|0)!=(0);
 $74 = HEAP32[34136>>2]|0;
 $75 = ($74|0)==(0);
 $or$cond5 = $73 & $75;
 if (!($or$cond5)) {
  STACKTOP = sp;return 0;
 }
 $76 = ((($dummy$i38)) + 4|0);
 (_sigemptyset(($76|0))|0);
 $77 = ((($dummy$i38)) + 132|0);
 HEAP32[$77>>2] = 0;
 HEAP32[$act$i$i37>>2] = 370;
 $78 = ((($act$i$i37)) + 132|0);
 HEAP32[$78>>2] = 268435456;
 $79 = ((($act$i$i37)) + 4|0);
 (_sigemptyset(($79|0))|0);
 (_sigemptyset(((34148)|0))|0);
 (_sigaction(28,($act$i$i37|0),($old_handler$i$i36|0))|0);
 _memcpy((34144|0),($old_handler$i$i36|0),140)|0;
 $80 = HEAP32[34144>>2]|0;
 $81 = ($80|0)==((1)|0);
 if ($81) {
  (_sigaction(28,(34144|0),($dummy$i38|0))|0);
 }
 HEAP32[34136>>2] = 1;
 STACKTOP = sp;return 0;
}
function _rl_clear_signals() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $dummy = 0, $dummy$i = 0, $dummy$i10 = 0, $dummy$i12 = 0, $dummy$i14 = 0, $dummy$i16 = 0, $dummy$i4 = 0, $dummy$i6 = 0, $dummy$i8 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1264|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $dummy$i16 = sp + 1120|0;
 $dummy$i14 = sp + 980|0;
 $dummy$i12 = sp + 840|0;
 $dummy$i10 = sp + 700|0;
 $dummy$i8 = sp + 560|0;
 $dummy$i6 = sp + 420|0;
 $dummy$i4 = sp + 280|0;
 $dummy$i = sp + 140|0;
 $dummy = sp;
 $0 = HEAP32[32632>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[32848>>2]|0;
 $3 = ($2|0)==(1);
 $or$cond = $1 & $3;
 if ($or$cond) {
  $4 = ((($dummy)) + 4|0);
  (_sigemptyset(($4|0))|0);
  $5 = ((($dummy$i)) + 4|0);
  (_sigemptyset(($5|0))|0);
  $6 = ((($dummy$i)) + 132|0);
  HEAP32[$6>>2] = 0;
  $7 = HEAP32[32984>>2]|0;
  $8 = ($7|0)==((1)|0);
  if (!($8)) {
   (_sigaction(2,(32984|0),($dummy$i|0))|0);
  }
  $9 = ((($dummy$i4)) + 4|0);
  (_sigemptyset(($9|0))|0);
  $10 = ((($dummy$i4)) + 132|0);
  HEAP32[$10>>2] = 0;
  $11 = HEAP32[33128>>2]|0;
  $12 = ($11|0)==((1)|0);
  if (!($12)) {
   (_sigaction(15,(33128|0),($dummy$i4|0))|0);
  }
  $13 = ((($dummy$i6)) + 4|0);
  (_sigemptyset(($13|0))|0);
  $14 = ((($dummy$i6)) + 132|0);
  HEAP32[$14>>2] = 0;
  $15 = HEAP32[33272>>2]|0;
  $16 = ($15|0)==((1)|0);
  if (!($16)) {
   (_sigaction(1,(33272|0),($dummy$i6|0))|0);
  }
  $17 = ((($dummy$i8)) + 4|0);
  (_sigemptyset(($17|0))|0);
  $18 = ((($dummy$i8)) + 132|0);
  HEAP32[$18>>2] = 0;
  $19 = HEAP32[33416>>2]|0;
  $20 = ($19|0)==((1)|0);
  if (!($20)) {
   (_sigaction(3,(33416|0),($dummy$i8|0))|0);
  }
  $21 = ((($dummy$i10)) + 4|0);
  (_sigemptyset(($21|0))|0);
  $22 = ((($dummy$i10)) + 132|0);
  HEAP32[$22>>2] = 0;
  $23 = HEAP32[33560>>2]|0;
  $24 = ($23|0)==((1)|0);
  if (!($24)) {
   (_sigaction(14,(33560|0),($dummy$i10|0))|0);
  }
  $25 = ((($dummy$i12)) + 4|0);
  (_sigemptyset(($25|0))|0);
  $26 = ((($dummy$i12)) + 132|0);
  HEAP32[$26>>2] = 0;
  $27 = HEAP32[33704>>2]|0;
  $28 = ($27|0)==((1)|0);
  if (!($28)) {
   (_sigaction(20,(33704|0),($dummy$i12|0))|0);
  }
  $29 = ((($dummy$i14)) + 4|0);
  (_sigemptyset(($29|0))|0);
  $30 = ((($dummy$i14)) + 132|0);
  HEAP32[$30>>2] = 0;
  $31 = HEAP32[33848>>2]|0;
  $32 = ($31|0)==((1)|0);
  if (!($32)) {
   (_sigaction(22,(33848|0),($dummy$i14|0))|0);
  }
  $33 = ((($dummy$i16)) + 4|0);
  (_sigemptyset(($33|0))|0);
  $34 = ((($dummy$i16)) + 132|0);
  HEAP32[$34>>2] = 0;
  $35 = HEAP32[33992>>2]|0;
  $36 = ($35|0)==((1)|0);
  if (!($36)) {
   (_sigaction(21,(33992|0),($dummy$i16|0))|0);
  }
  HEAP32[32848>>2] = 0;
 }
 $37 = HEAP32[32640>>2]|0;
 $38 = ($37|0)!=(0);
 $39 = HEAP32[34136>>2]|0;
 $40 = ($39|0)==(1);
 $or$cond3 = $38 & $40;
 if (!($or$cond3)) {
  STACKTOP = sp;return 0;
 }
 $41 = ((($dummy)) + 4|0);
 (_sigemptyset(($41|0))|0);
 (_sigaction(28,(34144|0),($dummy|0))|0);
 HEAP32[34136>>2] = 0;
 STACKTOP = sp;return 0;
}
function __rl_block_sigint() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34288>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  return;
 }
 HEAP32[34288>>2] = 1;
 return;
}
function __rl_release_sigint() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34288>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return;
 }
 HEAP32[34288>>2] = 0;
 $2 = HEAP32[32656>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = HEAP32[32656>>2]|0;
 HEAP32[32656>>2] = 0;
 $5 = ($4|0)==(28);
 if (!($5)) {
  __rl_handle_signal($4);
  return;
 }
 _rl_resize_terminal();
 $6 = HEAP32[34496>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  return;
 }
 (FUNCTION_TABLE_i[$6 & 511]()|0);
 return;
}
function __rl_handle_signal($sig) {
 $sig = $sig|0;
 var $$old2$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0$i = 0, $c$0$in$i = 0, $cslen$0$i = 0, $cstr$i = 0;
 var $or$cond$i = 0, $set = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $cstr$i = sp + 128|0;
 $set = sp;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 32768;
 HEAP32[13488>>2] = $1;
 $2 = HEAP32[32696>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = HEAP32[32704>>2]|0;
  FUNCTION_TABLE_vii[$2 & 511]($sig,$4);
  HEAP32[32696>>2] = 0;
  HEAP32[32704>>2] = 0;
 }
 switch ($sig|0) {
 case 2:  {
  label = 4;
  break;
 }
 case 3: case 14: case 21: case 22: case 20: case 1: case 15:  {
  break;
 }
 default: {
  $33 = HEAP32[13488>>2]|0;
  $34 = $33 & -32769;
  HEAP32[13488>>2] = $34;
  STACKTOP = sp;return;
 }
 }
 if ((label|0) == 4) {
  __rl_reset_completion_state();
  _rl_free_undo_list();
  $5 = (_current_history()|0);
  $6 = ($5|0)==(0|0);
  if (!($6)) {
   $7 = ((($5)) + 8|0);
   HEAP32[$7>>2] = 0;
  }
  __rl_kill_kbd_macro();
  (_rl_clear_message()|0);
  __rl_reset_argument();
 }
 $8 = HEAP32[32664>>2]|0;
 $9 = ($8|0)==(0);
 $10 = HEAP32[13720>>2]|0;
 $11 = ($10|0)==(0);
 $or$cond$i = $9 | $11;
 do {
  if (!($or$cond$i)) {
   if ((($sig|0) == 2)) {
    $c$0$in$i = 32672;
   } else if ((($sig|0) == 3)) {
    $c$0$in$i = 32680;
   } else if ((($sig|0) == 20)) {
    $c$0$in$i = 32688;
   } else {
    break;
   }
   $c$0$i = HEAP32[$c$0$in$i>>2]|0;
   $12 = ($c$0$i|0)<(32);
   if ($12) {
    $13 = $c$0$i & 128;
    $14 = ($13|0)==(0);
    if ($14) {
     HEAP8[$cstr$i>>0] = 94;
     $15 = $c$0$i | 64;
     $16 = $15 & 255;
     $17 = ($16|0)==($15|0);
     if ($17) {
      $18 = (_islower($15)|0);
      $19 = ($18|0)==(0);
      if ($19) {
       $22 = $15;
       label = 18;
      } else {
       $20 = (_toupper($15)|0);
       $22 = $20;
       label = 18;
      }
     } else {
      $22 = $15;
      label = 18;
     }
    } else {
     label = 19;
    }
   } else {
    $$old2$i = ($c$0$i|0)==(127);
    if ($$old2$i) {
     HEAP8[$cstr$i>>0] = 94;
     $22 = 63;
     label = 18;
    } else {
     label = 19;
    }
   }
   if ((label|0) == 18) {
    $21 = $22&255;
    $23 = ((($cstr$i)) + 1|0);
    HEAP8[$23>>0] = $21;
    $24 = ((($cstr$i)) + 2|0);
    HEAP8[$24>>0] = 0;
    $cslen$0$i = 2;
   }
   else if ((label|0) == 19) {
    $25 = $c$0$i&255;
    HEAP8[$cstr$i>>0] = $25;
    $26 = ((($cstr$i)) + 1|0);
    HEAP8[$26>>0] = 0;
    $cslen$0$i = 1;
   }
   __rl_output_some_chars($cstr$i,$cslen$0$i);
  }
 } while(0);
 __rl_clean_up_for_exit();
 $27 = HEAP32[28600>>2]|0;
 $28 = ($27|0)==(0|0);
 if (!($28)) {
  FUNCTION_TABLE_v[$27 & 511]();
 }
 (_rl_clear_pending_input()|0);
 (_rl_clear_signals()|0);
 (_sigemptyset(($set|0))|0);
 (_sigprocmask(0,(0|0),($set|0))|0);
 (_sigdelset(($set|0),($sig|0))|0);
 $29 = (_getpid()|0);
 (_kill(($29|0),($sig|0))|0);
 (_sigprocmask(2,($set|0),(0|0))|0);
 $30 = HEAP32[28592>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = HEAP32[13736>>2]|0;
  FUNCTION_TABLE_vi[$30 & 511]($32);
 }
 (_rl_set_signals()|0);
 $33 = HEAP32[13488>>2]|0;
 $34 = $33 & -32769;
 HEAP32[13488>>2] = $34;
 STACKTOP = sp;return;
}
function _rl_signal_handler($sig) {
 $sig = $sig|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[32648>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  HEAP32[32656>>2] = $sig;
  return;
 } else {
  HEAP32[32648>>2] = 0;
  __rl_handle_signal($sig);
  return;
 }
}
function _rl_sigwinch_handler($sig) {
 $sig = $sig|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $switch = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 32768;
 HEAP32[13488>>2] = $1;
 HEAP32[32656>>2] = $sig;
 $2 = HEAP32[34144>>2]|0;
 $switch = ($2>>>0)<((2)>>>0);
 if (!($switch)) {
  FUNCTION_TABLE_vi[$2 & 511]($sig);
 }
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 & -32769;
 HEAP32[13488>>2] = $4;
 return;
}
function __rl_walphabetic($wc) {
 $wc = $wc|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $memchr = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_iswalnum($wc)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 1;
  return ($$0|0);
 }
 $2 = HEAP32[34296>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $7 = 0;
 } else {
  $4 = $wc & 127;
  $memchr = (_memchr(34304,$4,9)|0);
  $5 = ($memchr|0)!=(0|0);
  $7 = $5;
 }
 $6 = $7&1;
 $$0 = $6;
 return ($$0|0);
}
function __rl_abort_internal() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_ding()|0);
 (_rl_clear_message()|0);
 __rl_reset_argument();
 (_rl_clear_pending_input()|0);
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & -4097;
 HEAP32[13488>>2] = $1;
 $2 = HEAP32[34432>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  HEAP32[13496>>2] = 0;
  _longjmp((13792|0),1);
  // unreachable;
 }
 while(1) {
  __rl_pop_executing_macro();
  $4 = HEAP32[34432>>2]|0;
  $5 = ($4|0)==(0|0);
  if ($5) {
   break;
  }
 }
 HEAP32[13496>>2] = 0;
 _longjmp((13792|0),1);
 // unreachable;
 return (0)|0;
}
function _rl_abort($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__rl_abort_internal()|0);
 // unreachable;
 return (0)|0;
}
function __rl_null_function($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function _rl_tty_status($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_ding()|0);
 return 0;
}
function _rl_copy_text($from,$to) {
 $from = $from|0;
 $to = $to|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $from$to = 0, $to$from = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($from|0)>($to|0);
 $from$to = $0 ? $from : $to;
 $to$from = $0 ? $to : $from;
 $1 = (($from$to) - ($to$from))|0;
 $2 = (($1) + 1)|0;
 $3 = (_xmalloc($2)|0);
 $4 = HEAP32[13632>>2]|0;
 $5 = (($4) + ($to$from)|0);
 (_strncpy(($3|0),($5|0),($1|0))|0);
 $6 = (($3) + ($1)|0);
 HEAP8[$6>>0] = 0;
 return ($3|0);
}
function _rl_extend_line_buffer($len) {
 $len = $len|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13640>>2]|0;
 $1 = ($0|0)>($len|0);
 if ($1) {
  __rl_set_the_line();
  return;
 }
 $$pre = HEAP32[13632>>2]|0;
 $3 = $0;$4 = $$pre;
 while(1) {
  $2 = (($3) + 256)|0;
  HEAP32[13640>>2] = $2;
  $5 = (_xrealloc($4,$2)|0);
  HEAP32[13632>>2] = $5;
  $6 = HEAP32[13640>>2]|0;
  $7 = ($6|0)>($len|0);
  if ($7) {
   break;
  } else {
   $3 = $6;$4 = $5;
  }
 }
 __rl_set_the_line();
 return;
}
function _rl_tilde_expand($ignore,$key) {
 $ignore = $ignore|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $end$0 = 0, $end$0$lcssa = 0, $or$cond = 0, $start$0$lcssa = 0, $start$013 = 0, $start$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = (($0) + -1)|0;
 $2 = HEAP32[13768>>2]|0;
 $3 = ($0|0)==($2|0);
 $4 = HEAP32[13632>>2]|0;
 if ($3) {
  $5 = (($4) + ($0)|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(126);
  if ($7) {
   $8 = (_tilde_expand(34320)|0);
   (__rl_replace_text($8,$1,$0)|0);
   _xfree($8);
   return 0;
  }
 }
 $9 = (($4) + ($1)|0);
 $10 = HEAP8[$9>>0]|0;
 L6: do {
  if ((($10<<24>>24) == 32)) {
   $start$0$lcssa = $1;
   label = 7;
  } else if ((($10<<24>>24) == 126)) {
   $start$1 = $1;
  } else {
   $12 = $10;$start$013 = $1;
   while(1) {
    $11 = ($12<<24>>24)!=(9);
    $13 = ($start$013|0)>(-1);
    $or$cond = $13 & $11;
    if (!($or$cond)) {
     $start$0$lcssa = $start$013;
     label = 7;
     break L6;
    }
    $14 = (($start$013) + -1)|0;
    $15 = (($4) + ($14)|0);
    $16 = HEAP8[$15>>0]|0;
    $17 = ($16<<24>>24)==(32);
    if ($17) {
     $start$0$lcssa = $14;
     label = 7;
     break;
    } else {
     $12 = $16;$start$013 = $14;
    }
   }
  }
 } while(0);
 if ((label|0) == 7) {
  $18 = (($start$0$lcssa) + 1)|0;
  $start$1 = $18;
 }
 $end$0 = $start$1;
 while(1) {
  $19 = (($end$0) + 1)|0;
  $20 = ($19|0)<($2|0);
  if (!($20)) {
   $end$0$lcssa = $end$0;
   break;
  }
  $21 = (($4) + ($19)|0);
  $22 = HEAP8[$21>>0]|0;
  if ((($22<<24>>24) == 9) | (($22<<24>>24) == 32)) {
   $end$0$lcssa = $end$0;
   break;
  } else {
   $end$0 = $19;
  }
 }
 $23 = (($4) + ($start$1)|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(126);
 if (!($25)) {
  return 0;
 }
 $26 = (($end$0$lcssa) - ($start$1))|0;
 $27 = (($26) + 1)|0;
 $28 = (($26) + 2)|0;
 $29 = (_xmalloc($28)|0);
 $30 = HEAP32[13632>>2]|0;
 $31 = (($30) + ($start$1)|0);
 (_strncpy(($29|0),($31|0),($27|0))|0);
 $32 = (($29) + ($27)|0);
 HEAP8[$32>>0] = 0;
 $33 = (_tilde_expand($29)|0);
 _xfree($29);
 (__rl_replace_text($33,$start$1,$end$0$lcssa)|0);
 _xfree($33);
 return 0;
}
function __rl_ttymsg($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $args = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $args = sp;
 HEAP32[$args>>2] = $varargs;
 $0 = HEAP32[_stderr>>2]|0;
 (_fwrite((34328|0),10,1,($0|0))|0);
 (_vfprintf(($0|0),($format|0),($args|0))|0);
 (_fputc(10,($0|0))|0);
 (_fflush(($0|0))|0);
 (_rl_forced_update_display()|0);
 STACKTOP = sp;return;
}
function __rl_errmsg($format,$varargs) {
 $format = $format|0;
 $varargs = $varargs|0;
 var $0 = 0, $args = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $args = sp;
 HEAP32[$args>>2] = $varargs;
 $0 = HEAP32[_stderr>>2]|0;
 (_fwrite((34328|0),10,1,($0|0))|0);
 (_vfprintf(($0|0),($format|0),($args|0))|0);
 (_fputc(10,($0|0))|0);
 (_fflush(($0|0))|0);
 STACKTOP = sp;return;
}
function __rl_strindex($s1,$s2) {
 $s1 = $s1|0;
 $s2 = $s2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s2|0))|0);
 $1 = (_strlen(($s1|0))|0);
 $2 = ($1|0)<($0|0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $i$01 = 0;
 }
 while(1) {
  $6 = (($s1) + ($i$01)|0);
  $7 = (_strncasecmp($6,$s2,$0)|0);
  $8 = ($7|0)==(0);
  $4 = (($i$01) + 1)|0;
  if ($8) {
   $$0 = $6;
   label = 4;
   break;
  }
  $3 = (($1) - ($4))|0;
  $5 = ($3|0)<($0|0);
  if ($5) {
   $$0 = 0;
   label = 4;
   break;
  } else {
   $i$01 = $4;
  }
 }
 if ((label|0) == 4) {
  return ($$0|0);
 }
 return (0)|0;
}
function __rl_qsort_string_compare($s1,$s2) {
 $s1 = $s1|0;
 $s2 = $s2|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$s1>>2]|0;
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = HEAP32[$s2>>2]|0;
 $4 = HEAP8[$3>>0]|0;
 $5 = $4 << 24 >> 24;
 $6 = (($2) - ($5))|0;
 $7 = ($1<<24>>24)==($4<<24>>24);
 if (!($7)) {
  $result$0 = $6;
  return ($result$0|0);
 }
 $8 = (_strcmp($0,$3)|0);
 $result$0 = $8;
 return ($result$0|0);
}
function _rl_kill_text($from,$to) {
 $from = $from|0;
 $to = $to|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $storemerge = 0, $storemerge$in = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($from|0)==($to|0);
 if (!($0)) {
  $1 = (_rl_copy_text($from,$to)|0);
  (_rl_delete_text($from,$to)|0);
  $2 = ($from|0)<($to|0);
  $3 = $2&1;
  __rl_copy_to_kill_ring($1,$3);
 }
 $storemerge$in = HEAP32[13456>>2]|0;
 $storemerge = (($storemerge$in) + 1)|0;
 HEAP32[13456>>2] = $storemerge;
 return 0;
}
function _rl_kill_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_backward_kill_word($1,$key)|0);
  return 0;
 }
 $2 = HEAP32[13784>>2]|0;
 (_rl_forward_word($count,$key)|0);
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (_rl_copy_text($2,$3)|0);
  (_rl_delete_text($2,$3)|0);
  $6 = ($2|0)<($3|0);
  $7 = $6&1;
  __rl_copy_to_kill_ring($5,$7);
  $storemerge$in$i = HEAP32[13456>>2]|0;
  $storemerge$i = (($storemerge$in$i) + 1)|0;
  HEAP32[13456>>2] = $storemerge$i;
 }
 HEAP32[13784>>2] = $2;
 $8 = HEAP32[13440>>2]|0;
 $9 = ($8|0)==(1);
 if (!($9)) {
  return 0;
 }
 HEAP32[13952>>2] = $2;
 return 0;
}
function _rl_backward_kill_word($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_kill_word($1,$ignore)|0);
  return 0;
 }
 $2 = HEAP32[13784>>2]|0;
 (_rl_backward_word($count,$ignore)|0);
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==($2|0);
 if (!($4)) {
  $5 = (_rl_copy_text($2,$3)|0);
  (_rl_delete_text($2,$3)|0);
  $6 = ($2|0)<($3|0);
  $7 = $6&1;
  __rl_copy_to_kill_ring($5,$7);
  $storemerge$in$i = HEAP32[13456>>2]|0;
  $storemerge$i = (($storemerge$in$i) + 1)|0;
  HEAP32[13456>>2] = $storemerge$i;
 }
 $8 = HEAP32[13440>>2]|0;
 $9 = ($8|0)==(1);
 if (!($9)) {
  return 0;
 }
 $10 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $10;
 return 0;
}
function _rl_kill_line($direction,$ignore) {
 $direction = $direction|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$i$i = 0;
 var $storemerge$in$i = 0, $storemerge$in$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($direction|0)<(0);
 $1 = HEAP32[13784>>2]|0;
 if (!($0)) {
  (_rl_end_of_line(1,$ignore)|0);
  $11 = HEAP32[13784>>2]|0;
  $12 = ($1|0)==($11|0);
  if (!($12)) {
   $13 = (_rl_copy_text($1,$11)|0);
   (_rl_delete_text($1,$11)|0);
   $14 = ($1|0)<($11|0);
   $15 = $14&1;
   __rl_copy_to_kill_ring($13,$15);
   $storemerge$in$i = HEAP32[13456>>2]|0;
   $storemerge$i = (($storemerge$in$i) + 1)|0;
   HEAP32[13456>>2] = $storemerge$i;
  }
  HEAP32[13784>>2] = $1;
  $16 = HEAP32[13440>>2]|0;
  $17 = ($16|0)==(1);
  if (!($17)) {
   return 0;
  }
  HEAP32[13952>>2] = $1;
  return 0;
 }
 $2 = ($1|0)==(0);
 if ($2) {
  (_rl_ding()|0);
  return 0;
 }
 (_rl_beg_of_line(1,$ignore)|0);
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==($1|0);
 if (!($4)) {
  $5 = (_rl_copy_text($1,$3)|0);
  (_rl_delete_text($1,$3)|0);
  $6 = ($1|0)<($3|0);
  $7 = $6&1;
  __rl_copy_to_kill_ring($5,$7);
  $storemerge$in$i$i = HEAP32[13456>>2]|0;
  $storemerge$i$i = (($storemerge$in$i$i) + 1)|0;
  HEAP32[13456>>2] = $storemerge$i$i;
 }
 $8 = HEAP32[13440>>2]|0;
 $9 = ($8|0)==(1);
 if (!($9)) {
  return 0;
 }
 $10 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $10;
 return 0;
}
function _rl_backward_kill_line($direction,$ignore) {
 $direction = $direction|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$i$i = 0;
 var $storemerge$in$i = 0, $storemerge$in$i$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($direction|0)<(0);
 $1 = HEAP32[13784>>2]|0;
 if ($0) {
  (_rl_end_of_line(1,$ignore)|0);
  $2 = HEAP32[13784>>2]|0;
  $3 = ($1|0)==($2|0);
  if (!($3)) {
   $4 = (_rl_copy_text($1,$2)|0);
   (_rl_delete_text($1,$2)|0);
   $5 = ($1|0)<($2|0);
   $6 = $5&1;
   __rl_copy_to_kill_ring($4,$6);
   $storemerge$in$i$i = HEAP32[13456>>2]|0;
   $storemerge$i$i = (($storemerge$in$i$i) + 1)|0;
   HEAP32[13456>>2] = $storemerge$i$i;
  }
  HEAP32[13784>>2] = $1;
  $7 = HEAP32[13440>>2]|0;
  $8 = ($7|0)==(1);
  if (!($8)) {
   return 0;
  }
  HEAP32[13952>>2] = $1;
  return 0;
 }
 $9 = ($1|0)==(0);
 if ($9) {
  (_rl_ding()|0);
  return 0;
 }
 (_rl_beg_of_line(1,$ignore)|0);
 $10 = HEAP32[13784>>2]|0;
 $11 = ($10|0)==($1|0);
 if (!($11)) {
  $12 = (_rl_copy_text($1,$10)|0);
  (_rl_delete_text($1,$10)|0);
  $13 = ($1|0)<($10|0);
  $14 = $13&1;
  __rl_copy_to_kill_ring($12,$14);
  $storemerge$in$i = HEAP32[13456>>2]|0;
  $storemerge$i = (($storemerge$in$i) + 1)|0;
  HEAP32[13456>>2] = $storemerge$i;
 }
 $15 = HEAP32[13440>>2]|0;
 $16 = ($15|0)==(1);
 if (!($16)) {
  return 0;
 }
 $17 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $17;
 return 0;
}
function _rl_kill_full_line($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_begin_undo_group()|0);
 HEAP32[13784>>2] = 0;
 $0 = HEAP32[13768>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (_rl_copy_text(0,$0)|0);
  (_rl_delete_text(0,$0)|0);
  $3 = ($0|0)>(0);
  $4 = $3&1;
  __rl_copy_to_kill_ring($2,$4);
 }
 $storemerge$in$i = HEAP32[13456>>2]|0;
 $storemerge$i = (($storemerge$in$i) + 1)|0;
 HEAP32[13456>>2] = $storemerge$i;
 HEAP32[13952>>2] = 0;
 (_rl_end_undo_group()|0);
 return 0;
}
function _rl_unix_word_rubout($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$count = 0, $$in = 0, $$lcssa = 0, $$lcssa23 = 0, $$pre = 0, $$pre8 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_ding()|0);
  return 0;
 }
 $2 = ($count|0)<(1);
 $$count = $2 ? 1 : $count;
 $3 = ($$count|0)==(0);
 if ($3) {
  $$lcssa = $0;
 } else {
  $$in = $$count;$7 = $0;
  while(1) {
   $5 = (($$in) + -1)|0;
   $6 = ($7|0)==(0);
   L8: do {
    if ($6) {
     $25 = 0;
    } else {
     $$pre = HEAP32[13632>>2]|0;
     $9 = $7;
     while(1) {
      $8 = (($9) + -1)|0;
      $10 = (($$pre) + ($8)|0);
      $11 = HEAP8[$10>>0]|0;
      if (!((($11<<24>>24) == 9) | (($11<<24>>24) == 32))) {
       $$lcssa23 = $9;
       break;
      }
      HEAP32[13784>>2] = $8;
      $12 = ($8|0)==(0);
      if ($12) {
       $25 = 0;
       break L8;
      } else {
       $9 = $8;
      }
     }
     $$pre8 = HEAP32[13632>>2]|0;
     $14 = $$lcssa23;
     while(1) {
      $13 = (($14) + -1)|0;
      $15 = (($$pre8) + ($13)|0);
      $16 = HEAP8[$15>>0]|0;
      if ((($16<<24>>24) == 9) | (($16<<24>>24) == 32)) {
       $25 = $14;
       break L8;
      }
      HEAP32[13784>>2] = $13;
      $17 = ($13|0)==(0);
      if ($17) {
       $25 = 0;
       break;
      } else {
       $14 = $13;
      }
     }
    }
   } while(0);
   $4 = ($5|0)==(0);
   if ($4) {
    $$lcssa = $25;
    break;
   } else {
    $$in = $5;$7 = $25;
   }
  }
 }
 $18 = ($0|0)==($$lcssa|0);
 if (!($18)) {
  $19 = (_rl_copy_text($0,$$lcssa)|0);
  (_rl_delete_text($0,$$lcssa)|0);
  $20 = ($0|0)<($$lcssa|0);
  $21 = $20&1;
  __rl_copy_to_kill_ring($19,$21);
 }
 $storemerge$in$i = HEAP32[13456>>2]|0;
 $storemerge$i = (($storemerge$in$i) + 1)|0;
 HEAP32[13456>>2] = $storemerge$i;
 $22 = HEAP32[13440>>2]|0;
 $23 = ($22|0)==(1);
 if (!($23)) {
  return 0;
 }
 $24 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $24;
 return 0;
}
function _rl_unix_filename_rubout($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$count = 0, $$in = 0, $$lcssa9 = 0, $$pr = 0, $$pre = 0, $$sink = 0, $$sink10 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$113 = 0;
 var $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_ding()|0);
  return 0;
 }
 $2 = ($count|0)<(1);
 $$count = $2 ? 1 : $count;
 $3 = ($$count|0)==(0);
 if ($3) {
  $$lcssa9 = $0;
 } else {
  $$pre = HEAP32[13632>>2]|0;
  $$in = $$count;$$pr = $0;
  while(1) {
   $5 = (($$in) + -1)|0;
   $6 = ($$pr|0)==(0);
   L9: do {
    if ($6) {
     $30 = 0;
    } else {
     $7 = (($$pr) + -1)|0;
     $8 = (($$pre) + ($7)|0);
     $$sink10 = HEAP8[$8>>0]|0;
     $9 = $$sink10 << 24 >> 24;
     $11 = $$pr;$31 = $9;
     while(1) {
      if (!((($31|0) == 9) | (($31|0) == 32) | (($31|0) == 47))) {
       $17 = $11;$c$113 = $31;
       break;
      }
      $10 = (($11) + -1)|0;
      HEAP32[13784>>2] = $10;
      $12 = (($11) + -2)|0;
      $13 = (($$pre) + ($12)|0);
      $$sink = HEAP8[$13>>0]|0;
      $14 = $$sink << 24 >> 24;
      $15 = ($10|0)==(0);
      if ($15) {
       $30 = 0;
       break L9;
      } else {
       $11 = $10;$31 = $14;
      }
     }
     while(1) {
      if ((($c$113|0) == 9) | (($c$113|0) == 32) | (($c$113|0) == 47)) {
       $30 = $17;
       break L9;
      }
      $16 = (($17) + -1)|0;
      HEAP32[13784>>2] = $16;
      $18 = (($17) + -2)|0;
      $19 = (($$pre) + ($18)|0);
      $20 = HEAP8[$19>>0]|0;
      $21 = $20 << 24 >> 24;
      $22 = ($16|0)==(0);
      if ($22) {
       $30 = 0;
       break;
      } else {
       $17 = $16;$c$113 = $21;
      }
     }
    }
   } while(0);
   $4 = ($5|0)==(0);
   if ($4) {
    $$lcssa9 = $30;
    break;
   } else {
    $$in = $5;$$pr = $30;
   }
  }
 }
 $23 = ($0|0)==($$lcssa9|0);
 if (!($23)) {
  $24 = (_rl_copy_text($0,$$lcssa9)|0);
  (_rl_delete_text($0,$$lcssa9)|0);
  $25 = ($0|0)<($$lcssa9|0);
  $26 = $25&1;
  __rl_copy_to_kill_ring($24,$26);
 }
 $storemerge$in$i = HEAP32[13456>>2]|0;
 $storemerge$i = (($storemerge$in$i) + 1)|0;
 HEAP32[13456>>2] = $storemerge$i;
 $27 = HEAP32[13440>>2]|0;
 $28 = ($27|0)==(1);
 if (!($28)) {
  return 0;
 }
 $29 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $29;
 return 0;
}
function _rl_unix_line_discard($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$lobit = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $storemerge$i = 0, $storemerge$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_ding()|0);
  return 0;
 }
 $2 = (_rl_copy_text($0,0)|0);
 (_rl_delete_text($0,0)|0);
 $$lobit = $0 >>> 31;
 __rl_copy_to_kill_ring($2,$$lobit);
 $storemerge$in$i = HEAP32[13456>>2]|0;
 $storemerge$i = (($storemerge$in$i) + 1)|0;
 HEAP32[13456>>2] = $storemerge$i;
 HEAP32[13784>>2] = 0;
 $3 = HEAP32[13440>>2]|0;
 $4 = ($3|0)==(1);
 if (!($4)) {
  return 0;
 }
 HEAP32[13952>>2] = 0;
 return 0;
}
function _rl_copy_region_to_kill($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13952>>2]|0;
 $1 = HEAP32[13784>>2]|0;
 $2 = ($0|0)==($1|0);
 if (!($2)) {
  $3 = (_rl_copy_text($1,$0)|0);
  $4 = HEAP32[13784>>2]|0;
  $5 = HEAP32[13952>>2]|0;
  $6 = ($4|0)<($5|0);
  $7 = $6&1;
  __rl_copy_to_kill_ring($3,$7);
 }
 $8 = HEAP32[13456>>2]|0;
 $9 = (($8) + 1)|0;
 HEAP32[13456>>2] = $9;
 return 0;
}
function _rl_kill_region($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13952>>2]|0;
 $2 = ($0|0)<($1|0);
 $3 = $2 ? $0 : $1;
 $4 = ($1|0)==($0|0);
 if (!($4)) {
  $5 = (_rl_copy_text($0,$1)|0);
  $6 = HEAP32[13784>>2]|0;
  $7 = HEAP32[13952>>2]|0;
  (_rl_delete_text($6,$7)|0);
  $8 = HEAP32[13784>>2]|0;
  $9 = HEAP32[13952>>2]|0;
  $10 = ($8|0)<($9|0);
  $11 = $10&1;
  __rl_copy_to_kill_ring($5,$11);
 }
 $12 = HEAP32[13456>>2]|0;
 $13 = (($12) + 1)|0;
 HEAP32[13456>>2] = $13;
 __rl_fix_point(1);
 HEAP32[13784>>2] = $3;
 return 0;
}
function _rl_copy_forward_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_copy_backward_word($1,$key)|0);
  return 0;
 }
 $2 = HEAP32[13952>>2]|0;
 $3 = HEAP32[13784>>2]|0;
 (_rl_forward_word($count,0)|0);
 $4 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $4;
 (_rl_backward_word($count,0)|0);
 $5 = HEAP32[13952>>2]|0;
 $6 = HEAP32[13784>>2]|0;
 $7 = ($5|0)==($6|0);
 if (!($7)) {
  $8 = (_rl_copy_text($6,$5)|0);
  $9 = HEAP32[13784>>2]|0;
  $10 = HEAP32[13952>>2]|0;
  $11 = ($9|0)<($10|0);
  $12 = $11&1;
  __rl_copy_to_kill_ring($8,$12);
 }
 $13 = HEAP32[13456>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[13456>>2] = $14;
 HEAP32[13952>>2] = $2;
 HEAP32[13784>>2] = $3;
 return 0;
}
function _rl_copy_backward_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_copy_forward_word($1,$key)|0);
  return 0;
 }
 $2 = HEAP32[13952>>2]|0;
 $3 = HEAP32[13784>>2]|0;
 (_rl_backward_word($count,0)|0);
 $4 = HEAP32[13784>>2]|0;
 HEAP32[13952>>2] = $4;
 (_rl_forward_word($count,0)|0);
 $5 = HEAP32[13952>>2]|0;
 $6 = HEAP32[13784>>2]|0;
 $7 = ($5|0)==($6|0);
 if (!($7)) {
  $8 = (_rl_copy_text($6,$5)|0);
  $9 = HEAP32[13784>>2]|0;
  $10 = HEAP32[13952>>2]|0;
  $11 = ($9|0)<($10|0);
  $12 = $11&1;
  __rl_copy_to_kill_ring($8,$12);
 }
 $13 = HEAP32[13456>>2]|0;
 $14 = (($13) + 1)|0;
 HEAP32[13456>>2] = $14;
 HEAP32[13952>>2] = $2;
 HEAP32[13784>>2] = $3;
 return 0;
}
function _rl_yank($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34344>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (__rl_abort_internal()|0);
  // unreachable;
 } else {
  $2 = HEAP32[13784>>2]|0;
  (__rl_set_mark_at_pos($2)|0);
  $3 = HEAP32[34352>>2]|0;
  $4 = HEAP32[34344>>2]|0;
  $5 = (($4) + ($3<<2)|0);
  $6 = HEAP32[$5>>2]|0;
  (_rl_insert_text($6)|0);
  return 0;
 }
 return (0)|0;
}
function _rl_yank_pop($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13496>>2]|0;
 $notlhs = ($0|0)==(233|0);
 $notrhs = ($0|0)==(230|0);
 $or$cond$not = $notrhs | $notlhs;
 $1 = HEAP32[34344>>2]|0;
 $2 = ($1|0)!=(0|0);
 $or$cond3 = $or$cond$not & $2;
 if (!($or$cond3)) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 $3 = HEAP32[34352>>2]|0;
 $4 = (($1) + ($3<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = (_strlen(($5|0))|0);
 $7 = HEAP32[13784>>2]|0;
 $8 = (($7) - ($6))|0;
 $9 = ($8|0)>(-1);
 if (!($9)) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 $10 = ($6|0)==(0);
 if (!($10)) {
  $11 = HEAP32[13632>>2]|0;
  $12 = (($11) + ($8)|0);
  $13 = HEAP8[$12>>0]|0;
  $14 = HEAP8[$5>>0]|0;
  $15 = ($13<<24>>24)==($14<<24>>24);
  if (!($15)) {
   (__rl_abort_internal()|0);
   // unreachable;
  }
  $16 = (_strncmp($12,$5,$6)|0);
  $17 = ($16|0)==(0);
  if (!($17)) {
   (__rl_abort_internal()|0);
   // unreachable;
  }
 }
 (_rl_delete_text($8,$7)|0);
 HEAP32[13784>>2] = $8;
 $18 = HEAP32[34352>>2]|0;
 $19 = (($18) + -1)|0;
 HEAP32[34352>>2] = $19;
 $20 = ($18|0)<(1);
 if ($20) {
  $21 = HEAP32[34360>>2]|0;
  $22 = (($21) + -1)|0;
  HEAP32[34352>>2] = $22;
 }
 $23 = HEAP32[34344>>2]|0;
 $24 = ($23|0)==(0|0);
 if ($24) {
  (__rl_abort_internal()|0);
  // unreachable;
 } else {
  (__rl_set_mark_at_pos($8)|0);
  $25 = HEAP32[34352>>2]|0;
  $26 = HEAP32[34344>>2]|0;
  $27 = (($26) + ($25<<2)|0);
  $28 = HEAP32[$27>>2]|0;
  (_rl_insert_text($28)|0);
  return 0;
 }
 return (0)|0;
}
function _rl_yank_nth_arg($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_yank_nth_arg_internal($count,$ignore,0)|0);
 return ($0|0);
}
function _rl_yank_last_arg($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$ = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $retval$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13496>>2]|0;
 $1 = ($0|0)==(231|0);
 if ($1) {
  $3 = HEAP32[34400>>2]|0;
  $4 = ($3|0)==(0);
  if (!($4)) {
   (_rl_do_undo()|0);
  }
  $5 = ($count|0)<(0);
  $6 = HEAP32[34392>>2]|0;
  if ($5) {
   $7 = (0 - ($6))|0;
   HEAP32[34392>>2] = $7;
   $10 = $7;
  } else {
   $10 = $6;
  }
  $8 = HEAP32[34368>>2]|0;
  $9 = (($8) + ($10))|0;
  $11 = ($9|0)<(0);
  $$ = $11 ? 0 : $9;
  HEAP32[34368>>2] = $$;
  $$pr = HEAP32[34376>>2]|0;
  $13 = $$pr;$15 = $$;
 } else {
  HEAP32[34368>>2] = 0;
  $2 = HEAP32[13472>>2]|0;
  HEAP32[34376>>2] = $2;
  HEAP32[34384>>2] = $count;
  HEAP32[34392>>2] = 1;
  $13 = $2;$15 = 0;
 }
 $12 = ($13|0)==(0);
 if ($12) {
  $17 = (_rl_yank_nth_arg_internal(36,$key,$15)|0);
  $retval$0 = $17;
  $18 = ($retval$0|0)==(0);
  $19 = $18&1;
  HEAP32[34400>>2] = $19;
  return ($retval$0|0);
 } else {
  $14 = HEAP32[34384>>2]|0;
  $16 = (_rl_yank_nth_arg_internal($14,$key,$15)|0);
  $retval$0 = $16;
  $18 = ($retval$0|0)==(0);
  $19 = $18&1;
  HEAP32[34400>>2] = $19;
  return ($retval$0|0);
 }
 return (0)|0;
}
function __rl_copy_to_kill_ring($text,$append) {
 $text = $text|0;
 $append = $append|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $slot$0 = 0, $slot$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13456>>2]|0;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $2 = HEAP32[34344>>2]|0;
   $3 = ($2|0)==(0|0);
   if ($3) {
    HEAP32[34360>>2] = 1;
    $4 = (_xmalloc(8)|0);
    HEAP32[34344>>2] = $4;
    HEAP32[$4>>2] = 0;
    $slot$1 = 0;
    break;
   }
   $5 = HEAP32[34360>>2]|0;
   $6 = ($5|0)==(10);
   if ($6) {
    $7 = HEAP32[$2>>2]|0;
    _xfree($7);
    $8 = HEAP32[34344>>2]|0;
    $9 = ((($8)) + 4|0);
    $10 = HEAP32[$9>>2]|0;
    HEAP32[$8>>2] = $10;
    $11 = HEAP32[34344>>2]|0;
    $12 = ((($11)) + 8|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ((($11)) + 4|0);
    HEAP32[$14>>2] = $13;
    $15 = HEAP32[34344>>2]|0;
    $16 = ((($15)) + 12|0);
    $17 = HEAP32[$16>>2]|0;
    $18 = ((($15)) + 8|0);
    HEAP32[$18>>2] = $17;
    $19 = HEAP32[34344>>2]|0;
    $20 = ((($19)) + 16|0);
    $21 = HEAP32[$20>>2]|0;
    $22 = ((($19)) + 12|0);
    HEAP32[$22>>2] = $21;
    $23 = HEAP32[34344>>2]|0;
    $24 = ((($23)) + 20|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ((($23)) + 16|0);
    HEAP32[$26>>2] = $25;
    $27 = HEAP32[34344>>2]|0;
    $28 = ((($27)) + 24|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ((($27)) + 20|0);
    HEAP32[$30>>2] = $29;
    $31 = HEAP32[34344>>2]|0;
    $32 = ((($31)) + 28|0);
    $33 = HEAP32[$32>>2]|0;
    $34 = ((($31)) + 24|0);
    HEAP32[$34>>2] = $33;
    $35 = HEAP32[34344>>2]|0;
    $36 = ((($35)) + 32|0);
    $37 = HEAP32[$36>>2]|0;
    $38 = ((($35)) + 28|0);
    HEAP32[$38>>2] = $37;
    $39 = HEAP32[34344>>2]|0;
    $40 = ((($39)) + 36|0);
    $41 = HEAP32[$40>>2]|0;
    $42 = ((($39)) + 32|0);
    HEAP32[$42>>2] = $41;
    $43 = HEAP32[34344>>2]|0;
    $44 = ((($43)) + 40|0);
    $45 = HEAP32[$44>>2]|0;
    $46 = ((($43)) + 36|0);
    HEAP32[$46>>2] = $45;
    $$pre = HEAP32[34344>>2]|0;
    $51 = $$pre;$slot$0 = 9;
   } else {
    $47 = (($5) + 1)|0;
    HEAP32[34360>>2] = $47;
    $48 = $47 << 2;
    $49 = (_xrealloc($2,$48)|0);
    HEAP32[34344>>2] = $49;
    $51 = $49;$slot$0 = $5;
   }
   $50 = (($51) + ($slot$0<<2)|0);
   HEAP32[$50>>2] = 0;
   $slot$1 = $slot$0;
  } else {
   $52 = HEAP32[34360>>2]|0;
   $53 = (($52) + -1)|0;
   $slot$1 = $53;
  }
 } while(0);
 $54 = HEAP32[13456>>2]|0;
 $55 = ($54|0)!=(0);
 $56 = HEAP32[13440>>2]|0;
 $57 = ($56|0)!=(0);
 $or$cond = $55 & $57;
 $58 = HEAP32[34344>>2]|0;
 $59 = (($58) + ($slot$1<<2)|0);
 if (!($or$cond)) {
  HEAP32[$59>>2] = $text;
  HEAP32[34352>>2] = $slot$1;
  return;
 }
 $60 = HEAP32[$59>>2]|0;
 $61 = (_strlen(($60|0))|0);
 $62 = (($61) + 1)|0;
 $63 = (_strlen(($text|0))|0);
 $64 = (($62) + ($63))|0;
 $65 = (_xmalloc($64)|0);
 $66 = ($append|0)==(0);
 if ($66) {
  (_strcpy(($65|0),($text|0))|0);
  (_strcat(($65|0),($60|0))|0);
 } else {
  (_strcpy(($65|0),($60|0))|0);
  (_strcat(($65|0),($text|0))|0);
 }
 _xfree($60);
 _xfree($text);
 $67 = HEAP32[34344>>2]|0;
 $68 = (($67) + ($slot$1<<2)|0);
 HEAP32[$68>>2] = $65;
 HEAP32[34352>>2] = $slot$1;
 return;
}
function _rl_yank_nth_arg_internal($count,$ignore,$history_skip) {
 $count = $count|0;
 $ignore = $ignore|0;
 $history_skip = $history_skip|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_where_history()|0);
 $1 = ($history_skip|0)>(0);
 if ($1) {
  $i$01 = 0;
  while(1) {
   (_previous_history()|0);
   $2 = (($i$01) + 1)|0;
   $exitcond = ($2|0)==($history_skip|0);
   if ($exitcond) {
    break;
   } else {
    $i$01 = $2;
   }
  }
 }
 $3 = (_previous_history()|0);
 (_history_set_pos($0)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $5 = HEAP32[$3>>2]|0;
 $6 = (_history_arg_extract($count,$count,$5)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $8 = HEAP8[$6>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  (_rl_ding()|0);
  _free($6);
  $$0 = -1;
  return ($$0|0);
 }
 (_rl_begin_undo_group()|0);
 $10 = HEAP32[13784>>2]|0;
 (__rl_set_mark_at_pos($10)|0);
 $11 = HEAP32[13440>>2]|0;
 $12 = ($11|0)==(0);
 if ($12) {
  (_rl_vi_append_mode(1,$ignore)|0);
  (_rl_insert_text(36328)|0);
 }
 (_rl_insert_text($6)|0);
 _xfree($6);
 (_rl_end_undo_group()|0);
 $$0 = 0;
 return ($$0|0);
}
function _rl_add_undo($what,$start,$end,$text) {
 $what = $what|0;
 $start = $start|0;
 $end = $end|0;
 $text = $text|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(20)|0);
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = $what;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = $start;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = $end;
 $4 = ((($0)) + 12|0);
 HEAP32[$4>>2] = $text;
 HEAP32[$0>>2] = 0;
 $5 = HEAP32[34424>>2]|0;
 HEAP32[$0>>2] = $5;
 HEAP32[34424>>2] = $0;
 return;
}
function _rl_free_undo_list() {
 var $$01$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34424>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$01$i = $0;
  while(1) {
   $2 = HEAP32[$$01$i>>2]|0;
   $3 = ((($$01$i)) + 16|0);
   $4 = HEAP32[$3>>2]|0;
   $5 = ($4|0)==(0);
   if ($5) {
    $6 = ((($$01$i)) + 12|0);
    $7 = HEAP32[$6>>2]|0;
    _xfree($7);
   }
   _xfree($$01$i);
   $8 = ($2|0)==(0|0);
   if ($8) {
    break;
   } else {
    $$01$i = $2;
   }
  }
 }
 HEAP32[34424>>2] = 0;
 _replace_history_data(-1,$0,0);
 return;
}
function _rl_do_undo() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $end$0 = 0, $end$1 = 0, $or$cond = 0, $start$0 = 0, $start$1 = 0, $switch = 0, $waiting_for_begin$0 = 0, $waiting_for_begin$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $end$0 = 0;$start$0 = 0;$waiting_for_begin$0 = 0;
 while(1) {
  $0 = HEAP32[34424>>2]|0;
  $1 = ($0|0)==(0|0);
  if ($1) {
   $$0 = 0;
   label = 23;
   break;
  }
  HEAP32[34408>>2] = 1;
  $2 = HEAP32[13488>>2]|0;
  $3 = $2 | 65536;
  HEAP32[13488>>2] = $3;
  $4 = ((($0)) + 16|0);
  $5 = HEAP32[$4>>2]|0;
  $switch = ($5>>>0)<(2);
  do {
   if ($switch) {
    $6 = ((($0)) + 4|0);
    $7 = HEAP32[$6>>2]|0;
    if ((($7|0) == -1)) {
     $8 = HEAP32[13784>>2]|0;
     $42 = $8;
    } else if ((($7|0) == -2)) {
     $9 = HEAP32[13768>>2]|0;
     $42 = $9;
    } else {
     $42 = $7;
    }
    $10 = ((($0)) + 8|0);
    $11 = HEAP32[$10>>2]|0;
    if ((($11|0) == -1)) {
     $12 = HEAP32[13784>>2]|0;
     $end$1 = $12;$start$1 = $42;
     break;
    } else if ((($11|0) == -2)) {
     $13 = HEAP32[13768>>2]|0;
     $end$1 = $13;$start$1 = $42;
     break;
    } else {
     $end$1 = $11;$start$1 = $42;
     break;
    }
   } else {
    $end$1 = $end$0;$start$1 = $start$0;
   }
  } while(0);
  do {
   if ((($5|0) == 2)) {
    $20 = ($waiting_for_begin$0|0)==(0);
    if ($20) {
     (_rl_ding()|0);
     $waiting_for_begin$1 = 0;
     break;
    } else {
     $21 = (($waiting_for_begin$0) + -1)|0;
     $waiting_for_begin$1 = $21;
     break;
    }
   } else if ((($5|0) == 0)) {
    HEAP32[13784>>2] = $start$1;
    $14 = ((($0)) + 12|0);
    $15 = HEAP32[$14>>2]|0;
    (_rl_insert_text($15)|0);
    $16 = HEAP32[34424>>2]|0;
    $17 = ((($16)) + 12|0);
    $18 = HEAP32[$17>>2]|0;
    _xfree($18);
    $waiting_for_begin$1 = $waiting_for_begin$0;
   } else if ((($5|0) == 3)) {
    $19 = (($waiting_for_begin$0) + 1)|0;
    $waiting_for_begin$1 = $19;
   } else if ((($5|0) == 1)) {
    (_rl_delete_text($start$1,$end$1)|0);
    HEAP32[13784>>2] = $start$1;
    $waiting_for_begin$1 = $waiting_for_begin$0;
   } else {
    $waiting_for_begin$1 = $waiting_for_begin$0;
   }
  } while(0);
  HEAP32[34408>>2] = 0;
  $22 = HEAP32[13488>>2]|0;
  $23 = $22 & -65537;
  HEAP32[13488>>2] = $23;
  $24 = HEAP32[34424>>2]|0;
  $25 = HEAP32[$24>>2]|0;
  HEAP32[34424>>2] = $25;
  $26 = (_current_history()|0);
  $27 = ($26|0)==(0|0);
  if (!($27)) {
   $28 = ((($26)) + 8|0);
   $29 = HEAP32[$28>>2]|0;
   $30 = ($29|0)!=(0|0);
   $31 = ($29|0)==($24|0);
   $or$cond = $30 & $31;
   if ($or$cond) {
    $32 = (_where_history()|0);
    $33 = HEAP32[13632>>2]|0;
    $34 = HEAP32[34424>>2]|0;
    $35 = (_replace_history_entry($32,$33,$34)|0);
    $36 = HEAP32[$35>>2]|0;
    _xfree($36);
    $37 = ((($35)) + 4|0);
    $38 = HEAP32[$37>>2]|0;
    $39 = ($38|0)==(0|0);
    if (!($39)) {
     _free($38);
    }
    _xfree($35);
   }
  }
  $40 = HEAP32[34424>>2]|0;
  _replace_history_data(-1,$24,$40);
  _xfree($24);
  $41 = ($waiting_for_begin$1|0)==(0);
  if ($41) {
   $$0 = 1;
   label = 23;
   break;
  } else {
   $end$0 = $end$1;$start$0 = $start$1;$waiting_for_begin$0 = $waiting_for_begin$1;
  }
 }
 if ((label|0) == 23) {
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_begin_undo_group() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(20)|0);
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = 2;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $2 = HEAP32[34424>>2]|0;
 HEAP32[$0>>2] = $2;
 HEAP32[34424>>2] = $0;
 $3 = HEAP32[34416>>2]|0;
 $4 = (($3) + 1)|0;
 HEAP32[34416>>2] = $4;
 return 0;
}
function _rl_end_undo_group() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(20)|0);
 $1 = ((($0)) + 16|0);
 HEAP32[$1>>2] = 3;
 ;HEAP32[$0>>2]=0|0;HEAP32[$0+4>>2]=0|0;HEAP32[$0+8>>2]=0|0;HEAP32[$0+12>>2]=0|0;
 $2 = HEAP32[34424>>2]|0;
 HEAP32[$0>>2] = $2;
 HEAP32[34424>>2] = $0;
 $3 = HEAP32[34416>>2]|0;
 $4 = (($3) + -1)|0;
 HEAP32[34416>>2] = $4;
 return 0;
}
function _rl_modifying($start,$end) {
 $start = $start|0;
 $end = $end|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $end$start = 0, $start$end = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($start|0)>($end|0);
 $start$end = $0 ? $start : $end;
 $end$start = $0 ? $end : $start;
 $1 = ($end$start|0)==($start$end|0);
 if ($1) {
  return 0;
 }
 $2 = (_rl_copy_text($end$start,$start$end)|0);
 $3 = (_xmalloc(20)|0);
 $4 = ((($3)) + 16|0);
 HEAP32[$4>>2] = 2;
 ;HEAP32[$3>>2]=0|0;HEAP32[$3+4>>2]=0|0;HEAP32[$3+8>>2]=0|0;HEAP32[$3+12>>2]=0|0;
 $5 = HEAP32[34424>>2]|0;
 HEAP32[$3>>2] = $5;
 HEAP32[34424>>2] = $3;
 $6 = HEAP32[34416>>2]|0;
 $7 = (($6) + 1)|0;
 HEAP32[34416>>2] = $7;
 $8 = (_xmalloc(20)|0);
 $9 = ((($8)) + 16|0);
 HEAP32[$9>>2] = 0;
 $10 = ((($8)) + 4|0);
 HEAP32[$10>>2] = $end$start;
 $11 = ((($8)) + 8|0);
 HEAP32[$11>>2] = $start$end;
 $12 = ((($8)) + 12|0);
 HEAP32[$12>>2] = $2;
 HEAP32[$8>>2] = 0;
 $13 = HEAP32[34424>>2]|0;
 HEAP32[$8>>2] = $13;
 HEAP32[34424>>2] = $8;
 $14 = (_xmalloc(20)|0);
 $15 = ((($14)) + 16|0);
 HEAP32[$15>>2] = 1;
 $16 = ((($14)) + 4|0);
 HEAP32[$16>>2] = $end$start;
 $17 = ((($14)) + 8|0);
 HEAP32[$17>>2] = $start$end;
 $18 = ((($14)) + 12|0);
 HEAP32[$18>>2] = 0;
 HEAP32[$14>>2] = 0;
 $19 = HEAP32[34424>>2]|0;
 HEAP32[$14>>2] = $19;
 HEAP32[34424>>2] = $14;
 $20 = (_xmalloc(20)|0);
 $21 = ((($20)) + 16|0);
 HEAP32[$21>>2] = 3;
 ;HEAP32[$20>>2]=0|0;HEAP32[$20+4>>2]=0|0;HEAP32[$20+8>>2]=0|0;HEAP32[$20+12>>2]=0|0;
 $22 = HEAP32[34424>>2]|0;
 HEAP32[$20>>2] = $22;
 HEAP32[34424>>2] = $20;
 $23 = HEAP32[34416>>2]|0;
 $24 = (($23) + -1)|0;
 HEAP32[34416>>2] = $24;
 return 0;
}
function _rl_revert_line($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pr = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34424>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_ding()|0);
  return 0;
 }
 while(1) {
  (_rl_do_undo()|0);
  $$pr = HEAP32[34424>>2]|0;
  $2 = ($$pr|0)==(0|0);
  if ($2) {
   break;
  }
 }
 $3 = HEAP32[13440>>2]|0;
 $4 = ($3|0)==(0);
 if (!($4)) {
  return 0;
 }
 HEAP32[13952>>2] = 0;
 HEAP32[13784>>2] = 0;
 return 0;
}
function _rl_undo_command($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$012 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(1);
 if ($0) {
  return 0;
 } else {
  $$012 = $count;
 }
 while(1) {
  $3 = (_rl_do_undo()|0);
  $4 = ($3|0)==(0);
  $2 = (($$012) + -1)|0;
  if ($4) {
   break;
  }
  $1 = ($2|0)==(0);
  if ($1) {
   label = 5;
   break;
  } else {
   $$012 = $2;
  }
 }
 if ((label|0) == 5) {
  return 0;
 }
 (_rl_ding()|0);
 return 0;
}
function __rl_with_macro_input($string) {
 $string = $string|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(12)|0);
 $1 = HEAP32[34440>>2]|0;
 HEAP32[$0>>2] = $1;
 $2 = HEAP32[34448>>2]|0;
 $3 = ((($0)) + 8|0);
 HEAP32[$3>>2] = $2;
 $4 = HEAP32[34432>>2]|0;
 $5 = ((($0)) + 4|0);
 HEAP32[$5>>2] = $4;
 HEAP32[34440>>2] = $0;
 HEAP32[34432>>2] = $string;
 HEAP32[34448>>2] = 0;
 $6 = HEAP32[13488>>2]|0;
 $7 = $6 | 2048;
 HEAP32[13488>>2] = $7;
 return;
}
function __rl_next_macro_key() {
 var $$0 = 0, $$lcssa = 0, $$lcssa23 = 0, $$lcssa25 = 0, $$pr$i = 0, $$pr$i2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $4 = $0;
 }
 while(1) {
  $2 = HEAP32[34448>>2]|0;
  $3 = (($4) + ($2)|0);
  $5 = HEAP8[$3>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $$lcssa = $4;$$lcssa23 = $2;$$lcssa25 = $3;
   break;
  }
  _free($4);
  HEAP32[34432>>2] = 0;
  HEAP32[34448>>2] = 0;
  $7 = HEAP32[34440>>2]|0;
  $8 = ($7|0)==(0|0);
  if ($8) {
   label = 10;
   break;
  }
  $9 = ((($7)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  HEAP32[34432>>2] = $10;
  $11 = ((($7)) + 8|0);
  $12 = HEAP32[$11>>2]|0;
  HEAP32[34448>>2] = $12;
  $13 = HEAP32[$7>>2]|0;
  HEAP32[34440>>2] = $13;
  _xfree($7);
  $$pr$i = HEAP32[34432>>2]|0;
  $14 = ($$pr$i|0)==(0|0);
  if ($14) {
   label = 10;
   break;
  } else {
   $4 = $$pr$i;
  }
 }
 if ((label|0) == 10) {
  $36 = HEAP32[13488>>2]|0;
  $37 = $36 & -2049;
  HEAP32[13488>>2] = $37;
  $$0 = 0;
  return ($$0|0);
 }
 $15 = (($$lcssa23) + 1)|0;
 HEAP32[34448>>2] = $15;
 $16 = HEAP8[$$lcssa25>>0]|0;
 $17 = $16 << 24 >> 24;
 $18 = HEAP32[13488>>2]|0;
 $19 = $18 & 524288;
 $20 = ($19|0)==(0);
 $21 = $18 & 72;
 $22 = ($21|0)==(0);
 $or$cond = $20 | $22;
 if ($or$cond) {
  $$0 = $17;
  return ($$0|0);
 }
 $23 = (($$lcssa) + ($15)|0);
 $24 = HEAP8[$23>>0]|0;
 $25 = ($24<<24>>24)==(0);
 if (!($25)) {
  $$0 = $17;
  return ($$0|0);
 }
 _free($$lcssa);
 HEAP32[34432>>2] = 0;
 HEAP32[34448>>2] = 0;
 $26 = HEAP32[34440>>2]|0;
 $27 = ($26|0)==(0|0);
 if (!($27)) {
  $28 = ((($26)) + 4|0);
  $29 = HEAP32[$28>>2]|0;
  HEAP32[34432>>2] = $29;
  $30 = ((($26)) + 8|0);
  $31 = HEAP32[$30>>2]|0;
  HEAP32[34448>>2] = $31;
  $32 = HEAP32[$26>>2]|0;
  HEAP32[34440>>2] = $32;
  _xfree($26);
  $$pr$i2 = HEAP32[34432>>2]|0;
  $33 = ($$pr$i2|0)==(0|0);
  if (!($33)) {
   $$0 = $17;
   return ($$0|0);
  }
 }
 $34 = HEAP32[13488>>2]|0;
 $35 = $34 & -2049;
 HEAP32[13488>>2] = $35;
 $$0 = $17;
 return ($$0|0);
}
function __rl_pop_executing_macro() {
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34432>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  _free($0);
 }
 HEAP32[34432>>2] = 0;
 HEAP32[34448>>2] = 0;
 $2 = HEAP32[34440>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  $4 = ((($2)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  HEAP32[34432>>2] = $5;
  $6 = ((($2)) + 8|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[34448>>2] = $7;
  $8 = HEAP32[$2>>2]|0;
  HEAP32[34440>>2] = $8;
  _xfree($2);
  $$pr = HEAP32[34432>>2]|0;
  $9 = ($$pr|0)==(0|0);
  if (!($9)) {
   return;
  }
 }
 $10 = HEAP32[13488>>2]|0;
 $11 = $10 & -2049;
 HEAP32[13488>>2] = $11;
 return;
}
function __rl_prev_macro_key() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34432>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = HEAP32[34448>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 $4 = (($2) + -1)|0;
 HEAP32[34448>>2] = $4;
 $5 = (($0) + ($4)|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = $6 << 24 >> 24;
 $$0 = $7;
 return ($$0|0);
}
function __rl_add_macro_char($c) {
 $c = $c|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34456>>2]|0;
 $1 = (($0) + 1)|0;
 $2 = HEAP32[34464>>2]|0;
 $3 = ($1|0)<($2|0);
 $$pre = HEAP32[34472>>2]|0;
 do {
  if ($3) {
   $12 = $$pre;
  } else {
   $4 = ($$pre|0)==(0|0);
   if ($4) {
    HEAP32[34464>>2] = 25;
    $5 = (_xmalloc(25)|0);
    HEAP32[34472>>2] = $5;
    $12 = $5;
    break;
   } else {
    $6 = (($2) + 25)|0;
    HEAP32[34464>>2] = $6;
    $7 = (_xrealloc($$pre,$6)|0);
    HEAP32[34472>>2] = $7;
    $12 = $7;
    break;
   }
  }
 } while(0);
 $8 = $c&255;
 $9 = HEAP32[34456>>2]|0;
 $10 = (($9) + 1)|0;
 HEAP32[34456>>2] = $10;
 $11 = (($12) + ($9)|0);
 HEAP8[$11>>0] = $8;
 $13 = HEAP32[34456>>2]|0;
 $14 = HEAP32[34472>>2]|0;
 $15 = (($14) + ($13)|0);
 HEAP8[$15>>0] = 0;
 return;
}
function __rl_kill_kbd_macro() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34472>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  _xfree($0);
  HEAP32[34472>>2] = 0;
 }
 HEAP32[34456>>2] = 0;
 HEAP32[34464>>2] = 0;
 $2 = HEAP32[34432>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 HEAP32[34432>>2] = 0;
 HEAP32[34448>>2] = 0;
 $4 = HEAP32[13488>>2]|0;
 $5 = $4 & -4097;
 HEAP32[13488>>2] = $5;
 return;
}
function _rl_start_kbd_macro($ignore1,$ignore2) {
 $ignore1 = $ignore1|0;
 $ignore2 = $ignore2|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 4096;
 $2 = ($1|0)==(0);
 if (!($2)) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 $3 = HEAP32[13472>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  HEAP32[34456>>2] = 0;
  $21 = $0;
  $20 = $21 | 4096;
  HEAP32[13488>>2] = $20;
  return 0;
 }
 $5 = HEAP32[34472>>2]|0;
 $6 = ($5|0)==(0|0);
 if ($6) {
  $21 = $0;
  $20 = $21 | 4096;
  HEAP32[13488>>2] = $20;
  return 0;
 }
 $7 = (_strlen(($5|0))|0);
 $8 = (($7) + 1)|0;
 $9 = (_xmalloc($8)|0);
 $10 = HEAP32[34472>>2]|0;
 $11 = (_strcpy(($9|0),($10|0))|0);
 $12 = (_xmalloc(12)|0);
 $13 = HEAP32[34440>>2]|0;
 HEAP32[$12>>2] = $13;
 $14 = HEAP32[34448>>2]|0;
 $15 = ((($12)) + 8|0);
 HEAP32[$15>>2] = $14;
 $16 = HEAP32[34432>>2]|0;
 $17 = ((($12)) + 4|0);
 HEAP32[$17>>2] = $16;
 HEAP32[34440>>2] = $12;
 HEAP32[34432>>2] = $11;
 HEAP32[34448>>2] = 0;
 $18 = HEAP32[13488>>2]|0;
 $19 = $18 | 2048;
 HEAP32[13488>>2] = $19;
 $21 = $19;
 $20 = $21 | 4096;
 HEAP32[13488>>2] = $20;
 return 0;
}
function _rl_end_kbd_macro($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 4096;
 $2 = ($1|0)==(0);
 if ($2) {
  (__rl_abort_internal()|0);
  // unreachable;
 } else {
  $3 = HEAP32[13552>>2]|0;
  $4 = HEAP32[34456>>2]|0;
  $5 = (($4) - ($3))|0;
  HEAP32[34456>>2] = $5;
  $6 = HEAP32[34472>>2]|0;
  $7 = (($6) + ($5)|0);
  HEAP8[$7>>0] = 0;
  $8 = HEAP32[13488>>2]|0;
  $9 = $8 & -4097;
  HEAP32[13488>>2] = $9;
  $10 = (($count) + -1)|0;
  (_rl_call_last_kbd_macro($10,0)|0);
  return 0;
 }
 return (0)|0;
}
function _rl_call_last_kbd_macro($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$012 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34472>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 $2 = HEAP32[13488>>2]|0;
 $3 = $2 & 4096;
 $4 = ($3|0)==(0);
 if (!($4)) {
  (_rl_ding()|0);
  $6 = HEAP32[34456>>2]|0;
  $7 = (($6) + -1)|0;
  HEAP32[34456>>2] = $7;
  $8 = HEAP32[34472>>2]|0;
  $9 = (($8) + ($7)|0);
  HEAP8[$9>>0] = 0;
  return 0;
 }
 $5 = ($count|0)==(0);
 if ($5) {
  return 0;
 } else {
  $$012 = $count;
 }
 while(1) {
  $10 = (($$012) + -1)|0;
  $11 = HEAP32[34472>>2]|0;
  $12 = (_strlen(($11|0))|0);
  $13 = (($12) + 1)|0;
  $14 = (_xmalloc($13)|0);
  $15 = HEAP32[34472>>2]|0;
  $16 = (_strcpy(($14|0),($15|0))|0);
  $17 = (_xmalloc(12)|0);
  $18 = HEAP32[34440>>2]|0;
  HEAP32[$17>>2] = $18;
  $19 = HEAP32[34448>>2]|0;
  $20 = ((($17)) + 8|0);
  HEAP32[$20>>2] = $19;
  $21 = HEAP32[34432>>2]|0;
  $22 = ((($17)) + 4|0);
  HEAP32[$22>>2] = $21;
  HEAP32[34440>>2] = $17;
  HEAP32[34432>>2] = $16;
  HEAP32[34448>>2] = 0;
  $23 = HEAP32[13488>>2]|0;
  $24 = $23 | 2048;
  HEAP32[13488>>2] = $24;
  $25 = ($10|0)==(0);
  if ($25) {
   break;
  } else {
   $$012 = $10;
  }
 }
 return 0;
}
function _rl_print_last_kbd_macro($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[34472>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_ding()|0);
  STACKTOP = sp;return 0;
 }
 $2 = (__rl_untranslate_macro_value($0,1)|0);
 (_rl_crlf()|0);
 HEAP32[$vararg_buffer>>2] = $2;
 (_printf((34480|0),($vararg_buffer|0))|0);
 $3 = HEAP32[_stdout>>2]|0;
 (_fflush(($3|0))|0);
 (_rl_crlf()|0);
 $4 = ($2|0)==(0|0);
 if (!($4)) {
  _free($2);
 }
 (_rl_forced_update_display()|0);
 HEAP32[32256>>2] = 1;
 STACKTOP = sp;return 0;
}
function _rl_getc($stream) {
 $stream = $stream|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $c = sp;
 while(1) {
  $0 = HEAP32[32656>>2]|0;
  $1 = ($0|0)==(0);
  if (!($1)) {
   $2 = HEAP32[32656>>2]|0;
   __rl_signal_handler($2);
  }
  $3 = (_fileno(($stream|0))|0);
  $4 = (_read(($3|0),($c|0),1)|0);
  if ((($4|0) == 0)) {
   $$0 = -1;
   label = 18;
   break;
  } else if ((($4|0) == 1)) {
   label = 5;
   break;
  }
  $7 = (___errno_location()|0);
  $8 = HEAP32[$7>>2]|0;
  if ((($8|0) == 11)) {
   $9 = (_fileno(($stream|0))|0);
   $10 = (_sh_unset_nodelay_mode($9)|0);
   $11 = ($10|0)<(0);
   if ($11) {
    $$0 = -1;
    label = 18;
    break;
   } else {
    continue;
   }
  } else if (!((($8|0) == 4))) {
   label = 8;
   break;
  }
  $16 = HEAP32[32656>>2]|0;
  $17 = ($16|0)==(1);
  if ($17) {
   label = 11;
   break;
  }
  $18 = HEAP32[32656>>2]|0;
  $19 = ($18|0)==(15);
  if ($19) {
   label = 11;
   break;
  }
  $24 = HEAP32[32656>>2]|0;
  $25 = ($24|0)==(2);
  if ($25) {
   label = 14;
  } else {
   $26 = HEAP32[32656>>2]|0;
   $27 = ($26|0)==(3);
   if ($27) {
    label = 14;
   }
  }
  if ((label|0) == 14) {
   label = 0;
   $28 = HEAP32[32656>>2]|0;
   $29 = ($28|0)==(0);
   if (!($29)) {
    $30 = HEAP32[32656>>2]|0;
    __rl_signal_handler($30);
   }
  }
  $31 = HEAP32[34496>>2]|0;
  $32 = ($31|0)==(0|0);
  if ($32) {
   continue;
  }
  (FUNCTION_TABLE_i[$31 & 511]()|0);
 }
 if ((label|0) == 5) {
  $5 = HEAP8[$c>>0]|0;
  $6 = $5&255;
  $$0 = $6;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 8) {
  $12 = HEAP32[13488>>2]|0;
  $13 = $12 >>> 3;
  $14 = $13 | -2;
  $15 = $14 ^ 1;
  $$0 = $15;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 11) {
  $20 = HEAP32[13488>>2]|0;
  $21 = $20 >>> 3;
  $22 = $21 | -2;
  $23 = $22 ^ 1;
  $$0 = $23;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 18) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __rl_pushed_input_available() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34520>>2]|0;
 $1 = HEAP32[34528>>2]|0;
 $2 = ($0|0)!=($1|0);
 $3 = $2&1;
 return ($3|0);
}
function __rl_unget_char($key) {
 $key = $key|0;
 var $$ = 0, $$0 = 0, $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34528>>2]|0;
 $1 = HEAP32[34520>>2]|0;
 $2 = ($0|0)>($1|0);
 $3 = (($0) - ($1))|0;
 $$0$i = $2 ? 1 : -511;
 $4 = ($3|0)==($$0$i|0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = (($0) + -1)|0;
 $6 = ($0|0)<(1);
 $$ = $6 ? 511 : $5;
 HEAP32[34528>>2] = $$;
 $7 = $key&255;
 $8 = (34536 + ($$)|0);
 HEAP8[$8>>0] = $7;
 $$0 = 1;
 return ($$0|0);
}
function __rl_input_available() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $exceptfds = 0, $readfds = 0, $timeout = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $readfds = sp + 136|0;
 $exceptfds = sp + 8|0;
 $timeout = sp;
 $0 = HEAP32[34504>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $3 = HEAP32[13504>>2]|0;
  $4 = (_fileno(($3|0))|0);
  dest=$readfds; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  dest=$exceptfds; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $5 = $4 & 31;
  $6 = 1 << $5;
  $7 = $4 >>> 5;
  $8 = (($readfds) + ($7<<2)|0);
  $9 = HEAP32[$8>>2]|0;
  $10 = $9 | $6;
  HEAP32[$8>>2] = $10;
  $11 = (($exceptfds) + ($7<<2)|0);
  $12 = HEAP32[$11>>2]|0;
  $13 = $12 | $6;
  HEAP32[$11>>2] = $13;
  HEAP32[$timeout>>2] = 0;
  $14 = HEAP32[35048>>2]|0;
  $15 = ((($timeout)) + 4|0);
  HEAP32[$15>>2] = $14;
  $16 = (($4) + 1)|0;
  $17 = (_select(($16|0),($readfds|0),(0|0),($exceptfds|0),($timeout|0))|0);
  $18 = ($17|0)>(0);
  $19 = $18&1;
  $$0 = $19;
  STACKTOP = sp;return ($$0|0);
 } else {
  $2 = (FUNCTION_TABLE_i[$0 & 511]()|0);
  $$0 = $2;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __rl_input_queued($t) {
 $t = $t|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exceptfds$i = 0, $readfds$i = 0, $timeout$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 272|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $readfds$i = sp + 136|0;
 $exceptfds$i = sp + 8|0;
 $timeout$i = sp;
 $0 = HEAP32[35048>>2]|0;
 $1 = ($t|0)>(-1);
 if ($1) {
  HEAP32[35048>>2] = $t;
 }
 $2 = HEAP32[34504>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $5 = HEAP32[13504>>2]|0;
  $6 = (_fileno(($5|0))|0);
  dest=$readfds$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  dest=$exceptfds$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $7 = $6 & 31;
  $8 = 1 << $7;
  $9 = $6 >>> 5;
  $10 = (($readfds$i) + ($9<<2)|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = $11 | $8;
  HEAP32[$10>>2] = $12;
  $13 = (($exceptfds$i) + ($9<<2)|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 | $8;
  HEAP32[$13>>2] = $15;
  HEAP32[$timeout$i>>2] = 0;
  $16 = HEAP32[35048>>2]|0;
  $17 = ((($timeout$i)) + 4|0);
  HEAP32[$17>>2] = $16;
  $18 = (($6) + 1)|0;
  $19 = (_select(($18|0),($readfds$i|0),(0|0),($exceptfds$i|0),($timeout$i|0))|0);
  $20 = ($19|0)>(0);
  $21 = $20&1;
  $$0$i = $21;
 } else {
  $4 = (FUNCTION_TABLE_i[$2 & 511]()|0);
  $$0$i = $4;
 }
 $22 = ($0|0)>(-1);
 if (!($22)) {
  STACKTOP = sp;return ($$0$i|0);
 }
 HEAP32[35048>>2] = $0;
 STACKTOP = sp;return ($$0$i|0);
}
function __rl_insert_typein($c) {
 $c = $c|0;
 var $$ = 0, $$$i = 0, $$$lcssa = 0, $$0$i$i = 0, $$lcssa = 0, $$lcssa31 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0, $i$07 = 0, $i$07$lcssa = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(512)|0);
 $1 = $c&255;
 HEAP8[$0>>0] = $1;
 $2 = HEAP32[34520>>2]|0;
 $3 = HEAP32[34528>>2]|0;
 $4 = ($2|0)==($3|0);
 L1: do {
  if ($4) {
   $i$06 = 1;
  } else {
   $30 = $2;$6 = $3;$i$07 = 1;
   while(1) {
    $5 = (($6) + 1)|0;
    $7 = (34536 + ($6)|0);
    $8 = HEAP8[$7>>0]|0;
    $9 = $8&255;
    $10 = ($6|0)>(510);
    $$ = $10 ? 0 : $5;
    HEAP32[34528>>2] = $$;
    $11 = HEAP32[13432>>2]|0;
    $12 = (($11) + ($9<<3)|0);
    $13 = HEAP8[$12>>0]|0;
    $14 = ($13<<24>>24)==(0);
    if (!($14)) {
     $$$lcssa = $$;$$lcssa = $30;$$lcssa31 = $8;$i$07$lcssa = $i$07;
     break;
    }
    $15 = (((($11) + ($9<<3)|0)) + 4|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==(215|0);
    if (!($17)) {
     $$$lcssa = $$;$$lcssa = $30;$$lcssa31 = $8;$i$07$lcssa = $i$07;
     break;
    }
    $18 = (($i$07) + 1)|0;
    $19 = (($0) + ($i$07)|0);
    HEAP8[$19>>0] = $8;
    $20 = HEAP32[34520>>2]|0;
    $21 = HEAP32[34528>>2]|0;
    $22 = ($20|0)==($21|0);
    if ($22) {
     $i$06 = $18;
     break L1;
    } else {
     $30 = $20;$6 = $21;$i$07 = $18;
    }
   }
   $23 = ($$$lcssa|0)>($$lcssa|0);
   $24 = (($$$lcssa) - ($$lcssa))|0;
   $$0$i$i = $23 ? 1 : -511;
   $25 = ($24|0)==($$0$i$i|0);
   if ($25) {
    $i$06 = $i$07$lcssa;
   } else {
    $26 = (($$$lcssa) + -1)|0;
    $27 = ($$$lcssa|0)<(1);
    $$$i = $27 ? 511 : $26;
    HEAP32[34528>>2] = $$$i;
    $28 = (34536 + ($$$i)|0);
    HEAP8[$28>>0] = $$lcssa31;
    $i$06 = $i$07$lcssa;
   }
  }
 } while(0);
 $29 = (($0) + ($i$06)|0);
 HEAP8[$29>>0] = 0;
 (_rl_insert_text($0)|0);
 _xfree($0);
 return;
}
function _rl_stuff_char($key) {
 $key = $key|0;
 var $$0 = 0, $$0$i = 0, $$01 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[34528>>2]|0;
 $1 = HEAP32[34520>>2]|0;
 $2 = ($0|0)>($1|0);
 $3 = (($0) - ($1))|0;
 $$0$i = $2 ? 1 : -511;
 $4 = ($3|0)==($$0$i|0);
 if ($4) {
  $$01 = 0;
  return ($$01|0);
 }
 $5 = ($key|0)==(-1);
 if ($5) {
  HEAP32[13584>>2] = -1;
  $6 = HEAP32[13488>>2]|0;
  $7 = $6 | 131072;
  HEAP32[13488>>2] = $7;
  $$0 = 10;
 } else {
  $$0 = $key;
 }
 $8 = $$0&255;
 $9 = (($1) + 1)|0;
 HEAP32[34520>>2] = $9;
 $10 = (34536 + ($1)|0);
 HEAP8[$10>>0] = $8;
 $11 = ($1|0)>(510);
 if (!($11)) {
  $$01 = 1;
  return ($$01|0);
 }
 HEAP32[34520>>2] = 0;
 $$01 = 1;
 return ($$01|0);
}
function _rl_execute_next($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13584>>2] = $c;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 131072;
 HEAP32[13488>>2] = $1;
 return 0;
}
function _rl_clear_pending_input() {
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13584>>2] = 0;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & -131073;
 HEAP32[13488>>2] = $1;
 return 0;
}
function _rl_read_key() {
 var $$ = 0, $$0 = 0, $$0$i$i = 0, $$0$i$i$i = 0, $$0$i$i2$i = 0, $$0$i$i5$i = 0, $$0$i3 = 0, $$0$i6$i = 0, $$0$i9$i = 0, $$0$v$i$i = 0, $$6 = 0, $$lcssa = 0, $$pr = 0, $$pre$i = 0, $$pre15$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0;
 var $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0;
 var $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0;
 var $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0;
 var $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $chars_avail$i = 0, $exceptfds$i = 0, $input$i = 0, $readfds$i = 0, $timeout$i = 0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 304|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $chars_avail$i = sp + 296|0;
 $input$i = sp + 300|0;
 $readfds$i = sp + 168|0;
 $exceptfds$i = sp + 40|0;
 $timeout$i = sp + 32|0;
 $0 = HEAP32[13584>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  HEAP32[13584>>2] = 0;
  $2 = HEAP32[13488>>2]|0;
  $3 = $2 & -131073;
  HEAP32[13488>>2] = $3;
  $$0 = $0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = (__rl_next_macro_key()|0);
 $5 = ($4|0)==(0);
 if (!($5)) {
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = HEAP32[34488>>2]|0;
 $7 = ($6|0)==(0|0);
 if ($7) {
  $104 = HEAP32[34520>>2]|0;
  $105 = HEAP32[34528>>2]|0;
  $106 = ($104|0)==($105|0);
  if ($106) {
   $112 = HEAP32[34512>>2]|0;
   $113 = HEAP32[13504>>2]|0;
   $114 = (FUNCTION_TABLE_ii[$112 & 511]($113)|0);
   $119 = $114;
  } else {
   $107 = (($105) + 1)|0;
   $108 = (34536 + ($105)|0);
   $109 = HEAP8[$108>>0]|0;
   $110 = $109&255;
   $111 = ($105|0)>(510);
   $$6 = $111 ? 0 : $107;
   HEAP32[34528>>2] = $$6;
   $119 = $110;
  }
  $115 = HEAP32[32656>>2]|0;
  $116 = ($115|0)==(0);
  if ($116) {
   $$0 = $119;
   STACKTOP = sp;return ($$0|0);
  }
  $117 = HEAP32[32656>>2]|0;
  __rl_signal_handler($117);
  $$0 = $119;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ((($timeout$i)) + 4|0);
 while(1) {
  $10 = HEAP32[34520>>2]|0;
  $11 = HEAP32[34528>>2]|0;
  $12 = ($10|0)==($11|0);
  if (!($12)) {
   $$lcssa = $11;
   label = 8;
   break;
  }
  HEAP32[$chars_avail$i>>2] = 0;
  $18 = HEAP32[13504>>2]|0;
  $19 = (_fileno(($18|0))|0);
  dest=$readfds$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  dest=$exceptfds$i; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $20 = $19 & 31;
  $21 = 1 << $20;
  $22 = $19 >>> 5;
  $23 = (($readfds$i) + ($22<<2)|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = $24 | $21;
  HEAP32[$23>>2] = $25;
  $26 = (($exceptfds$i) + ($22<<2)|0);
  $27 = HEAP32[$26>>2]|0;
  $28 = $27 | $21;
  HEAP32[$26>>2] = $28;
  $29 = HEAP32[35048>>2]|0;
  $30 = (($29|0) / 1000000)&-1;
  HEAP32[$timeout$i>>2] = $30;
  $31 = (($29|0) % 1000000)&-1;
  HEAP32[$8>>2] = $31;
  $32 = (($19) + 1)|0;
  $33 = (_select(($32|0),($readfds$i|0),(0|0),($exceptfds$i|0),($timeout$i|0))|0);
  $34 = ($33|0)<(1);
  L22: do {
   if ($34) {
    $$0$i3 = 0;
   } else {
    $35 = (___errno_location()|0);
    HEAP32[$35>>2] = 0;
    HEAP32[$vararg_buffer>>2] = $chars_avail$i;
    $36 = (_ioctl(($19|0),21531,($vararg_buffer|0))|0);
    $37 = ($36|0)==(-1);
    do {
     if ($37) {
      $38 = HEAP32[$35>>2]|0;
      $39 = ($38|0)==(5);
      if ($39) {
       $$0$i3 = -1;
       break L22;
      }
      HEAP32[$vararg_buffer1>>2] = 0;
      $40 = (_fcntl(($19|0),3,($vararg_buffer1|0))|0);
      $41 = $40 | 2048;
      HEAP32[$vararg_buffer4>>2] = $41;
      (_fcntl(($19|0),4,($vararg_buffer4|0))|0);
      $42 = (_read(($19|0),($input$i|0),1)|0);
      HEAP32[$chars_avail$i>>2] = $42;
      HEAP32[$vararg_buffer7>>2] = $40;
      (_fcntl(($19|0),4,($vararg_buffer7|0))|0);
      $43 = HEAP32[$chars_avail$i>>2]|0;
      if ((($43|0) == -1)) {
       $$0$i3 = 0;
       break L22;
      } else if (!((($43|0) == 0))) {
       $55 = $43;
       break;
      }
      $44 = HEAP32[34528>>2]|0;
      $45 = HEAP32[34520>>2]|0;
      $46 = ($44|0)>($45|0);
      $47 = (($44) - ($45))|0;
      $$0$i$i$i = $46 ? 1 : -511;
      $48 = ($47|0)==($$0$i$i$i|0);
      if ($48) {
       $$0$i3 = 0;
       break L22;
      }
      HEAP32[13584>>2] = -1;
      $49 = HEAP32[13488>>2]|0;
      $50 = $49 | 131072;
      HEAP32[13488>>2] = $50;
      $51 = (($45) + 1)|0;
      HEAP32[34520>>2] = $51;
      $52 = (34536 + ($45)|0);
      HEAP8[$52>>0] = 10;
      $53 = ($45|0)>(510);
      if (!($53)) {
       $$0$i3 = 0;
       break L22;
      }
      HEAP32[34520>>2] = 0;
      $$0$i3 = 0;
      break L22;
     } else {
      $$pre$i = HEAP32[$chars_avail$i>>2]|0;
      $55 = $$pre$i;
     }
    } while(0);
    $54 = ($55|0)<(1);
    if ($54) {
     $$0$i3 = 0;
    } else {
     $56 = HEAP32[34528>>2]|0;
     $57 = HEAP32[34520>>2]|0;
     $58 = ($56|0)>($57|0);
     $59 = (($56) - ($57))|0;
     $$0$v$i$i = $58 ? -1 : 511;
     $$0$i9$i = (($$0$v$i$i) + ($59))|0;
     $60 = ($55|0)>($$0$i9$i|0);
     if ($60) {
      HEAP32[$chars_avail$i>>2] = $$0$i9$i;
      $118 = $$0$i9$i;
     } else {
      $118 = $55;
     }
     $61 = ($$0$i9$i|0)<(511);
     if ($61) {
      HEAP32[$chars_avail$i>>2] = 0;
      $63 = 0;
     } else {
      $63 = $118;
     }
     if ($37) {
      $85 = ($63|0)==(0);
      if ($85) {
       $$0$i3 = 1;
       break;
      }
      $86 = HEAP8[$input$i>>0]|0;
      $$0$i$i2$i = $58 ? 1 : -511;
      $87 = ($59|0)==($$0$i$i2$i|0);
      if ($87) {
       $$0$i3 = 1;
       break;
      }
      $88 = $86 << 24 >> 24;
      $89 = ($86<<24>>24)==(-1);
      if ($89) {
       HEAP32[13584>>2] = -1;
       $90 = HEAP32[13488>>2]|0;
       $91 = $90 | 131072;
       HEAP32[13488>>2] = $91;
       $$0$i$i = 10;
      } else {
       $$0$i$i = $88;
      }
      $92 = $$0$i$i&255;
      $93 = (($57) + 1)|0;
      HEAP32[34520>>2] = $93;
      $94 = (34536 + ($57)|0);
      HEAP8[$94>>0] = $92;
      $95 = ($57|0)>(510);
      if (!($95)) {
       $$0$i3 = 1;
       break;
      }
      HEAP32[34520>>2] = 0;
      $$0$i3 = 1;
      break;
     }
     $62 = (($63) + -1)|0;
     HEAP32[$chars_avail$i>>2] = $62;
     $64 = ($63|0)==(0);
     if ($64) {
      $$0$i3 = 1;
     } else {
      while(1) {
       $65 = HEAP32[32656>>2]|0;
       $66 = ($65|0)==(0);
       if (!($66)) {
        $67 = HEAP32[32656>>2]|0;
        __rl_signal_handler($67);
       }
       $68 = HEAP32[34512>>2]|0;
       $69 = HEAP32[13504>>2]|0;
       $70 = (FUNCTION_TABLE_ii[$68 & 511]($69)|0);
       $71 = HEAP32[34528>>2]|0;
       $72 = HEAP32[34520>>2]|0;
       $73 = ($71|0)>($72|0);
       $74 = (($71) - ($72))|0;
       $$0$i$i5$i = $73 ? 1 : -511;
       $75 = ($74|0)==($$0$i$i5$i|0);
       if ($75) {
        $$0$i3 = 1;
        break L22;
       }
       $76 = ($70|0)==(-1);
       if ($76) {
        HEAP32[13584>>2] = -1;
        $77 = HEAP32[13488>>2]|0;
        $78 = $77 | 131072;
        HEAP32[13488>>2] = $78;
        $$0$i6$i = 10;
       } else {
        $$0$i6$i = $70;
       }
       $79 = $$0$i6$i&255;
       $80 = (($72) + 1)|0;
       HEAP32[34520>>2] = $80;
       $81 = (34536 + ($72)|0);
       HEAP8[$81>>0] = $79;
       $82 = ($72|0)>(510);
       if ($82) {
        HEAP32[34520>>2] = 0;
       }
       if ((($70|0) == 10) | (($70|0) == 13)) {
        $$0$i3 = 1;
        break L22;
       }
       $$pre15$i = HEAP32[$chars_avail$i>>2]|0;
       $83 = (($$pre15$i) + -1)|0;
       HEAP32[$chars_avail$i>>2] = $83;
       $84 = ($$pre15$i|0)==(0);
       if ($84) {
        $$0$i3 = 1;
        break;
       }
      }
     }
    }
   }
  } while(0);
  $96 = ($$0$i3|0)<(0);
  if ($96) {
   label = 40;
   break;
  }
  $97 = ($$0$i3|0)>(0);
  if (!($97)) {
   $98 = HEAP32[32656>>2]|0;
   $99 = ($98|0)==(0);
   if (!($99)) {
    $100 = HEAP32[32656>>2]|0;
    __rl_signal_handler($100);
   }
   $101 = HEAP32[13776>>2]|0;
   $102 = ($101|0)==(0);
   if (!($102)) {
    $$0 = 10;
    label = 51;
    break;
   }
   $103 = HEAP32[34488>>2]|0;
   (FUNCTION_TABLE_i[$103 & 511]()|0);
  }
  $$pr = HEAP32[34488>>2]|0;
  $9 = ($$pr|0)==(0|0);
  if ($9) {
   $$0 = 0;
   label = 51;
   break;
  }
 }
 if ((label|0) == 8) {
  $13 = (($$lcssa) + 1)|0;
  $14 = (34536 + ($$lcssa)|0);
  $15 = HEAP8[$14>>0]|0;
  $16 = $15&255;
  $17 = ($$lcssa|0)>(510);
  $$ = $17 ? 0 : $13;
  HEAP32[34528>>2] = $$;
  STACKTOP = sp;return ($16|0);
 }
 else if ((label|0) == 40) {
  HEAP32[13776>>2] = 1;
  $$0 = 10;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 51) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __rl_read_mbchar($mbchar,$size) {
 $mbchar = $mbchar|0;
 $size = $size|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mb_len$0 = 0, $mb_len$1 = 0, $ps = 0, $wc = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $wc = sp + 8|0;
 $ps = sp;
 $mb_len$0 = 0;
 while(1) {
  $0 = $ps;
  $1 = $0;
  HEAP32[$1>>2] = 0;
  $2 = (($0) + 4)|0;
  $3 = $2;
  HEAP32[$3>>2] = 0;
  $4 = ($mb_len$0|0)<($size|0);
  if (!($4)) {
   $mb_len$1 = $mb_len$0;
   break;
  }
  $5 = HEAP32[13488>>2]|0;
  $6 = $5 | 64;
  HEAP32[13488>>2] = $6;
  $7 = (_rl_read_key()|0);
  $8 = HEAP32[13488>>2]|0;
  $9 = $8 & -65;
  HEAP32[13488>>2] = $9;
  $10 = ($7|0)<(0);
  if ($10) {
   $mb_len$1 = $mb_len$0;
   break;
  }
  $11 = $7&255;
  $12 = (($mb_len$0) + 1)|0;
  $13 = (($mbchar) + ($mb_len$0)|0);
  HEAP8[$13>>0] = $11;
  $14 = (_mbrtowc($wc,$mbchar,$12,$ps)|0);
  if ((($14|0) == -2)) {
   $mb_len$0 = $12;
  } else if ((($14|0) == 0)) {
   label = 5;
   break;
  } else {
   $mb_len$1 = $12;
   break;
  }
 }
 if ((label|0) == 5) {
  HEAP8[$mbchar>>0] = 0;
  $mb_len$1 = 1;
 }
 STACKTOP = sp;return ($mb_len$1|0);
}
function __rl_read_mbstring($first,$mb,$mlen) {
 $first = $first|0;
 $mb = $mb|0;
 $mlen = $mlen|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$0$lcssa = 0, $c$03 = 0;
 var $i$02 = 0, $or$cond = 0, $or$cond1 = 0, $ps = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps = sp;
 _memset(($mb|0),0,($mlen|0))|0;
 $0 = ($first|0)>(-1);
 $1 = ($mlen|0)>(0);
 $or$cond1 = $1 & $0;
 if ($or$cond1) {
  $c$03 = $first;$i$02 = 0;
 } else {
  $c$0$lcssa = $first;
  STACKTOP = sp;return ($c$0$lcssa|0);
 }
 while(1) {
  $2 = $c$03&255;
  $3 = (($mb) + ($i$02)|0);
  HEAP8[$3>>0] = $2;
  $4 = $ps;
  $5 = $4;
  HEAP32[$5>>2] = 0;
  $6 = (($4) + 4)|0;
  $7 = $6;
  HEAP32[$7>>2] = 0;
  $8 = (__rl_get_char_len($mb,$ps)|0);
  $9 = ($8|0)==(-2);
  if (!($9)) {
   $c$0$lcssa = $c$03;
   label = 4;
   break;
  }
  $10 = HEAP32[13488>>2]|0;
  $11 = $10 | 64;
  HEAP32[13488>>2] = $11;
  $12 = (_rl_read_key()|0);
  $13 = HEAP32[13488>>2]|0;
  $14 = $13 & -65;
  HEAP32[13488>>2] = $14;
  $15 = (($i$02) + 1)|0;
  $16 = ($12|0)>(-1);
  $17 = ($15|0)<($mlen|0);
  $or$cond = $17 & $16;
  if ($or$cond) {
   $c$03 = $12;$i$02 = $15;
  } else {
   $c$0$lcssa = $12;
   label = 4;
   break;
  }
 }
 if ((label|0) == 4) {
  STACKTOP = sp;return ($c$0$lcssa|0);
 }
 return (0)|0;
}
function __rl_callback_data_alloc($count) {
 $count = $count|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_xmalloc(12)|0);
 HEAP32[$0>>2] = $count;
 $1 = ((($0)) + 8|0);
 HEAP32[$1>>2] = 0;
 $2 = ((($0)) + 4|0);
 HEAP32[$2>>2] = 0;
 return ($0|0);
}
function __rl_get_screen_size($tty,$ignore_env) {
 $tty = $tty|0;
 $ignore_env = $ignore_env|0;
 var $$pr$pre = 0, $$pr7 = 0, $$pr9$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $vararg_buffer = 0, $wc$0 = 0, $window_size = 0, $wr$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $window_size = sp + 8|0;
 HEAP32[$vararg_buffer>>2] = $window_size;
 $0 = (_ioctl(($tty|0),21523,($vararg_buffer|0))|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = ((($window_size)) + 2|0);
  $3 = HEAP16[$2>>1]|0;
  $4 = $3&65535;
  $5 = HEAP16[$window_size>>1]|0;
  $6 = $5&65535;
  $wc$0 = $4;$wr$0 = $6;
 } else {
  $wc$0 = -1;$wr$0 = -1;
 }
 $7 = ($ignore_env|0)!=(0);
 $8 = HEAP32[35072>>2]|0;
 $9 = ($8|0)==(0);
 $or$cond = $7 | $9;
 if ($or$cond) {
  HEAP32[35112>>2] = $wc$0;
  HEAP32[35120>>2] = $wr$0;
  $10 = ($wc$0|0)<(1);
  if ($10) {
   label = 6;
  } else {
   $22 = $wr$0;
  }
 } else {
  HEAP32[35120>>2] = -1;
  HEAP32[35112>>2] = -1;
  label = 6;
 }
 if ((label|0) == 6) {
  $11 = ($ignore_env|0)==(0);
  if ($11) {
   $12 = (_sh_get_env_value(38576)|0);
   $13 = ($12|0)==(0|0);
   if ($13) {
    $$pr$pre = HEAP32[35112>>2]|0;
    $16 = $$pr$pre;
   } else {
    $14 = (_atoi($12)|0);
    HEAP32[35112>>2] = $14;
    $16 = $14;
   }
   $15 = ($16|0)<(1);
   if ($15) {
    label = 11;
   }
  } else {
   label = 11;
  }
  if ((label|0) == 11) {
   HEAP32[35112>>2] = $wc$0;
   $17 = ($wc$0|0)<(1);
   $18 = HEAP32[35248>>2]|0;
   $19 = ($18|0)!=(0|0);
   $or$cond3 = $17 & $19;
   if ($or$cond3) {
    $20 = (_tgetnum(35256)|0);
    HEAP32[35112>>2] = $20;
   }
  }
  $$pr7 = HEAP32[35120>>2]|0;
  $22 = $$pr7;
 }
 $21 = ($22|0)<(1);
 do {
  if ($21) {
   $23 = ($ignore_env|0)==(0);
   if ($23) {
    $24 = (_sh_get_env_value(38568)|0);
    $25 = ($24|0)==(0|0);
    if ($25) {
     $$pr9$pre = HEAP32[35120>>2]|0;
     $28 = $$pr9$pre;
    } else {
     $26 = (_atoi($24)|0);
     HEAP32[35120>>2] = $26;
     $28 = $26;
    }
    $27 = ($28|0)<(1);
    if (!($27)) {
     $36 = $28;
     break;
    }
   }
   HEAP32[35120>>2] = $wr$0;
   $29 = ($wr$0|0)<(1);
   $30 = HEAP32[35248>>2]|0;
   $31 = ($30|0)!=(0|0);
   $or$cond5 = $29 & $31;
   if ($or$cond5) {
    $32 = (_tgetnum(35264)|0);
    HEAP32[35120>>2] = $32;
    $36 = $32;
   } else {
    $36 = $wr$0;
   }
  } else {
   $36 = $22;
  }
 } while(0);
 $33 = HEAP32[35112>>2]|0;
 $34 = ($33|0)<(2);
 if ($34) {
  HEAP32[35112>>2] = 80;
  $40 = 80;
 } else {
  $40 = $33;
 }
 $35 = ($36|0)<(1);
 if ($35) {
  HEAP32[35120>>2] = 24;
  $39 = 24;
 } else {
  $39 = $36;
 }
 $37 = HEAP32[35080>>2]|0;
 $38 = ($37|0)==(0);
 if (!($38)) {
  _sh_set_lines_and_columns($39,$40);
 }
 $41 = HEAP32[35096>>2]|0;
 $42 = ($41|0)==(0);
 $43 = HEAP32[35112>>2]|0;
 if (!($42)) {
  $47 = $43;
  $45 = HEAP32[35120>>2]|0;
  $46 = Math_imul($45, $47)|0;
  HEAP32[35128>>2] = $46;
  STACKTOP = sp;return;
 }
 $44 = (($43) + -1)|0;
 HEAP32[35112>>2] = $44;
 $47 = $44;
 $45 = HEAP32[35120>>2]|0;
 $46 = Math_imul($45, $47)|0;
 HEAP32[35128>>2] = $46;
 STACKTOP = sp;return;
}
function __rl_init_terminal_io($terminal_name) {
 $terminal_name = $terminal_name|0;
 var $$ = 0, $$in = 0, $$pre = 0, $$pre10 = 0, $$pre9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $buffer = 0, $exitcond$i = 0, $i$01$i = 0;
 var $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0, $phitmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $buffer = sp;
 $0 = ($terminal_name|0)==(0|0);
 if ($0) {
  $1 = (_sh_get_env_value(38592)|0);
  $6 = $1;
 } else {
  $6 = $terminal_name;
 }
 HEAP32[35136>>2] = 0;
 HEAP32[35144>>2] = 0;
 HEAP32[35152>>2] = 0;
 $2 = HEAP32[13504>>2]|0;
 $3 = ($2|0)==(0|0);
 if ($3) {
  $27 = 0;
 } else {
  $4 = (_fileno(($2|0))|0);
  $27 = $4;
 }
 $5 = ($6|0)==(0|0);
 $$ = $5 ? 35272 : $6;
 $7 = HEAP32[32248>>2]|0;
 $8 = ($7|0)==(296|0);
 if ($8) {
  $9 = HEAP32[35248>>2]|0;
  $10 = ($9|0)==(0|0);
  if ($10) {
   $11 = (_xmalloc(2032)|0);
   HEAP32[35248>>2] = $11;
   $$in = $11;
  } else {
   $$in = $9;
  }
  $12 = $$in;
  $13 = HEAP32[35280>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   $15 = (_xmalloc(4080)|0);
   HEAP32[35280>>2] = $15;
   $$pre = HEAP32[35248>>2]|0;
   $16 = $$pre;$17 = $15;
  } else {
   $16 = $12;$17 = $13;
  }
  HEAP32[$buffer>>2] = $16;
  $18 = (_tgetent($17,$$)|0);
  $phitmp = ($18|0)<(1);
  if (!($phitmp)) {
   $i$01$i = 0;
   while(1) {
    $35 = (35432 + ($i$01$i<<3)|0);
    $36 = HEAP32[$35>>2]|0;
    $37 = (_tgetstr($36,$buffer)|0);
    $38 = (((35432 + ($i$01$i<<3)|0)) + 4|0);
    $39 = HEAP32[$38>>2]|0;
    HEAP32[$39>>2] = $37;
    $40 = (($i$01$i) + 1)|0;
    $exitcond$i = ($40|0)==(29);
    if ($exitcond$i) {
     break;
    } else {
     $i$01$i = $40;
    }
   }
   HEAP32[35664>>2] = 1;
   $41 = HEAP32[35232>>2]|0;
   $42 = ($41|0)==(0|0);
   if ($42) {
    $44 = 0;
   } else {
    $43 = HEAP8[$41>>0]|0;
    $44 = $43;
   }
   HEAP8[37296>>0] = $44;
   $45 = HEAP32[35224>>2]|0;
   HEAP32[37224>>2] = $45;
   $46 = HEAP32[35208>>2]|0;
   HEAP32[37216>>2] = $46;
   $47 = HEAP32[35144>>2]|0;
   $48 = ($47|0)==(0|0);
   if ($48) {
    HEAP32[35144>>2] = 35288;
   }
   $49 = (_tgetflag(35672)|0);
   $50 = ($49|0)==(0);
   if ($50) {
    $54 = 0;
   } else {
    $51 = (_tgetflag(35680)|0);
    $52 = ($51|0)!=(0);
    $54 = $52;
   }
   $53 = $54&1;
   HEAP32[35096>>2] = $53;
   $55 = HEAP32[35112>>2]|0;
   $56 = ($55|0)<(1);
   $57 = HEAP32[35120>>2]|0;
   $58 = ($57|0)<(1);
   $or$cond5 = $56 | $58;
   if ($or$cond5) {
    __rl_get_screen_size($27,0);
   }
   $59 = HEAP32[35160>>2]|0;
   $60 = ($59|0)!=(0|0);
   $61 = HEAP32[35184>>2]|0;
   $62 = ($61|0)!=(0|0);
   $or$cond7 = $60 | $62;
   if ($or$cond7) {
    $66 = 1;
   } else {
    $63 = HEAP32[35168>>2]|0;
    $64 = ($63|0)!=(0|0);
    $66 = $64;
   }
   $65 = $66&1;
   HEAP32[35088>>2] = $65;
   $67 = (_tgetflag(35688)|0);
   $68 = ($67|0)!=(0);
   $69 = $68&1;
   HEAP32[35424>>2] = $69;
   if (!($68)) {
    HEAP32[35392>>2] = 0;
    HEAP32[35400>>2] = 0;
   }
   $70 = HEAP32[3358]|0;
   HEAP32[13432>>2] = 22352;
   $71 = HEAP32[35328>>2]|0;
   (_rl_bind_keyseq_if_unbound($71,208)|0);
   $72 = HEAP32[35320>>2]|0;
   (_rl_bind_keyseq_if_unbound($72,200)|0);
   $73 = HEAP32[35304>>2]|0;
   (_rl_bind_keyseq_if_unbound($73,185)|0);
   $74 = HEAP32[35312>>2]|0;
   (_rl_bind_keyseq_if_unbound($74,153)|0);
   $75 = HEAP32[35360>>2]|0;
   (_rl_bind_keyseq_if_unbound($75,159)|0);
   $76 = HEAP32[35368>>2]|0;
   (_rl_bind_keyseq_if_unbound($76,181)|0);
   $77 = HEAP32[35336>>2]|0;
   (_rl_bind_keyseq_if_unbound($77,169)|0);
   HEAP32[13432>>2] = 24408;
   $78 = HEAP32[35328>>2]|0;
   (_rl_bind_keyseq_if_unbound($78,208)|0);
   $79 = HEAP32[35320>>2]|0;
   (_rl_bind_keyseq_if_unbound($79,200)|0);
   $80 = HEAP32[35304>>2]|0;
   (_rl_bind_keyseq_if_unbound($80,185)|0);
   $81 = HEAP32[35312>>2]|0;
   (_rl_bind_keyseq_if_unbound($81,153)|0);
   $82 = HEAP32[35360>>2]|0;
   (_rl_bind_keyseq_if_unbound($82,159)|0);
   $83 = HEAP32[35368>>2]|0;
   (_rl_bind_keyseq_if_unbound($83,181)|0);
   $84 = HEAP32[35336>>2]|0;
   (_rl_bind_keyseq_if_unbound($84,169)|0);
   HEAP32[13432>>2] = 26464;
   $85 = HEAP32[35328>>2]|0;
   (_rl_bind_keyseq_if_unbound($85,208)|0);
   $86 = HEAP32[35320>>2]|0;
   (_rl_bind_keyseq_if_unbound($86,200)|0);
   $87 = HEAP32[35304>>2]|0;
   (_rl_bind_keyseq_if_unbound($87,185)|0);
   $88 = HEAP32[35312>>2]|0;
   (_rl_bind_keyseq_if_unbound($88,153)|0);
   $89 = HEAP32[35360>>2]|0;
   (_rl_bind_keyseq_if_unbound($89,159)|0);
   $90 = HEAP32[35368>>2]|0;
   (_rl_bind_keyseq_if_unbound($90,181)|0);
   $91 = HEAP32[35336>>2]|0;
   (_rl_bind_keyseq_if_unbound($91,169)|0);
   HEAP32[3358] = $70;
   STACKTOP = sp;return 0;
  }
 }
 $19 = HEAP32[35248>>2]|0;
 $20 = ($19|0)==(0|0);
 if (!($20)) {
  _free($19);
 }
 $21 = HEAP32[35280>>2]|0;
 $22 = ($21|0)==(0|0);
 if (!($22)) {
  _free($21);
 }
 HEAP32[35248>>2] = 0;
 HEAP32[35280>>2] = 0;
 HEAP32[$buffer>>2] = 0;
 HEAP32[35096>>2] = 0;
 $23 = HEAP32[35112>>2]|0;
 $24 = ($23|0)<(1);
 $25 = HEAP32[35120>>2]|0;
 $26 = ($25|0)<(1);
 $or$cond = $24 | $26;
 if ($or$cond) {
  __rl_get_screen_size($27,0);
  $$pre9 = HEAP32[35112>>2]|0;
  $$pre10 = HEAP32[35120>>2]|0;
  $29 = $$pre9;$31 = $$pre10;
 } else {
  $29 = $23;$31 = $25;
 }
 $28 = ($29|0)<(1);
 $30 = ($31|0)<(1);
 $or$cond3 = $28 | $30;
 if ($or$cond3) {
  HEAP32[35112>>2] = 79;
  HEAP32[35120>>2] = 24;
  $33 = 24;$34 = 79;
 } else {
  $33 = $31;$34 = $29;
 }
 $32 = Math_imul($33, $34)|0;
 HEAP32[35128>>2] = $32;
 HEAP32[35144>>2] = 35288;
 HEAP32[35160>>2] = 0;
 HEAP32[35168>>2] = 0;
 HEAP32[35176>>2] = 0;
 HEAP32[35184>>2] = 0;
 HEAP32[35296>>2] = 0;
 HEAP32[35192>>2] = 0;
 HEAP32[35200>>2] = 0;
 HEAP32[35208>>2] = 0;
 HEAP32[35304>>2] = 0;
 HEAP32[35312>>2] = 0;
 HEAP32[35320>>2] = 0;
 HEAP32[35328>>2] = 0;
 HEAP32[35336>>2] = 0;
 HEAP32[35344>>2] = 0;
 HEAP32[35352>>2] = 0;
 HEAP32[35360>>2] = 0;
 HEAP32[35368>>2] = 0;
 HEAP32[35376>>2] = 0;
 HEAP32[35384>>2] = 0;
 HEAP32[35392>>2] = 0;
 HEAP32[35400>>2] = 0;
 HEAP32[35408>>2] = 0;
 HEAP32[35416>>2] = 0;
 HEAP32[35216>>2] = 0;
 HEAP32[35424>>2] = 0;
 HEAP32[35088>>2] = 0;
 HEAP8[37296>>0] = 0;
 HEAP32[35224>>2] = 37232;
 HEAP32[37224>>2] = 37232;
 HEAP32[37216>>2] = 0;
 STACKTOP = sp;return 0;
}
function _rl_resize_terminal() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13504>>2]|0;
 $1 = (_fileno(($0|0))|0);
 __rl_get_screen_size($1,1);
 $2 = HEAP32[13520>>2]|0;
 $3 = ($2|0)==(0);
 if ($3) {
  return;
 }
 $4 = HEAP32[32248>>2]|0;
 $5 = ($4|0)==(296|0);
 if (!($5)) {
  (_rl_forced_update_display()|0);
  return;
 }
 $6 = HEAP32[13488>>2]|0;
 $7 = $6 & 8388608;
 $8 = ($7|0)==(0);
 if (!($8)) {
  return;
 }
 __rl_redisplay_after_sigwinch();
 return;
}
function __rl_output_character_function($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13752>>2]|0;
 $1 = (_putc(($c|0),($0|0))|0);
 return ($1|0);
}
function __rl_output_some_chars($string,$count) {
 $string = $string|0;
 $count = $count|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13752>>2]|0;
 (_fwrite(($string|0),1,($count|0),($0|0))|0);
 return;
}
function __rl_backspace($count) {
 $count = $count|0;
 var $$pre = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $exitcond = 0, $exitcond6 = 0, $exitcond69 = 0, $i$13 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35224>>2]|0;
 $1 = ($0|0)==(0|0);
 $2 = ($count|0)>(0);
 if ($1) {
  if ($2) {
   $i$13 = 0;
  } else {
   return 0;
  }
  while(1) {
   $5 = HEAP32[13752>>2]|0;
   (_putc(8,($5|0))|0);
   $6 = (($i$13) + 1)|0;
   $exitcond = ($6|0)==($count|0);
   if ($exitcond) {
    break;
   } else {
    $i$13 = $6;
   }
  }
  return 0;
 }
 if (!($2)) {
  return 0;
 }
 (_tputs($0,1,368)|0);
 $exitcond69 = ($count|0)==(1);
 if ($exitcond69) {
  return 0;
 } else {
  $4 = 1;
 }
 while(1) {
  $$pre = HEAP32[35224>>2]|0;
  (_tputs($$pre,1,368)|0);
  $3 = (($4) + 1)|0;
  $exitcond6 = ($3|0)==($count|0);
  if ($exitcond6) {
   break;
  } else {
   $4 = $3;
  }
 }
 return 0;
}
function _rl_crlf() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13752>>2]|0;
 (_putc(10,($0|0))|0);
 return 0;
}
function _rl_ding() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13520>>2]|0;
 $1 = ($0|0)==(0);
 do {
  if ($1) {
   $$0 = -1;
  } else {
   $2 = HEAP32[13616>>2]|0;
   if ((($2|0) == 2)) {
    $3 = HEAP32[35296>>2]|0;
    $4 = ($3|0)==(0|0);
    if (!($4)) {
     (_tputs($3,1,368)|0);
     $$0 = 0;
     break;
    }
   } else if (!((($2|0) == 1))) {
    $$0 = 0;
    break;
   }
   $5 = HEAP32[_stderr>>2]|0;
   (_fputc(7,($5|0))|0);
   (_fflush(($5|0))|0);
   $$0 = 0;
  }
 } while(0);
 return ($$0|0);
}
function __rl_enable_meta_key() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35424>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[35400>>2]|0;
 $3 = ($2|0)!=(0|0);
 $or$cond = $1 & $3;
 if (!($or$cond)) {
  return;
 }
 (_tputs($2,1,368)|0);
 HEAP32[35696>>2] = 1;
 return;
}
function __rl_disable_meta_key() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[35424>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[35392>>2]|0;
 $3 = ($2|0)!=(0|0);
 $or$cond = $1 & $3;
 $4 = HEAP32[35696>>2]|0;
 $5 = ($4|0)!=(0);
 $or$cond3 = $or$cond & $5;
 if (!($or$cond3)) {
  return;
 }
 (_tputs($2,1,368)|0);
 HEAP32[35696>>2] = 0;
 return;
}
function __rl_control_keypad($on) {
 $on = $on|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($on|0)!=(0);
 $1 = HEAP32[35384>>2]|0;
 $2 = ($1|0)!=(0|0);
 $or$cond = $0 & $2;
 if ($or$cond) {
  (_tputs($1,1,368)|0);
  return;
 }
 $3 = ($on|0)==(0);
 $4 = HEAP32[35376>>2]|0;
 $5 = ($4|0)!=(0|0);
 $or$cond3 = $3 & $5;
 if (!($or$cond3)) {
  return;
 }
 (_tputs($4,1,368)|0);
 return;
}
function _rl_insert_text($string) {
 $string = $string|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa2 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($string|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP8[$string>>0]|0;
 $2 = ($1<<24>>24)==(0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = (_strlen(($string|0))|0);
 $4 = ($3|0)==(0);
 if ($4) {
  $$0 = 0;
  return ($$0|0);
 }
 $5 = HEAP32[13768>>2]|0;
 $6 = (($5) + ($3))|0;
 $7 = HEAP32[13640>>2]|0;
 $8 = ($6|0)<($7|0);
 if ($8) {
  $11 = $5;
 } else {
  _rl_extend_line_buffer($6);
  $$pre = HEAP32[13768>>2]|0;
  $11 = $$pre;
 }
 $9 = HEAP32[13784>>2]|0;
 $10 = ($11|0)<($9|0);
 $12 = HEAP32[13632>>2]|0;
 if ($10) {
  $$lcssa = $9;$$lcssa2 = $12;
 } else {
  $14 = $12;$i$03 = $11;
  while(1) {
   $13 = (($14) + ($i$03)|0);
   $15 = HEAP8[$13>>0]|0;
   $16 = (($i$03) + ($3))|0;
   $17 = (($14) + ($16)|0);
   HEAP8[$17>>0] = $15;
   $18 = (($i$03) + -1)|0;
   $19 = HEAP32[13784>>2]|0;
   $20 = ($i$03|0)>($19|0);
   $21 = HEAP32[13632>>2]|0;
   if ($20) {
    $14 = $21;$i$03 = $18;
   } else {
    $$lcssa = $19;$$lcssa2 = $21;
    break;
   }
  }
 }
 $22 = (($$lcssa2) + ($$lcssa)|0);
 (_strncpy(($22|0),($string|0),($3|0))|0);
 $23 = HEAP32[34408>>2]|0;
 $24 = ($23|0)==(0);
 do {
  if ($24) {
   $25 = ($3|0)==(1);
   $26 = HEAP32[34424>>2]|0;
   $27 = ($26|0)!=(0|0);
   $or$cond = $25 & $27;
   if ($or$cond) {
    $28 = ((($26)) + 16|0);
    $29 = HEAP32[$28>>2]|0;
    $30 = ($29|0)==(1);
    if ($30) {
     $31 = ((($26)) + 8|0);
     $32 = HEAP32[$31>>2]|0;
     $33 = HEAP32[13784>>2]|0;
     $34 = ($32|0)==($33|0);
     if ($34) {
      $35 = ((($26)) + 4|0);
      $36 = HEAP32[$35>>2]|0;
      $37 = (($32) - ($36))|0;
      $38 = ($37|0)<(20);
      if ($38) {
       $39 = (($32) + 1)|0;
       HEAP32[$31>>2] = $39;
       break;
      }
     }
    }
   }
   $40 = HEAP32[13784>>2]|0;
   $41 = (($40) + ($3))|0;
   _rl_add_undo(1,$40,$41,0);
  }
 } while(0);
 $42 = HEAP32[13784>>2]|0;
 $43 = (($42) + ($3))|0;
 HEAP32[13784>>2] = $43;
 $44 = HEAP32[13768>>2]|0;
 $45 = (($44) + ($3))|0;
 HEAP32[13768>>2] = $45;
 $46 = HEAP32[13632>>2]|0;
 $47 = (($46) + ($45)|0);
 HEAP8[$47>>0] = 0;
 $$0 = $3;
 return ($$0|0);
}
function _rl_delete_text($from,$to) {
 $from = $from|0;
 $to = $to|0;
 var $$$1 = 0, $$1 = 0, $$12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $from$to = 0, $i$03 = 0, $to$from = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($from|0)>($to|0);
 $from$to = $0 ? $from : $to;
 $to$from = $0 ? $to : $from;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($from$to|0)>($1|0);
 $3 = ($to$from|0)>($1|0);
 $$12 = $2 ? $1 : $from$to;
 $4 = $2 & $3;
 $$1 = $4 ? $1 : $to$from;
 $5 = ($$1|0)<(0);
 $$$1 = $5 ? 0 : $$1;
 $6 = (_rl_copy_text($$$1,$$12)|0);
 $7 = (($$12) - ($$$1))|0;
 $8 = HEAP32[13768>>2]|0;
 $9 = (($8) - ($7))|0;
 $10 = ($$$1|0)<($9|0);
 if ($10) {
  $i$03 = $$$1;
  while(1) {
   $11 = (($i$03) + ($7))|0;
   $12 = HEAP32[13632>>2]|0;
   $13 = (($12) + ($11)|0);
   $14 = HEAP8[$13>>0]|0;
   $15 = (($12) + ($i$03)|0);
   HEAP8[$15>>0] = $14;
   $16 = (($i$03) + 1)|0;
   $17 = HEAP32[13768>>2]|0;
   $18 = (($17) - ($7))|0;
   $19 = ($16|0)<($18|0);
   if ($19) {
    $i$03 = $16;
   } else {
    break;
   }
  }
 }
 $20 = HEAP32[34408>>2]|0;
 $21 = ($20|0)==(0);
 if ($21) {
  _rl_add_undo(0,$$$1,$$12,$6);
  $22 = HEAP32[13768>>2]|0;
  $23 = (($22) - ($7))|0;
  HEAP32[13768>>2] = $23;
  $24 = HEAP32[13632>>2]|0;
  $25 = (($24) + ($23)|0);
  HEAP8[$25>>0] = 0;
  return ($7|0);
 } else {
  _xfree($6);
  $22 = HEAP32[13768>>2]|0;
  $23 = (($22) - ($7))|0;
  HEAP32[13768>>2] = $23;
  $24 = HEAP32[13632>>2]|0;
  $25 = (($24) + ($23)|0);
  HEAP8[$25>>0] = 0;
  return ($7|0);
 }
 return (0)|0;
}
function __rl_fix_point($fix_mark_too) {
 $fix_mark_too = $fix_mark_too|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)>($1|0);
 if ($2) {
  HEAP32[13784>>2] = $1;
 } else {
  $3 = ($0|0)<(0);
  if ($3) {
   HEAP32[13784>>2] = 0;
  }
 }
 $4 = ($fix_mark_too|0)==(0);
 if ($4) {
  return;
 }
 $5 = HEAP32[13952>>2]|0;
 $6 = ($5|0)>($1|0);
 if ($6) {
  HEAP32[13952>>2] = $1;
  return;
 }
 $7 = ($5|0)<(0);
 if (!($7)) {
  return;
 }
 HEAP32[13952>>2] = 0;
 return;
}
function __rl_replace_text($text,$start,$end) {
 $text = $text|0;
 $start = $start|0;
 $end = $end|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $n$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 (_rl_begin_undo_group()|0);
 $0 = ($start|0)>($end|0);
 if (!($0)) {
  $1 = (($end) + 1)|0;
  (_rl_delete_text($start,$1)|0);
 }
 HEAP32[13784>>2] = $start;
 $2 = HEAP8[$text>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $n$0 = 0;
  (_rl_end_undo_group()|0);
  return ($n$0|0);
 }
 $4 = (_rl_insert_text($text)|0);
 $n$0 = $4;
 (_rl_end_undo_group()|0);
 return ($n$0|0);
}
function _rl_replace_line($text,$clear_undo) {
 $text = $text|0;
 $clear_undo = $clear_undo|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($text|0))|0);
 $1 = HEAP32[13640>>2]|0;
 $2 = ($0|0)<($1|0);
 if (!($2)) {
  _rl_extend_line_buffer($0);
 }
 $3 = HEAP32[13632>>2]|0;
 (_strcpy(($3|0),($text|0))|0);
 HEAP32[13768>>2] = $0;
 $4 = ($clear_undo|0)==(0);
 if ($4) {
  $7 = $0;
 } else {
  _rl_free_undo_list();
  $$pre = HEAP32[13768>>2]|0;
  $7 = $$pre;
 }
 $5 = HEAP32[13784>>2]|0;
 $6 = ($5|0)>($7|0);
 if ($6) {
  HEAP32[13784>>2] = $7;
 } else {
  $8 = ($5|0)<(0);
  if ($8) {
   HEAP32[13784>>2] = 0;
  }
 }
 $9 = HEAP32[13952>>2]|0;
 $10 = ($9|0)>($7|0);
 if ($10) {
  HEAP32[13952>>2] = $7;
  return;
 }
 $11 = ($9|0)<(0);
 if (!($11)) {
  return;
 }
 HEAP32[13952>>2] = 0;
 return;
}
function _rl_forward_byte($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = HEAP32[13784>>2]|0;
  $3 = ($2|0)<($1|0);
  if ($3) {
   HEAP32[13784>>2] = 0;
   (_rl_ding()|0);
   $$pr = HEAP32[13784>>2]|0;
   $6 = $$pr;
  } else {
   $4 = (($2) + ($count))|0;
   HEAP32[13784>>2] = $4;
   $6 = $4;
  }
  $5 = ($6|0)<(0);
  if (!($5)) {
   return 0;
  }
  HEAP32[13784>>2] = 0;
  return 0;
 }
 $7 = ($count|0)>(0);
 do {
  if ($7) {
   $8 = HEAP32[13784>>2]|0;
   $9 = (($8) + ($count))|0;
   $10 = HEAP32[13768>>2]|0;
   $11 = ($10|0)>(0);
   if ($11) {
    $12 = HEAP32[13440>>2]|0;
    $13 = ($12|0)==(0);
    $14 = HEAP32[13432>>2]|0;
    $15 = ($14|0)==(24408|0);
    $16 = $13 & $15;
    $17 = $16&1;
    $18 = (($10) - ($17))|0;
    $20 = $18;
   } else {
    $20 = $10;
   }
   $19 = ($9|0)>($20|0);
   if ($19) {
    HEAP32[13784>>2] = $20;
    (_rl_ding()|0);
    break;
   } else {
    HEAP32[13784>>2] = $9;
    break;
   }
  }
 } while(0);
 $21 = HEAP32[13768>>2]|0;
 $22 = ($21|0)<(0);
 if (!($22)) {
  return 0;
 }
 HEAP32[13768>>2] = 0;
 return 0;
}
function _rl_backward_byte($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pr = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_forward_byte($1,$key)|0);
  return 0;
 }
 $2 = ($count|0)>(0);
 do {
  if ($2) {
   $3 = HEAP32[13784>>2]|0;
   $4 = ($3|0)<($count|0);
   if ($4) {
    HEAP32[13784>>2] = 0;
    (_rl_ding()|0);
    label = 7;
    break;
   } else {
    $5 = (($3) - ($count))|0;
    HEAP32[13784>>2] = $5;
    $7 = $5;
    break;
   }
  } else {
   label = 7;
  }
 } while(0);
 if ((label|0) == 7) {
  $$pr = HEAP32[13784>>2]|0;
  $7 = $$pr;
 }
 $6 = ($7|0)<(0);
 if (!($6)) {
  return 0;
 }
 HEAP32[13784>>2] = 0;
 return 0;
}
function __rl_forward_char_internal($count) {
 $count = $count|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, $point$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13632>>2]|0;
 $1 = HEAP32[13784>>2]|0;
 $2 = (__rl_find_next_mbchar($0,$1,$count,1)|0);
 $3 = HEAP32[13768>>2]|0;
 $4 = ($2|0)>=($3|0);
 $5 = HEAP32[13440>>2]|0;
 $6 = ($5|0)==(0);
 $or$cond = $4 & $6;
 $7 = HEAP32[13432>>2]|0;
 $8 = ($7|0)==(24408|0);
 $or$cond3 = $or$cond & $8;
 if ($or$cond3) {
  $9 = HEAP32[13632>>2]|0;
  $10 = (__rl_find_prev_mbchar($9,$3,1)|0);
  $$pre = HEAP32[13768>>2]|0;
  $12 = $$pre;$point$0 = $10;
 } else {
  $12 = $3;$point$0 = $2;
 }
 $11 = ($12|0)<(0);
 if (!($11)) {
  return ($point$0|0);
 }
 HEAP32[13768>>2] = 0;
 return ($point$0|0);
}
function _rl_forward_char($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pr$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond$i = 0, $or$cond3$i = 0, $point$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36240>>2]|0;
 $1 = ($0|0)==(0);
 $2 = ($count|0)<(0);
 if ($1) {
  if ($2) {
   $25 = (0 - ($count))|0;
   (_rl_backward_char($25,$key)|0);
   return 0;
  }
  $26 = ($count|0)>(0);
  if (!($26)) {
   return 0;
  }
  $27 = HEAP32[13784>>2]|0;
  $28 = HEAP32[13768>>2]|0;
  $29 = ($27|0)==($28|0);
  $30 = HEAP32[13440>>2]|0;
  $31 = ($30|0)==(1);
  $or$cond = $29 & $31;
  if ($or$cond) {
   (_rl_ding()|0);
   return 0;
  }
  $32 = HEAP32[13632>>2]|0;
  $33 = (__rl_find_next_mbchar($32,$27,$count,1)|0);
  $34 = HEAP32[13768>>2]|0;
  $35 = ($33|0)>=($34|0);
  $36 = HEAP32[13440>>2]|0;
  $37 = ($36|0)==(0);
  $or$cond$i = $35 & $37;
  $38 = HEAP32[13432>>2]|0;
  $39 = ($38|0)==(24408|0);
  $or$cond3$i = $or$cond$i & $39;
  if ($or$cond3$i) {
   $40 = HEAP32[13632>>2]|0;
   $41 = (__rl_find_prev_mbchar($40,$34,1)|0);
   $$pre$i = HEAP32[13768>>2]|0;
   $43 = $$pre$i;$point$0$i = $41;
  } else {
   $43 = $34;$point$0$i = $33;
  }
  $42 = ($43|0)<(0);
  if ($42) {
   HEAP32[13768>>2] = 0;
  }
  $44 = HEAP32[13784>>2]|0;
  $45 = ($44|0)==($point$0$i|0);
  if ($45) {
   (_rl_ding()|0);
  }
  HEAP32[13784>>2] = $point$0$i;
  return 0;
 }
 if ($2) {
  $3 = (0 - ($count))|0;
  $4 = HEAP32[13784>>2]|0;
  $5 = ($4|0)<($3|0);
  if ($5) {
   HEAP32[13784>>2] = 0;
   (_rl_ding()|0);
   $$pr$i = HEAP32[13784>>2]|0;
   $8 = $$pr$i;
  } else {
   $6 = (($4) + ($count))|0;
   HEAP32[13784>>2] = $6;
   $8 = $6;
  }
  $7 = ($8|0)<(0);
  if (!($7)) {
   return 0;
  }
  HEAP32[13784>>2] = 0;
  return 0;
 }
 $9 = ($count|0)>(0);
 do {
  if ($9) {
   $10 = HEAP32[13784>>2]|0;
   $11 = (($10) + ($count))|0;
   $12 = HEAP32[13768>>2]|0;
   $13 = ($12|0)>(0);
   if ($13) {
    $14 = HEAP32[13440>>2]|0;
    $15 = ($14|0)==(0);
    $16 = HEAP32[13432>>2]|0;
    $17 = ($16|0)==(24408|0);
    $18 = $15 & $17;
    $19 = $18&1;
    $20 = (($12) - ($19))|0;
    $22 = $20;
   } else {
    $22 = $12;
   }
   $21 = ($11|0)>($22|0);
   if ($21) {
    HEAP32[13784>>2] = $22;
    (_rl_ding()|0);
    break;
   } else {
    HEAP32[13784>>2] = $11;
    break;
   }
  }
 } while(0);
 $23 = HEAP32[13768>>2]|0;
 $24 = ($23|0)<(0);
 if (!($24)) {
  return 0;
 }
 HEAP32[13768>>2] = 0;
 return 0;
}
function _rl_backward_char($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$014 = 0, $$pr$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $point$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36240>>2]|0;
 $1 = ($0|0)==(0);
 $2 = ($count|0)<(0);
 if ($1) {
  if ($2) {
   $24 = (0 - ($count))|0;
   (_rl_forward_char($24,$key)|0);
   return 0;
  }
  $25 = ($count|0)>(0);
  if (!($25)) {
   return 0;
  }
  $26 = HEAP32[13784>>2]|0;
  $27 = ($26|0)>(0);
  if ($27) {
   $$014 = $count;$point$05 = $26;
   while(1) {
    $28 = HEAP32[13632>>2]|0;
    $29 = (__rl_find_prev_mbchar($28,$point$05,1)|0);
    $30 = (($$014) + -1)|0;
    $31 = ($$014|0)>(1);
    $32 = ($29|0)>(0);
    $33 = $31 & $32;
    if ($33) {
     $$014 = $30;$point$05 = $29;
    } else {
     break;
    }
   }
   if (!($31)) {
    HEAP32[13784>>2] = $29;
    return 0;
   }
  }
  HEAP32[13784>>2] = 0;
  (_rl_ding()|0);
  return 0;
 }
 if ($2) {
  $3 = HEAP32[13784>>2]|0;
  $4 = (($3) - ($count))|0;
  $5 = HEAP32[13768>>2]|0;
  $6 = ($5|0)>(0);
  if ($6) {
   $7 = HEAP32[13440>>2]|0;
   $8 = ($7|0)==(0);
   $9 = HEAP32[13432>>2]|0;
   $10 = ($9|0)==(24408|0);
   $11 = $8 & $10;
   $12 = $11&1;
   $13 = (($5) - ($12))|0;
   $15 = $13;
  } else {
   $15 = $5;
  }
  $14 = ($4|0)>($15|0);
  if ($14) {
   HEAP32[13784>>2] = $15;
   (_rl_ding()|0);
  } else {
   HEAP32[13784>>2] = $4;
  }
  $16 = HEAP32[13768>>2]|0;
  $17 = ($16|0)<(0);
  if (!($17)) {
   return 0;
  }
  HEAP32[13768>>2] = 0;
  return 0;
 } else {
  $18 = ($count|0)>(0);
  do {
   if ($18) {
    $19 = HEAP32[13784>>2]|0;
    $20 = ($19|0)<($count|0);
    if ($20) {
     HEAP32[13784>>2] = 0;
     (_rl_ding()|0);
     label = 14;
     break;
    } else {
     $21 = (($19) - ($count))|0;
     HEAP32[13784>>2] = $21;
     $23 = $21;
     break;
    }
   } else {
    label = 14;
   }
  } while(0);
  if ((label|0) == 14) {
   $$pr$i = HEAP32[13784>>2]|0;
   $23 = $$pr$i;
  }
  $22 = ($23|0)<(0);
  if (!($22)) {
   return 0;
  }
  HEAP32[13784>>2] = 0;
  return 0;
 }
 return (0)|0;
}
function _rl_beg_of_line($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13784>>2] = 0;
 return 0;
}
function _rl_end_of_line($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13768>>2]|0;
 HEAP32[13784>>2] = $0;
 return 0;
}
function _rl_forward_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0112 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge$be = 0;
 var $storemerge$ph = 0, $storemerge2$be = 0, $storemerge2$ph = 0, $storemerge27 = 0, $storemerge9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $2 = (0 - ($count))|0;
  (_rl_backward_word($2,$key)|0);
  return 0;
 }
 $1 = ($count|0)==(0);
 if ($1) {
  return 0;
 } else {
  $$0112 = $count;
 }
 while(1) {
  $3 = HEAP32[13784>>2]|0;
  $4 = HEAP32[13768>>2]|0;
  $5 = ($3|0)==($4|0);
  if ($5) {
   label = 26;
   break;
  }
  $6 = HEAP32[13632>>2]|0;
  $7 = (__rl_char_value($6,$3)|0);
  $8 = (__rl_walphabetic($7)|0);
  $9 = ($8|0)==(0);
  L10: do {
   if ($9) {
    $10 = HEAP32[36240>>2]|0;
    $11 = ($10|0)==(0);
    if ($11) {
     $12 = HEAP32[13632>>2]|0;
     $13 = HEAP32[13784>>2]|0;
     $14 = (__rl_find_next_mbchar($12,$13,1,1)|0);
     $storemerge2$ph = $14;
    } else {
     $15 = HEAP32[13784>>2]|0;
     $16 = (($15) + 1)|0;
     $storemerge2$ph = $16;
    }
    HEAP32[13784>>2] = $storemerge2$ph;
    $17 = HEAP32[13768>>2]|0;
    $18 = ($storemerge2$ph|0)<($17|0);
    if ($18) {
     $storemerge27 = $storemerge2$ph;
     while(1) {
      $19 = HEAP32[13632>>2]|0;
      $20 = (__rl_char_value($19,$storemerge27)|0);
      $21 = (__rl_walphabetic($20)|0);
      $22 = ($21|0)==(0);
      if (!($22)) {
       break L10;
      }
      $23 = HEAP32[36240>>2]|0;
      $24 = ($23|0)==(0);
      if ($24) {
       $25 = HEAP32[13632>>2]|0;
       $26 = HEAP32[13784>>2]|0;
       $27 = (__rl_find_next_mbchar($25,$26,1,1)|0);
       $storemerge2$be = $27;
      } else {
       $28 = HEAP32[13784>>2]|0;
       $29 = (($28) + 1)|0;
       $storemerge2$be = $29;
      }
      HEAP32[13784>>2] = $storemerge2$be;
      $30 = HEAP32[13768>>2]|0;
      $31 = ($storemerge2$be|0)<($30|0);
      if ($31) {
       $storemerge27 = $storemerge2$be;
      } else {
       break;
      }
     }
    }
   }
  } while(0);
  $32 = HEAP32[13784>>2]|0;
  $33 = HEAP32[13768>>2]|0;
  $34 = ($32|0)==($33|0);
  if ($34) {
   label = 26;
   break;
  }
  $35 = HEAP32[36240>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   $37 = HEAP32[13632>>2]|0;
   $38 = (__rl_find_next_mbchar($37,$32,1,1)|0);
   $$pre = HEAP32[13768>>2]|0;
   $41 = $$pre;$storemerge$ph = $38;
  } else {
   $39 = (($32) + 1)|0;
   $41 = $33;$storemerge$ph = $39;
  }
  HEAP32[13784>>2] = $storemerge$ph;
  $40 = ($storemerge$ph|0)<($41|0);
  L29: do {
   if ($40) {
    $storemerge9 = $storemerge$ph;
    while(1) {
     $42 = HEAP32[13632>>2]|0;
     $43 = (__rl_char_value($42,$storemerge9)|0);
     $44 = (__rl_walphabetic($43)|0);
     $45 = ($44|0)==(0);
     if ($45) {
      break L29;
     }
     $46 = HEAP32[36240>>2]|0;
     $47 = ($46|0)==(0);
     if ($47) {
      $48 = HEAP32[13632>>2]|0;
      $49 = HEAP32[13784>>2]|0;
      $50 = (__rl_find_next_mbchar($48,$49,1,1)|0);
      $storemerge$be = $50;
     } else {
      $51 = HEAP32[13784>>2]|0;
      $52 = (($51) + 1)|0;
      $storemerge$be = $52;
     }
     HEAP32[13784>>2] = $storemerge$be;
     $53 = HEAP32[13768>>2]|0;
     $54 = ($storemerge$be|0)<($53|0);
     if ($54) {
      $storemerge9 = $storemerge$be;
     } else {
      break;
     }
    }
   }
  } while(0);
  $55 = (($$0112) + -1)|0;
  $56 = ($55|0)==(0);
  if ($56) {
   label = 26;
   break;
  } else {
   $$0112 = $55;
  }
 }
 if ((label|0) == 26) {
  return 0;
 }
 return (0)|0;
}
function _rl_backward_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$016 = 0, $$ph = 0, $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $2 = (0 - ($count))|0;
  (_rl_forward_word($2,$key)|0);
  return 0;
 }
 $1 = ($count|0)==(0);
 if ($1) {
  return 0;
 } else {
  $$016 = $count;
 }
 while(1) {
  $3 = HEAP32[13784>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
   label = 22;
   break;
  }
  $5 = HEAP32[36240>>2]|0;
  $6 = ($5|0)==(0);
  if ($6) {
   $7 = HEAP32[13632>>2]|0;
   $8 = (__rl_find_prev_mbchar($7,$3,1)|0);
   $11 = $8;
  } else {
   $9 = (($3) + -1)|0;
   $11 = $9;
  }
  $10 = HEAP32[13632>>2]|0;
  $12 = (__rl_char_value($10,$11)|0);
  $13 = (__rl_walphabetic($12)|0);
  $14 = ($13|0)==(0);
  L14: do {
   if ($14) {
    $storemerge = $11;
    while(1) {
     HEAP32[13784>>2] = $storemerge;
     $15 = ($storemerge|0)>(0);
     if (!($15)) {
      $$ph = $storemerge;
      break L14;
     }
     $16 = HEAP32[36240>>2]|0;
     $17 = ($16|0)==(0);
     if ($17) {
      $18 = HEAP32[13632>>2]|0;
      $19 = (__rl_find_prev_mbchar($18,$storemerge,1)|0);
      $22 = $19;
     } else {
      $20 = (($storemerge) + -1)|0;
      $22 = $20;
     }
     $21 = HEAP32[13632>>2]|0;
     $23 = (__rl_char_value($21,$22)|0);
     $24 = (__rl_walphabetic($23)|0);
     $25 = ($24|0)==(0);
     if ($25) {
      $storemerge = $22;
     } else {
      label = 14;
      break;
     }
    }
   } else {
    label = 14;
   }
  } while(0);
  if ((label|0) == 14) {
   label = 0;
   $$pr = HEAP32[13784>>2]|0;
   $$ph = $$pr;
  }
  $26 = ($$ph|0)==(0);
  L25: do {
   if (!($26)) {
    $30 = $$ph;
    while(1) {
     $27 = HEAP32[36240>>2]|0;
     $28 = ($27|0)==(0);
     if ($28) {
      $29 = HEAP32[13632>>2]|0;
      $31 = (__rl_find_prev_mbchar($29,$30,1)|0);
      $34 = $31;
     } else {
      $32 = (($30) + -1)|0;
      $34 = $32;
     }
     $33 = HEAP32[13632>>2]|0;
     $35 = (__rl_char_value($33,$34)|0);
     $36 = (__rl_walphabetic($35)|0);
     $37 = ($36|0)==(0);
     if ($37) {
      break L25;
     }
     HEAP32[13784>>2] = $34;
     $38 = ($34|0)==(0);
     if ($38) {
      break;
     } else {
      $30 = $34;
     }
    }
   }
  } while(0);
  $39 = (($$016) + -1)|0;
  $40 = ($39|0)==(0);
  if ($40) {
   label = 22;
   break;
  } else {
   $$016 = $39;
  }
 }
 if ((label|0) == 22) {
  return 0;
 }
 return (0)|0;
}
function _rl_refresh_line($ignore1,$ignore2) {
 $ignore1 = $ignore1|0;
 $ignore2 = $ignore2|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__rl_current_display_line()|0);
 __rl_move_vert($0);
 $1 = HEAP32[13632>>2]|0;
 __rl_move_cursor_relative(0,$1);
 __rl_clear_to_eol(0);
 (_rl_forced_update_display()|0);
 HEAP32[32256>>2] = 1;
 return 0;
}
function _rl_clear_screen($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  __rl_clear_screen();
  (_rl_forced_update_display()|0);
  HEAP32[32256>>2] = 1;
  return 0;
 } else {
  $2 = (__rl_current_display_line()|0);
  __rl_move_vert($2);
  $3 = HEAP32[13632>>2]|0;
  __rl_move_cursor_relative(0,$3);
  __rl_clear_to_eol(0);
  (_rl_forced_update_display()|0);
  HEAP32[32256>>2] = 1;
  return 0;
 }
 return (0)|0;
}
function _rl_skip_csi_sequence($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 while(1) {
  $2 = (_rl_read_key()|0);
  $3 = $2 & -32;
  $4 = ($3|0)==(32);
  if (!($4)) {
   break;
  }
 }
 $5 = HEAP32[13488>>2]|0;
 $6 = $5 & -65;
 HEAP32[13488>>2] = $6;
 return 0;
}
function _rl_arrow_keys($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $$pr$i = 0, $$pr$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 64;
 HEAP32[13488>>2] = $1;
 $2 = (_rl_read_key()|0);
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 & -65;
 HEAP32[13488>>2] = $4;
 $5 = $2 & 255;
 $6 = ($5|0)==($2|0);
 if ($6) {
  $7 = (_islower($2)|0);
  $8 = ($7|0)==(0);
  if ($8) {
   $59 = $2;
  } else {
   $9 = (_toupper($2)|0);
   $59 = $9;
  }
 } else {
  $59 = $2;
 }
 if ((($59|0) == 67)) {
  $10 = HEAP32[36240>>2]|0;
  $11 = ($10|0)==(0);
  if ($11) {
   (_rl_forward_char($count,$2)|0);
   return 0;
  }
  $12 = ($count|0)<(0);
  if ($12) {
   $13 = (0 - ($count))|0;
   $14 = HEAP32[13784>>2]|0;
   $15 = ($14|0)<($13|0);
   if ($15) {
    HEAP32[13784>>2] = 0;
    (_rl_ding()|0);
    $$pr$i = HEAP32[13784>>2]|0;
    $18 = $$pr$i;
   } else {
    $16 = (($14) + ($count))|0;
    HEAP32[13784>>2] = $16;
    $18 = $16;
   }
   $17 = ($18|0)<(0);
   if (!($17)) {
    return 0;
   }
   HEAP32[13784>>2] = 0;
   return 0;
  }
  $19 = ($count|0)>(0);
  do {
   if ($19) {
    $20 = HEAP32[13784>>2]|0;
    $21 = (($20) + ($count))|0;
    $22 = HEAP32[13768>>2]|0;
    $23 = ($22|0)>(0);
    if ($23) {
     $24 = HEAP32[13440>>2]|0;
     $25 = ($24|0)==(0);
     $26 = HEAP32[13432>>2]|0;
     $27 = ($26|0)==(24408|0);
     $28 = $25 & $27;
     $29 = $28&1;
     $30 = (($22) - ($29))|0;
     $32 = $30;
    } else {
     $32 = $22;
    }
    $31 = ($21|0)>($32|0);
    if ($31) {
     HEAP32[13784>>2] = $32;
     (_rl_ding()|0);
     break;
    } else {
     HEAP32[13784>>2] = $21;
     break;
    }
   }
  } while(0);
  $33 = HEAP32[13768>>2]|0;
  $34 = ($33|0)<(0);
  if (!($34)) {
   return 0;
  }
  HEAP32[13768>>2] = 0;
  return 0;
 } else if ((($59|0) == 66)) {
  (_rl_get_next_history($count,$2)|0);
  return 0;
 } else if ((($59|0) == 68)) {
  $35 = HEAP32[36240>>2]|0;
  $36 = ($35|0)==(0);
  if ($36) {
   (_rl_backward_char($count,$2)|0);
   return 0;
  }
  $37 = ($count|0)<(0);
  if ($37) {
   $38 = HEAP32[13784>>2]|0;
   $39 = (($38) - ($count))|0;
   $40 = HEAP32[13768>>2]|0;
   $41 = ($40|0)>(0);
   if ($41) {
    $42 = HEAP32[13440>>2]|0;
    $43 = ($42|0)==(0);
    $44 = HEAP32[13432>>2]|0;
    $45 = ($44|0)==(24408|0);
    $46 = $43 & $45;
    $47 = $46&1;
    $48 = (($40) - ($47))|0;
    $50 = $48;
   } else {
    $50 = $40;
   }
   $49 = ($39|0)>($50|0);
   if ($49) {
    HEAP32[13784>>2] = $50;
    (_rl_ding()|0);
   } else {
    HEAP32[13784>>2] = $39;
   }
   $51 = HEAP32[13768>>2]|0;
   $52 = ($51|0)<(0);
   if (!($52)) {
    return 0;
   }
   HEAP32[13768>>2] = 0;
   return 0;
  } else {
   $53 = ($count|0)>(0);
   do {
    if ($53) {
     $54 = HEAP32[13784>>2]|0;
     $55 = ($54|0)<($count|0);
     if ($55) {
      HEAP32[13784>>2] = 0;
      (_rl_ding()|0);
      label = 37;
      break;
     } else {
      $56 = (($54) - ($count))|0;
      HEAP32[13784>>2] = $56;
      $58 = $56;
      break;
     }
    } else {
     label = 37;
    }
   } while(0);
   if ((label|0) == 37) {
    $$pr$i1 = HEAP32[13784>>2]|0;
    $58 = $$pr$i1;
   }
   $57 = ($58|0)<(0);
   if (!($57)) {
    return 0;
   }
   HEAP32[13784>>2] = 0;
   return 0;
  }
 } else if ((($59|0) == 65)) {
  (_rl_get_previous_history($count,$2)|0);
  return 0;
 } else {
  (_rl_ding()|0);
  return 0;
 }
 return (0)|0;
}
function __rl_insert_char($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$1$off = 0, $$24 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $i$0$lcssa = 0, $i$03 = 0, $i$17 = 0, $incoming = 0;
 var $incoming_length$0 = 0, $str = 0, $wc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $incoming = sp + 6|0;
 $wc = sp;
 $str = sp + 4|0;
 $0 = ($count|0)<(1);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $1 = HEAP32[36240>>2]|0;
 $2 = ($1|0)==(0);
 do {
  if ($2) {
   $5 = HEAP32[35928>>2]|0;
   $6 = ($5|0)<(1);
   if ($6) {
    HEAP32[35928>>2] = $count;
    $$02 = $count;
   } else {
    $$02 = $5;
   }
   $7 = 35936;
   $8 = $7;
   $9 = HEAP32[$8>>2]|0;
   $10 = (($7) + 4)|0;
   $11 = $10;
   $12 = HEAP32[$11>>2]|0;
   $13 = $c&255;
   $14 = HEAP32[35944>>2]|0;
   $15 = (($14) + 1)|0;
   HEAP32[35944>>2] = $15;
   $16 = (35952 + ($14)|0);
   HEAP8[$16>>0] = $13;
   $17 = (_mbrtowc($wc,35952,$15,35936)|0);
   if ((($17|0) == -2)) {
    $18 = 35936;
    $19 = $18;
    HEAP32[$19>>2] = $9;
    $20 = (($18) + 4)|0;
    $21 = $20;
    HEAP32[$21>>2] = $12;
    $$0 = 1;
    STACKTOP = sp;return ($$0|0);
   } else if ((($17|0) == 0)) {
    HEAP8[$incoming>>0] = 0;
    $30 = HEAP32[35944>>2]|0;
    $31 = (($30) + -1)|0;
    HEAP32[35944>>2] = $31;
    $32 = 35936;
    $33 = $32;
    HEAP32[$33>>2] = 0;
    $34 = (($32) + 4)|0;
    $35 = $34;
    HEAP32[$35>>2] = 0;
    $$1 = $$02;$incoming_length$0 = 0;
    break;
   } else if ((($17|0) == -1)) {
    $22 = HEAP8[35952>>0]|0;
    HEAP8[$incoming>>0] = $22;
    $23 = ((($incoming)) + 1|0);
    HEAP8[$23>>0] = 0;
    $24 = HEAP32[35944>>2]|0;
    $25 = (($24) + -1)|0;
    HEAP32[35944>>2] = $25;
    _memmove((35952|0),((35953)|0),($25|0))|0;
    $26 = 35936;
    $27 = $26;
    HEAP32[$27>>2] = 0;
    $28 = (($26) + 4)|0;
    $29 = $28;
    HEAP32[$29>>2] = 0;
    $$1 = $$02;$incoming_length$0 = 1;
    break;
   } else {
    $36 = HEAP32[35944>>2]|0;
    _memcpy(($incoming|0),(35952|0),($36|0))|0;
    $37 = (($incoming) + ($36)|0);
    HEAP8[$37>>0] = 0;
    HEAP32[35944>>2] = 0;
    $$1 = $$02;$incoming_length$0 = $36;
    break;
   }
  } else {
   $3 = $c&255;
   HEAP8[$incoming>>0] = $3;
   $4 = ((($incoming)) + 1|0);
   HEAP8[$4>>0] = 0;
   $$1 = $count;$incoming_length$0 = 1;
  }
 } while(0);
 $$1$off = (($$1) + -2)|0;
 $38 = ($$1$off>>>0)<(1023);
 if ($38) {
  $39 = Math_imul($$1, $incoming_length$0)|0;
  $40 = (($39) + 1)|0;
  $41 = (_xmalloc($40)|0);
  $42 = ($39|0)>(0);
  if ($42) {
   $i$03 = 0;
   while(1) {
    $43 = (($41) + ($i$03)|0);
    (_strncpy(($43|0),($incoming|0),($incoming_length$0|0))|0);
    $44 = (($i$03) + ($incoming_length$0))|0;
    $45 = ($44|0)<($39|0);
    if ($45) {
     $i$03 = $44;
    } else {
     $i$0$lcssa = $44;
     break;
    }
   }
  } else {
   $i$0$lcssa = 0;
  }
  HEAP32[35928>>2] = 0;
  $46 = (($41) + ($i$0$lcssa)|0);
  HEAP8[$46>>0] = 0;
  (_rl_insert_text($41)|0);
  _xfree($41);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $47 = ($$1|0)>(1024);
 if ($47) {
  $48 = $incoming_length$0 << 10;
  $49 = $48 | 1;
  $50 = (_xmalloc($49)|0);
  $51 = ($incoming_length$0|0)>(0);
  if ($51) {
   $i$17 = 0;
   while(1) {
    $53 = (($50) + ($i$17)|0);
    (_strncpy(($53|0),($incoming|0),($incoming_length$0|0))|0);
    $54 = (($i$17) + ($incoming_length$0))|0;
    $55 = ($54|0)<($48|0);
    if ($55) {
     $i$17 = $54;
    } else {
     break;
    }
   }
   $52 = ($$1|0)==(0);
   if (!($52)) {
    $$24 = $$1;
    label = 21;
   }
  } else {
   $$24 = $$1;
   label = 21;
  }
  if ((label|0) == 21) {
   while(1) {
    label = 0;
    $56 = ($$24|0)>(1024);
    $57 = $56 ? 1024 : $$24;
    $58 = Math_imul($57, $incoming_length$0)|0;
    $59 = (($50) + ($58)|0);
    HEAP8[$59>>0] = 0;
    (_rl_insert_text($50)|0);
    $60 = (($$24) - ($57))|0;
    $61 = ($$24|0)==($57|0);
    if ($61) {
     break;
    } else {
     $$24 = $60;
     label = 21;
    }
   }
  }
  _xfree($50);
  HEAP32[35928>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $62 = HEAP32[36240>>2]|0;
 $63 = ($62|0)==(0);
 if ($63) {
  (_rl_insert_text($incoming)|0);
  HEAP32[35928>>2] = 0;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $64 = HEAP32[13488>>2]|0;
 $65 = $64 & 2048;
 $66 = ($65|0)==(0);
 if ($66) {
  $67 = (__rl_pushed_input_available()|0);
  $68 = ($67|0)==(0);
  if (!($68)) {
   __rl_insert_typein($c);
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $69 = ((($str)) + 1|0);
 HEAP8[$69>>0] = 0;
 $70 = $c&255;
 HEAP8[$str>>0] = $70;
 (_rl_insert_text($str)|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __rl_overwrite_char($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $exitcond = 0, $i$02 = 0, $mbkey = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mbkey = sp;
 $0 = ($count|0)>(0);
 $1 = HEAP32[36240>>2]|0;
 $2 = ($1|0)==(0);
 $or$cond = $0 & $2;
 if ($or$cond) {
  (__rl_read_mbstring($c,$mbkey,16)|0);
 }
 (_rl_begin_undo_group()|0);
 if (!($0)) {
  (_rl_end_undo_group()|0);
  STACKTOP = sp;return 0;
 }
 $i$02 = 0;
 while(1) {
  $3 = HEAP32[36240>>2]|0;
  $4 = ($3|0)==(0);
  if ($4) {
   (_rl_insert_text($mbkey)|0);
  } else {
   (__rl_insert_char(1,$c)|0);
  }
  $5 = HEAP32[13784>>2]|0;
  $6 = HEAP32[13768>>2]|0;
  $7 = ($5|0)<($6|0);
  if ($7) {
   (_rl_delete(1,$c)|0);
  }
  $8 = (($i$02) + 1)|0;
  $exitcond = ($8|0)==($count|0);
  if ($exitcond) {
   break;
  } else {
   $i$02 = $8;
  }
 }
 (_rl_end_undo_group()|0);
 STACKTOP = sp;return 0;
}
function _rl_delete($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = (__rl_rubout_char($1,$key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13784>>2]|0;
 $4 = HEAP32[13768>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $6 = ($count|0)>(1);
 $7 = HEAP32[13472>>2]|0;
 $8 = ($7|0)!=(0);
 $or$cond = $6 | $8;
 $9 = HEAP32[36240>>2]|0;
 $10 = ($9|0)==(0);
 if (!($or$cond)) {
  if ($10) {
   $26 = HEAP32[13632>>2]|0;
   $27 = (__rl_find_next_mbchar($26,$3,1,1)|0);
   $$pre = HEAP32[13784>>2]|0;
   $29 = $$pre;$30 = $27;
  } else {
   $28 = (($3) + 1)|0;
   $29 = $3;$30 = $28;
  }
  (_rl_delete_text($29,$30)|0);
  $$0 = 0;
  return ($$0|0);
 }
 if ($10) {
  (_rl_forward_char($count,$key)|0);
 } else {
  $11 = ($count|0)>(0);
  do {
   if ($11) {
    $12 = (($3) + ($count))|0;
    $13 = ($4|0)>(0);
    if ($13) {
     $14 = HEAP32[13440>>2]|0;
     $15 = ($14|0)==(0);
     $16 = HEAP32[13432>>2]|0;
     $17 = ($16|0)==(24408|0);
     $18 = $15 & $17;
     $19 = $18&1;
     $20 = (($4) - ($19))|0;
     $22 = $20;
    } else {
     $22 = $4;
    }
    $21 = ($12|0)>($22|0);
    if ($21) {
     HEAP32[13784>>2] = $22;
     (_rl_ding()|0);
     $$pre2 = HEAP32[13768>>2]|0;
     $24 = $$pre2;
     break;
    } else {
     HEAP32[13784>>2] = $12;
     $24 = $4;
     break;
    }
   } else {
    $24 = $4;
   }
  } while(0);
  $23 = ($24|0)<(0);
  if ($23) {
   HEAP32[13768>>2] = 0;
  }
 }
 $25 = HEAP32[13784>>2]|0;
 (_rl_kill_text($3,$25)|0);
 HEAP32[13784>>2] = $3;
 $$0 = 0;
 return ($$0|0);
}
function _rl_insert($count,$c) {
 $count = $count|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13448>>2]|0;
 $1 = ($0|0)==(1);
 if ($1) {
  $2 = (__rl_insert_char($count,$c)|0);
  $3 = $2;
  return ($3|0);
 } else {
  (__rl_overwrite_char($count,$c)|0);
  $3 = 0;
  return ($3|0);
 }
 return (0)|0;
}
function _rl_quoted_insert($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pre = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 524288;
 $2 = ($1|0)==(0);
 if ($2) {
  (__rl_disable_tty_signals()|0);
  $$pre = HEAP32[13488>>2]|0;
  $4 = $$pre;
 } else {
  $4 = $0;
 }
 $3 = $4 & 524288;
 $5 = ($3|0)==(0);
 if (!($5)) {
  $6 = (__rl_callback_data_alloc($count)|0);
  HEAP32[35064>>2] = $6;
  HEAP32[35056>>2] = 371;
  $$0 = 0;
  return ($$0|0);
 }
 $7 = $4 | 64;
 HEAP32[13488>>2] = $7;
 $8 = (_rl_read_key()|0);
 $9 = HEAP32[13488>>2]|0;
 $10 = $9 & -65;
 HEAP32[13488>>2] = $10;
 $11 = ($8|0)<(0);
 if ($11) {
  $$0 = -1;
  return ($$0|0);
 }
 $12 = $9 & 4096;
 $13 = ($12|0)==(0);
 if ($13) {
  $15 = $10;
 } else {
  __rl_add_macro_char($8);
  $$pre$i = HEAP32[13488>>2]|0;
  $15 = $$pre$i;
 }
 $14 = $15 & 524288;
 $16 = ($14|0)==(0);
 if ($16) {
  (__rl_restore_tty_signals()|0);
 }
 $17 = (__rl_insert_char($count,$8)|0);
 $$0 = $17;
 return ($$0|0);
}
function _rl_tab_insert($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__rl_insert_char($count,9)|0);
 return ($0|0);
}
function _rl_newline($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13776>>2] = 1;
 $0 = HEAP32[36032>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = HEAP32[13784>>2]|0;
  $3 = HEAP32[13768>>2]|0;
  $4 = ($2|0)==($3|0);
  $5 = $4 ? -1 : $2;
  HEAP32[36040>>2] = $5;
 }
 $6 = HEAP32[13488>>2]|0;
 $7 = $6 | 16777216;
 HEAP32[13488>>2] = $7;
 $8 = HEAP32[13440>>2]|0;
 $9 = ($8|0)==(0);
 if ($9) {
  __rl_vi_done_inserting();
  $10 = HEAP32[14128>>2]|0;
  $11 = (__rl_vi_textmod_command($10)|0);
  $12 = ($11|0)==(0);
  if ($12) {
   __rl_vi_reset_last();
  }
 }
 $13 = HEAP32[13624>>2]|0;
 $14 = ($13|0)!=(0);
 $15 = HEAP32[13784>>2]|0;
 $16 = HEAP32[13768>>2]|0;
 $17 = $16 | $15;
 $18 = ($17|0)==(0);
 $19 = $14 & $18;
 $20 = HEAP32[13520>>2]|0;
 $21 = ($20|0)==(0);
 $or$cond = $21 | $19;
 if ($or$cond) {
  return 0;
 }
 __rl_update_final();
 return 0;
}
function _rl_do_lowercase_version($ignore1,$ignore2) {
 $ignore1 = $ignore1|0;
 $ignore2 = $ignore2|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 return 0;
}
function __rl_overwrite_rubout($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$pr$i$i = 0, $$pre = 0, $$pre7 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$03 = 0, $l$0$lcssa = 0, $l$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  (_rl_ding()|0);
  $$0 = 1;
  return ($$0|0);
 }
 $2 = ($count|0)>(0);
 L5: do {
  if ($2) {
   $6 = $0;$i$03 = 0;$l$04 = 0;
   while(1) {
    $3 = HEAP32[36240>>2]|0;
    $4 = ($3|0)==(0);
    do {
     if ($4) {
      $9 = ($6|0)>(0);
      if ($9) {
       $10 = HEAP32[13632>>2]|0;
       $11 = (__rl_find_prev_mbchar($10,$6,1)|0);
       HEAP32[13784>>2] = $11;
       $14 = $11;
       break;
      } else {
       HEAP32[13784>>2] = 0;
       (_rl_ding()|0);
       $$pre7 = HEAP32[13784>>2]|0;
       $14 = $$pre7;
       break;
      }
     } else {
      $5 = ($6|0)<(1);
      if (!($5)) {
       $7 = (($6) + -1)|0;
       HEAP32[13784>>2] = $7;
       $14 = $7;
       break;
      }
      HEAP32[13784>>2] = 0;
      (_rl_ding()|0);
      $$pr$i$i = HEAP32[13784>>2]|0;
      $8 = ($$pr$i$i|0)<(0);
      if ($8) {
       HEAP32[13784>>2] = 0;
       $14 = 0;
      } else {
       $14 = $$pr$i$i;
      }
     }
    } while(0);
    $12 = HEAP32[13632>>2]|0;
    $13 = (($12) + ($14)|0);
    $15 = HEAP8[$13>>0]|0;
    $16 = $15 << 24 >> 24;
    $17 = (_rl_character_len($16,$14)|0);
    $18 = (($17) + ($l$04))|0;
    $19 = (($i$03) + 1)|0;
    $exitcond = ($19|0)==($count|0);
    if ($exitcond) {
     $l$0$lcssa = $18;
     break L5;
    }
    $$pre = HEAP32[13784>>2]|0;
    $6 = $$pre;$i$03 = $19;$l$04 = $18;
   }
  } else {
   $l$0$lcssa = 0;
  }
 } while(0);
 (_rl_begin_undo_group()|0);
 $20 = ($count|0)>(1);
 $21 = HEAP32[13472>>2]|0;
 $22 = ($21|0)!=(0);
 $or$cond = $20 | $22;
 $23 = HEAP32[13784>>2]|0;
 if ($or$cond) {
  (_rl_kill_text($0,$23)|0);
 } else {
  (_rl_delete_text($0,$23)|0);
 }
 $24 = HEAP32[13784>>2]|0;
 $25 = HEAP32[13768>>2]|0;
 $26 = ($24|0)<($25|0);
 if ($26) {
  (__rl_insert_char($l$0$lcssa,32)|0);
  HEAP32[13784>>2] = $24;
 }
 (_rl_end_undo_group()|0);
 $$0 = 0;
 return ($$0|0);
}
function _rl_rubout($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = (_rl_delete($1,$key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $5 = HEAP32[13448>>2]|0;
 $6 = ($5|0)==(0);
 if ($6) {
  $7 = (__rl_overwrite_rubout($count,$key)|0);
  $$0 = $7;
  return ($$0|0);
 } else {
  $8 = (__rl_rubout_char($count,$key)|0);
  $$0 = $8;
  return ($$0|0);
 }
 return (0)|0;
}
function __rl_rubout_char($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  $2 = (_rl_delete($1,$key)|0);
  $$0 = $2;
  return ($$0|0);
 }
 $3 = HEAP32[13784>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 $5 = ($count|0)>(1);
 $6 = HEAP32[13472>>2]|0;
 $7 = ($6|0)!=(0);
 $or$cond = $5 | $7;
 if ($or$cond) {
  (_rl_backward_char($count,$key)|0);
  $8 = HEAP32[13784>>2]|0;
  (_rl_kill_text($3,$8)|0);
  $$0 = 0;
  return ($$0|0);
 }
 $9 = HEAP32[36240>>2]|0;
 $10 = ($9|0)==(0);
 if ($10) {
  $25 = HEAP32[13632>>2]|0;
  $26 = (__rl_find_prev_mbchar($25,$3,1)|0);
  HEAP32[13784>>2] = $26;
  (_rl_delete_text($26,$3)|0);
  $$0 = 0;
  return ($$0|0);
 }
 $11 = (($3) + -1)|0;
 HEAP32[13784>>2] = $11;
 $12 = HEAP32[13632>>2]|0;
 $13 = (($12) + ($11)|0);
 $14 = HEAP8[$13>>0]|0;
 (_rl_delete_text($11,$3)|0);
 $15 = HEAP32[13784>>2]|0;
 $16 = HEAP32[13768>>2]|0;
 $17 = ($15|0)==($16|0);
 if (!($17)) {
  $$0 = 0;
  return ($$0|0);
 }
 $18 = $14&255;
 $19 = (_isprint($18)|0);
 $20 = ($19|0)!=(0);
 $21 = HEAP32[32280>>2]|0;
 $22 = ($21|0)!=(0);
 $or$cond3 = $20 & $22;
 if (!($or$cond3)) {
  $$0 = 0;
  return ($$0|0);
 }
 $23 = HEAP32[13784>>2]|0;
 $24 = (_rl_character_len($18,$23)|0);
 __rl_erase_at_end_of_line($24);
 $$0 = 0;
 return ($$0|0);
}
function _rl_rubout_or_delete($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13768>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[13784>>2]|0;
 $3 = ($2|0)==($0|0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  $4 = (__rl_rubout_char($count,$key)|0);
  $$0 = $4;
  return ($$0|0);
 } else {
  $5 = (_rl_delete($count,$key)|0);
  $$0 = $5;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_delete_horizontal_space($count,$ignore) {
 $count = $count|0;
 $ignore = $ignore|0;
 var $$pr = 0, $$pre = 0, $$pre5 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $$pr = HEAP32[13784>>2]|0;
 $0 = ($$pr|0)==(0);
 L1: do {
  if ($0) {
   $7 = 0;
  } else {
   $$pre = HEAP32[13632>>2]|0;
   $2 = $$pr;
   while(1) {
    $1 = (($2) + -1)|0;
    $3 = (($$pre) + ($1)|0);
    $4 = HEAP8[$3>>0]|0;
    if (!((($4<<24>>24) == 9) | (($4<<24>>24) == 32))) {
     $7 = $2;
     break L1;
    }
    HEAP32[13784>>2] = $1;
    $8 = ($1|0)==(0);
    if ($8) {
     $7 = 0;
     break;
    } else {
     $2 = $1;
    }
   }
  }
 } while(0);
 $5 = HEAP32[13768>>2]|0;
 $6 = ($7|0)<($5|0);
 L7: do {
  if ($6) {
   $$pre5 = HEAP32[13632>>2]|0;
   $10 = $7;
   while(1) {
    $9 = (($$pre5) + ($10)|0);
    $11 = HEAP8[$9>>0]|0;
    if (!((($11<<24>>24) == 9) | (($11<<24>>24) == 32))) {
     $15 = $10;
     break L7;
    }
    $12 = (($10) + 1)|0;
    HEAP32[13784>>2] = $12;
    $13 = ($12|0)<($5|0);
    if ($13) {
     $10 = $12;
    } else {
     $15 = $12;
     break;
    }
   }
  } else {
   $15 = $7;
  }
 } while(0);
 $14 = ($7|0)==($15|0);
 if (!($14)) {
  (_rl_delete_text($7,$15)|0);
  HEAP32[13784>>2] = $7;
 }
 $16 = ($7|0)<(0);
 if (!($16)) {
  return 0;
 }
 HEAP32[13784>>2] = 0;
 return 0;
}
function _rl_delete_or_show_completions($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13768>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[13784>>2]|0;
 $3 = ($2|0)==($0|0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  $4 = (_rl_possible_completions($count,$key)|0);
  $$0 = $4;
  return ($$0|0);
 } else {
  $5 = (_rl_delete($count,$key)|0);
  $$0 = $5;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_insert_comment($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13784>>2] = 0;
 $0 = HEAP32[13992>>2]|0;
 $1 = ($0|0)!=(0|0);
 $2 = $1 ? $0 : 35968;
 $3 = HEAP32[13472>>2]|0;
 $4 = ($3|0)==(0);
 L1: do {
  if ($4) {
   (_rl_insert_text($2)|0);
  } else {
   $5 = (_strlen(($2|0))|0);
   $6 = ($5|0)==(0);
   do {
    if (!($6)) {
     $7 = HEAP8[$2>>0]|0;
     $8 = HEAP32[13632>>2]|0;
     $9 = HEAP8[$8>>0]|0;
     $10 = ($7<<24>>24)==($9<<24>>24);
     if ($10) {
      $11 = (_strncmp($2,$8,$5)|0);
      $12 = ($11|0)==(0);
      if ($12) {
       break;
      }
     }
     (_rl_insert_text($2)|0);
     break L1;
    }
   } while(0);
   (_rl_delete_text(0,$5)|0);
  }
 } while(0);
 $13 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$13 & 511]();
 HEAP32[13776>>2] = 1;
 $14 = HEAP32[36032>>2]|0;
 $15 = ($14|0)==(0);
 if (!($15)) {
  $16 = HEAP32[13784>>2]|0;
  $17 = HEAP32[13768>>2]|0;
  $18 = ($16|0)==($17|0);
  $19 = $18 ? -1 : $16;
  HEAP32[36040>>2] = $19;
 }
 $20 = HEAP32[13488>>2]|0;
 $21 = $20 | 16777216;
 HEAP32[13488>>2] = $21;
 $22 = HEAP32[13440>>2]|0;
 $23 = ($22|0)==(0);
 if ($23) {
  __rl_vi_done_inserting();
  $24 = HEAP32[14128>>2]|0;
  $25 = (__rl_vi_textmod_command($24)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   __rl_vi_reset_last();
  }
 }
 $27 = HEAP32[13624>>2]|0;
 $28 = ($27|0)!=(0);
 $29 = HEAP32[13784>>2]|0;
 $30 = HEAP32[13768>>2]|0;
 $31 = $30 | $29;
 $32 = ($31|0)==(0);
 $33 = $28 & $32;
 $34 = HEAP32[13520>>2]|0;
 $35 = ($34|0)==(0);
 $or$cond$i = $35 | $33;
 if ($or$cond$i) {
  return 0;
 }
 __rl_update_final();
 return 0;
}
function _rl_upcase_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_change_case($count,1)|0);
 return ($0|0);
}
function _rl_downcase_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_change_case($count,2)|0);
 return ($0|0);
}
function _rl_capitalize_word($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_rl_change_case($count,3)|0);
 return ($0|0);
}
function _rl_transpose_words($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13784>>2]|0;
 $1 = ($count|0)==(0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 (_rl_forward_word($count,$key)|0);
 $2 = HEAP32[13784>>2]|0;
 (_rl_backward_word(1,$key)|0);
 $3 = HEAP32[13784>>2]|0;
 (_rl_backward_word($count,$key)|0);
 $4 = HEAP32[13784>>2]|0;
 (_rl_forward_word(1,$key)|0);
 $5 = HEAP32[13784>>2]|0;
 $6 = ($4|0)==($3|0);
 $7 = ($3|0)<($5|0);
 $or$cond = $6 | $7;
 if ($or$cond) {
  (_rl_ding()|0);
  HEAP32[13784>>2] = $0;
  $$0 = -1;
  return ($$0|0);
 } else {
  $8 = (_rl_copy_text($4,$5)|0);
  $9 = (_rl_copy_text($3,$2)|0);
  (_rl_begin_undo_group()|0);
  HEAP32[13784>>2] = $3;
  (_rl_delete_text($3,$2)|0);
  (_rl_insert_text($8)|0);
  HEAP32[13784>>2] = $4;
  (_rl_delete_text($4,$5)|0);
  (_rl_insert_text($9)|0);
  HEAP32[13784>>2] = $2;
  (_rl_end_undo_group()|0);
  _xfree($8);
  _xfree($9);
  $$0 = 0;
  return ($$0|0);
 }
 return (0)|0;
}
function _rl_transpose_chars($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$lcssa = 0, $i$03 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)==(0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP32[13784>>2]|0;
 $2 = ($1|0)==(0);
 $3 = HEAP32[13768>>2]|0;
 $4 = ($3|0)<(2);
 $or$cond = $2 | $4;
 if ($or$cond) {
  (_rl_ding()|0);
  $$0 = -1;
  return ($$0|0);
 }
 (_rl_begin_undo_group()|0);
 $5 = HEAP32[13784>>2]|0;
 $6 = HEAP32[13768>>2]|0;
 $7 = ($5|0)==($6|0);
 if ($7) {
  $8 = HEAP32[36240>>2]|0;
  $9 = ($8|0)==(0);
  if ($9) {
   $10 = HEAP32[13632>>2]|0;
   $11 = (__rl_find_prev_mbchar($10,$5,1)|0);
   $13 = $11;
  } else {
   $12 = (($5) + -1)|0;
   $13 = $12;
  }
  HEAP32[13784>>2] = $13;
  $$02 = 1;$17 = $13;
 } else {
  $$02 = $count;$17 = $5;
 }
 $14 = HEAP32[36240>>2]|0;
 $15 = ($14|0)==(0);
 if ($15) {
  $16 = HEAP32[13632>>2]|0;
  $18 = (__rl_find_prev_mbchar($16,$17,1)|0);
  $20 = $18;
 } else {
  $19 = (($17) + -1)|0;
  $20 = $19;
 }
 HEAP32[13784>>2] = $20;
 $21 = (($17) - ($20))|0;
 $22 = (($21) + 1)|0;
 $23 = (_xmalloc($22)|0);
 $24 = ($21|0)>(0);
 if ($24) {
  $i$03 = 0;
  while(1) {
   $25 = HEAP32[13784>>2]|0;
   $26 = (($25) + ($i$03))|0;
   $27 = HEAP32[13632>>2]|0;
   $28 = (($27) + ($26)|0);
   $29 = HEAP8[$28>>0]|0;
   $30 = (($23) + ($i$03)|0);
   HEAP8[$30>>0] = $29;
   $31 = (($i$03) + 1)|0;
   $exitcond = ($31|0)==($21|0);
   if ($exitcond) {
    $i$0$lcssa = $21;
    break;
   } else {
    $i$03 = $31;
   }
  }
 } else {
  $i$0$lcssa = 0;
 }
 $32 = (($23) + ($i$0$lcssa)|0);
 HEAP8[$32>>0] = 0;
 $33 = HEAP32[13784>>2]|0;
 $34 = (($33) + ($21))|0;
 (_rl_delete_text($33,$34)|0);
 $35 = HEAP32[13632>>2]|0;
 $36 = HEAP32[13784>>2]|0;
 $37 = (__rl_find_next_mbchar($35,$36,$$02,1)|0);
 HEAP32[13784>>2] = $37;
 $38 = HEAP32[13768>>2]|0;
 $39 = ($37|0)>($38|0);
 if ($39) {
  HEAP32[13784>>2] = $38;
 } else {
  $40 = ($37|0)<(0);
  if ($40) {
   HEAP32[13784>>2] = 0;
  }
 }
 (_rl_insert_text($23)|0);
 (_rl_end_undo_group()|0);
 _xfree($23);
 $$0 = 0;
 return ($$0|0);
}
function __rl_char_search_internal($count,$dir,$smbchar,$len) {
 $count = $count|0;
 $dir = $dir|0;
 $smbchar = $smbchar|0;
 $len = $len|0;
 var $$0 = 0, $$02$ph9 = 0, $$sink = 0, $$sink$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0;
 var $or$cond24 = 0, $or$cond4 = 0, $pos$0$ph8 = 0, $pos$07$be = 0, $pos$0725 = 0, $pos$1 = 0, $pos$1$lcssa = 0, $pos$1$ph = 0, $pos$1$us = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($dir|0)==(0);
 if ($0) {
  $$0 = -1;
  return ($$0|0);
 }
 $1 = ($dir|0)<(0);
 $2 = ($count|0)==(0);
 if ($2) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = $dir >> 31;
 $4 = $3 | 1;
 $5 = HEAP32[13784>>2]|0;
 $6 = ($dir|0)<(1);
 $7 = ($4|0)>(0);
 $8 = ($dir|0)==(-1);
 $9 = ($dir|0)==(1);
 $$02$ph9 = $count;$pos$0$ph8 = $5;
 L7: while(1) {
  $10 = ($pos$0$ph8|0)<(1);
  $or$cond24 = $1 & $10;
  if ($or$cond24) {
   break;
  } else {
   $pos$0725 = $pos$0$ph8;
  }
  L9: while(1) {
   $12 = HEAP32[13768>>2]|0;
   $13 = ($pos$0725|0)<($12|0);
   $or$cond4 = $6 | $13;
   if (!($or$cond4)) {
    break L7;
   }
   $14 = HEAP32[13632>>2]|0;
   if ($7) {
    $15 = (__rl_find_next_mbchar($14,$pos$0725,1,0)|0);
    $pos$1$ph = $15;
   } else {
    $16 = (__rl_find_prev_mbchar($14,$pos$0725,0)|0);
    $pos$1$ph = $16;
   }
   if ($1) {
    $pos$1$us = $pos$1$ph;
    while(1) {
     $17 = HEAP32[13632>>2]|0;
     $18 = HEAP32[13768>>2]|0;
     $19 = (__rl_is_mbchar_matched($17,$pos$1$us,$18,$smbchar,$len)|0);
     $20 = ($19|0)==(0);
     if (!($20)) {
      $pos$1$lcssa = $pos$1$us;
      break L9;
     }
     $21 = HEAP32[13632>>2]|0;
     $22 = (__rl_find_prev_mbchar($21,$pos$1$us,0)|0);
     $$sink$us = ($22|0)==($pos$1$us|0);
     if ($$sink$us) {
      $pos$07$be = $pos$1$us;
      break;
     } else {
      $pos$1$us = $22;
     }
    }
   } else {
    $pos$1 = $pos$1$ph;
    while(1) {
     $23 = HEAP32[13632>>2]|0;
     $24 = HEAP32[13768>>2]|0;
     $25 = (__rl_is_mbchar_matched($23,$pos$1,$24,$smbchar,$len)|0);
     $26 = ($25|0)==(0);
     if (!($26)) {
      $pos$1$lcssa = $pos$1;
      break L9;
     }
     $33 = HEAP32[13632>>2]|0;
     $34 = (__rl_find_next_mbchar($33,$pos$1,1,0)|0);
     $$sink = ($34|0)==($pos$1|0);
     if ($$sink) {
      $pos$07$be = $pos$1;
      break;
     } else {
      $pos$1 = $34;
     }
    }
   }
   $11 = ($pos$07$be|0)<(1);
   $or$cond = $1 & $11;
   if ($or$cond) {
    break L7;
   } else {
    $pos$0725 = $pos$07$be;
   }
  }
  $27 = (($$02$ph9) + -1)|0;
  if ($1) {
   if ($8) {
    $28 = HEAP32[13632>>2]|0;
    $29 = (__rl_find_next_mbchar($28,$pos$1$lcssa,1,0)|0);
    $storemerge = $29;
   } else {
    $storemerge = $pos$1$lcssa;
   }
  } else {
   if ($9) {
    $31 = HEAP32[13632>>2]|0;
    $32 = (__rl_find_prev_mbchar($31,$pos$1$lcssa,0)|0);
    $storemerge = $32;
   } else {
    $storemerge = $pos$1$lcssa;
   }
  }
  HEAP32[13784>>2] = $storemerge;
  $30 = ($27|0)==(0);
  if ($30) {
   $$0 = 0;
   label = 22;
   break;
  } else {
   $$02$ph9 = $27;$pos$0$ph8 = $pos$1$lcssa;
  }
 }
 if ((label|0) == 22) {
  return ($$0|0);
 }
 (_rl_ding()|0);
 $$0 = -1;
 return ($$0|0);
}
function _rl_char_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$0$i = 0, $$02$ph9$i = 0, $$02$ph9$i3 = 0, $$sink$i = 0, $$sink$us$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mbchar$i = 0, $pos$0$ph8$i = 0, $pos$0$ph8$i4 = 0, $pos$07$i15 = 0, $pos$07$i614 = 0, $pos$1$i = 0, $pos$1$i$lcssa = 0, $pos$1$i$lcssa35 = 0, $pos$1$us$i = 0, $pos$1$us$i$lcssa = 0, $pos$1$us$i$lcssa34 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mbchar$i = sp;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 524288;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (__rl_callback_data_alloc($count)|0);
  HEAP32[35064>>2] = $3;
  $4 = ((($3)) + 4|0);
  HEAP32[$4>>2] = 2;
  $5 = ((($3)) + 8|0);
  HEAP32[$5>>2] = -2;
  HEAP32[35056>>2] = 372;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__rl_read_mbchar($mbchar$i,16)|0);
 $7 = ($6|0)<(1);
 L5: do {
  if ($7) {
   $$0$i = -1;
  } else {
   $8 = ($count|0)<(0);
   if ($8) {
    $9 = (0 - ($count))|0;
    $10 = HEAP32[13784>>2]|0;
    $$02$ph9$i3 = $9;$pos$0$ph8$i4 = $10;
    L9: while(1) {
     $11 = ($pos$0$ph8$i4|0)<(1);
     if ($11) {
      break;
     } else {
      $pos$07$i614 = $pos$0$ph8$i4;
     }
     L11: while(1) {
      $13 = HEAP32[13632>>2]|0;
      $14 = (__rl_find_prev_mbchar($13,$pos$07$i614,0)|0);
      $pos$1$us$i = $14;
      while(1) {
       $15 = HEAP32[13632>>2]|0;
       $16 = HEAP32[13768>>2]|0;
       $17 = (__rl_is_mbchar_matched($15,$pos$1$us$i,$16,$mbchar$i,$6)|0);
       $18 = ($17|0)==(0);
       if (!($18)) {
        $pos$1$us$i$lcssa = $pos$1$us$i;
        break L11;
       }
       $19 = HEAP32[13632>>2]|0;
       $20 = (__rl_find_prev_mbchar($19,$pos$1$us$i,0)|0);
       $$sink$us$i = ($20|0)==($pos$1$us$i|0);
       if ($$sink$us$i) {
        $pos$1$us$i$lcssa34 = $pos$1$us$i;
        break;
       } else {
        $pos$1$us$i = $20;
       }
      }
      $12 = ($pos$1$us$i$lcssa34|0)<(1);
      if ($12) {
       break L9;
      } else {
       $pos$07$i614 = $pos$1$us$i$lcssa34;
      }
     }
     $21 = (($$02$ph9$i3) + -1)|0;
     HEAP32[13784>>2] = $pos$1$us$i$lcssa;
     $22 = ($21|0)==(0);
     if ($22) {
      $$0$i = 0;
      break L5;
     } else {
      $$02$ph9$i3 = $21;$pos$0$ph8$i4 = $pos$1$us$i$lcssa;
     }
    }
    (_rl_ding()|0);
    $$0$i = -1;
    break;
   }
   $23 = ($count|0)==(0);
   if ($23) {
    $$0$i = 0;
   } else {
    $24 = HEAP32[13784>>2]|0;
    $$02$ph9$i = $count;$pos$0$ph8$i = $24;
    L21: while(1) {
     $25 = HEAP32[13768>>2]|0;
     $26 = ($pos$0$ph8$i|0)<($25|0);
     if ($26) {
      $pos$07$i15 = $pos$0$ph8$i;
     } else {
      break;
     }
     L23: while(1) {
      $29 = HEAP32[13632>>2]|0;
      $30 = (__rl_find_next_mbchar($29,$pos$07$i15,1,0)|0);
      $pos$1$i = $30;
      while(1) {
       $31 = HEAP32[13632>>2]|0;
       $32 = HEAP32[13768>>2]|0;
       $33 = (__rl_is_mbchar_matched($31,$pos$1$i,$32,$mbchar$i,$6)|0);
       $34 = ($33|0)==(0);
       if (!($34)) {
        $pos$1$i$lcssa = $pos$1$i;
        break L23;
       }
       $37 = HEAP32[13632>>2]|0;
       $38 = (__rl_find_next_mbchar($37,$pos$1$i,1,0)|0);
       $$sink$i = ($38|0)==($pos$1$i|0);
       if ($$sink$i) {
        $pos$1$i$lcssa35 = $pos$1$i;
        break;
       } else {
        $pos$1$i = $38;
       }
      }
      $27 = HEAP32[13768>>2]|0;
      $28 = ($pos$1$i$lcssa35|0)<($27|0);
      if ($28) {
       $pos$07$i15 = $pos$1$i$lcssa35;
      } else {
       break L21;
      }
     }
     $35 = (($$02$ph9$i) + -1)|0;
     HEAP32[13784>>2] = $pos$1$i$lcssa;
     $36 = ($35|0)==(0);
     if ($36) {
      $$0$i = 0;
      break L5;
     } else {
      $$02$ph9$i = $35;$pos$0$ph8$i = $pos$1$i$lcssa;
     }
    }
    (_rl_ding()|0);
    $$0$i = -1;
   }
  }
 } while(0);
 $$0 = $$0$i;
 STACKTOP = sp;return ($$0|0);
}
function _rl_backward_char_search($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $$0$i = 0, $$02$ph9$i = 0, $$02$ph9$i3 = 0, $$sink$i = 0, $$sink$us$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mbchar$i = 0, $pos$0$ph8$i = 0, $pos$0$ph8$i4 = 0, $pos$07$i15 = 0, $pos$07$i614 = 0, $pos$1$i = 0, $pos$1$i$lcssa = 0, $pos$1$i$lcssa34 = 0, $pos$1$us$i = 0, $pos$1$us$i$lcssa = 0, $pos$1$us$i$lcssa35 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mbchar$i = sp;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 & 524288;
 $2 = ($1|0)==(0);
 if (!($2)) {
  $3 = (__rl_callback_data_alloc($count)|0);
  HEAP32[35064>>2] = $3;
  $4 = ((($3)) + 4|0);
  HEAP32[$4>>2] = -2;
  $5 = ((($3)) + 8|0);
  HEAP32[$5>>2] = 2;
  HEAP32[35056>>2] = 372;
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $6 = (__rl_read_mbchar($mbchar$i,16)|0);
 $7 = ($6|0)<(1);
 L5: do {
  if ($7) {
   $$0$i = -1;
  } else {
   $8 = ($count|0)<(0);
   if ($8) {
    $9 = (0 - ($count))|0;
    $10 = HEAP32[13784>>2]|0;
    $$02$ph9$i3 = $9;$pos$0$ph8$i4 = $10;
    L9: while(1) {
     $11 = HEAP32[13768>>2]|0;
     $12 = ($pos$0$ph8$i4|0)<($11|0);
     if ($12) {
      $pos$07$i614 = $pos$0$ph8$i4;
     } else {
      break;
     }
     L11: while(1) {
      $15 = HEAP32[13632>>2]|0;
      $16 = (__rl_find_next_mbchar($15,$pos$07$i614,1,0)|0);
      $pos$1$i = $16;
      while(1) {
       $17 = HEAP32[13632>>2]|0;
       $18 = HEAP32[13768>>2]|0;
       $19 = (__rl_is_mbchar_matched($17,$pos$1$i,$18,$mbchar$i,$6)|0);
       $20 = ($19|0)==(0);
       if (!($20)) {
        $pos$1$i$lcssa = $pos$1$i;
        break L11;
       }
       $23 = HEAP32[13632>>2]|0;
       $24 = (__rl_find_next_mbchar($23,$pos$1$i,1,0)|0);
       $$sink$i = ($24|0)==($pos$1$i|0);
       if ($$sink$i) {
        $pos$1$i$lcssa34 = $pos$1$i;
        break;
       } else {
        $pos$1$i = $24;
       }
      }
      $13 = HEAP32[13768>>2]|0;
      $14 = ($pos$1$i$lcssa34|0)<($13|0);
      if ($14) {
       $pos$07$i614 = $pos$1$i$lcssa34;
      } else {
       break L9;
      }
     }
     $21 = (($$02$ph9$i3) + -1)|0;
     HEAP32[13784>>2] = $pos$1$i$lcssa;
     $22 = ($21|0)==(0);
     if ($22) {
      $$0$i = 0;
      break L5;
     } else {
      $$02$ph9$i3 = $21;$pos$0$ph8$i4 = $pos$1$i$lcssa;
     }
    }
    (_rl_ding()|0);
    $$0$i = -1;
    break;
   }
   $25 = ($count|0)==(0);
   if ($25) {
    $$0$i = 0;
   } else {
    $26 = HEAP32[13784>>2]|0;
    $$02$ph9$i = $count;$pos$0$ph8$i = $26;
    L21: while(1) {
     $27 = ($pos$0$ph8$i|0)<(1);
     if ($27) {
      break;
     } else {
      $pos$07$i15 = $pos$0$ph8$i;
     }
     L23: while(1) {
      $29 = HEAP32[13632>>2]|0;
      $30 = (__rl_find_prev_mbchar($29,$pos$07$i15,0)|0);
      $pos$1$us$i = $30;
      while(1) {
       $31 = HEAP32[13632>>2]|0;
       $32 = HEAP32[13768>>2]|0;
       $33 = (__rl_is_mbchar_matched($31,$pos$1$us$i,$32,$mbchar$i,$6)|0);
       $34 = ($33|0)==(0);
       if (!($34)) {
        $pos$1$us$i$lcssa = $pos$1$us$i;
        break L23;
       }
       $35 = HEAP32[13632>>2]|0;
       $36 = (__rl_find_prev_mbchar($35,$pos$1$us$i,0)|0);
       $$sink$us$i = ($36|0)==($pos$1$us$i|0);
       if ($$sink$us$i) {
        $pos$1$us$i$lcssa35 = $pos$1$us$i;
        break;
       } else {
        $pos$1$us$i = $36;
       }
      }
      $28 = ($pos$1$us$i$lcssa35|0)<(1);
      if ($28) {
       break L21;
      } else {
       $pos$07$i15 = $pos$1$us$i$lcssa35;
      }
     }
     $37 = (($$02$ph9$i) + -1)|0;
     HEAP32[13784>>2] = $pos$1$us$i$lcssa;
     $38 = ($37|0)==(0);
     if ($38) {
      $$0$i = 0;
      break L5;
     } else {
      $$02$ph9$i = $37;$pos$0$ph8$i = $pos$1$us$i$lcssa;
     }
    }
    (_rl_ding()|0);
    $$0$i = -1;
   }
  }
 } while(0);
 $$0 = $$0$i;
 STACKTOP = sp;return ($$0|0);
}
function __rl_set_mark_at_pos($position) {
 $position = $position|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13768>>2]|0;
 $1 = ($0|0)<($position|0);
 if ($1) {
  $$0 = -1;
  return ($$0|0);
 }
 HEAP32[13952>>2] = $position;
 $$0 = 0;
 return ($$0|0);
}
function _rl_set_mark($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)!=(0);
 $2 = HEAP32[13784>>2]|0;
 $3 = $1 ? $count : $2;
 $4 = HEAP32[13768>>2]|0;
 $5 = ($4|0)<($3|0);
 if ($5) {
  $$0$i = -1;
  return ($$0$i|0);
 }
 HEAP32[13952>>2] = $3;
 $$0$i = 0;
 return ($$0$i|0);
}
function _rl_exchange_point_and_mark($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13952>>2]|0;
 $1 = HEAP32[13768>>2]|0;
 $2 = ($0|0)>($1|0);
 if ($2) {
  HEAP32[13952>>2] = -1;
 } else {
  $3 = ($0|0)==(-1);
  if (!($3)) {
   $4 = HEAP32[13784>>2]|0;
   HEAP32[13784>>2] = $0;
   HEAP32[13952>>2] = $4;
   $$0 = 0;
   return ($$0|0);
  }
 }
 (_rl_ding()|0);
 $$0 = -1;
 return ($$0|0);
}
function __rl_insert_next_callback($data) {
 $data = $data|0;
 var $$0$i = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$data>>2]|0;
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $1 = HEAP32[13488>>2]|0;
 $2 = $1 | 64;
 HEAP32[13488>>2] = $2;
 $3 = (_rl_read_key()|0);
 $4 = HEAP32[13488>>2]|0;
 $5 = $4 & -65;
 HEAP32[13488>>2] = $5;
 $6 = ($3|0)<(0);
 if ($6) {
  $$0$i = -1;
  return ($$0$i|0);
 }
 $7 = $4 & 4096;
 $8 = ($7|0)==(0);
 if ($8) {
  $10 = $5;
 } else {
  __rl_add_macro_char($3);
  $$pre$i = HEAP32[13488>>2]|0;
  $10 = $$pre$i;
 }
 $9 = $10 & 524288;
 $11 = ($9|0)==(0);
 if ($11) {
  (__rl_restore_tty_signals()|0);
 }
 $12 = (__rl_insert_char($0,$3)|0);
 $$0$i = $12;
 return ($$0$i|0);
}
function _rl_change_case($count,$op) {
 $count = $count|0;
 $op = $op|0;
 var $$ = 0, $$0 = 0, $$6 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0;
 var $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $7 = 0, $8 = 0, $9 = 0, $inword$0$be = 0, $inword$07 = 0, $inword$1 = 0, $isascii = 0, $mb = 0, $mps = 0, $nop$0 = 0, $op$off = 0, $or$cond = 0, $start$18 = 0, $switch = 0;
 var $wc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $wc = sp + 8|0;
 $mb = sp + 12|0;
 $mps = sp;
 $0 = HEAP32[13784>>2]|0;
 (_rl_forward_word($count,0)|0);
 $1 = HEAP32[13784>>2]|0;
 $op$off = (($op) + -1)|0;
 $switch = ($op$off>>>0)<(3);
 if (!($switch)) {
  (_rl_ding()|0);
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ($count|0)<(0);
 $$ = $2 ? $0 : $1;
 $$6 = $2 ? $1 : $0;
 $3 = $mps;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 $5 = (($3) + 4)|0;
 $6 = $5;
 HEAP32[$6>>2] = 0;
 (_rl_modifying($$6,$$)|0);
 $7 = ($$|0)>($$6|0);
 if ($7) {
  $8 = ($op|0)==(3);
  $inword$07 = 0;$start$18 = $$6;
  while(1) {
   $9 = HEAP32[13632>>2]|0;
   $10 = (__rl_char_value($9,$start$18)|0);
   $11 = HEAP32[36240>>2]|0;
   $12 = ($11|0)==(0);
   if ($12) {
    $13 = HEAP32[13632>>2]|0;
    $14 = (__rl_find_next_mbchar($13,$start$18,1,1)|0);
    $19 = $14;
   } else {
    $15 = (($start$18) + 1)|0;
    $19 = $15;
   }
   $16 = (__rl_walphabetic($10)|0);
   $17 = ($16|0)==(0);
   do {
    if ($17) {
     $inword$0$be = 0;
    } else {
     $20 = ($inword$07|0)!=(0);
     $21 = $20 ? 2 : 1;
     $nop$0 = $8 ? $21 : $op;
     $inword$1 = $8 ? 1 : $inword$07;
     $22 = HEAP32[36240>>2]|0;
     $23 = ($22|0)!=(0);
     $isascii = ($10>>>0)<(128);
     $or$cond = $isascii | $23;
     if ($or$cond) {
      $24 = ($nop$0|0)==(1);
      $25 = $10 & 255;
      $26 = ($25|0)==($10|0);
      if ($24) {
       if ($26) {
        $27 = (_islower($10)|0);
        $28 = ($27|0)==(0);
        if ($28) {
         $34 = $10;
        } else {
         $29 = (_toupper($10)|0);
         $34 = $29;
        }
       } else {
        $34 = $10;
       }
      } else {
       if ($26) {
        $30 = (_isupper($10)|0);
        $31 = ($30|0)==(0);
        if ($31) {
         $34 = $10;
        } else {
         $32 = (_tolower($10)|0);
         $34 = $32;
        }
       } else {
        $34 = $10;
       }
      }
      $33 = $34&255;
      $35 = HEAP32[13632>>2]|0;
      $36 = (($35) + ($start$18)|0);
      HEAP8[$36>>0] = $33;
      $inword$0$be = $inword$1;
      break;
     }
     $37 = HEAP32[13632>>2]|0;
     $38 = (($37) + ($start$18)|0);
     $39 = (($$) - ($start$18))|0;
     $40 = (_mbrtowc($wc,$38,$39,$mps)|0);
     $41 = ($40>>>0)>(4294967293);
     do {
      if ($41) {
       $42 = HEAP32[13632>>2]|0;
       $43 = (($42) + ($start$18)|0);
       $44 = HEAP8[$43>>0]|0;
       $45 = $44 << 24 >> 24;
       HEAP32[$wc>>2] = $45;
       $48 = $45;
      } else {
       $46 = ($40|0)==(0);
       if ($46) {
        HEAP32[$wc>>2] = 0;
        $48 = 0;
        break;
       } else {
        $$pre = HEAP32[$wc>>2]|0;
        $48 = $$pre;
        break;
       }
      }
     } while(0);
     $47 = ($nop$0|0)==(1);
     if ($47) {
      $49 = (_iswlower($48)|0);
      $50 = ($49|0)==(0);
      $51 = HEAP32[$wc>>2]|0;
      if ($50) {
       $59 = $51;
      } else {
       $52 = (_towupper($51)|0);
       $59 = $52;
      }
     } else {
      $53 = (_iswupper($48)|0);
      $54 = ($53|0)==(0);
      $55 = HEAP32[$wc>>2]|0;
      if ($54) {
       $59 = $55;
      } else {
       $56 = (_towlower($55)|0);
       $59 = $56;
      }
     }
     $57 = HEAP32[$wc>>2]|0;
     $58 = ($59|0)==($57|0);
     if ($58) {
      $inword$0$be = $inword$1;
     } else {
      $60 = (_wcrtomb($mb,$59,$mps)|0);
      $61 = ($60|0)>(0);
      if ($61) {
       $62 = (($mb) + ($60)|0);
       HEAP8[$62>>0] = 0;
      }
      $63 = HEAP32[13632>>2]|0;
      $64 = (($63) + ($start$18)|0);
      (_strncpy(($64|0),($mb|0),($60|0))|0);
      $inword$0$be = $inword$1;
     }
    }
   } while(0);
   $18 = ($$|0)>($19|0);
   if ($18) {
    $inword$07 = $inword$0$be;$start$18 = $19;
   } else {
    break;
   }
  }
 }
 HEAP32[13784>>2] = $$;
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __rl_char_search_callback($data) {
 $data = $data|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $mbchar$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $mbchar$i = sp;
 HEAP32[35056>>2] = 0;
 HEAP32[32264>>2] = 1;
 $0 = HEAP32[$data>>2]|0;
 $1 = ((($data)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($data)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = (__rl_read_mbchar($mbchar$i,16)|0);
 $6 = ($5|0)<(1);
 if ($6) {
  $$0$i = -1;
  STACKTOP = sp;return ($$0$i|0);
 }
 $7 = ($0|0)<(0);
 if ($7) {
  $8 = (0 - ($0))|0;
  $9 = (__rl_char_search_internal($8,$4,$mbchar$i,$5)|0);
  $$0$i = $9;
  STACKTOP = sp;return ($$0$i|0);
 } else {
  $10 = (__rl_char_search_internal($0,$2,$mbchar$i,$5)|0);
  $$0$i = $10;
  STACKTOP = sp;return ($$0$i|0);
 }
 return (0)|0;
}
function __rl_init_eightbit() {
 var $$0 = 0, $$lspec$0 = 0, $$pr4 = 0, $$pre = 0, $$pre$i = 0, $$sink = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lspec$0 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_sh_get_env_value(35976)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  label = 3;
 } else {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if ($3) {
   label = 3;
  } else {
   $lspec$0 = $0;
  }
 }
 do {
  if ((label|0) == 3) {
   $4 = (_sh_get_env_value(35984)|0);
   $5 = ($4|0)==(0|0);
   if (!($5)) {
    $$pre$i = HEAP8[$4>>0]|0;
    $6 = ($$pre$i<<24>>24)==(0);
    if (!($6)) {
     $lspec$0 = $4;
     break;
    }
   }
   $7 = (_sh_get_env_value(36000)|0);
   $8 = ($7|0)==(0|0);
   if (!($8)) {
    $$pre = HEAP8[$7>>0]|0;
    $9 = ($$pre<<24>>24)==(0);
    if (!($9)) {
     $lspec$0 = $7;
     break;
    }
   }
   $10 = (_setlocale(0,(0|0))|0);
   $lspec$0 = $10;
  }
 } while(0);
 $11 = ($lspec$0|0)==(0|0);
 $$lspec$0 = $11 ? 37352 : $lspec$0;
 $12 = (_setlocale(0,($$lspec$0|0))|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  $$0 = 0;
  return ($$0|0);
 }
 $14 = HEAP8[$12>>0]|0;
 $15 = ($14<<24>>24)==(0);
 if ($15) {
  $$0 = 0;
  return ($$0|0);
 }
 $16 = (_nl_langinfo(14)|0);
 $17 = HEAP8[$16>>0]|0;
 if ((($17<<24>>24) == 117)) {
  $19 = (_strcmp($16,36016)|0);
  $$sink = $19;
  label = 13;
 } else if ((($17<<24>>24) == 85)) {
  $18 = (_strcmp($16,36008)|0);
  $$sink = $18;
  label = 13;
 } else {
  $storemerge = 0;
 }
 if ((label|0) == 13) {
  $20 = ($$sink|0)==(0);
  $21 = $20&1;
  $storemerge = $21;
 }
 HEAP32[36248>>2] = $storemerge;
 $$pr4 = HEAP8[$12>>0]|0;
 if ((($$pr4<<24>>24) == 67)) {
  $22 = ((($12)) + 1|0);
  $23 = HEAP8[$22>>0]|0;
  $24 = ($23<<24>>24)==(0);
  if ($24) {
   $$0 = 0;
   return ($$0|0);
  }
 } else if ((($$pr4<<24>>24) == 80)) {
  $25 = (_strcmp($12,36024)|0);
  $26 = ($25|0)==(0);
  if ($26) {
   $$0 = 0;
   return ($$0|0);
  }
 } else if ((($$pr4<<24>>24) == 0)) {
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[13736>>2] = 1;
 HEAP32[13688>>2] = 0;
 HEAP32[13696>>2] = 1;
 $$0 = 1;
 return ($$0|0);
}
function __rl_arg_overflow() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13464>>2]|0;
 $1 = ($0|0)>(1000000);
 if (!($1)) {
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[36048>>2] = 0;
 HEAP32[13464>>2] = 0;
 HEAP32[13472>>2] = 0;
 (_rl_ding()|0);
 _rl_restore_prompt();
 (_rl_clear_message()|0);
 $2 = HEAP32[13488>>2]|0;
 $3 = $2 & -1025;
 HEAP32[13488>>2] = $3;
 $$0 = 1;
 return ($$0|0);
}
function __rl_arg_getchar() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[13480>>2]|0;
 $1 = HEAP32[13464>>2]|0;
 $2 = Math_imul($1, $0)|0;
 HEAP32[$vararg_buffer>>2] = $2;
 (_rl_message(36064,$vararg_buffer)|0);
 $3 = HEAP32[13488>>2]|0;
 $4 = $3 | 64;
 HEAP32[13488>>2] = $4;
 $5 = (_rl_read_key()|0);
 $6 = HEAP32[13488>>2]|0;
 $7 = $6 & -65;
 HEAP32[13488>>2] = $7;
 STACKTOP = sp;return ($5|0);
}
function __rl_arg_dispatch($cxt,$c) {
 $cxt = $cxt|0;
 $c = $c|0;
 var $$0 = 0, $$off = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond3 = 0, $or$cond5 = 0, $or$cond7 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13432>>2]|0;
 $1 = (($0) + ($c<<3)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $4 = (((($0) + ($c<<3)|0)) + 4|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(225|0);
  if ($6) {
   $7 = $cxt & 2;
   $8 = ($7|0)==(0);
   if ($8) {
    $9 = HEAP32[13464>>2]|0;
    $10 = $9 << 2;
    HEAP32[13464>>2] = $10;
    $$0 = 1;
    return ($$0|0);
   }
   $11 = HEAP32[13488>>2]|0;
   $12 = $11 & 524288;
   $13 = ($12|0)==(0);
   if (!($13)) {
    $14 = HEAP32[36048>>2]|0;
    $15 = $14 | 4;
    HEAP32[36048>>2] = $15;
    $$0 = 0;
    return ($$0|0);
   }
   $16 = $11 | 64;
   HEAP32[13488>>2] = $16;
   $17 = (_rl_read_key()|0);
   $18 = HEAP32[13488>>2]|0;
   $19 = $18 & -65;
   HEAP32[13488>>2] = $19;
   _rl_restore_prompt();
   (_rl_clear_message()|0);
   $20 = HEAP32[13488>>2]|0;
   $21 = $20 & -1025;
   HEAP32[13488>>2] = $21;
   $22 = ($17|0)<(0);
   if ($22) {
    $$0 = -1;
    return ($$0|0);
   }
   $23 = HEAP32[13432>>2]|0;
   $24 = (__rl_dispatch($17,$23)|0);
   $$0 = $24;
   return ($$0|0);
  }
 }
 $25 = $c & -129;
 $$off = (($25) + -48)|0;
 $26 = ($$off>>>0)<(10);
 if ($26) {
  $27 = HEAP32[13472>>2]|0;
  $28 = ($27|0)==(0);
  if ($28) {
   $32 = $$off;
  } else {
   $29 = HEAP32[13464>>2]|0;
   $30 = ($29*10)|0;
   $31 = (($30) + ($$off))|0;
   $32 = $31;
  }
  HEAP32[13464>>2] = $32;
  HEAP32[13472>>2] = 1;
  $33 = HEAP32[36048>>2]|0;
  $34 = $33 | 2;
  HEAP32[36048>>2] = $34;
  $$0 = 1;
  return ($$0|0);
 }
 $35 = ($25|0)==(45);
 $36 = HEAP32[13472>>2]|0;
 $37 = ($36|0)==(0);
 $or$cond3 = $35 & $37;
 if ($or$cond3) {
  HEAP32[13464>>2] = 1;
  $38 = HEAP32[36048>>2]|0;
  $39 = $38 | 1;
  HEAP32[36048>>2] = $39;
  HEAP32[13480>>2] = -1;
  $$0 = 1;
  return ($$0|0);
 }
 $40 = HEAP32[36048>>2]|0;
 $41 = $40 & 1;
 $42 = ($41|0)!=(0);
 $43 = HEAP32[13464>>2]|0;
 $44 = ($43|0)==(1);
 $or$cond5 = $42 & $44;
 $or$cond7 = $37 & $or$cond5;
 if ($or$cond7) {
  HEAP32[13472>>2] = 1;
 }
 _rl_restore_prompt();
 (_rl_clear_message()|0);
 $45 = HEAP32[13488>>2]|0;
 $46 = $45 & -1025;
 HEAP32[13488>>2] = $46;
 $47 = HEAP32[13432>>2]|0;
 $48 = (__rl_dispatch($c,$47)|0);
 $49 = HEAP32[13488>>2]|0;
 $50 = $49 & 524288;
 $51 = ($50|0)==(0);
 if ($51) {
  $$0 = $48;
  return ($$0|0);
 }
 $52 = HEAP32[13776>>2]|0;
 $53 = ($52|0)==(0);
 if (!($53)) {
  $$0 = 0;
  return ($$0|0);
 }
 $54 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$54 & 511]();
 $$0 = 0;
 return ($$0|0);
}
function _rl_universal_argument($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$pr = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 _rl_save_prompt();
 HEAP32[36048>>2] = 0;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 1024;
 HEAP32[13488>>2] = $1;
 $2 = HEAP32[13464>>2]|0;
 $3 = $2 << 2;
 HEAP32[13464>>2] = $3;
 $4 = $0 & 524288;
 $5 = ($4|0)==(0);
 if (!($5)) {
  $25 = 0;
  STACKTOP = sp;return ($25|0);
 }
 $6 = ($3|0)>(1000000);
 L4: do {
  if (!($6)) {
   $12 = $3;
   while(1) {
    $10 = HEAP32[13480>>2]|0;
    $11 = Math_imul($12, $10)|0;
    HEAP32[$vararg_buffer>>2] = $11;
    (_rl_message(36064,$vararg_buffer)|0);
    $13 = HEAP32[13488>>2]|0;
    $14 = $13 | 64;
    HEAP32[13488>>2] = $14;
    $15 = (_rl_read_key()|0);
    $16 = HEAP32[13488>>2]|0;
    $17 = $16 & -65;
    HEAP32[13488>>2] = $17;
    $18 = ($15|0)<(0);
    if ($18) {
     label = 6;
     break;
    }
    $19 = HEAP32[36048>>2]|0;
    $20 = (__rl_arg_dispatch($19,$15)|0);
    $21 = ($20|0)<(1);
    if ($21) {
     $25 = $20;
     label = 9;
     break;
    }
    $22 = HEAP32[13488>>2]|0;
    $23 = $22 & 1024;
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = $20;
     label = 9;
     break;
    }
    $$pr = HEAP32[13464>>2]|0;
    $7 = ($$pr|0)>(1000000);
    if ($7) {
     break L4;
    } else {
     $12 = $$pr;
    }
   }
   if ((label|0) == 6) {
    (__rl_abort_internal()|0);
    // unreachable;
   }
   else if ((label|0) == 9) {
    STACKTOP = sp;return ($25|0);
   }
  }
 } while(0);
 HEAP32[36048>>2] = 0;
 HEAP32[13464>>2] = 0;
 HEAP32[13472>>2] = 0;
 (_rl_ding()|0);
 _rl_restore_prompt();
 (_rl_clear_message()|0);
 $8 = HEAP32[13488>>2]|0;
 $9 = $8 & -1025;
 HEAP32[13488>>2] = $9;
 $25 = 1;
 STACKTOP = sp;return ($25|0);
}
function __rl_reset_argument() {
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13480>>2] = 1;
 HEAP32[13464>>2] = 1;
 HEAP32[13472>>2] = 0;
 HEAP32[36048>>2] = 0;
 return;
}
function _rl_digit_argument($ignore,$key) {
 $ignore = $ignore|0;
 $key = $key|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 _rl_save_prompt();
 HEAP32[36048>>2] = 0;
 $0 = HEAP32[13488>>2]|0;
 $1 = $0 | 1024;
 HEAP32[13488>>2] = $1;
 $2 = $0 & 524288;
 $3 = ($2|0)==(0);
 if (!($3)) {
  (__rl_arg_dispatch(0,$key)|0);
  $4 = HEAP32[13480>>2]|0;
  $5 = HEAP32[13464>>2]|0;
  $6 = Math_imul($5, $4)|0;
  HEAP32[$vararg_buffer>>2] = $6;
  (_rl_message(36064,$vararg_buffer)|0);
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 (_rl_execute_next($key)|0);
 while(1) {
  $7 = HEAP32[13464>>2]|0;
  $8 = ($7|0)>(1000000);
  if ($8) {
   label = 5;
   break;
  }
  $11 = HEAP32[13480>>2]|0;
  $12 = Math_imul($7, $11)|0;
  HEAP32[$vararg_buffer1>>2] = $12;
  (_rl_message(36064,$vararg_buffer1)|0);
  $13 = HEAP32[13488>>2]|0;
  $14 = $13 | 64;
  HEAP32[13488>>2] = $14;
  $15 = (_rl_read_key()|0);
  $16 = HEAP32[13488>>2]|0;
  $17 = $16 & -65;
  HEAP32[13488>>2] = $17;
  $18 = ($15|0)<(0);
  if ($18) {
   label = 7;
   break;
  }
  $19 = HEAP32[36048>>2]|0;
  $20 = (__rl_arg_dispatch($19,$15)|0);
  $21 = ($20|0)<(1);
  if ($21) {
   $$0 = $20;
   label = 10;
   break;
  }
  $22 = HEAP32[13488>>2]|0;
  $23 = $22 & 1024;
  $24 = ($23|0)==(0);
  if ($24) {
   $$0 = $20;
   label = 10;
   break;
  }
 }
 if ((label|0) == 5) {
  HEAP32[36048>>2] = 0;
  HEAP32[13464>>2] = 0;
  HEAP32[13472>>2] = 0;
  (_rl_ding()|0);
  _rl_restore_prompt();
  (_rl_clear_message()|0);
  $9 = HEAP32[13488>>2]|0;
  $10 = $9 & -1025;
  HEAP32[13488>>2] = $10;
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 else if ((label|0) == 7) {
  (__rl_abort_internal()|0);
  // unreachable;
 }
 else if ((label|0) == 10) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __rl_start_using_history() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 _using_history();
 $0 = HEAP32[36056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  HEAP32[36056>>2] = 0;
  return;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _free($5);
 }
 _xfree($0);
 HEAP32[36056>>2] = 0;
 return;
}
function __rl_free_history_entry($entry) {
 $entry = $entry|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($entry|0)==(0|0);
 if ($0) {
  return;
 }
 $1 = HEAP32[$entry>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  _free($1);
 }
 $3 = ((($entry)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _free($4);
 }
 _xfree($entry);
 return;
}
function _rl_maybe_replace_line() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_current_history()|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  return 0;
 }
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = HEAP32[34424>>2]|0;
 $5 = ($3|0)==($4|0);
 if ($5) {
  return 0;
 }
 $6 = (_where_history()|0);
 $7 = HEAP32[13632>>2]|0;
 $8 = HEAP32[34424>>2]|0;
 $9 = (_replace_history_entry($6,$7,$8)|0);
 $10 = HEAP32[$9>>2]|0;
 _xfree($10);
 $11 = ((($9)) + 4|0);
 $12 = HEAP32[$11>>2]|0;
 $13 = ($12|0)==(0|0);
 if (!($13)) {
  _free($12);
 }
 _xfree($9);
 return 0;
}
function _rl_maybe_unsave_line() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  (_rl_ding()|0);
  return 0;
 }
 $2 = HEAP32[$0>>2]|0;
 _rl_replace_line($2,0);
 $3 = HEAP32[36056>>2]|0;
 $4 = ((($3)) + 8|0);
 $5 = HEAP32[$4>>2]|0;
 HEAP32[34424>>2] = $5;
 $6 = ($3|0)==(0|0);
 if (!($6)) {
  $7 = HEAP32[$3>>2]|0;
  $8 = ($7|0)==(0|0);
  if (!($8)) {
   _free($7);
  }
  $9 = ((($3)) + 4|0);
  $10 = HEAP32[$9>>2]|0;
  $11 = ($10|0)==(0|0);
  if (!($11)) {
   _free($10);
  }
  _xfree($3);
 }
 HEAP32[36056>>2] = 0;
 $12 = HEAP32[13768>>2]|0;
 HEAP32[13784>>2] = $12;
 return 0;
}
function _rl_maybe_save_line() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36056>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  return 0;
 }
 $2 = (_xmalloc(12)|0);
 HEAP32[36056>>2] = $2;
 $3 = HEAP32[13632>>2]|0;
 $4 = (_strlen(($3|0))|0);
 $5 = (($4) + 1)|0;
 $6 = (_xmalloc($5)|0);
 $7 = HEAP32[13632>>2]|0;
 $8 = (_strcpy(($6|0),($7|0))|0);
 $9 = HEAP32[36056>>2]|0;
 HEAP32[$9>>2] = $8;
 $10 = HEAP32[36056>>2]|0;
 $11 = ((($10)) + 4|0);
 HEAP32[$11>>2] = 0;
 $12 = HEAP32[34424>>2]|0;
 $13 = HEAP32[36056>>2]|0;
 $14 = ((($13)) + 8|0);
 HEAP32[$14>>2] = $12;
 return 0;
}
function __rl_free_saved_history_line() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36056>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return 0;
 }
 $2 = HEAP32[$0>>2]|0;
 $3 = ($2|0)==(0|0);
 if (!($3)) {
  _free($2);
 }
 $4 = ((($0)) + 4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = ($5|0)==(0|0);
 if (!($6)) {
  _free($5);
 }
 _xfree($0);
 HEAP32[36056>>2] = 0;
 return 0;
}
function __rl_revert_all_lines() {
 var $$saved_undo_list$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $entry$0$ph = 0, $entry$02 = 0, $saved_undo_list$0$lcssa = 0, $saved_undo_list$01 = 0;
 var $saved_undo_list$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13632>>2]|0;
 $1 = (_strlen(($0|0))|0);
 $2 = (($1) + 1)|0;
 $3 = (_xmalloc($2)|0);
 $4 = HEAP32[13632>>2]|0;
 $5 = (_strcpy(($3|0),($4|0))|0);
 $6 = HEAP32[34424>>2]|0;
 $7 = (_where_history()|0);
 $8 = HEAP32[36096>>2]|0;
 $9 = ($7|0)==($8|0);
 if ($9) {
  $10 = (_previous_history()|0);
  $entry$0$ph = $10;
 } else {
  $11 = (_current_history()|0);
  $entry$0$ph = $11;
 }
 $12 = ($entry$0$ph|0)==(0|0);
 if ($12) {
  $saved_undo_list$0$lcssa = $6;
  HEAP32[34424>>2] = $saved_undo_list$0$lcssa;
  (_history_set_pos($7)|0);
  _rl_replace_line($5,0);
  __rl_set_the_line();
  _xfree($5);
  return;
 } else {
  $entry$02 = $entry$0$ph;$saved_undo_list$01 = $6;
 }
 while(1) {
  $13 = ((($entry$02)) + 8|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = ($14|0)==(0|0);
  if ($15) {
   $saved_undo_list$2 = $saved_undo_list$01;
  } else {
   $16 = ($14|0)==($saved_undo_list$01|0);
   $$saved_undo_list$0 = $16 ? 0 : $saved_undo_list$01;
   $17 = HEAP32[$entry$02>>2]|0;
   _rl_replace_line($17,0);
   $18 = HEAP32[$13>>2]|0;
   HEAP32[34424>>2] = $18;
   $19 = HEAP32[13768>>2]|0;
   HEAP32[13784>>2] = $19;
   HEAP32[13952>>2] = 0;
   $20 = HEAP32[13440>>2]|0;
   $21 = ($20|0)==(0);
   if ($21) {
    HEAP32[13784>>2] = 0;
    HEAP32[13952>>2] = $19;
   }
   $22 = ($18|0)==(0);
   if (!($22)) {
    while(1) {
     (_rl_do_undo()|0);
     $23 = HEAP32[34424>>2]|0;
     $24 = ($23|0)==(0|0);
     if ($24) {
      break;
     }
    }
   }
   $25 = HEAP32[$entry$02>>2]|0;
   $26 = ($25|0)==(0|0);
   if (!($26)) {
    _free($25);
   }
   $27 = HEAP32[13632>>2]|0;
   $28 = (_strlen(($27|0))|0);
   $29 = (($28) + 1)|0;
   $30 = (_xmalloc($29)|0);
   $31 = HEAP32[13632>>2]|0;
   $32 = (_strcpy(($30|0),($31|0))|0);
   HEAP32[$entry$02>>2] = $32;
   HEAP32[$13>>2] = 0;
   $saved_undo_list$2 = $$saved_undo_list$0;
  }
  $33 = (_previous_history()|0);
  $34 = ($33|0)==(0|0);
  if ($34) {
   $saved_undo_list$0$lcssa = $saved_undo_list$2;
   break;
  } else {
   $entry$02 = $33;$saved_undo_list$01 = $saved_undo_list$2;
  }
 }
 HEAP32[34424>>2] = $saved_undo_list$0$lcssa;
 (_history_set_pos($7)|0);
 _rl_replace_line($5,0);
 __rl_set_the_line();
 _xfree($5);
 return;
}
function _rl_beginning_of_history($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_where_history()|0);
 $1 = (($0) + 1)|0;
 (_rl_get_previous_history($1,$key)|0);
 return 0;
}
function _rl_get_previous_history($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$$$i = 0, $$$i = 0, $$045 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $7 = 0, $8 = 0, $9 = 0, $old_temp$0$lcssa = 0, $old_temp$0$temp$1 = 0, $old_temp$06 = 0, $or$cond$i = 0, $or$cond3 = 0, $or$cond3$i = 0, $temp$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_get_next_history($1,$key)|0);
  return 0;
 }
 $2 = ($count|0)==(0);
 if ($2) {
  return 0;
 }
 $3 = HEAP32[36040>>2]|0;
 $4 = ($3|0)==(-1);
 if ($4) {
  $5 = HEAP32[13784>>2]|0;
  $6 = HEAP32[13768>>2]|0;
  $7 = $6 | $5;
  $8 = ($7|0)==(0);
  if (!($8)) {
   $9 = ($5|0)==($6|0);
   $10 = $9 ? -1 : $5;
   HEAP32[36040>>2] = $10;
  }
 }
 $11 = HEAP32[36056>>2]|0;
 $12 = ($11|0)==(0|0);
 if ($12) {
  $13 = (_xmalloc(12)|0);
  HEAP32[36056>>2] = $13;
  $14 = HEAP32[13632>>2]|0;
  $15 = (_strlen(($14|0))|0);
  $16 = (($15) + 1)|0;
  $17 = (_xmalloc($16)|0);
  $18 = HEAP32[13632>>2]|0;
  $19 = (_strcpy(($17|0),($18|0))|0);
  $20 = HEAP32[36056>>2]|0;
  HEAP32[$20>>2] = $19;
  $21 = HEAP32[36056>>2]|0;
  $22 = ((($21)) + 4|0);
  HEAP32[$22>>2] = 0;
  $23 = HEAP32[34424>>2]|0;
  $24 = HEAP32[36056>>2]|0;
  $25 = ((($24)) + 8|0);
  HEAP32[$25>>2] = $23;
 }
 $26 = (_current_history()|0);
 $27 = ($26|0)==(0|0);
 if ($27) {
  $$045 = $count;$old_temp$06 = 0;
 } else {
  $28 = ((($26)) + 8|0);
  $29 = HEAP32[$28>>2]|0;
  $30 = HEAP32[34424>>2]|0;
  $31 = ($29|0)==($30|0);
  if ($31) {
   $$045 = $count;$old_temp$06 = 0;
  } else {
   $32 = (_where_history()|0);
   $33 = HEAP32[13632>>2]|0;
   $34 = HEAP32[34424>>2]|0;
   $35 = (_replace_history_entry($32,$33,$34)|0);
   $36 = HEAP32[$35>>2]|0;
   _xfree($36);
   $37 = ((($35)) + 4|0);
   $38 = HEAP32[$37>>2]|0;
   $39 = ($38|0)==(0|0);
   if (!($39)) {
    _free($38);
   }
   _xfree($35);
   $$045 = $count;$old_temp$06 = 0;
  }
 }
 while(1) {
  $42 = (_previous_history()|0);
  $43 = ($42|0)==(0|0);
  $41 = (($$045) + -1)|0;
  if ($43) {
   $old_temp$0$lcssa = $old_temp$06;$temp$1 = 0;
   break;
  }
  $40 = ($41|0)==(0);
  if ($40) {
   $old_temp$0$lcssa = $42;$temp$1 = $42;
   break;
  } else {
   $$045 = $41;$old_temp$06 = $42;
  }
 }
 $44 = ($temp$1|0)==(0|0);
 $45 = ($old_temp$0$lcssa|0)!=(0|0);
 $or$cond3 = $45 & $44;
 $old_temp$0$temp$1 = $or$cond3 ? $old_temp$0$lcssa : $temp$1;
 $46 = ($old_temp$0$temp$1|0)==(0|0);
 if ($46) {
  (_rl_ding()|0);
  return 0;
 }
 $47 = HEAP32[$old_temp$0$temp$1>>2]|0;
 _rl_replace_line($47,0);
 $48 = ((($old_temp$0$temp$1)) + 8|0);
 $49 = HEAP32[$48>>2]|0;
 HEAP32[34424>>2] = $49;
 $50 = HEAP32[13768>>2]|0;
 HEAP32[13784>>2] = $50;
 HEAP32[13952>>2] = 0;
 $51 = HEAP32[13440>>2]|0;
 $52 = ($51|0)==(0);
 if ($52) {
  HEAP32[13784>>2] = 0;
  HEAP32[13952>>2] = $50;
 }
 $53 = HEAP32[36032>>2]|0;
 $54 = ($53|0)!=(0);
 $55 = HEAP32[36040>>2]|0;
 $56 = ($55|0)!=(-1);
 $or$cond$i = $54 & $56;
 $57 = $or$cond$i ? $55 : $50;
 $58 = ($57|0)>($50|0);
 $$$i = $58 ? $50 : $57;
 $59 = HEAP32[13432>>2]|0;
 $60 = ($59|0)!=(26464|0);
 $or$cond3$i = $52 & $60;
 $$$$i = $or$cond3$i ? 0 : $$$i;
 HEAP32[13784>>2] = $$$$i;
 $61 = ($51|0)==(1);
 if (!($61)) {
  return 0;
 }
 $62 = ($$$$i|0)==($50|0);
 $63 = $62 ? 0 : $50;
 HEAP32[13952>>2] = $63;
 return 0;
}
function _rl_end_of_history($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_current_history()|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = ((($0)) + 8|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = HEAP32[34424>>2]|0;
  $5 = ($3|0)==($4|0);
  if (!($5)) {
   $6 = (_where_history()|0);
   $7 = HEAP32[13632>>2]|0;
   $8 = HEAP32[34424>>2]|0;
   $9 = (_replace_history_entry($6,$7,$8)|0);
   $10 = HEAP32[$9>>2]|0;
   _xfree($10);
   $11 = ((($9)) + 4|0);
   $12 = HEAP32[$11>>2]|0;
   $13 = ($12|0)==(0|0);
   if (!($13)) {
    _free($12);
   }
   _xfree($9);
  }
 }
 _using_history();
 $14 = HEAP32[36056>>2]|0;
 $15 = ($14|0)==(0|0);
 if ($15) {
  (_rl_ding()|0);
  return 0;
 }
 $16 = HEAP32[$14>>2]|0;
 _rl_replace_line($16,0);
 $17 = HEAP32[36056>>2]|0;
 $18 = ((($17)) + 8|0);
 $19 = HEAP32[$18>>2]|0;
 HEAP32[34424>>2] = $19;
 $20 = ($17|0)==(0|0);
 if (!($20)) {
  $21 = HEAP32[$17>>2]|0;
  $22 = ($21|0)==(0|0);
  if (!($22)) {
   _free($21);
  }
  $23 = ((($17)) + 4|0);
  $24 = HEAP32[$23>>2]|0;
  $25 = ($24|0)==(0|0);
  if (!($25)) {
   _free($24);
  }
  _xfree($17);
 }
 HEAP32[36056>>2] = 0;
 $26 = HEAP32[13768>>2]|0;
 HEAP32[13784>>2] = $26;
 return 0;
}
function _rl_get_next_history($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $$$$i = 0, $$$i = 0, $$024 = 0, $$lcssa9 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond$i = 0, $or$cond3$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($count|0)<(0);
 if ($0) {
  $1 = (0 - ($count))|0;
  (_rl_get_previous_history($1,$key)|0);
  return 0;
 }
 $2 = ($count|0)==(0);
 if ($2) {
  return 0;
 }
 $3 = (_current_history()|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 8|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = HEAP32[34424>>2]|0;
  $8 = ($6|0)==($7|0);
  if (!($8)) {
   $9 = (_where_history()|0);
   $10 = HEAP32[13632>>2]|0;
   $11 = HEAP32[34424>>2]|0;
   $12 = (_replace_history_entry($9,$10,$11)|0);
   $13 = HEAP32[$12>>2]|0;
   _xfree($13);
   $14 = ((($12)) + 4|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ($15|0)==(0|0);
   if (!($16)) {
    _free($15);
   }
   _xfree($12);
  }
 }
 $17 = HEAP32[36040>>2]|0;
 $18 = ($17|0)==(-1);
 if ($18) {
  $19 = HEAP32[13784>>2]|0;
  $20 = HEAP32[13768>>2]|0;
  $21 = $20 | $19;
  $22 = ($21|0)==(0);
  if ($22) {
   $$024 = $count;
  } else {
   $23 = ($19|0)==($20|0);
   $24 = $23 ? -1 : $19;
   HEAP32[36040>>2] = $24;
   $$024 = $count;
  }
 } else {
  $$024 = $count;
 }
 while(1) {
  $27 = (_next_history()|0);
  $28 = ($27|0)==(0|0);
  $26 = (($$024) + -1)|0;
  if ($28) {
   break;
  }
  $25 = ($26|0)==(0);
  if ($25) {
   $$lcssa9 = $27;
   label = 23;
   break;
  } else {
   $$024 = $26;
  }
 }
 if ((label|0) == 23) {
  $42 = HEAP32[$$lcssa9>>2]|0;
  _rl_replace_line($42,0);
  $43 = ((($$lcssa9)) + 8|0);
  $44 = HEAP32[$43>>2]|0;
  HEAP32[34424>>2] = $44;
  $45 = HEAP32[13768>>2]|0;
  HEAP32[13784>>2] = $45;
  HEAP32[13952>>2] = 0;
  $46 = HEAP32[13440>>2]|0;
  $47 = ($46|0)==(0);
  if ($47) {
   HEAP32[13784>>2] = 0;
   HEAP32[13952>>2] = $45;
  }
  $48 = HEAP32[36032>>2]|0;
  $49 = ($48|0)!=(0);
  $50 = HEAP32[36040>>2]|0;
  $51 = ($50|0)!=(-1);
  $or$cond$i = $49 & $51;
  $52 = $or$cond$i ? $50 : $45;
  $53 = ($52|0)>($45|0);
  $$$i = $53 ? $45 : $52;
  $54 = HEAP32[13432>>2]|0;
  $55 = ($54|0)!=(26464|0);
  $or$cond3$i = $47 & $55;
  $$$$i = $or$cond3$i ? 0 : $$$i;
  HEAP32[13784>>2] = $$$$i;
  $56 = ($46|0)==(1);
  if (!($56)) {
   return 0;
  }
  $57 = ($$$$i|0)==($45|0);
  $58 = $57 ? 0 : $45;
  HEAP32[13952>>2] = $58;
  return 0;
 }
 $29 = HEAP32[36056>>2]|0;
 $30 = ($29|0)==(0|0);
 if ($30) {
  (_rl_ding()|0);
  return 0;
 }
 $31 = HEAP32[$29>>2]|0;
 _rl_replace_line($31,0);
 $32 = HEAP32[36056>>2]|0;
 $33 = ((($32)) + 8|0);
 $34 = HEAP32[$33>>2]|0;
 HEAP32[34424>>2] = $34;
 $35 = ($32|0)==(0|0);
 if (!($35)) {
  $36 = HEAP32[$32>>2]|0;
  $37 = ($36|0)==(0|0);
  if (!($37)) {
   _free($36);
  }
  $38 = ((($32)) + 4|0);
  $39 = HEAP32[$38>>2]|0;
  $40 = ($39|0)==(0|0);
  if (!($40)) {
   _free($39);
  }
  _xfree($32);
 }
 HEAP32[36056>>2] = 0;
 $41 = HEAP32[13768>>2]|0;
 HEAP32[13784>>2] = $41;
 return 0;
}
function _rl_vi_editing_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13448>>2] = 1;
 HEAP32[13440>>2] = 0;
 (_rl_vi_insert_mode(1,$key)|0);
 return 0;
}
function __rl_set_insert_mode($im,$force) {
 $im = $im|0;
 $force = $force|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13448>>2] = $im;
 return;
}
function _rl_emacs_editing_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAP32[13440>>2] = 1;
 HEAP32[13448>>2] = 1;
 HEAP32[13432>>2] = 22352;
 $0 = HEAP32[13728>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  return 0;
 }
 __rl_reset_prompt();
 return 0;
}
function _rl_overwrite_mode($count,$key) {
 $count = $count|0;
 $key = $key|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = HEAP32[13448>>2]|0;
  $3 = $2 ^ 1;
  HEAP32[13448>>2] = $3;
  return 0;
 }
 $4 = ($count|0)>(0);
 if ($4) {
  HEAP32[13448>>2] = 0;
  return 0;
 } else {
  HEAP32[13448>>2] = 1;
  return 0;
 }
 return (0)|0;
}
function _using_history() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36096>>2]|0;
 HEAP32[36088>>2] = $0;
 return;
}
function _where_history() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36088>>2]|0;
 return ($0|0);
}
function _history_set_pos($pos) {
 $pos = $pos|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $notlhs = 0, $notrhs = 0, $or$cond$not = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36096>>2]|0;
 $notlhs = ($0|0)>=($pos|0);
 $notrhs = ($pos|0)>(-1);
 $or$cond$not = $notrhs & $notlhs;
 $1 = HEAP32[36120>>2]|0;
 $2 = ($1|0)!=(0|0);
 $or$cond3 = $or$cond$not & $2;
 if (!($or$cond3)) {
  $$0 = 0;
  return ($$0|0);
 }
 HEAP32[36088>>2] = $pos;
 $$0 = 1;
 return ($$0|0);
}
function _history_list() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36120>>2]|0;
 return ($0|0);
}
function _current_history() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36088>>2]|0;
 $1 = HEAP32[36096>>2]|0;
 $2 = ($0|0)==($1|0);
 $3 = HEAP32[36120>>2]|0;
 $4 = ($3|0)==(0|0);
 $or$cond = $2 | $4;
 if ($or$cond) {
  $7 = 0;
  return ($7|0);
 }
 $5 = (($3) + ($0<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 return ($7|0);
}
function _previous_history() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36088>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = 0;
  return ($6|0);
 }
 $2 = (($0) + -1)|0;
 HEAP32[36088>>2] = $2;
 $3 = HEAP32[36120>>2]|0;
 $4 = (($3) + ($2<<2)|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5;
 return ($6|0);
}
function _next_history() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36088>>2]|0;
 $1 = HEAP32[36096>>2]|0;
 $2 = ($0|0)==($1|0);
 if ($2) {
  $7 = 0;
  return ($7|0);
 }
 $3 = (($0) + 1)|0;
 HEAP32[36088>>2] = $3;
 $4 = HEAP32[36120>>2]|0;
 $5 = (($4) + ($3<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $6;
 return ($7|0);
}
function _add_history($string) {
 $string = $string|0;
 var $$pre = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0;
 var $ts$i = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $ts$i = sp + 8|0;
 $0 = HEAP32[36136>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  label = 13;
 } else {
  $2 = HEAP32[36096>>2]|0;
  $3 = HEAP32[36104>>2]|0;
  $4 = ($2|0)==($3|0);
  if ($4) {
   $5 = ($2|0)==(0);
   if ($5) {
    STACKTOP = sp;return;
   }
   $6 = HEAP32[36120>>2]|0;
   $7 = HEAP32[$6>>2]|0;
   $8 = ($7|0)==(0|0);
   if ($8) {
    $15 = $2;
   } else {
    $9 = HEAP32[$7>>2]|0;
    $10 = ($9|0)==(0|0);
    if (!($10)) {
     _free($9);
    }
    $11 = ((($7)) + 4|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==(0|0);
    if (!($13)) {
     _free($12);
    }
    _xfree($7);
    $$pre = HEAP32[36096>>2]|0;
    $15 = $$pre;
   }
   $14 = ($15|0)>(0);
   if ($14) {
    $i$01 = 0;
    while(1) {
     $16 = (($i$01) + 1)|0;
     $17 = HEAP32[36120>>2]|0;
     $18 = (($17) + ($16<<2)|0);
     $19 = HEAP32[$18>>2]|0;
     $20 = (($17) + ($i$01<<2)|0);
     HEAP32[$20>>2] = $19;
     $21 = ($16|0)<($15|0);
     if ($21) {
      $i$01 = $16;
     } else {
      break;
     }
    }
   }
   $22 = HEAP32[36080>>2]|0;
   $23 = (($22) + 1)|0;
   HEAP32[36080>>2] = $23;
  } else {
   label = 13;
  }
 }
 do {
  if ((label|0) == 13) {
   $24 = HEAP32[36128>>2]|0;
   $25 = ($24|0)==(0);
   if ($25) {
    HEAP32[36128>>2] = 50;
    $26 = (_xmalloc(200)|0);
    HEAP32[36120>>2] = $26;
    HEAP32[36096>>2] = 1;
    break;
   }
   $27 = HEAP32[36096>>2]|0;
   $28 = (($24) + -1)|0;
   $29 = ($27|0)==($28|0);
   if ($29) {
    $30 = (($24) + 50)|0;
    HEAP32[36128>>2] = $30;
    $31 = HEAP32[36120>>2]|0;
    $32 = $30 << 2;
    $33 = (_xrealloc($31,$32)|0);
    HEAP32[36120>>2] = $33;
    $$pre2 = HEAP32[36096>>2]|0;
    $35 = $$pre2;
   } else {
    $35 = $27;
   }
   $34 = (($35) + 1)|0;
   HEAP32[36096>>2] = $34;
  }
 } while(0);
 $36 = (_time((0|0))|0);
 HEAP32[$vararg_buffer>>2] = $36;
 (_snprintf($ts$i,63,36144,$vararg_buffer)|0);
 $37 = (_strlen(($ts$i|0))|0);
 $38 = (($37) + 1)|0;
 $39 = (_xmalloc($38)|0);
 $40 = (_strcpy(($39|0),($ts$i|0))|0);
 $41 = HEAP8[36152>>0]|0;
 HEAP8[$40>>0] = $41;
 $42 = (_xmalloc(12)|0);
 $43 = ($string|0)==(0|0);
 if ($43) {
  $48 = 0;
 } else {
  $44 = (_strlen(($string|0))|0);
  $45 = (($44) + 1)|0;
  $46 = (_xmalloc($45)|0);
  $47 = (_strcpy(($46|0),($string|0))|0);
  $48 = $47;
 }
 HEAP32[$42>>2] = $48;
 $49 = ((($42)) + 8|0);
 HEAP32[$49>>2] = 0;
 $50 = ((($42)) + 4|0);
 HEAP32[$50>>2] = $40;
 $51 = HEAP32[36096>>2]|0;
 $52 = HEAP32[36120>>2]|0;
 $53 = (($52) + ($51<<2)|0);
 HEAP32[$53>>2] = 0;
 $54 = (($51) + -1)|0;
 $55 = HEAP32[36120>>2]|0;
 $56 = (($55) + ($54<<2)|0);
 HEAP32[$56>>2] = $42;
 STACKTOP = sp;return;
}
function _replace_history_entry($which,$line,$data) {
 $which = $which|0;
 $line = $line|0;
 $data = $data|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($which|0)>(-1);
 $1 = HEAP32[36096>>2]|0;
 $2 = ($1|0)>($which|0);
 $or$cond = $0 & $2;
 if (!($or$cond)) {
  $$0 = 0;
  return ($$0|0);
 }
 $3 = (_xmalloc(12)|0);
 $4 = HEAP32[36120>>2]|0;
 $5 = (($4) + ($which<<2)|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (_strlen(($line|0))|0);
 $8 = (($7) + 1)|0;
 $9 = (_xmalloc($8)|0);
 $10 = (_strcpy(($9|0),($line|0))|0);
 HEAP32[$3>>2] = $10;
 $11 = ((($3)) + 8|0);
 HEAP32[$11>>2] = $data;
 $12 = ((($6)) + 4|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = (_strlen(($13|0))|0);
 $15 = (($14) + 1)|0;
 $16 = (_xmalloc($15)|0);
 $17 = HEAP32[$12>>2]|0;
 $18 = (_strcpy(($16|0),($17|0))|0);
 $19 = ((($3)) + 4|0);
 HEAP32[$19>>2] = $18;
 $20 = HEAP32[36120>>2]|0;
 $21 = (($20) + ($which<<2)|0);
 HEAP32[$21>>2] = $3;
 $$0 = $6;
 return ($$0|0);
}
function _replace_history_data($which,$old,$new) {
 $which = $which|0;
 $old = $old|0;
 $new = $new|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$06 = 0;
 var $i$06$last$07 = 0, $i$06$us = 0, $last$0$lcssa = 0, $last$07 = 0, $last$07$us = 0, $last$1 = 0, $last$1$us = 0, $or$cond = 0, $or$cond3 = 0, $or$cond5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($which|0)<(-2);
 if ($0) {
  return;
 }
 $1 = HEAP32[36096>>2]|0;
 $2 = ($1|0)<=($which|0);
 $3 = ($1|0)==(0);
 $or$cond = $2 | $3;
 $4 = HEAP32[36120>>2]|0;
 $5 = ($4|0)==(0|0);
 $or$cond3 = $or$cond | $5;
 if ($or$cond3) {
  return;
 }
 $6 = ($which|0)>(-1);
 if ($6) {
  $18 = (($4) + ($which<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)==(0|0);
  if ($20) {
   return;
  }
  $21 = ((($19)) + 8|0);
  $22 = HEAP32[$21>>2]|0;
  $23 = ($22|0)==($old|0);
  if (!($23)) {
   return;
  }
  HEAP32[$21>>2] = $new;
  return;
 }
 $7 = ($1|0)>(0);
 if (!($7)) {
  return;
 }
 $8 = ($which|0)==(-1);
 L20: do {
  if ($8) {
   $10 = $4;$i$06$us = 0;$last$07$us = -1;
   while(1) {
    $9 = (($10) + ($i$06$us<<2)|0);
    $11 = HEAP32[$9>>2]|0;
    $12 = ($11|0)==(0|0);
    if ($12) {
     $last$1$us = $last$07$us;
    } else {
     $13 = ((($11)) + 8|0);
     $14 = HEAP32[$13>>2]|0;
     $15 = ($14|0)==($old|0);
     if ($15) {
      HEAP32[$13>>2] = $new;
      $last$1$us = $i$06$us;
     } else {
      $last$1$us = $last$07$us;
     }
    }
    $16 = (($i$06$us) + 1)|0;
    $17 = ($16|0)<($1|0);
    if (!($17)) {
     $last$0$lcssa = $last$1$us;
     break L20;
    }
    $$pre = HEAP32[36120>>2]|0;
    $10 = $$pre;$i$06$us = $16;$last$07$us = $last$1$us;
   }
  } else {
   $i$06 = 0;$last$07 = -1;
   while(1) {
    $24 = (($4) + ($i$06<<2)|0);
    $25 = HEAP32[$24>>2]|0;
    $26 = ($25|0)==(0|0);
    if ($26) {
     $last$1 = $last$07;
    } else {
     $27 = ((($25)) + 8|0);
     $28 = HEAP32[$27>>2]|0;
     $29 = ($28|0)==($old|0);
     $i$06$last$07 = $29 ? $i$06 : $last$07;
     $last$1 = $i$06$last$07;
    }
    $30 = (($i$06) + 1)|0;
    $31 = ($30|0)<($1|0);
    if ($31) {
     $i$06 = $30;$last$07 = $last$1;
    } else {
     $last$0$lcssa = $last$1;
     break;
    }
   }
  }
 } while(0);
 $32 = ($which|0)==(-2);
 $33 = ($last$0$lcssa|0)>(-1);
 $or$cond5 = $32 & $33;
 if (!($or$cond5)) {
  return;
 }
 $34 = HEAP32[36120>>2]|0;
 $35 = (($34) + ($last$0$lcssa<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 $37 = ((($36)) + 8|0);
 HEAP32[$37>>2] = $new;
 return;
}
function _stifle_history($max) {
 $max = $max|0;
 var $$lcssa = 0, $$lcssa16 = 0, $$max = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $i$0$lcssa = 0, $i$04 = 0, $i$11 = 0, $j$0$lcssa = 0, $j$02 = 0, $smax = 0;
 var $smax12 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($max|0)<(0);
 $$max = $0 ? 0 : $max;
 $1 = HEAP32[36096>>2]|0;
 $2 = ($1|0)>($$max|0);
 if (!($2)) {
  HEAP32[36136>>2] = 1;
  HEAP32[36104>>2] = $$max;
  HEAP32[36112>>2] = $$max;
  return;
 }
 $3 = ($1|0)>($$max|0);
 if ($3) {
  $4 = ($max|0)>(0);
  $smax12 = $4 ? $max : 0;
  $5 = (($1) - ($smax12))|0;
  $i$04 = 0;
  while(1) {
   $6 = HEAP32[36120>>2]|0;
   $7 = (($6) + ($i$04<<2)|0);
   $8 = HEAP32[$7>>2]|0;
   $9 = ($8|0)==(0|0);
   if (!($9)) {
    $10 = HEAP32[$8>>2]|0;
    $11 = ($10|0)==(0|0);
    if (!($11)) {
     _free($10);
    }
    $12 = ((($8)) + 4|0);
    $13 = HEAP32[$12>>2]|0;
    $14 = ($13|0)==(0|0);
    if (!($14)) {
     _free($13);
    }
    _xfree($8);
   }
   $15 = (($i$04) + 1)|0;
   $exitcond = ($15|0)==($5|0);
   if ($exitcond) {
    $i$0$lcssa = $5;
    break;
   } else {
    $i$04 = $15;
   }
  }
 } else {
  $i$0$lcssa = 0;
 }
 HEAP32[36080>>2] = $i$0$lcssa;
 $16 = ($$max|0)>(0);
 $17 = HEAP32[36120>>2]|0;
 if ($16) {
  $18 = HEAP32[36096>>2]|0;
  $19 = (($18) - ($$max))|0;
  $20 = ($max|0)>(0);
  $22 = $17;$i$11 = $19;$j$02 = 0;
  while(1) {
   $21 = (($22) + ($i$11<<2)|0);
   $23 = HEAP32[$21>>2]|0;
   $24 = (($22) + ($j$02<<2)|0);
   HEAP32[$24>>2] = $23;
   $25 = (($i$11) + 1)|0;
   $26 = (($j$02) + 1)|0;
   $27 = ($26|0)<($$max|0);
   $28 = HEAP32[36120>>2]|0;
   if ($27) {
    $22 = $28;$i$11 = $25;$j$02 = $26;
   } else {
    $$lcssa16 = $28;
    break;
   }
  }
  $smax = $20 ? $max : 0;
  $$lcssa = $$lcssa16;$j$0$lcssa = $smax;
 } else {
  $$lcssa = $17;$j$0$lcssa = 0;
 }
 $29 = (($$lcssa) + ($j$0$lcssa<<2)|0);
 HEAP32[$29>>2] = 0;
 HEAP32[36096>>2] = $j$0$lcssa;
 HEAP32[36136>>2] = 1;
 HEAP32[36104>>2] = $$max;
 HEAP32[36112>>2] = $$max;
 return;
}
function _unstifle_history() {
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36136>>2]|0;
 $1 = ($0|0)==(0);
 if ($1) {
  $3 = HEAP32[36104>>2]|0;
  $4 = (0 - ($3))|0;
  $$0 = $4;
  return ($$0|0);
 } else {
  HEAP32[36136>>2] = 0;
  $2 = HEAP32[36104>>2]|0;
  $$0 = $2;
  return ($$0|0);
 }
 return (0)|0;
}
function _history_is_stifled() {
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36136>>2]|0;
 return ($0|0);
}
function _history_arg_extract($first,$last,$string) {
 $first = $first|0;
 $last = $last|0;
 $string = $string|0;
 var $$$05 = 0, $$0 = 0, $$04 = 0, $$05 = 0, $$1 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond = 0, $exitcond18 = 0, $exitcond19 = 0, $i$014 = 0, $i$110 = 0, $i$29 = 0, $len$0 = 0, $len$0$lcssa = 0, $offset$0$be = 0;
 var $offset$011 = 0, $or$cond = 0, $or$cond3 = 0, $or$cond7 = 0, $phitmp = 0, $result$0 = 0, $size$015 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_history_tokenize_internal($string,-1,0)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $len$0 = 0;
 }
 while(1) {
  $2 = (($0) + ($len$0<<2)|0);
  $3 = HEAP32[$2>>2]|0;
  $4 = ($3|0)==(0|0);
  $5 = (($len$0) + 1)|0;
  if ($4) {
   $len$0$lcssa = $len$0;
   break;
  } else {
   $len$0 = $5;
  }
 }
 $6 = ($last|0)<(0);
 $7 = (($last) + -1)|0;
 $8 = (($7) + ($len$0$lcssa))|0;
 $$05 = $6 ? $8 : $last;
 $9 = ($first|0)<(0);
 $10 = (($first) + -1)|0;
 $11 = (($10) + ($len$0$lcssa))|0;
 $$04 = $9 ? $11 : $first;
 $12 = ($$05|0)==(36);
 $13 = (($len$0$lcssa) + -1)|0;
 $$$05 = $12 ? $13 : $$05;
 $14 = ($$04|0)==(36);
 $$1 = $14 ? $13 : $$04;
 $15 = (($$$05) + 1)|0;
 $16 = ($$1|0)<($len$0$lcssa|0);
 do {
  if ($16) {
   $17 = ($$$05|0)>=($len$0$lcssa|0);
   $18 = ($$1|0)<(0);
   $or$cond = $17 | $18;
   $19 = ($$$05|0)<(-1);
   $or$cond3 = $19 | $or$cond;
   $20 = ($$1|0)>($15|0);
   $or$cond7 = $20 | $or$cond3;
   if ($or$cond7) {
    $result$0 = 0;
   } else {
    $21 = ($$1|0)<($15|0);
    if ($21) {
     $i$014 = $$1;$size$015 = 0;
    } else {
     $22 = (_xmalloc(1)|0);
     HEAP8[$22>>0] = 0;
     $result$0 = $22;
     break;
    }
    while(1) {
     $23 = (($0) + ($i$014<<2)|0);
     $24 = HEAP32[$23>>2]|0;
     $25 = (_strlen(($24|0))|0);
     $26 = (($size$015) + 1)|0;
     $27 = (($26) + ($25))|0;
     $28 = (($i$014) + 1)|0;
     $exitcond19 = ($28|0)==($15|0);
     if ($exitcond19) {
      $$lcssa = $27;
      break;
     } else {
      $i$014 = $28;$size$015 = $27;
     }
    }
    $phitmp = (($$lcssa) + 1)|0;
    $29 = (_xmalloc($phitmp)|0);
    HEAP8[$29>>0] = 0;
    if ($21) {
     $i$110 = $$1;$offset$011 = 0;
     while(1) {
      $30 = (($29) + ($offset$011)|0);
      $31 = (($0) + ($i$110<<2)|0);
      $32 = HEAP32[$31>>2]|0;
      (_strcpy(($30|0),($32|0))|0);
      $33 = HEAP32[$31>>2]|0;
      $34 = (_strlen(($33|0))|0);
      $35 = (($34) + ($offset$011))|0;
      $36 = (($i$110) + 1)|0;
      $37 = ($36|0)<($15|0);
      if ($37) {
       $38 = (($35) + 1)|0;
       $39 = (($29) + ($35)|0);
       HEAP8[$39>>0] = 32;
       $40 = (($29) + ($38)|0);
       HEAP8[$40>>0] = 0;
       $offset$0$be = $38;
      } else {
       $offset$0$be = $35;
      }
      $exitcond18 = ($36|0)==($15|0);
      if ($exitcond18) {
       $result$0 = $29;
       break;
      } else {
       $i$110 = $36;$offset$011 = $offset$0$be;
      }
     }
    } else {
     $result$0 = $29;
    }
   }
  } else {
   $result$0 = 0;
  }
 } while(0);
 $41 = ($len$0$lcssa|0)>(0);
 if ($41) {
  $i$29 = 0;
  while(1) {
   $42 = (($0) + ($i$29<<2)|0);
   $43 = HEAP32[$42>>2]|0;
   _xfree($43);
   $44 = (($i$29) + 1)|0;
   $exitcond = ($44|0)==($len$0$lcssa|0);
   if ($exitcond) {
    break;
   } else {
    $i$29 = $44;
   }
  }
 }
 _xfree($0);
 $$0 = $result$0;
 return ($$0|0);
}
function _history_tokenize_internal($string,$wind,$indp) {
 $string = $string|0;
 $wind = $wind|0;
 $indp = $indp|0;
 var $$lcssa = 0, $$lcssa40 = 0, $$lcssa41 = 0, $$lcssa42 = 0, $$not$us = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $i$016 = 0, $i$016$us = 0, $i$1 = 0, $i$1$lcssa = 0, $i$1$us = 0, $i$1$us$lcssa = 0, $i$2 = 0, $i$2$in = 0;
 var $i$2$in$us = 0, $i$2$us = 0, $i$3 = 0, $i$3$us = 0, $or$cond = 0, $or$cond11$us = 0, $or$cond4 = 0, $or$cond4$us = 0, $or$cond9 = 0, $or$cond9$us = 0, $result$0$lcssa = 0, $result$015 = 0, $result$015$us = 0, $result$1 = 0, $result$1$us = 0, $result_index$017 = 0, $result_index$017$us = 0, $size$018 = 0, $size$018$us = 0, $size$1 = 0;
 var $size$1$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($indp|0)!=(0|0);
 $1 = ($wind|0)!=(-1);
 $or$cond = $1 & $0;
 if ($or$cond) {
  HEAP32[$indp>>2] = -1;
 }
 $2 = HEAP8[$string>>0]|0;
 $3 = ($2<<24>>24)==(0);
 if ($3) {
  $result$0$lcssa = 0;
  return ($result$0$lcssa|0);
 }
 if ($or$cond) {
  $i$016$us = 0;$result$015$us = 0;$result_index$017$us = 0;$size$018$us = 0;
 } else {
  $i$016 = 0;$result$015 = 0;$result_index$017 = 0;$size$018 = 0;
  while(1) {
   $i$1 = $i$016;
   while(1) {
    $36 = (($string) + ($i$1)|0);
    $37 = HEAP8[$36>>0]|0;
    if (!((($37<<24>>24) == 32) | (($37<<24>>24) == 9))) {
     $$lcssa41 = $36;$$lcssa42 = $37;$i$1$lcssa = $i$1;
     break;
    }
    $38 = (($i$1) + 1)|0;
    $i$1 = $38;
   }
   $39 = ($$lcssa42<<24>>24)==(0);
   $40 = HEAP8[36152>>0]|0;
   $41 = ($$lcssa42<<24>>24)==($40<<24>>24);
   $or$cond9 = $39 | $41;
   if ($or$cond9) {
    $result$0$lcssa = $result$015;
    label = 27;
    break;
   }
   $42 = (_history_tokenize_word($string,$i$1$lcssa)|0);
   $43 = ($42|0)==($i$1$lcssa|0);
   $44 = HEAP32[36160>>2]|0;
   $45 = ($44|0)!=(0|0);
   $or$cond4 = $43 & $45;
   L15: do {
    if ($or$cond4) {
     $i$2$in = $i$1$lcssa;
     while(1) {
      $i$2 = (($i$2$in) + 1)|0;
      $46 = (($string) + ($i$2)|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = ($47<<24>>24)==(0);
      if ($48) {
       $i$3 = $i$2;
       break L15;
      }
      $49 = $47 << 24 >> 24;
      $50 = (_strchr($44,$49)|0);
      $51 = ($50|0)==(0|0);
      if ($51) {
       $i$3 = $i$2;
       break;
      } else {
       $i$2$in = $i$2;
      }
     }
    } else {
     $i$3 = $42;
    }
   } while(0);
   $52 = (($result_index$017) + 2)|0;
   $53 = ($52|0)<($size$018|0);
   if ($53) {
    $result$1 = $result$015;$size$1 = $size$018;
   } else {
    $54 = (($size$018) + 10)|0;
    $55 = $54 << 2;
    $56 = (_xrealloc($result$015,$55)|0);
    $result$1 = $56;$size$1 = $54;
   }
   $57 = (($i$3) - ($i$1$lcssa))|0;
   $58 = (($57) + 1)|0;
   $59 = (_xmalloc($58)|0);
   (_strncpy(($59|0),($$lcssa41|0),($57|0))|0);
   $60 = (($59) + ($57)|0);
   HEAP8[$60>>0] = 0;
   $61 = (($result_index$017) + 1)|0;
   $62 = (($result$1) + ($result_index$017<<2)|0);
   HEAP32[$62>>2] = $59;
   $63 = (($result$1) + ($61<<2)|0);
   HEAP32[$63>>2] = 0;
   $64 = (($string) + ($i$3)|0);
   $65 = HEAP8[$64>>0]|0;
   $66 = ($65<<24>>24)==(0);
   if ($66) {
    $result$0$lcssa = $result$1;
    label = 27;
    break;
   } else {
    $i$016 = $i$3;$result$015 = $result$1;$result_index$017 = $61;$size$018 = $size$1;
   }
  }
  if ((label|0) == 27) {
   return ($result$0$lcssa|0);
  }
 }
 while(1) {
  $i$1$us = $i$016$us;
  while(1) {
   $4 = (($string) + ($i$1$us)|0);
   $5 = HEAP8[$4>>0]|0;
   if (!((($5<<24>>24) == 32) | (($5<<24>>24) == 9))) {
    $$lcssa = $4;$$lcssa40 = $5;$i$1$us$lcssa = $i$1$us;
    break;
   }
   $6 = (($i$1$us) + 1)|0;
   $i$1$us = $6;
  }
  $7 = ($$lcssa40<<24>>24)==(0);
  $8 = HEAP8[36152>>0]|0;
  $9 = ($$lcssa40<<24>>24)==($8<<24>>24);
  $or$cond9$us = $7 | $9;
  if ($or$cond9$us) {
   $result$0$lcssa = $result$015$us;
   label = 27;
   break;
  }
  $10 = (_history_tokenize_word($string,$i$1$us$lcssa)|0);
  $11 = ($10|0)==($i$1$us$lcssa|0);
  $12 = HEAP32[36160>>2]|0;
  $13 = ($12|0)!=(0|0);
  $or$cond4$us = $11 & $13;
  L33: do {
   if ($or$cond4$us) {
    $i$2$in$us = $i$1$us$lcssa;
    while(1) {
     $i$2$us = (($i$2$in$us) + 1)|0;
     $14 = (($string) + ($i$2$us)|0);
     $15 = HEAP8[$14>>0]|0;
     $16 = ($15<<24>>24)==(0);
     if ($16) {
      $i$3$us = $i$2$us;
      break L33;
     }
     $17 = $15 << 24 >> 24;
     $18 = (_strchr($12,$17)|0);
     $19 = ($18|0)==(0|0);
     if ($19) {
      $i$3$us = $i$2$us;
      break;
     } else {
      $i$2$in$us = $i$2$us;
     }
    }
   } else {
    $i$3$us = $10;
   }
  } while(0);
  $$not$us = ($i$1$us$lcssa|0)<=($wind|0);
  $20 = ($i$3$us|0)>($wind|0);
  $or$cond11$us = $$not$us & $20;
  if ($or$cond11$us) {
   HEAP32[$indp>>2] = $result_index$017$us;
  }
  $21 = (($result_index$017$us) + 2)|0;
  $22 = ($21|0)<($size$018$us|0);
  if ($22) {
   $result$1$us = $result$015$us;$size$1$us = $size$018$us;
  } else {
   $23 = (($size$018$us) + 10)|0;
   $24 = $23 << 2;
   $25 = (_xrealloc($result$015$us,$24)|0);
   $result$1$us = $25;$size$1$us = $23;
  }
  $26 = (($i$3$us) - ($i$1$us$lcssa))|0;
  $27 = (($26) + 1)|0;
  $28 = (_xmalloc($27)|0);
  (_strncpy(($28|0),($$lcssa|0),($26|0))|0);
  $29 = (($28) + ($26)|0);
  HEAP8[$29>>0] = 0;
  $30 = (($result_index$017$us) + 1)|0;
  $31 = (($result$1$us) + ($result_index$017$us<<2)|0);
  HEAP32[$31>>2] = $28;
  $32 = (($result$1$us) + ($30<<2)|0);
  HEAP32[$32>>2] = 0;
  $33 = (($string) + ($i$3$us)|0);
  $34 = HEAP8[$33>>0]|0;
  $35 = ($34<<24>>24)==(0);
  if ($35) {
   $result$0$lcssa = $result$1$us;
   label = 27;
   break;
  } else {
   $i$016$us = $i$3$us;$result$015$us = $result$1$us;$result_index$017$us = $30;$size$018$us = $size$1$us;
  }
 }
 if ((label|0) == 27) {
  return ($result$0$lcssa|0);
 }
 return (0)|0;
}
function _history_tokenize_word($string,$ind) {
 $string = $string|0;
 $ind = $ind|0;
 var $$ = 0, $$0 = 0, $$35 = 0, $$9 = 0, $$delimiter$1 = 0, $$delimiter$134 = 0, $$ind = 0, $$ind10 = 0, $$mux = 0, $$phi$trans$insert = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $delimiter$1 = 0, $delimiter$1$ph = 0, $delimiter$2 = 0, $i$0 = 0, $i$1$ph$ = 0, $i$1$ph39 = 0, $i$2 = 0, $i$2$ph = 0, $i$3 = 0;
 var $memchr = 0, $memchr5 = 0, $memchr6 = 0, $memchr7 = 0, $memchr8 = 0, $nestdelim$0$ph38 = 0, $nestdelim$1 = 0, $nestdelim$1$ph = 0, $nestdelim$2 = 0, $or$cond = 0, $or$cond40 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($string) + ($ind)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L1: do {
  if ($2) {
   $delimiter$1$ph = 0;$i$2$ph = $ind;$nestdelim$1$ph = 0;
  } else {
   $3 = $1 << 24 >> 24;
   $memchr8 = (_memchr(36184,$3,4)|0);
   $4 = ($memchr8|0)==(0|0);
   if (!($4)) {
    $5 = (($ind) + 1)|0;
    $$0 = $5;
    return ($$0|0);
   }
   $memchr7 = (_memchr(36192,$3,7)|0);
   $6 = ($memchr7|0)==(0|0);
   L7: do {
    if ($6) {
     $23 = $1;
    } else {
     $7 = (($ind) + 1)|0;
     $8 = (($string) + ($7)|0);
     $9 = HEAP8[$8>>0]|0;
     $10 = ($9<<24>>24)==($1<<24>>24);
     $11 = ($9<<24>>24)!=(36);
     $or$cond = $10 & $11;
     if ($or$cond) {
      $12 = ($1<<24>>24)==(60);
      if ($12) {
       $13 = (($ind) + 2)|0;
       $14 = (($string) + ($13)|0);
       $15 = HEAP8[$14>>0]|0;
       $16 = ($15<<24>>24)==(45);
       $$mux = $16 ? $7 : $ind;
       if ($16) {
        $i$0 = $$mux;
       } else {
        $17 = ($15<<24>>24)==(60);
        $$ind = $17 ? $7 : $ind;
        $i$0 = $$ind;
       }
      } else {
       $i$0 = $ind;
      }
      $18 = (($i$0) + 2)|0;
      $$0 = $18;
      return ($$0|0);
     }
     do {
      if ((($9<<24>>24) == 62)) {
       if ((($1<<24>>24) == 36)) {
        $23 = 36;
        break L7;
       } else if ((($1<<24>>24) == 38)) {
        break;
       } else {
        $$0 = $7;
       }
       return ($$0|0);
      } else if ((($9<<24>>24) == 40)) {
       if ((($1<<24>>24) == 36) | (($1<<24>>24) == 60) | (($1<<24>>24) == 62)) {
        $20 = (($ind) + 2)|0;
        $delimiter$1$ph = 41;$i$2$ph = $20;$nestdelim$1$ph = 1;
        break L1;
       } else {
        $$0 = $7;
        return ($$0|0);
       }
      } else if ((($9<<24>>24) == 38)) {
       if ((($1<<24>>24) == 36)) {
        $23 = 36;
        break L7;
       } else if ((($1<<24>>24) == 60) | (($1<<24>>24) == 62)) {
        break;
       } else {
        $$0 = $7;
       }
       return ($$0|0);
      } else {
       $21 = ($1<<24>>24)==(36);
       if ($21) {
        $23 = 36;
        break L7;
       } else {
        $$0 = $7;
       }
       return ($$0|0);
      }
     } while(0);
     $19 = (($ind) + 2)|0;
     $$0 = $19;
     return ($$0|0);
    }
   } while(0);
   $22 = $23 << 24 >> 24;
   $memchr6 = (_memchr(36200,$22,6)|0);
   $24 = ($memchr6|0)==(0|0);
   if ($24) {
    $32 = $1;$i$1$ph39 = $ind;$nestdelim$0$ph38 = 0;
   } else {
    $25 = (($ind) + 1)|0;
    $26 = (($string) + ($25)|0);
    $27 = HEAP8[$26>>0]|0;
    $28 = ($27<<24>>24)==(40);
    $29 = (($ind) + 2)|0;
    $$9 = $28&1;
    $$ind10 = $28 ? $29 : $ind;
    if ($28) {
     $delimiter$1$ph = 41;$i$2$ph = $$ind10;$nestdelim$1$ph = $$9;
     break;
    }
    $$phi$trans$insert = (($string) + ($$ind10)|0);
    $$pre = HEAP8[$$phi$trans$insert>>0]|0;
    $30 = ($$pre<<24>>24)==(0);
    if ($30) {
     $delimiter$1$ph = 0;$i$2$ph = $$ind10;$nestdelim$1$ph = $$9;
     break;
    } else {
     $32 = $$pre;$i$1$ph39 = $$ind10;$nestdelim$0$ph38 = $$9;
    }
   }
   $31 = $32 << 24 >> 24;
   $memchr5 = (_memchr(36208,$31,4)|0);
   $33 = ($memchr5|0)==(0|0);
   $$ = $33 ? 0 : $31;
   $34 = $33&1;
   $35 = $34 ^ 1;
   $i$1$ph$ = (($35) + ($i$1$ph39))|0;
   $delimiter$1$ph = $$;$i$2$ph = $i$1$ph$;$nestdelim$1$ph = $nestdelim$0$ph38;
  }
 } while(0);
 $36 = HEAP32[36160>>2]|0;
 $delimiter$1 = $delimiter$1$ph;$i$2 = $i$2$ph;$nestdelim$1 = $nestdelim$1$ph;
 L36: while(1) {
  $37 = (($string) + ($i$2)|0);
  $38 = HEAP8[$37>>0]|0;
  if ((($38<<24>>24) == 92)) {
   $39 = (($i$2) + 1)|0;
   $40 = (($string) + ($39)|0);
   $41 = HEAP8[$40>>0]|0;
   $42 = ($41<<24>>24)!=(10);
   $43 = ($delimiter$1|0)==(39);
   $or$cond40 = $42 & $43;
   if ($or$cond40) {
    label = 24;
   } else {
    $delimiter$2 = $delimiter$1;$i$3 = $39;$nestdelim$2 = $nestdelim$1;
   }
  } else if ((($38<<24>>24) == 0)) {
   $$0 = $i$2;
   label = 35;
   break;
  } else {
   label = 24;
  }
  do {
   if ((label|0) == 24) {
    label = 0;
    $44 = ($nestdelim$1|0)==(0);
    if (!($44)) {
     $45 = ($38<<24>>24)==(40);
     if ($45) {
      $46 = (($nestdelim$1) + 1)|0;
      $delimiter$2 = $delimiter$1;$i$3 = $i$2;$nestdelim$2 = $46;
      break;
     }
     $47 = $38 << 24 >> 24;
     $48 = ($47|0)==($delimiter$1|0);
     if ($48) {
      $49 = (($nestdelim$1) + -1)|0;
      $50 = ($49|0)==(0);
      $$delimiter$1 = $50 ? 0 : $delimiter$1;
      $delimiter$2 = $$delimiter$1;$i$3 = $i$2;$nestdelim$2 = $49;
      break;
     }
    }
    $51 = ($delimiter$1|0)==(0);
    if (!($51)) {
     $52 = $38 << 24 >> 24;
     $53 = ($52|0)==($delimiter$1|0);
     $$delimiter$134 = $53 ? 0 : $delimiter$1;
     $delimiter$2 = $$delimiter$134;$i$3 = $i$2;$nestdelim$2 = $nestdelim$1;
     break;
    }
    $54 = ($38<<24>>24)==(0);
    if ($54) {
     $delimiter$2 = 0;$i$3 = $i$2;$nestdelim$2 = $nestdelim$1;
    } else {
     $55 = $38 << 24 >> 24;
     $56 = (_strchr($36,$55)|0);
     $57 = ($56|0)==(0|0);
     if (!($57)) {
      $$0 = $i$2;
      label = 35;
      break L36;
     }
     $memchr = (_memchr(36208,$55,4)|0);
     $58 = ($memchr|0)==(0|0);
     $$35 = $58 ? 0 : $55;
     $delimiter$2 = $$35;$i$3 = $i$2;$nestdelim$2 = $nestdelim$1;
    }
   }
  } while(0);
  $59 = (($i$3) + 1)|0;
  $delimiter$1 = $delimiter$2;$i$2 = $59;$nestdelim$1 = $nestdelim$2;
 }
 if ((label|0) == 35) {
  return ($$0|0);
 }
 return (0)|0;
}
function _history_search($string,$direction) {
 $string = $string|0;
 $direction = $direction|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_history_search_internal($string,$direction,0)|0);
 return ($0|0);
}
function _history_search_prefix($string,$direction) {
 $string = $string|0;
 $direction = $direction|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_history_search_internal($string,$direction,1)|0);
 return ($0|0);
}
function _history_search_internal($string,$direction,$anchored) {
 $string = $string|0;
 $direction = $direction|0;
 $anchored = $anchored|0;
 var $$0 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0;
 var $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$1$be = 0, $i$120 = 0, $i$120$lcssa95 = 0, $i$12096 = 0;
 var $i$12097 = 0, $line_index$0$lcssa12 = 0, $line_index$017 = 0, $line_index$1$lcssa11 = 0, $line_index$116 = 0, $or$cond = 0, $or$cond4 = 0, $or$cond5 = 0, $or$cond8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36088>>2]|0;
 $1 = ($direction|0)<(0);
 $2 = ($string|0)==(0|0);
 if ($2) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = HEAP8[$string>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$0 = -1;
  return ($$0|0);
 }
 $5 = HEAP32[36096>>2]|0;
 $6 = ($5|0)!=(0);
 $7 = ($0|0)<($5|0);
 $or$cond = $1 | $7;
 $or$cond4 = $6 & $or$cond;
 if (!($or$cond4)) {
  $$0 = -1;
  return ($$0|0);
 }
 $$not = $1 ^ 1;
 $or$cond5 = $7 | $$not;
 $8 = (($5) + -1)|0;
 $i$0 = $or$cond5 ? $0 : $8;
 $9 = (_history_list()|0);
 $10 = (_strlen(($string|0))|0);
 $11 = $i$0 & $direction;
 $12 = ($11|0)<(0);
 if ($12) {
  $$0 = -1;
  return ($$0|0);
 }
 $13 = HEAP32[36096>>2]|0;
 $14 = ($anchored|0)==(1);
 $15 = ($10|0)==(0);
 $i$120 = $i$0;
 L13: while(1) {
  $16 = ($i$120|0)==($13|0);
  $or$cond8 = $16 & $$not;
  if ($or$cond8) {
   $$0 = -1;
   label = 38;
   break;
  }
  $17 = (($9) + ($i$120<<2)|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = HEAP32[$18>>2]|0;
  $20 = (_strlen(($19|0))|0);
  $21 = ($20|0)<($10|0);
  do {
   if ($21) {
    if ($1) {
     $22 = (($i$120) + -1)|0;
     $i$1$be = $22;
     break;
    } else {
     $25 = (($i$120) + 1)|0;
     $i$1$be = $25;
     break;
    }
   } else {
    if ($14) {
     if ($15) {
      $i$120$lcssa95 = $i$120;
      label = 16;
      break L13;
     }
     $26 = HEAP8[$string>>0]|0;
     $27 = HEAP8[$19>>0]|0;
     $28 = ($26<<24>>24)==($27<<24>>24);
     if ($28) {
      $29 = (_strncmp($string,$19,$10)|0);
      $30 = ($29|0)==(0);
      if ($30) {
       $i$120$lcssa95 = $i$120;
       label = 16;
       break L13;
      }
     }
     if ($1) {
      $31 = (($i$120) + -1)|0;
      $i$1$be = $31;
      break;
     } else {
      $32 = (($i$120) + 1)|0;
      $i$1$be = $32;
      break;
     }
    }
    $33 = (($20) - ($10))|0;
    $34 = ($33|0)>(-1);
    if ($1) {
     if ($34) {
      if ($15) {
       $i$12097 = $i$120;$line_index$0$lcssa12 = $33;
       label = 26;
       break L13;
      }
      $35 = HEAP8[$string>>0]|0;
      $line_index$017 = $33;
      while(1) {
       $36 = (($19) + ($line_index$017)|0);
       $37 = HEAP8[$36>>0]|0;
       $38 = ($35<<24>>24)==($37<<24>>24);
       if ($38) {
        $39 = (_strncmp($string,$36,$10)|0);
        $40 = ($39|0)==(0);
        if ($40) {
         $i$12097 = $i$120;$line_index$0$lcssa12 = $line_index$017;
         label = 26;
         break L13;
        }
       }
       $41 = (($line_index$017) + -1)|0;
       $42 = ($line_index$017|0)>(0);
       if ($42) {
        $line_index$017 = $41;
       } else {
        label = 35;
        break;
       }
      }
     } else {
      label = 36;
     }
    } else {
     if ($34) {
      if ($15) {
       $i$12096 = $i$120;$line_index$1$lcssa11 = 0;
       label = 33;
       break L13;
      }
      $43 = HEAP8[$string>>0]|0;
      $line_index$116 = 0;
      while(1) {
       $44 = (($19) + ($line_index$116)|0);
       $45 = HEAP8[$44>>0]|0;
       $46 = ($43<<24>>24)==($45<<24>>24);
       if ($46) {
        $47 = (_strncmp($string,$44,$10)|0);
        $48 = ($47|0)==(0);
        if ($48) {
         $i$12096 = $i$120;$line_index$1$lcssa11 = $line_index$116;
         label = 33;
         break L13;
        }
       }
       $49 = (($line_index$116) + 1)|0;
       $50 = ($line_index$116|0)<($33|0);
       if ($50) {
        $line_index$116 = $49;
       } else {
        label = 35;
        break;
       }
      }
     } else {
      label = 37;
     }
    }
    if ((label|0) == 35) {
     label = 0;
     if ($1) {
      label = 36;
     } else {
      label = 37;
     }
    }
    if ((label|0) == 36) {
     label = 0;
     $51 = (($i$120) + -1)|0;
     $i$1$be = $51;
     break;
    }
    else if ((label|0) == 37) {
     label = 0;
     $52 = (($i$120) + 1)|0;
     $i$1$be = $52;
     break;
    }
   }
  } while(0);
  $23 = $i$1$be & $direction;
  $24 = ($23|0)<(0);
  if ($24) {
   $$0 = -1;
   label = 38;
   break;
  } else {
   $i$120 = $i$1$be;
  }
 }
 if ((label|0) == 16) {
  HEAP32[36088>>2] = $i$120$lcssa95;
  $$0 = 0;
  return ($$0|0);
 }
 else if ((label|0) == 26) {
  HEAP32[36088>>2] = $i$12097;
  $$0 = $line_index$0$lcssa12;
  return ($$0|0);
 }
 else if ((label|0) == 33) {
  HEAP32[36088>>2] = $i$12096;
  $$0 = $line_index$1$lcssa11;
  return ($$0|0);
 }
 else if ((label|0) == 38) {
  return ($$0|0);
 }
 return (0)|0;
}
function _sh_set_lines_and_columns($lines,$cols) {
 $lines = $lines|0;
 $cols = $cols|0;
 var $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $lines;
 (_sprintf(36216,37288,$vararg_buffer)|0);
 (_setenv((38568|0),(36216|0),1)|0);
 HEAP32[$vararg_buffer1>>2] = $cols;
 (_sprintf(36216,37288,$vararg_buffer1)|0);
 (_setenv((38576|0),(36216|0),1)|0);
 STACKTOP = sp;return;
}
function _sh_get_env_value($varname) {
 $varname = $varname|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getenv(($varname|0))|0);
 return ($0|0);
}
function _sh_get_home_dir() {
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[36232>>2]|0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $$0 = $0;
  return ($$0|0);
 }
 HEAP32[36232>>2] = 0;
 $2 = (_getuid()|0);
 $3 = (_getpwuid(($2|0))|0);
 $4 = ($3|0)==(0|0);
 if (!($4)) {
  $5 = ((($3)) + 20|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (_strlen(($6|0))|0);
  $8 = (($7) + 1)|0;
  $9 = (_xmalloc($8)|0);
  $10 = HEAP32[$5>>2]|0;
  $11 = (_strcpy(($9|0),($10|0))|0);
  HEAP32[36232>>2] = $11;
 }
 _endpwent();
 $12 = HEAP32[36232>>2]|0;
 $$0 = $12;
 return ($$0|0);
}
function _sh_unset_nodelay_mode($fd) {
 $fd = $fd|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = 0;
 $0 = (_fcntl(($fd|0),3,($vararg_buffer|0))|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $0 & 2048;
 $3 = ($2|0)==(0);
 if ($3) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $4 = $0 & -2049;
 HEAP32[$vararg_buffer1>>2] = $4;
 $5 = (_fcntl(($fd|0),4,($vararg_buffer1|0))|0);
 $$0 = $5;
 STACKTOP = sp;return ($$0|0);
}
function __rl_get_char_len($src,$ps) {
 $src = $src|0;
 $ps = $ps|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($src|0))|0);
 $1 = (_mbrlen($src,$0,$ps)|0);
 if ((($1|0) == 0)) {
  $$0 = 0;
 } else if ((($1|0) == -2)) {
  $2 = ($ps|0)==(0|0);
  if ($2) {
   $$0 = -2;
  } else {
   $3 = $ps;
   $4 = $3;
   HEAP32[$4>>2] = 0;
   $5 = (($3) + 4)|0;
   $6 = $5;
   HEAP32[$6>>2] = 0;
   $$0 = -2;
  }
 } else if ((($1|0) == -1)) {
  $7 = ($ps|0)==(0|0);
  if ($7) {
   $$0 = -1;
  } else {
   $8 = $ps;
   $9 = $8;
   HEAP32[$9>>2] = 0;
   $10 = (($8) + 4)|0;
   $11 = $10;
   HEAP32[$11>>2] = 0;
   $$0 = -1;
  }
 } else {
  $$0 = $1;
 }
 return ($$0|0);
}
function __rl_compare_chars($buf1,$pos1,$ps1,$buf2,$pos2,$ps2) {
 $buf1 = $buf1|0;
 $pos1 = $pos1|0;
 $ps1 = $ps1|0;
 $buf2 = $buf2|0;
 $pos2 = $pos2|0;
 $ps2 = $ps2|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $i$04 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($buf1) + ($pos1)|0);
 $1 = (_strlen(($0|0))|0);
 $2 = (_mbrlen($0,$1,$ps1)|0);
 L1: do {
  if ((($2|0) == 0)) {
   $$0 = 0;
  } else if ((($2|0) == -1)) {
   $8 = ($ps1|0)==(0|0);
   if ($8) {
    $$0 = 0;
   } else {
    $9 = $ps1;
    $10 = $9;
    HEAP32[$10>>2] = 0;
    $11 = (($9) + 4)|0;
    $12 = $11;
    HEAP32[$12>>2] = 0;
    $$0 = 0;
   }
  } else if ((($2|0) == -2)) {
   $3 = ($ps1|0)==(0|0);
   if ($3) {
    $$0 = 0;
   } else {
    $4 = $ps1;
    $5 = $4;
    HEAP32[$5>>2] = 0;
    $6 = (($4) + 4)|0;
    $7 = $6;
    HEAP32[$7>>2] = 0;
    $$0 = 0;
   }
  } else {
   $13 = ($2|0)<(1);
   if ($13) {
    $$0 = 0;
   } else {
    $14 = (($buf2) + ($pos2)|0);
    $15 = (_strlen(($14|0))|0);
    $16 = (_mbrlen($14,$15,$ps2)|0);
    if ((($16|0) == -2)) {
     $17 = ($ps2|0)==(0|0);
     if ($17) {
      $$0 = 0;
      break;
     }
     $18 = $ps2;
     $19 = $18;
     HEAP32[$19>>2] = 0;
     $20 = (($18) + 4)|0;
     $21 = $20;
     HEAP32[$21>>2] = 0;
     $$0 = 0;
     break;
    } else if ((($16|0) == -1)) {
     $22 = ($ps2|0)==(0|0);
     if ($22) {
      $$0 = 0;
      break;
     }
     $23 = $ps2;
     $24 = $23;
     HEAP32[$24>>2] = 0;
     $25 = (($23) + 4)|0;
     $26 = $25;
     HEAP32[$26>>2] = 0;
     $$0 = 0;
     break;
    } else if ((($16|0) == 0)) {
     $$0 = 0;
     break;
    } else {
     $27 = ($16|0)>(0);
     $28 = ($2|0)==($16|0);
     $or$cond = $27 & $28;
     if (!($or$cond)) {
      $$0 = 0;
      break;
     }
     $29 = HEAP8[$0>>0]|0;
     $30 = HEAP8[$14>>0]|0;
     $31 = ($29<<24>>24)==($30<<24>>24);
     if (!($31)) {
      $$0 = 0;
      break;
     }
     $32 = ($2|0)>(1);
     if ($32) {
      $i$04 = 1;
     } else {
      $$0 = 1;
      break;
     }
     while(1) {
      $35 = (($i$04) + ($pos1))|0;
      $36 = (($buf1) + ($35)|0);
      $37 = HEAP8[$36>>0]|0;
      $38 = (($i$04) + ($pos2))|0;
      $39 = (($buf2) + ($38)|0);
      $40 = HEAP8[$39>>0]|0;
      $41 = ($37<<24>>24)==($40<<24>>24);
      $34 = (($i$04) + 1)|0;
      if (!($41)) {
       $$0 = 0;
       break L1;
      }
      $33 = ($34|0)<($2|0);
      if ($33) {
       $i$04 = $34;
      } else {
       $$0 = 1;
       break;
      }
     }
    }
   }
  }
 } while(0);
 return ($$0|0);
}
function __rl_adjust_point($string,$point,$ps) {
 $string = $string|0;
 $point = $point|0;
 $ps = $ps|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $pos$0$be = 0, $pos$0$be$us = 0, $pos$0$lcssa = 0, $pos$02 = 0, $pos$02$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($string|0))|0);
 $1 = ($point|0)<(0);
 $2 = ($0|0)<($point|0);
 $or$cond = $1 | $2;
 if ($or$cond) {
  $$0 = -1;
  return ($$0|0);
 }
 $3 = ($point|0)>(0);
 if ($3) {
  $4 = ($ps|0)==(0|0);
  if ($4) {
   $pos$02$us = 0;
   while(1) {
    $5 = (($string) + ($pos$02$us)|0);
    $6 = (($0) - ($pos$02$us))|0;
    $7 = (_mbrlen($5,$6,0)|0);
    $8 = ($7>>>0)>(4294967293);
    do {
     if ($8) {
      $12 = (($pos$02$us) + 1)|0;
      $pos$0$be$us = $12;
     } else {
      $9 = ($7|0)==(0);
      if ($9) {
       $11 = (($pos$02$us) + 1)|0;
       $pos$0$be$us = $11;
       break;
      } else {
       $10 = (($7) + ($pos$02$us))|0;
       $pos$0$be$us = $10;
       break;
      }
     }
    } while(0);
    $13 = ($pos$0$be$us|0)<($point|0);
    if ($13) {
     $pos$02$us = $pos$0$be$us;
    } else {
     $pos$0$lcssa = $pos$0$be$us;
     break;
    }
   }
  } else {
   $pos$02 = 0;
   while(1) {
    $14 = (($string) + ($pos$02)|0);
    $15 = (($0) - ($pos$02))|0;
    $16 = (_mbrlen($14,$15,$ps)|0);
    $17 = ($16>>>0)>(4294967293);
    do {
     if ($17) {
      $18 = (($pos$02) + 1)|0;
      $19 = $ps;
      $20 = $19;
      HEAP32[$20>>2] = 0;
      $21 = (($19) + 4)|0;
      $22 = $21;
      HEAP32[$22>>2] = 0;
      $pos$0$be = $18;
     } else {
      $23 = ($16|0)==(0);
      if ($23) {
       $24 = (($pos$02) + 1)|0;
       $pos$0$be = $24;
       break;
      } else {
       $26 = (($16) + ($pos$02))|0;
       $pos$0$be = $26;
       break;
      }
     }
    } while(0);
    $25 = ($pos$0$be|0)<($point|0);
    if ($25) {
     $pos$02 = $pos$0$be;
    } else {
     $pos$0$lcssa = $pos$0$be;
     break;
    }
   }
  }
 } else {
  $pos$0$lcssa = 0;
 }
 $27 = (($pos$0$lcssa) - ($point))|0;
 $$0 = $27;
 return ($$0|0);
}
function __rl_is_mbchar_matched($string,$seed,$end,$mbchar,$length) {
 $string = $string|0;
 $seed = $seed|0;
 $end = $end|0;
 $mbchar = $mbchar|0;
 $length = $length|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$01 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($end) - ($seed))|0;
 $1 = ($0|0)<($length|0);
 if ($1) {
  $$0 = 0;
  return ($$0|0);
 }
 $2 = ($length|0)>(0);
 if ($2) {
  $i$01 = 0;
 } else {
  $$0 = 1;
  return ($$0|0);
 }
 while(1) {
  $5 = (($i$01) + ($seed))|0;
  $6 = (($string) + ($5)|0);
  $7 = HEAP8[$6>>0]|0;
  $8 = (($mbchar) + ($i$01)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = ($7<<24>>24)==($9<<24>>24);
  $4 = (($i$01) + 1)|0;
  if (!($10)) {
   $$0 = 0;
   label = 5;
   break;
  }
  $3 = ($4|0)<($length|0);
  if ($3) {
   $i$01 = $4;
  } else {
   $$0 = 1;
   label = 5;
   break;
  }
 }
 if ((label|0) == 5) {
  return ($$0|0);
 }
 return (0)|0;
}
function __rl_char_value($buf,$ind) {
 $buf = $buf|0;
 $ind = $ind|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ps = 0, $wc = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $wc = sp + 8|0;
 $ps = sp;
 $0 = HEAP32[36240>>2]|0;
 $1 = ($0|0)==(0);
 if (!($1)) {
  $2 = (($buf) + ($ind)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3 << 24 >> 24;
  $$0 = $4;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = (_strlen(($buf|0))|0);
 $6 = (($5) + -1)|0;
 $7 = ($6|0)>($ind|0);
 if (!($7)) {
  $8 = (($buf) + ($ind)|0);
  $9 = HEAP8[$8>>0]|0;
  $10 = $9 << 24 >> 24;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = $ps;
 $12 = $11;
 HEAP32[$12>>2] = 0;
 $13 = (($11) + 4)|0;
 $14 = $13;
 HEAP32[$14>>2] = 0;
 $15 = (($buf) + ($ind)|0);
 $16 = (($5) - ($ind))|0;
 $17 = (_mbrtowc($wc,$15,$16,$ps)|0);
 $18 = (($17) + -1)|0;
 $19 = ($18>>>0)>(4294967292);
 if ($19) {
  $20 = HEAP8[$15>>0]|0;
  $21 = $20 << 24 >> 24;
  $$0 = $21;
  STACKTOP = sp;return ($$0|0);
 } else {
  $22 = HEAP32[$wc>>2]|0;
  $$0 = $22;
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function __rl_find_next_mbchar($string,$seed,$count,$flags) {
 $string = $string|0;
 $seed = $seed|0;
 $count = $count|0;
 $flags = $flags|0;
 var $$0$i = 0, $$0$i$i = 0, $$04$$i = 0, $$04$be$i = 0, $$04$be$us$i = 0, $$045$i = 0, $$045$us$i = 0, $$count$i = 0, $$seed$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0;
 var $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $7 = 0, $8 = 0, $9 = 0, $not$$i = 0, $point$0$be$i = 0;
 var $point$0$be$us$i = 0, $point$0$lcssa$i = 0, $point$06$i = 0, $point$06$us$i = 0, $point$1$i = 0, $pos$0$be$i$i = 0, $pos$0$lcssa$i$i = 0, $pos$02$i$i = 0, $ps$i = 0, $tmp$0$i = 0, $wc$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps$i = sp;
 $wc$i = sp + 8|0;
 $0 = $ps$i;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = ($seed|0)<(0);
 $$seed$i = $4 ? 0 : $seed;
 $5 = ($count|0)<(1);
 if ($5) {
  $$0$i = $$seed$i;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = (_strlen(($string|0))|0);
 $7 = ($6|0)<($$seed$i|0);
 if ($7) {
  $$0$i$i = -1;
 } else {
  $8 = ($$seed$i|0)>(0);
  if ($8) {
   $pos$02$i$i = 0;
   while(1) {
    $9 = (($string) + ($pos$02$i$i)|0);
    $10 = (($6) - ($pos$02$i$i))|0;
    $11 = (_mbrlen($9,$10,$ps$i)|0);
    $12 = ($11>>>0)>(4294967293);
    do {
     if ($12) {
      $13 = (($pos$02$i$i) + 1)|0;
      $14 = $ps$i;
      $15 = $14;
      HEAP32[$15>>2] = 0;
      $16 = (($14) + 4)|0;
      $17 = $16;
      HEAP32[$17>>2] = 0;
      $pos$0$be$i$i = $13;
     } else {
      $18 = ($11|0)==(0);
      if ($18) {
       $19 = (($pos$02$i$i) + 1)|0;
       $pos$0$be$i$i = $19;
       break;
      } else {
       $21 = (($11) + ($pos$02$i$i))|0;
       $pos$0$be$i$i = $21;
       break;
      }
     }
    } while(0);
    $20 = ($pos$0$be$i$i|0)<($$seed$i|0);
    if ($20) {
     $pos$02$i$i = $pos$0$be$i$i;
    } else {
     $pos$0$lcssa$i$i = $pos$0$be$i$i;
     break;
    }
   }
  } else {
   $pos$0$lcssa$i$i = 0;
  }
  $22 = (($pos$0$lcssa$i$i) - ($$seed$i))|0;
  $$0$i$i = $22;
 }
 $23 = (($$0$i$i) + ($$seed$i))|0;
 $24 = ($$0$i$i|0)>(0);
 $25 = $24 << 31 >> 31;
 $$count$i = (($25) + ($count))|0;
 $26 = ($$count$i|0)>(0);
 L18: do {
  if ($26) {
   $27 = ($flags|0)==(0);
   if ($27) {
    $$045$us$i = $$count$i;$point$06$us$i = $23;
    while(1) {
     $28 = (($string) + ($point$06$us$i)|0);
     $29 = (_strlen(($28|0))|0);
     $30 = ($29|0)==(0);
     if ($30) {
      $point$0$lcssa$i = $point$06$us$i;
      break L18;
     }
     $31 = (_mbrtowc($wc$i,$28,$29,$ps$i)|0);
     $32 = ($31>>>0)>(4294967293);
     if ($32) {
      $35 = (($point$06$us$i) + 1)|0;
      $36 = $ps$i;
      $37 = $36;
      HEAP32[$37>>2] = 0;
      $38 = (($36) + 4)|0;
      $39 = $38;
      HEAP32[$39>>2] = 0;
      $point$0$be$us$i = $35;
     } else {
      $33 = ($31|0)==(0);
      if ($33) {
       $point$0$lcssa$i = $point$06$us$i;
       break L18;
      }
      $34 = (($31) + ($point$06$us$i))|0;
      $point$0$be$us$i = $34;
     }
     $$04$be$us$i = (($$045$us$i) + -1)|0;
     $40 = ($$045$us$i|0)>(1);
     if ($40) {
      $$045$us$i = $$04$be$us$i;$point$06$us$i = $point$0$be$us$i;
     } else {
      $point$0$lcssa$i = $point$0$be$us$i;
      break;
     }
    }
   } else {
    $$045$i = $$count$i;$point$06$i = $23;
    while(1) {
     $41 = (($string) + ($point$06$i)|0);
     $42 = (_strlen(($41|0))|0);
     $43 = ($42|0)==(0);
     if ($43) {
      $point$0$lcssa$i = $point$06$i;
      break L18;
     }
     $44 = (_mbrtowc($wc$i,$41,$42,$ps$i)|0);
     $45 = ($44>>>0)>(4294967293);
     if ($45) {
      $46 = (($point$06$i) + 1)|0;
      $47 = (($$045$i) + -1)|0;
      $48 = $ps$i;
      $49 = $48;
      HEAP32[$49>>2] = 0;
      $50 = (($48) + 4)|0;
      $51 = $50;
      HEAP32[$51>>2] = 0;
      $$04$be$i = $47;$point$0$be$i = $46;
     } else {
      $52 = ($44|0)==(0);
      if ($52) {
       $point$0$lcssa$i = $point$06$i;
       break L18;
      }
      $53 = (($44) + ($point$06$i))|0;
      $54 = HEAP32[$wc$i>>2]|0;
      $55 = (_wcwidth($54)|0);
      $not$$i = ($55|0)!=(0);
      $56 = $not$$i << 31 >> 31;
      $$04$$i = (($56) + ($$045$i))|0;
      $$04$be$i = $$04$$i;$point$0$be$i = $53;
     }
     $57 = ($$04$be$i|0)>(0);
     if ($57) {
      $$045$i = $$04$be$i;$point$06$i = $point$0$be$i;
     } else {
      $point$0$lcssa$i = $point$0$be$i;
      break;
     }
    }
   }
  } else {
   $point$0$lcssa$i = $23;
  }
 } while(0);
 $58 = ($flags|0)==(0);
 if ($58) {
  $$0$i = $point$0$lcssa$i;
  STACKTOP = sp;return ($$0$i|0);
 }
 $59 = (($string) + ($point$0$lcssa$i)|0);
 $60 = (_strlen(($59|0))|0);
 $61 = (_mbrtowc($wc$i,$59,$60,$ps$i)|0);
 $point$1$i = $point$0$lcssa$i;$tmp$0$i = $61;
 while(1) {
  if ((($tmp$0$i|0) == 0) | (($tmp$0$i|0) == -2) | (($tmp$0$i|0) == -1)) {
   $$0$i = $point$1$i;
   label = 30;
   break;
  }
  $62 = HEAP32[$wc$i>>2]|0;
  $63 = (_wcwidth($62)|0);
  $64 = ($63|0)==(0);
  if (!($64)) {
   $$0$i = $point$1$i;
   label = 30;
   break;
  }
  $65 = (($point$1$i) + ($tmp$0$i))|0;
  $66 = (($string) + ($65)|0);
  $67 = (_strlen(($66|0))|0);
  $68 = (_mbrtowc($wc$i,$66,$67,$ps$i)|0);
  $point$1$i = $65;$tmp$0$i = $68;
 }
 if ((label|0) == 30) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return (0)|0;
}
function __rl_find_prev_mbchar($string,$seed,$flags) {
 $string = $string|0;
 $seed = $seed|0;
 $flags = $flags|0;
 var $$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $point$03$i = 0, $point$03$us$i = 0, $prev$0$point$0$i = 0, $prev$02$i = 0, $prev$02$us$i = 0;
 var $prev$02$us$i$phi = 0, $prev$1$i = 0, $ps$i = 0, $tmp$0$i = 0, $tmp$0$us$i = 0, $wc$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ps$i = sp;
 $wc$i = sp + 8|0;
 $0 = $ps$i;
 $1 = $0;
 HEAP32[$1>>2] = 0;
 $2 = (($0) + 4)|0;
 $3 = $2;
 HEAP32[$3>>2] = 0;
 $4 = (_strlen(($string|0))|0);
 $5 = ($seed|0)<(0);
 if ($5) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $6 = ($4|0)<($seed|0);
 if ($6) {
  $$0$i = $4;
  STACKTOP = sp;return ($$0$i|0);
 }
 $7 = ($seed|0)>(0);
 if (!($7)) {
  $$0$i = 0;
  STACKTOP = sp;return ($$0$i|0);
 }
 $8 = ($flags|0)==(0);
 if ($8) {
  $point$03$us$i = 0;$prev$02$us$i = 0;
  while(1) {
   $9 = (($string) + ($point$03$us$i)|0);
   $10 = (($4) - ($point$03$us$i))|0;
   $11 = (_mbrtowc($wc$i,$9,$10,$ps$i)|0);
   $12 = ($11>>>0)>(4294967293);
   if ($12) {
    $14 = $ps$i;
    $15 = $14;
    HEAP32[$15>>2] = 0;
    $16 = (($14) + 4)|0;
    $17 = $16;
    HEAP32[$17>>2] = 0;
    $tmp$0$us$i = 1;
   } else {
    $13 = ($11|0)==(0);
    if ($13) {
     $$0$i = $prev$02$us$i;
     label = 14;
     break;
    } else {
     $tmp$0$us$i = $11;
    }
   }
   $18 = (($tmp$0$us$i) + ($point$03$us$i))|0;
   $19 = ($18|0)<($seed|0);
   if ($19) {
    $prev$02$us$i$phi = $point$03$us$i;$point$03$us$i = $18;$prev$02$us$i = $prev$02$us$i$phi;
   } else {
    $$0$i = $point$03$us$i;
    label = 14;
    break;
   }
  }
  if ((label|0) == 14) {
   STACKTOP = sp;return ($$0$i|0);
  }
 } else {
  $point$03$i = 0;$prev$02$i = 0;
 }
 while(1) {
  $20 = (($string) + ($point$03$i)|0);
  $21 = (($4) - ($point$03$i))|0;
  $22 = (_mbrtowc($wc$i,$20,$21,$ps$i)|0);
  $23 = ($22>>>0)>(4294967293);
  if ($23) {
   $24 = $ps$i;
   $25 = $24;
   HEAP32[$25>>2] = 0;
   $26 = (($24) + 4)|0;
   $27 = $26;
   HEAP32[$27>>2] = 0;
   $prev$1$i = $point$03$i;$tmp$0$i = 1;
  } else {
   $28 = ($22|0)==(0);
   if ($28) {
    $$0$i = $prev$02$i;
    label = 14;
    break;
   }
   $29 = HEAP32[$wc$i>>2]|0;
   $30 = (_wcwidth($29)|0);
   $31 = ($30|0)==(0);
   $prev$0$point$0$i = $31 ? $prev$02$i : $point$03$i;
   $prev$1$i = $prev$0$point$0$i;$tmp$0$i = $22;
  }
  $32 = (($tmp$0$i) + ($point$03$i))|0;
  $33 = ($32|0)<($seed|0);
  if ($33) {
   $point$03$i = $32;$prev$02$i = $prev$1$i;
  } else {
   $$0$i = $prev$1$i;
   label = 14;
   break;
  }
 }
 if ((label|0) == 14) {
  STACKTOP = sp;return ($$0$i|0);
 }
 return (0)|0;
}
function _tilde_expand($string) {
 $string = $string|0;
 var $$0 = 0, $$0$i = 0, $$lcssa = 0, $$lcssa41 = 0, $$sum = 0, $$sum2 = 0, $$sum3 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $8 = 0;
 var $9 = 0, $i$03$i = 0, $i$04$i = 0, $i$04$i$lcssa = 0, $i$06$i = 0, $i$06$us$i = 0, $j$03$i = 0, $j$04$i12 = 0, $or$cond$i = 0, $phitmp$i = 0, $result$0 = 0, $result$1 = 0, $result$1$lcssa = 0, $result$2 = 0, $result_index$0 = 0, $result_size$0 = 0, $result_size$1 = 0, $result_size$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strchr($string,126)|0);
 $1 = ($0|0)==(0|0);
 $2 = (_strlen(($string|0))|0);
 if ($1) {
  $5 = (($2) + 1)|0;
  $6 = (_xmalloc($5)|0);
  $$0 = $string;$result$0 = $6;$result_index$0 = 0;$result_size$0 = $5;
 } else {
  $3 = (($2) + 16)|0;
  $4 = (_xmalloc($3)|0);
  $$0 = $string;$result$0 = $4;$result_index$0 = 0;$result_size$0 = $3;
 }
 while(1) {
  $7 = HEAP32[36272>>2]|0;
  $8 = (_strlen(($$0|0))|0);
  $9 = HEAP8[$$0>>0]|0;
  L6: do {
   if ((($9<<24>>24) == 126) | (($9<<24>>24) == 0)) {
    $$0$i = 0;
   } else {
    $10 = ($7|0)!=(0|0);
    $11 = ($8|0)>(0);
    $or$cond$i = $10 & $11;
    if ($or$cond$i) {
     $12 = HEAP32[$7>>2]|0;
     $13 = ($12|0)==(0|0);
     if ($13) {
      $$0$i = $8;
     } else {
      $i$04$i = 0;
      L9: while(1) {
       $14 = (($$0) + ($i$04$i)|0);
       $19 = $12;$j$03$i = 0;
       while(1) {
        $20 = (_strlen(($19|0))|0);
        $21 = (_strncmp($14,$19,$20)|0);
        $22 = ($21|0)==(0);
        $16 = (($j$03$i) + 1)|0;
        if ($22) {
         $$lcssa = $20;$i$04$i$lcssa = $i$04$i;
         break L9;
        }
        $15 = (($7) + ($16<<2)|0);
        $17 = HEAP32[$15>>2]|0;
        $18 = ($17|0)==(0|0);
        if ($18) {
         break;
        } else {
         $19 = $17;$j$03$i = $16;
        }
       }
       $24 = (($i$04$i) + 1)|0;
       $25 = ($24|0)<($8|0);
       if ($25) {
        $i$04$i = $24;
       } else {
        $$0$i = $8;
        break L6;
       }
      }
      $phitmp$i = (($i$04$i$lcssa) + -1)|0;
      $23 = (($phitmp$i) + ($$lcssa))|0;
      $$0$i = $23;
     }
    } else {
     $$0$i = $8;
    }
   }
  } while(0);
  $26 = (($$0$i) + ($result_index$0))|0;
  $27 = ($26|0)<($result_size$0|0);
  if ($27) {
   $result$1 = $result$0;$result_size$1 = $result_size$0;
  } else {
   $28 = (($result_size$0) + 20)|0;
   $29 = (($28) + ($$0$i))|0;
   $30 = (($29) + 1)|0;
   $31 = (_xrealloc($result$0,$30)|0);
   $result$1 = $31;$result_size$1 = $29;
  }
  $32 = (($result$1) + ($result_index$0)|0);
  (_strncpy(($32|0),($$0|0),($$0$i|0))|0);
  $33 = (($$0) + ($$0$i)|0);
  $34 = HEAP32[36280>>2]|0;
  $35 = (_strlen(($33|0))|0);
  $36 = ($35|0)>(0);
  L20: do {
   if ($36) {
    $37 = ($34|0)==(0|0);
    if ($37) {
     $i$06$us$i = 0;
     while(1) {
      $$sum3 = (($i$06$us$i) + ($$0$i))|0;
      $38 = (($$0) + ($$sum3)|0);
      $39 = HEAP8[$38>>0]|0;
      $40 = ($39<<24>>24)==(47);
      if ($40) {
       $i$03$i = $i$06$us$i;
       break L20;
      }
      $41 = (($i$06$us$i) + 1)|0;
      $42 = ($41|0)<($35|0);
      if ($42) {
       $i$06$us$i = $41;
      } else {
       $i$03$i = $41;
       break L20;
      }
     }
    } else {
     $i$06$i = 0;
    }
    while(1) {
     $$sum2 = (($i$06$i) + ($$0$i))|0;
     $43 = (($$0) + ($$sum2)|0);
     $44 = HEAP8[$43>>0]|0;
     $45 = ($44<<24>>24)==(47);
     if ($45) {
      $i$03$i = $i$06$i;
      break L20;
     }
     $46 = HEAP32[$34>>2]|0;
     $47 = ($46|0)==(0|0);
     if (!($47)) {
      $52 = $46;$j$04$i12 = 0;
      while(1) {
       $53 = (_strlen(($52|0))|0);
       $54 = (_strncmp($43,$52,$53)|0);
       $55 = ($54|0)==(0);
       $49 = (($j$04$i12) + 1)|0;
       if ($55) {
        $i$03$i = $i$06$i;
        break L20;
       }
       $48 = (($34) + ($49<<2)|0);
       $50 = HEAP32[$48>>2]|0;
       $51 = ($50|0)==(0|0);
       if ($51) {
        break;
       } else {
        $52 = $50;$j$04$i12 = $49;
       }
      }
     }
     $56 = (($i$06$i) + 1)|0;
     $57 = ($56|0)<($35|0);
     if ($57) {
      $i$06$i = $56;
     } else {
      $i$03$i = $56;
      break;
     }
    }
   } else {
    $i$03$i = 0;
   }
  } while(0);
  $58 = $i$03$i | $$0$i;
  $59 = ($58|0)==(0);
  if ($59) {
   $$lcssa41 = $26;$result$1$lcssa = $result$1;
   break;
  }
  $60 = (($i$03$i) + 1)|0;
  $61 = (_xmalloc($60)|0);
  (_strncpy(($61|0),($33|0),($i$03$i|0))|0);
  $62 = (($61) + ($i$03$i)|0);
  HEAP8[$62>>0] = 0;
  $$sum = (($i$03$i) + ($$0$i))|0;
  $63 = (($$0) + ($$sum)|0);
  $64 = (_tilde_expand_word($61)|0);
  _xfree($61);
  $65 = (_strlen(($64|0))|0);
  $66 = (($65) + ($26))|0;
  $67 = ($66|0)<($result_size$1|0);
  if ($67) {
   $result$2 = $result$1;$result_size$2 = $result_size$1;
  } else {
   $68 = (($result_size$1) + 20)|0;
   $69 = (($68) + ($65))|0;
   $70 = (($69) + 1)|0;
   $71 = (_xrealloc($result$1,$70)|0);
   $result$2 = $71;$result_size$2 = $69;
  }
  $72 = (($result$2) + ($26)|0);
  (_strcpy(($72|0),($64|0))|0);
  _xfree($64);
  $$0 = $63;$result$0 = $result$2;$result_index$0 = $66;$result_size$0 = $result_size$2;
 }
 $73 = (($result$1$lcssa) + ($$lcssa41)|0);
 HEAP8[$73>>0] = 0;
 return ($result$1$lcssa|0);
}
function _tilde_expand_word($filename) {
 $filename = $filename|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa12 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $8 = 0;
 var $9 = 0, $dirname$1 = 0, $expansion$04 = 0, $expansion$05 = 0, $i$0$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($filename|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = HEAP8[$filename>>0]|0;
 $2 = ($1<<24>>24)==(126);
 if (!($2)) {
  $3 = (_strlen(($filename|0))|0);
  $4 = (($3) + 1)|0;
  $5 = (_xmalloc($4)|0);
  $6 = (_strcpy(($5|0),($filename|0))|0);
  $$0 = $6;
  return ($$0|0);
 }
 $7 = ((($filename)) + 1|0);
 $8 = HEAP8[$7>>0]|0;
 if ((($8<<24>>24) == 47) | (($8<<24>>24) == 0)) {
  $9 = (_sh_get_env_value(36288)|0);
  $10 = ($9|0)==(0|0);
  if ($10) {
   $11 = (_sh_get_home_dir()|0);
   $12 = ($11|0)==(0|0);
   if ($12) {
    $18 = 0;$expansion$05 = 0;
   } else {
    $expansion$04 = $11;
    label = 7;
   }
  } else {
   $expansion$04 = $9;
   label = 7;
  }
  if ((label|0) == 7) {
   $13 = HEAP8[$expansion$04>>0]|0;
   $14 = ($13<<24>>24)==(0);
   if ($14) {
    $18 = 0;$expansion$05 = $expansion$04;
   } else {
    $15 = (_strlen(($expansion$04|0))|0);
    $18 = $15;$expansion$05 = $expansion$04;
   }
  }
  $16 = (_strlen(($7|0))|0);
  $17 = (($18) + 1)|0;
  $19 = (($17) + ($16))|0;
  $20 = (_xmalloc($19)|0);
  $21 = ($18|0)==(0);
  if (!($21)) {
   (_strcpy(($20|0),($expansion$05|0))|0);
  }
  $22 = (($20) + ($18)|0);
  (_strcpy(($22|0),($7|0))|0);
  $$0 = $20;
  return ($$0|0);
 }
 $23 = (_strlen(($filename|0))|0);
 $24 = (_xmalloc($23)|0);
 $i$0$i = 1;
 while(1) {
  $25 = (($filename) + ($i$0$i)|0);
  $26 = HEAP8[$25>>0]|0;
  $27 = (($i$0$i) + -1)|0;
  $28 = (($24) + ($27)|0);
  if ((($26<<24>>24) == 0) | (($26<<24>>24) == 47)) {
   $$lcssa = $25;$$lcssa12 = $28;
   break;
  }
  HEAP8[$28>>0] = $26;
  $29 = (($i$0$i) + 1)|0;
  $i$0$i = $29;
 }
 HEAP8[$$lcssa12>>0] = 0;
 $30 = HEAP32[36256>>2]|0;
 $31 = ($30|0)==(0|0);
 if (!($31)) {
  $32 = (FUNCTION_TABLE_ii[$30 & 511]($24)|0);
  $33 = ($32|0)==(0|0);
  if (!($33)) {
   $34 = HEAP8[$32>>0]|0;
   $35 = ($34<<24>>24)==(0);
   if ($35) {
    $39 = 0;
   } else {
    $36 = (_strlen(($32|0))|0);
    $39 = $36;
   }
   $37 = (_strlen(($$lcssa|0))|0);
   $38 = (($39) + 1)|0;
   $40 = (($38) + ($37))|0;
   $41 = (_xmalloc($40)|0);
   $42 = ($39|0)==(0);
   if (!($42)) {
    (_strcpy(($41|0),($32|0))|0);
   }
   $43 = (($41) + ($39)|0);
   (_strcpy(($43|0),($$lcssa|0))|0);
   _xfree($24);
   _xfree($32);
   $$0 = $41;
   return ($$0|0);
  }
 }
 $44 = (_getpwnam(($24|0))|0);
 $45 = ($44|0)==(0|0);
 do {
  if ($45) {
   $46 = HEAP32[36264>>2]|0;
   $47 = ($46|0)==(0|0);
   if (!($47)) {
    $48 = (FUNCTION_TABLE_ii[$46 & 511]($24)|0);
    $49 = ($48|0)==(0|0);
    if (!($49)) {
     $50 = HEAP8[$48>>0]|0;
     $51 = ($50<<24>>24)==(0);
     if ($51) {
      $55 = 0;
     } else {
      $52 = (_strlen(($48|0))|0);
      $55 = $52;
     }
     $53 = (_strlen(($$lcssa|0))|0);
     $54 = (($55) + 1)|0;
     $56 = (($54) + ($53))|0;
     $57 = (_xmalloc($56)|0);
     $58 = ($55|0)==(0);
     if (!($58)) {
      (_strcpy(($57|0),($48|0))|0);
     }
     $59 = (($57) + ($55)|0);
     (_strcpy(($59|0),($$lcssa|0))|0);
     _xfree($48);
     $60 = ($57|0)==(0|0);
     if (!($60)) {
      $dirname$1 = $57;
      break;
     }
    }
   }
   $61 = (_strlen(($filename|0))|0);
   $62 = (($61) + 1)|0;
   $63 = (_xmalloc($62)|0);
   $64 = (_strcpy(($63|0),($filename|0))|0);
   $dirname$1 = $64;
  } else {
   $65 = ((($44)) + 20|0);
   $66 = HEAP32[$65>>2]|0;
   $67 = ($66|0)==(0|0);
   if ($67) {
    $73 = 0;
   } else {
    $68 = HEAP8[$66>>0]|0;
    $69 = ($68<<24>>24)==(0);
    if ($69) {
     $73 = 0;
    } else {
     $70 = (_strlen(($66|0))|0);
     $73 = $70;
    }
   }
   $71 = (_strlen(($$lcssa|0))|0);
   $72 = (($73) + 1)|0;
   $74 = (($72) + ($71))|0;
   $75 = (_xmalloc($74)|0);
   $76 = ($73|0)==(0);
   if (!($76)) {
    (_strcpy(($75|0),($66|0))|0);
   }
   $77 = (($75) + ($73)|0);
   (_strcpy(($77|0),($$lcssa|0))|0);
   $dirname$1 = $75;
  }
 } while(0);
 _xfree($24);
 _endpwent();
 $$0 = $dirname$1;
 return ($$0|0);
}
function __rl_put_indicator($ind) {
 $ind = $ind|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($ind)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = HEAP32[$ind>>2]|0;
 $3 = HEAP32[13512>>2]|0;
 (_fwrite(($1|0),($2|0),1,($3|0))|0);
 return;
}
function __rl_set_normal_color() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $lhsc$i = 0, $not$$i = 0, $phitmp$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(36400)>>2]|0;
 $1 = HEAP32[(36404)>>2]|0;
 if ((($0|0) == 0)) {
  return;
 } else if ((($0|0) == 1)) {
  $lhsc$i = HEAP8[$1>>0]|0;
  $not$$i = ($lhsc$i<<24>>24)==(48);
  if ($not$$i) {
   return;
  }
 } else if ((($0|0) == 2)) {
  $2 = (_strncmp($1,36360,2)|0);
  $phitmp$i = ($2|0)==(0);
  if ($phitmp$i) {
   return;
  }
 }
 $3 = HEAP32[(36372)>>2]|0;
 $4 = HEAP32[36368>>2]|0;
 $5 = HEAP32[13512>>2]|0;
 (_fwrite(($3|0),($4|0),1,($5|0))|0);
 $6 = HEAP32[(36404)>>2]|0;
 $7 = HEAP32[(36400)>>2]|0;
 $8 = HEAP32[13512>>2]|0;
 (_fwrite(($6|0),($7|0),1,($8|0))|0);
 $9 = HEAP32[(36380)>>2]|0;
 $10 = HEAP32[(36376)>>2]|0;
 $11 = HEAP32[13512>>2]|0;
 (_fwrite(($9|0),($10|0),1,($11|0))|0);
 return;
}
function __rl_print_color_indicator($f) {
 $f = $f|0;
 var $$0 = 0, $$3 = 0, $$mux = 0, $$not = 0, $$sum = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0;
 var $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0;
 var $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $9 = 0, $astat = 0, $brmerge = 0, $colored_filetype$045 = 0, $ext$0 = 0, $ext$051 = 0, $ext$052 = 0;
 var $ext$1 = 0, $filename = 0, $lhsc$i = 0, $lhsc$i14 = 0, $lhsc$i19 = 0, $lhsc$i24 = 0, $lhsc$i29 = 0, $lhsc$i34 = 0, $lhsc$i4 = 0, $lhsc$i9 = 0, $name$0 = 0, $not$$i = 0, $not$$i10 = 0, $not$$i15 = 0, $not$$i20 = 0, $not$$i25 = 0, $not$$i30 = 0, $not$$i35 = 0, $not$$i5 = 0, $or$cond = 0;
 var $phitmp$i = 0, $phitmp$i11 = 0, $phitmp$i16 = 0, $phitmp$i21 = 0, $phitmp$i26 = 0, $phitmp$i31 = 0, $phitmp$i36 = 0, $phitmp$i6 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $filename = sp + 76|0;
 $astat = sp;
 HEAP32[$filename>>2] = 0;
 $0 = HEAP32[29016>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $name$0 = $f;
 } else {
  $2 = (_strlen(($f|0))|0);
  $3 = (($2) + 1)|0;
  $4 = (_xmalloc($3)|0);
  $5 = (_strcpy(($4|0),($f|0))|0);
  HEAP32[$filename>>2] = $5;
  $6 = HEAP32[29016>>2]|0;
  (FUNCTION_TABLE_ii[$6 & 511]($filename)|0);
  $7 = HEAP32[$filename>>2]|0;
  $name$0 = $7;
 }
 $8 = (_lstat(($name$0|0),($astat|0))|0);
 $9 = ($8|0)==(0);
 $10 = ((($astat)) + 12|0);
 $11 = HEAP32[$10>>2]|0;
 L4: do {
  if ($9) {
   $14 = $11 & 61440;
   if ((($14|0) == 16384)) {
    $36 = $11 & 512;
    $37 = ($36|0)!=(0);
    $$not = $37 ^ 1;
    $38 = $11 & 2;
    $39 = ($38|0)==(0);
    $or$cond = $39 | $$not;
    do {
     if (!($or$cond)) {
      $40 = HEAP32[(36528)>>2]|0;
      $41 = HEAP32[(36532)>>2]|0;
      if ((($40|0) == 0)) {
       break;
      } else if ((($40|0) == 1)) {
       $lhsc$i19 = HEAP8[$41>>0]|0;
       $not$$i20 = ($lhsc$i19<<24>>24)==(48);
       if ($not$$i20) {
        break;
       } else {
        $colored_filetype$045 = 20;$ext$1 = 0;
        break L4;
       }
      } else if ((($40|0) == 2)) {
       $42 = (_strncmp($41,36360,2)|0);
       $phitmp$i21 = ($42|0)==(0);
       if ($phitmp$i21) {
        break;
       } else {
        $colored_filetype$045 = 20;$ext$1 = 0;
        break L4;
       }
      } else {
       $colored_filetype$045 = 20;$ext$1 = 0;
       break L4;
      }
     }
    } while(0);
    if ($39) {
     if (!($37)) {
      $colored_filetype$045 = 6;$ext$1 = 0;
      break;
     }
    } else {
     $43 = HEAP32[(36520)>>2]|0;
     $44 = HEAP32[(36524)>>2]|0;
     if ((($43|0) == 1)) {
      $lhsc$i24 = HEAP8[$44>>0]|0;
      $not$$i25 = ($lhsc$i24<<24>>24)!=(48);
      $46 = $not$$i25;
     } else if ((($43|0) == 2)) {
      $45 = (_strncmp($44,36360,2)|0);
      $phitmp$i26 = ($45|0)!=(0);
      $46 = $phitmp$i26;
     } else if ((($43|0) == 0)) {
      $46 = 0;
     } else {
      $colored_filetype$045 = 19;$ext$1 = 0;
      break;
     }
     $brmerge = $46 | $$not;
     $$mux = $46 ? 19 : 6;
     if ($brmerge) {
      $colored_filetype$045 = $$mux;$ext$1 = 0;
      break;
     }
    }
    $47 = HEAP32[(36512)>>2]|0;
    $48 = HEAP32[(36516)>>2]|0;
    if ((($47|0) == 1)) {
     $lhsc$i29 = HEAP8[$48>>0]|0;
     $not$$i30 = ($lhsc$i29<<24>>24)!=(48);
     $51 = $not$$i30;
    } else if ((($47|0) == 0)) {
     $51 = 0;
    } else {
     $49 = ($47|0)==(2);
     if ($49) {
      $50 = (_strncmp($48,36360,2)|0);
      $phitmp$i31 = ($50|0)!=(0);
      $51 = $phitmp$i31;
     } else {
      $51 = 1;
     }
    }
    $$3 = $51 ? 18 : 6;
    $colored_filetype$045 = $$3;$ext$1 = 0;
    break;
   } else if ((($14|0) == 40960)) {
    $colored_filetype$045 = 7;$ext$1 = 0;
    break;
   } else if ((($14|0) == 24576)) {
    $colored_filetype$045 = 10;$ext$1 = 0;
    break;
   } else if ((($14|0) == 8192)) {
    $colored_filetype$045 = 11;$ext$1 = 0;
    break;
   } else if ((($14|0) == 32768)) {
    $15 = $11 & 2048;
    $16 = ($15|0)==(0);
    do {
     if (!($16)) {
      $17 = HEAP32[(36496)>>2]|0;
      $18 = HEAP32[(36500)>>2]|0;
      if ((($17|0) == 1)) {
       $lhsc$i = HEAP8[$18>>0]|0;
       $not$$i = ($lhsc$i<<24>>24)==(48);
       if ($not$$i) {
        break;
       } else {
        $colored_filetype$045 = 16;$ext$1 = 0;
        break L4;
       }
      } else if ((($17|0) == 0)) {
       break;
      } else if ((($17|0) == 2)) {
       $19 = (_strncmp($18,36360,2)|0);
       $phitmp$i = ($19|0)==(0);
       if ($phitmp$i) {
        break;
       } else {
        $colored_filetype$045 = 16;$ext$1 = 0;
        break L4;
       }
      } else {
       $colored_filetype$045 = 16;$ext$1 = 0;
       break L4;
      }
     }
    } while(0);
    $20 = $11 & 1024;
    $21 = ($20|0)==(0);
    do {
     if (!($21)) {
      $22 = HEAP32[(36504)>>2]|0;
      $23 = HEAP32[(36508)>>2]|0;
      if ((($22|0) == 0)) {
       break;
      } else if ((($22|0) == 2)) {
       $24 = (_strncmp($23,36360,2)|0);
       $phitmp$i6 = ($24|0)==(0);
       if ($phitmp$i6) {
        break;
       } else {
        $colored_filetype$045 = 17;$ext$1 = 0;
        break L4;
       }
      } else if ((($22|0) == 1)) {
       $lhsc$i4 = HEAP8[$23>>0]|0;
       $not$$i5 = ($lhsc$i4<<24>>24)==(48);
       if ($not$$i5) {
        break;
       } else {
        $colored_filetype$045 = 17;$ext$1 = 0;
        break L4;
       }
      } else {
       $colored_filetype$045 = 17;$ext$1 = 0;
       break L4;
      }
     }
    } while(0);
    $25 = $11 & 73;
    $26 = ($25|0)==(0);
    do {
     if (!($26)) {
      $27 = HEAP32[(36480)>>2]|0;
      $28 = HEAP32[(36484)>>2]|0;
      if ((($27|0) == 2)) {
       $29 = (_strncmp($28,36360,2)|0);
       $phitmp$i11 = ($29|0)==(0);
       if ($phitmp$i11) {
        break;
       } else {
        $colored_filetype$045 = 14;$ext$1 = 0;
        break L4;
       }
      } else if ((($27|0) == 1)) {
       $lhsc$i9 = HEAP8[$28>>0]|0;
       $not$$i10 = ($lhsc$i9<<24>>24)==(48);
       if ($not$$i10) {
        break;
       } else {
        $colored_filetype$045 = 14;$ext$1 = 0;
        break L4;
       }
      } else if ((($27|0) == 0)) {
       break;
      } else {
       $colored_filetype$045 = 14;$ext$1 = 0;
       break L4;
      }
     }
    } while(0);
    $30 = ((($astat)) + 16|0);
    $31 = HEAP32[$30>>2]|0;
    $32 = ($31>>>0)>(1);
    if (!($32)) {
     label = 42;
     break;
    }
    $33 = HEAP32[(36544)>>2]|0;
    $34 = HEAP32[(36548)>>2]|0;
    if ((($33|0) == 2)) {
     $35 = (_strncmp($34,36360,2)|0);
     $phitmp$i16 = ($35|0)==(0);
     if ($phitmp$i16) {
      label = 42;
      break;
     } else {
      $colored_filetype$045 = 22;$ext$1 = 0;
      break;
     }
    } else if ((($33|0) == 0)) {
     label = 42;
     break;
    } else if ((($33|0) == 1)) {
     $lhsc$i14 = HEAP8[$34>>0]|0;
     $not$$i15 = ($lhsc$i14<<24>>24)==(48);
     if ($not$$i15) {
      label = 42;
      break;
     } else {
      $colored_filetype$045 = 22;$ext$1 = 0;
      break;
     }
    } else {
     $colored_filetype$045 = 22;$ext$1 = 0;
     break;
    }
   } else if ((($14|0) == 4096)) {
    $colored_filetype$045 = 8;$ext$1 = 0;
    break;
   } else if ((($14|0) == 49152)) {
    $colored_filetype$045 = 9;$ext$1 = 0;
    break;
   } else {
    $colored_filetype$045 = 13;$ext$1 = 0;
    break;
   }
  } else {
   $12 = HEAP32[(36468)>>2]|0;
   $13 = ($12|0)==(0|0);
   if ($13) {
    label = 42;
   } else {
    $colored_filetype$045 = 12;$ext$1 = 0;
   }
  }
 } while(0);
 L56: do {
  if ((label|0) == 42) {
   $52 = (_strlen(($name$0|0))|0);
   $ext$051 = HEAP32[36352>>2]|0;
   $53 = ($ext$051|0)==(0|0);
   if ($53) {
    $colored_filetype$045 = 5;$ext$1 = 0;
   } else {
    $ext$052 = $ext$051;
    while(1) {
     $54 = HEAP32[$ext$052>>2]|0;
     $55 = ($52>>>0)<($54>>>0);
     if (!($55)) {
      $$sum = (($52) - ($54))|0;
      $56 = (($name$0) + ($$sum)|0);
      $57 = ((($ext$052)) + 4|0);
      $58 = HEAP32[$57>>2]|0;
      $59 = (_strncmp($56,$58,$54)|0);
      $60 = ($59|0)==(0);
      if ($60) {
       $colored_filetype$045 = 5;$ext$1 = $ext$052;
       break L56;
      }
     }
     $61 = ((($ext$052)) + 16|0);
     $ext$0 = HEAP32[$61>>2]|0;
     $62 = ($ext$0|0)==(0|0);
     if ($62) {
      $colored_filetype$045 = 5;$ext$1 = 0;
      break;
     } else {
      $ext$052 = $ext$0;
     }
    }
   }
  }
 } while(0);
 $63 = HEAP32[$filename>>2]|0;
 _free($63);
 $64 = ($ext$1|0)!=(0|0);
 $65 = ((($ext$1)) + 8|0);
 $66 = (36368 + ($colored_filetype$045<<3)|0);
 $67 = $64 ? $65 : $66;
 $68 = ((($67)) + 4|0);
 $69 = HEAP32[$68>>2]|0;
 $70 = ($69|0)==(0|0);
 if ($70) {
  $$0 = 1;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = HEAP32[(36400)>>2]|0;
 $72 = HEAP32[(36404)>>2]|0;
 if ((($71|0) == 1)) {
  $lhsc$i34 = HEAP8[$72>>0]|0;
  $not$$i35 = ($lhsc$i34<<24>>24)==(48);
  if (!($not$$i35)) {
   label = 50;
  }
 } else if ((($71|0) == 2)) {
  $73 = (_strncmp($72,36360,2)|0);
  $phitmp$i36 = ($73|0)==(0);
  if (!($phitmp$i36)) {
   label = 50;
  }
 } else if (!((($71|0) == 0))) {
  label = 50;
 }
 if ((label|0) == 50) {
  $74 = HEAP32[(36372)>>2]|0;
  $75 = HEAP32[36368>>2]|0;
  $76 = HEAP32[13512>>2]|0;
  (_fwrite(($74|0),($75|0),1,($76|0))|0);
  $77 = HEAP32[(36380)>>2]|0;
  $78 = HEAP32[(36376)>>2]|0;
  $79 = HEAP32[13512>>2]|0;
  (_fwrite(($77|0),($78|0),1,($79|0))|0);
 }
 $80 = HEAP32[(36372)>>2]|0;
 $81 = HEAP32[36368>>2]|0;
 $82 = HEAP32[13512>>2]|0;
 (_fwrite(($80|0),($81|0),1,($82|0))|0);
 $83 = HEAP32[$68>>2]|0;
 $84 = HEAP32[$67>>2]|0;
 $85 = HEAP32[13512>>2]|0;
 (_fwrite(($83|0),($84|0),1,($85|0))|0);
 $86 = HEAP32[(36380)>>2]|0;
 $87 = HEAP32[(36376)>>2]|0;
 $88 = HEAP32[13512>>2]|0;
 (_fwrite(($86|0),($87|0),1,($88|0))|0);
 $$0 = 0;
 STACKTOP = sp;return ($$0|0);
}
function __rl_prep_non_filename_text() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[(36388)>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $4 = HEAP32[(36372)>>2]|0;
  $5 = HEAP32[36368>>2]|0;
  $6 = HEAP32[13512>>2]|0;
  (_fwrite(($4|0),($5|0),1,($6|0))|0);
  $7 = HEAP32[(36396)>>2]|0;
  $8 = HEAP32[(36392)>>2]|0;
  $9 = HEAP32[13512>>2]|0;
  (_fwrite(($7|0),($8|0),1,($9|0))|0);
  $10 = HEAP32[(36380)>>2]|0;
  $11 = HEAP32[(36376)>>2]|0;
  $12 = HEAP32[13512>>2]|0;
  (_fwrite(($10|0),($11|0),1,($12|0))|0);
  return;
 } else {
  $2 = HEAP32[(36384)>>2]|0;
  $3 = HEAP32[13512>>2]|0;
  (_fwrite(($0|0),($2|0),1,($3|0))|0);
  return;
 }
}
function __rl_parse_colors() {
 var $$lcssa = 0, $$lcssa$lcssa = 0, $$pr$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $buf = 0, $e$012 = 0, $ext$016 = 0, $ext$016$lcssa = 0, $ext$016$phi = 0, $ind_no$013 = 0, $ind_no$013$lcssa = 0, $label = 0, $not$9 = 0;
 var $p = 0, $state$017 = 0, $state$017$phi = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 48|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $p = sp + 32|0;
 $buf = sp + 28|0;
 $label = sp + 36|0;
 $0 = (_sh_get_env_value(36560)|0);
 HEAP32[$p>>2] = $0;
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = HEAP8[$0>>0]|0;
  $3 = ($2<<24>>24)==(0);
  if (!($3)) {
   ;HEAP8[$label>>0]=HEAP8[36576>>0]|0;HEAP8[$label+1>>0]=HEAP8[36576+1>>0]|0;HEAP8[$label+2>>0]=HEAP8[36576+2>>0]|0;
   $4 = (_strlen(($0|0))|0);
   $5 = (($4) + 1)|0;
   $6 = (_xmalloc($5)|0);
   $7 = (_strcpy(($6|0),($0|0))|0);
   HEAP32[36584>>2] = $7;
   HEAP32[$buf>>2] = $7;
   $8 = ((($label)) + 1|0);
   $ext$016 = 0;$state$017 = 1;
   while(1) {
    if ((($state$017|0) == 3)) {
     $25 = HEAP32[$p>>2]|0;
     $26 = ((($25)) + 1|0);
     HEAP32[$p>>2] = $26;
     $27 = HEAP8[$25>>0]|0;
     $28 = ($27<<24>>24)==(61);
     if (!($28)) {
      break;
     }
     $29 = HEAP8[$label>>0]|0;
     $31 = 36592;$ind_no$013 = 0;
     while(1) {
      $30 = HEAP8[$31>>0]|0;
      $32 = ($29<<24>>24)==($30<<24>>24);
      if ($32) {
       $33 = (_strcmp($label,$31)|0);
       $34 = ($33|0)==(0);
       if ($34) {
        $ind_no$013$lcssa = $ind_no$013;
        label = 16;
        break;
       }
      }
      $39 = (($ind_no$013) + 1)|0;
      $40 = (36600 + ($39<<2)|0);
      $41 = HEAP32[$40>>2]|0;
      $42 = ($39|0)==(24);
      if ($42) {
       label = 18;
       break;
      } else {
       $31 = $41;$ind_no$013 = $39;
      }
     }
     if ((label|0) == 16) {
      label = 0;
      $35 = HEAP32[$buf>>2]|0;
      $36 = (((36368 + ($ind_no$013$lcssa<<3)|0)) + 4|0);
      HEAP32[$36>>2] = $35;
      $37 = (36368 + ($ind_no$013$lcssa<<3)|0);
      $38 = (_get_funky_string($buf,$p,0,$37)|0);
      if ($38) {
       $ext$016$phi = $ext$016;$state$017 = 1;$ext$016 = $ext$016$phi;
       continue;
      }
      $$pr$pre = HEAP32[$p>>2]|0;
      HEAP32[$vararg_buffer1>>2] = $label;
      __rl_errmsg(36704,$vararg_buffer1);
      $43 = ($$pr$pre|0)==(0|0);
      if ($43) {
       break;
      } else {
       $45 = $$pr$pre;
      }
     }
     else if ((label|0) == 18) {
      label = 0;
      HEAP32[$vararg_buffer>>2] = $label;
      __rl_errmsg(36704,$vararg_buffer);
      $45 = $26;
     }
     while(1) {
      $44 = HEAP8[$45>>0]|0;
      if ((($44<<24>>24) == 0) | (($44<<24>>24) == 58)) {
       $$lcssa = $45;
       break;
      }
      $46 = ((($45)) + 1|0);
      HEAP32[$p>>2] = $46;
      $45 = $46;
     }
     $47 = ($$lcssa|0)==(0|0);
     if ($47) {
      break;
     }
     $48 = HEAP8[$$lcssa>>0]|0;
     $49 = ($48<<24>>24)==(58);
     if ($49) {
      $ext$016$phi = $ext$016;$state$017 = 1;$ext$016 = $ext$016$phi;
      continue;
     } else {
      $$lcssa$lcssa = $$lcssa;
      label = 28;
      break;
     }
    } else if ((($state$017|0) == 4)) {
     $50 = HEAP32[$p>>2]|0;
     $51 = ((($50)) + 1|0);
     HEAP32[$p>>2] = $51;
     $52 = HEAP8[$50>>0]|0;
     $53 = ($52<<24>>24)==(61);
     if (!($53)) {
      $ext$016$lcssa = $ext$016;
      label = 26;
      break;
     }
     $54 = HEAP32[$buf>>2]|0;
     $55 = ((($ext$016)) + 12|0);
     HEAP32[$55>>2] = $54;
     $56 = ((($ext$016)) + 8|0);
     $57 = (_get_funky_string($buf,$p,0,$56)|0);
     if ($57) {
      $ext$016$phi = $ext$016;$state$017 = 1;$ext$016 = $ext$016$phi;
      continue;
     } else {
      $ext$016$lcssa = $ext$016;
      label = 26;
      break;
     }
    } else if ((($state$017|0) == 2)) {
     $21 = HEAP32[$p>>2]|0;
     $22 = HEAP8[$21>>0]|0;
     $23 = ($22<<24>>24)==(0);
     if ($23) {
      break;
     }
     $24 = ((($21)) + 1|0);
     HEAP32[$p>>2] = $24;
     HEAP8[$8>>0] = $22;
     $ext$016$phi = $ext$016;$state$017 = 3;$ext$016 = $ext$016$phi;
     continue;
    } else if ((($state$017|0) == 1)) {
     $9 = HEAP32[$p>>2]|0;
     $10 = HEAP8[$9>>0]|0;
     $11 = $10 << 24 >> 24;
     if ((($11|0) == 0)) {
      label = 32;
      break;
     } else if ((($11|0) == 42)) {
      $13 = (_xmalloc(20)|0);
      $14 = HEAP32[36352>>2]|0;
      $15 = ((($13)) + 16|0);
      HEAP32[$15>>2] = $14;
      HEAP32[36352>>2] = $13;
      $16 = ((($9)) + 1|0);
      HEAP32[$p>>2] = $16;
      $17 = HEAP32[$buf>>2]|0;
      $18 = ((($13)) + 4|0);
      HEAP32[$18>>2] = $17;
      $19 = (_get_funky_string($buf,$p,1,$13)|0);
      if ($19) {
       $ext$016 = $13;$state$017 = 4;
       continue;
      } else {
       break;
      }
     } else if ((($11|0) == 58)) {
      $12 = ((($9)) + 1|0);
      HEAP32[$p>>2] = $12;
      $ext$016$phi = $ext$016;$state$017 = 1;$ext$016 = $ext$016$phi;
      continue;
     } else {
      $20 = ((($9)) + 1|0);
      HEAP32[$p>>2] = $20;
      HEAP8[$label>>0] = $10;
      $ext$016$phi = $ext$016;$state$017 = 2;$ext$016 = $ext$016$phi;
      continue;
     }
    } else {
     $state$017$phi = $state$017;$ext$016$phi = $ext$016;$state$017 = $state$017$phi;$ext$016 = $ext$016$phi;
     continue;
    }
   }
   if ((label|0) == 26) {
    $58 = ((($ext$016$lcssa)) + 4|0);
    $59 = HEAP32[$58>>2]|0;
    $60 = ($59|0)==(0|0);
    if (!($60)) {
     HEAP32[$vararg_buffer4>>2] = $59;
     __rl_errmsg(36744,$vararg_buffer4);
    }
   }
   else if ((label|0) == 28) {
    $61 = HEAP8[$$lcssa$lcssa>>0]|0;
    $not$9 = ($61<<24>>24)==(0);
    if ($not$9) {
     STACKTOP = sp;return;
    }
   }
   else if ((label|0) == 32) {
    STACKTOP = sp;return;
   }
   __rl_errmsg(36776,$vararg_buffer7);
   $62 = HEAP32[36584>>2]|0;
   _free($62);
   $63 = HEAP32[36352>>2]|0;
   $64 = ($63|0)==(0|0);
   if (!($64)) {
    $e$012 = $63;
    while(1) {
     $65 = ((($e$012)) + 16|0);
     $66 = HEAP32[$65>>2]|0;
     _free($e$012);
     $67 = ($66|0)==(0|0);
     if ($67) {
      break;
     } else {
      $e$012 = $66;
     }
    }
   }
   HEAP32[36352>>2] = 0;
   HEAP32[28976>>2] = 0;
   STACKTOP = sp;return;
  }
 }
 HEAP32[36352>>2] = 0;
 STACKTOP = sp;return;
}
function _get_funky_string($dest,$src,$equals_end,$output_count) {
 $dest = $dest|0;
 $src = $src|0;
 $equals_end = $equals_end|0;
 $output_count = $output_count|0;
 var $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0;
 var $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $14 = 0, $15 = 0;
 var $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $count$0$lcssa = 0, $count$08 = 0, $count$08$lcssa60 = 0, $count$08$phi = 0, $count$08$us = 0, $count$08$us$lcssa57 = 0, $count$08$us$phi = 0, $count$1$ph = 0;
 var $count$1$us$ph = 0, $num$07 = 0, $num$07$phi = 0, $num$07$us = 0, $num$07$us$phi = 0, $num$1$ph = 0, $num$1$ph$us = 0, $num$13$ph = 0, $num$13$us$ph = 0, $or$cond1 = 0, $or$cond1$us = 0, $p$0$lcssa = 0, $p$010 = 0, $p$010$lcssa59 = 0, $p$010$phi = 0, $p$010$us = 0, $p$010$us$lcssa56 = 0, $p$010$us$phi = 0, $q$0$lcssa = 0, $q$012 = 0;
 var $q$012$lcssa58 = 0, $q$012$phi = 0, $q$012$us = 0, $q$012$us$lcssa55 = 0, $q$012$us$phi = 0, $q$1$ph = 0, $q$1$us$ph = 0, $state$0$lcssa = 0, $state$09 = 0, $state$09$us = 0, $state$2$ph = 0, $state$2$us$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[$src>>2]|0;
 $1 = HEAP32[$dest>>2]|0;
 L1: do {
  if ($equals_end) {
   $count$08$us = 0;$num$07$us = 0;$p$010$us = $0;$q$012$us = $1;$state$09$us = 0;
   L42: while(1) {
    switch ($state$09$us|0) {
    case 0:  {
     $58 = HEAP8[$p$010$us>>0]|0;
     $59 = $58 << 24 >> 24;
     switch ($59|0) {
     case 61: case 0: case 58:  {
      $count$0$lcssa = $count$08$us;$p$0$lcssa = $p$010$us;$q$0$lcssa = $q$012$us;$state$0$lcssa = 1;
      break L1;
      break;
     }
     case 92:  {
      $61 = ((($p$010$us)) + 1|0);
      $q$012$us$phi = $q$012$us;$num$07$us$phi = $num$07$us;$count$08$us$phi = $count$08$us;$p$010$us = $61;$state$09$us = 1;$q$012$us = $q$012$us$phi;$num$07$us = $num$07$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
      break;
     }
     case 94:  {
      $60 = ((($p$010$us)) + 1|0);
      $q$012$us$phi = $q$012$us;$num$07$us$phi = $num$07$us;$count$08$us$phi = $count$08$us;$p$010$us = $60;$state$09$us = 4;$q$012$us = $q$012$us$phi;$num$07$us = $num$07$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
      break;
     }
     default: {
      $62 = ((($p$010$us)) + 1|0);
      $63 = ((($q$012$us)) + 1|0);
      HEAP8[$q$012$us>>0] = $58;
      $64 = (($count$08$us) + 1)|0;
      $num$07$us$phi = $num$07$us;$count$08$us = $64;$p$010$us = $62;$q$012$us = $63;$state$09$us = 0;$num$07$us = $num$07$us$phi;
      continue L42;
     }
     }
     break;
    }
    case 2:  {
     $39 = HEAP8[$p$010$us>>0]|0;
     $40 = $39 & -8;
     $41 = ($40<<24>>24)==(48);
     if ($41) {
      $44 = $39&255;
      $45 = $num$07$us << 24 >> 24;
      $46 = $45 << 3;
      $47 = ((($p$010$us)) + 1|0);
      $48 = (($46) + 208)|0;
      $49 = (($48) + ($44))|0;
      $50 = $49&255;
      $q$012$us$phi = $q$012$us;$count$08$us$phi = $count$08$us;$num$07$us = $50;$p$010$us = $47;$state$09$us = 2;$q$012$us = $q$012$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
     } else {
      $42 = ((($q$012$us)) + 1|0);
      HEAP8[$q$012$us>>0] = $num$07$us;
      $43 = (($count$08$us) + 1)|0;
      $p$010$us$phi = $p$010$us;$num$07$us$phi = $num$07$us;$count$08$us = $43;$q$012$us = $42;$state$09$us = 0;$p$010$us = $p$010$us$phi;$num$07$us = $num$07$us$phi;
      continue L42;
     }
     break;
    }
    case 4:  {
     $2 = HEAP8[$p$010$us>>0]|0;
     $3 = ($2<<24>>24)<(64);
     $4 = ($2<<24>>24)==(127);
     $or$cond1$us = $3 | $4;
     if (!($or$cond1$us)) {
      $5 = $2&255;
      $6 = ((($p$010$us)) + 1|0);
      $7 = $5 & 31;
      $8 = $7&255;
      $9 = ((($q$012$us)) + 1|0);
      HEAP8[$q$012$us>>0] = $8;
      $10 = (($count$08$us) + 1)|0;
      $num$07$us$phi = $num$07$us;$count$08$us = $10;$p$010$us = $6;$q$012$us = $9;$state$09$us = 0;$num$07$us = $num$07$us$phi;
      continue L42;
     }
     $11 = ($2<<24>>24)==(63);
     if (!($11)) {
      $count$0$lcssa = $count$08$us;$p$0$lcssa = $p$010$us;$q$0$lcssa = $q$012$us;$state$0$lcssa = 0;
      break L1;
     }
     $12 = ((($q$012$us)) + 1|0);
     HEAP8[$q$012$us>>0] = 127;
     $13 = (($count$08$us) + 1)|0;
     $p$010$us$phi = $p$010$us;$num$07$us$phi = $num$07$us;$count$08$us = $13;$q$012$us = $12;$state$09$us = 0;$p$010$us = $p$010$us$phi;$num$07$us = $num$07$us$phi;
     continue L42;
     break;
    }
    case 1:  {
     $51 = HEAP8[$p$010$us>>0]|0;
     $52 = $51 << 24 >> 24;
     do {
      switch ($52|0) {
      case 95:  {
       $num$1$ph$us = 32;
       label = 27;
       break;
      }
      case 63:  {
       $num$1$ph$us = 127;
       label = 27;
       break;
      }
      case 98:  {
       $num$1$ph$us = 8;
       label = 27;
       break;
      }
      case 102:  {
       $num$1$ph$us = 12;
       label = 27;
       break;
      }
      case 88: case 120:  {
       $count$1$us$ph = $count$08$us;$num$13$us$ph = 0;$q$1$us$ph = $q$012$us;$state$2$us$ph = 3;
       break;
      }
      case 116:  {
       $num$1$ph$us = 9;
       label = 27;
       break;
      }
      case 97:  {
       $num$1$ph$us = 7;
       label = 27;
       break;
      }
      case 114:  {
       $num$1$ph$us = 13;
       label = 27;
       break;
      }
      case 101:  {
       $num$1$ph$us = 27;
       label = 27;
       break;
      }
      case 0:  {
       $count$08$us$lcssa57 = $count$08$us;$p$010$us$lcssa56 = $p$010$us;$q$012$us$lcssa55 = $q$012$us;
       break L42;
       break;
      }
      case 110:  {
       $num$1$ph$us = 10;
       label = 27;
       break;
      }
      case 118:  {
       $num$1$ph$us = 11;
       label = 27;
       break;
      }
      case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
       $53 = $51&255;
       $54 = (($53) + 208)|0;
       $55 = $54&255;
       $count$1$us$ph = $count$08$us;$num$13$us$ph = $55;$q$1$us$ph = $q$012$us;$state$2$us$ph = 2;
       break;
      }
      default: {
       $num$1$ph$us = $51;
       label = 27;
      }
      }
     } while(0);
     if ((label|0) == 27) {
      label = 0;
      $56 = ((($q$012$us)) + 1|0);
      HEAP8[$q$012$us>>0] = $num$1$ph$us;
      $57 = (($count$08$us) + 1)|0;
      $count$1$us$ph = $57;$num$13$us$ph = $num$1$ph$us;$q$1$us$ph = $56;$state$2$us$ph = 0;
     }
     $65 = ((($p$010$us)) + 1|0);
     $count$08$us = $count$1$us$ph;$num$07$us = $num$13$us$ph;$p$010$us = $65;$q$012$us = $q$1$us$ph;$state$09$us = $state$2$us$ph;
     continue L42;
     break;
    }
    case 3:  {
     $14 = HEAP8[$p$010$us>>0]|0;
     $15 = $14 << 24 >> 24;
     switch ($15|0) {
     case 102: case 101: case 100: case 99: case 98: case 97:  {
      $23 = $num$07$us << 24 >> 24;
      $24 = $23 << 4;
      $25 = ((($p$010$us)) + 1|0);
      $26 = $14&255;
      $27 = (($24) + 169)|0;
      $28 = (($27) + ($26))|0;
      $29 = $28&255;
      $q$012$us$phi = $q$012$us;$count$08$us$phi = $count$08$us;$num$07$us = $29;$p$010$us = $25;$state$09$us = 3;$q$012$us = $q$012$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
      break;
     }
     case 57: case 56: case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
      $30 = $num$07$us << 24 >> 24;
      $31 = $30 << 4;
      $32 = ((($p$010$us)) + 1|0);
      $33 = $14&255;
      $34 = (($31) + 208)|0;
      $35 = (($34) + ($33))|0;
      $36 = $35&255;
      $q$012$us$phi = $q$012$us;$count$08$us$phi = $count$08$us;$num$07$us = $36;$p$010$us = $32;$state$09$us = 3;$q$012$us = $q$012$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
      break;
     }
     case 70: case 69: case 68: case 67: case 66: case 65:  {
      $16 = $num$07$us << 24 >> 24;
      $17 = $16 << 4;
      $18 = ((($p$010$us)) + 1|0);
      $19 = $14&255;
      $20 = (($17) + 201)|0;
      $21 = (($20) + ($19))|0;
      $22 = $21&255;
      $q$012$us$phi = $q$012$us;$count$08$us$phi = $count$08$us;$num$07$us = $22;$p$010$us = $18;$state$09$us = 3;$q$012$us = $q$012$us$phi;$count$08$us = $count$08$us$phi;
      continue L42;
      break;
     }
     default: {
      $37 = ((($q$012$us)) + 1|0);
      HEAP8[$q$012$us>>0] = $num$07$us;
      $38 = (($count$08$us) + 1)|0;
      $p$010$us$phi = $p$010$us;$num$07$us$phi = $num$07$us;$count$08$us = $38;$q$012$us = $37;$state$09$us = 0;$p$010$us = $p$010$us$phi;$num$07$us = $num$07$us$phi;
      continue L42;
     }
     }
     break;
    }
    default: {
     $count$0$lcssa = $count$08$us;$p$0$lcssa = $p$010$us;$q$0$lcssa = $q$012$us;$state$0$lcssa = 0;
     break L1;
    }
    }
   }
   $66 = ((($p$010$us$lcssa56)) + 1|0);
   $count$0$lcssa = $count$08$us$lcssa57;$p$0$lcssa = $66;$q$0$lcssa = $q$012$us$lcssa55;$state$0$lcssa = 0;
  } else {
   $count$08 = 0;$num$07 = 0;$p$010 = $0;$q$012 = $1;$state$09 = 0;
   L2: while(1) {
    switch ($state$09|0) {
    case 3:  {
     $93 = HEAP8[$p$010>>0]|0;
     $94 = $93 << 24 >> 24;
     switch ($94|0) {
     case 102: case 101: case 100: case 99: case 98: case 97:  {
      $102 = $num$07 << 24 >> 24;
      $103 = $102 << 4;
      $104 = ((($p$010)) + 1|0);
      $105 = $93&255;
      $106 = (($103) + 169)|0;
      $107 = (($106) + ($105))|0;
      $108 = $107&255;
      $q$012$phi = $q$012;$count$08$phi = $count$08;$num$07 = $108;$p$010 = $104;$state$09 = 3;$q$012 = $q$012$phi;$count$08 = $count$08$phi;
      continue L2;
      break;
     }
     case 70: case 69: case 68: case 67: case 66: case 65:  {
      $109 = $num$07 << 24 >> 24;
      $110 = $109 << 4;
      $111 = ((($p$010)) + 1|0);
      $112 = $93&255;
      $113 = (($110) + 201)|0;
      $114 = (($113) + ($112))|0;
      $115 = $114&255;
      $q$012$phi = $q$012;$count$08$phi = $count$08;$num$07 = $115;$p$010 = $111;$state$09 = 3;$q$012 = $q$012$phi;$count$08 = $count$08$phi;
      continue L2;
      break;
     }
     case 57: case 56: case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
      $95 = $num$07 << 24 >> 24;
      $96 = $95 << 4;
      $97 = ((($p$010)) + 1|0);
      $98 = $93&255;
      $99 = (($96) + 208)|0;
      $100 = (($99) + ($98))|0;
      $101 = $100&255;
      $q$012$phi = $q$012;$count$08$phi = $count$08;$num$07 = $101;$p$010 = $97;$state$09 = 3;$q$012 = $q$012$phi;$count$08 = $count$08$phi;
      continue L2;
      break;
     }
     default: {
      $116 = ((($q$012)) + 1|0);
      HEAP8[$q$012>>0] = $num$07;
      $117 = (($count$08) + 1)|0;
      $p$010$phi = $p$010;$num$07$phi = $num$07;$count$08 = $117;$q$012 = $116;$state$09 = 0;$p$010 = $p$010$phi;$num$07 = $num$07$phi;
      continue L2;
     }
     }
     break;
    }
    case 1:  {
     $74 = HEAP8[$p$010>>0]|0;
     $75 = $74 << 24 >> 24;
     do {
      switch ($75|0) {
      case 88: case 120:  {
       $count$1$ph = $count$08;$num$13$ph = 0;$q$1$ph = $q$012;$state$2$ph = 3;
       break;
      }
      case 116:  {
       $num$1$ph = 9;
       label = 51;
       break;
      }
      case 118:  {
       $num$1$ph = 11;
       label = 51;
       break;
      }
      case 55: case 54: case 53: case 52: case 51: case 50: case 49: case 48:  {
       $76 = $74&255;
       $77 = (($76) + 208)|0;
       $78 = $77&255;
       $count$1$ph = $count$08;$num$13$ph = $78;$q$1$ph = $q$012;$state$2$ph = 2;
       break;
      }
      case 110:  {
       $num$1$ph = 10;
       label = 51;
       break;
      }
      case 97:  {
       $num$1$ph = 7;
       label = 51;
       break;
      }
      case 63:  {
       $num$1$ph = 127;
       label = 51;
       break;
      }
      case 95:  {
       $num$1$ph = 32;
       label = 51;
       break;
      }
      case 102:  {
       $num$1$ph = 12;
       label = 51;
       break;
      }
      case 114:  {
       $num$1$ph = 13;
       label = 51;
       break;
      }
      case 0:  {
       $count$08$lcssa60 = $count$08;$p$010$lcssa59 = $p$010;$q$012$lcssa58 = $q$012;
       break L2;
       break;
      }
      case 98:  {
       $num$1$ph = 8;
       label = 51;
       break;
      }
      case 101:  {
       $num$1$ph = 27;
       label = 51;
       break;
      }
      default: {
       $num$1$ph = $74;
       label = 51;
      }
      }
     } while(0);
     if ((label|0) == 51) {
      label = 0;
      $79 = ((($q$012)) + 1|0);
      HEAP8[$q$012>>0] = $num$1$ph;
      $80 = (($count$08) + 1)|0;
      $count$1$ph = $80;$num$13$ph = $num$1$ph;$q$1$ph = $79;$state$2$ph = 0;
     }
     $127 = ((($p$010)) + 1|0);
     $count$08 = $count$1$ph;$num$07 = $num$13$ph;$p$010 = $127;$q$012 = $q$1$ph;$state$09 = $state$2$ph;
     continue L2;
     break;
    }
    case 4:  {
     $118 = HEAP8[$p$010>>0]|0;
     $119 = ($118<<24>>24)<(64);
     $120 = ($118<<24>>24)==(127);
     $or$cond1 = $119 | $120;
     if (!($or$cond1)) {
      $121 = $118&255;
      $122 = ((($p$010)) + 1|0);
      $123 = $121 & 31;
      $124 = $123&255;
      $125 = ((($q$012)) + 1|0);
      HEAP8[$q$012>>0] = $124;
      $126 = (($count$08) + 1)|0;
      $num$07$phi = $num$07;$count$08 = $126;$p$010 = $122;$q$012 = $125;$state$09 = 0;$num$07 = $num$07$phi;
      continue L2;
     }
     $129 = ($118<<24>>24)==(63);
     if (!($129)) {
      $count$0$lcssa = $count$08;$p$0$lcssa = $p$010;$q$0$lcssa = $q$012;$state$0$lcssa = 0;
      break L1;
     }
     $130 = ((($q$012)) + 1|0);
     HEAP8[$q$012>>0] = 127;
     $131 = (($count$08) + 1)|0;
     $p$010$phi = $p$010;$num$07$phi = $num$07;$count$08 = $131;$q$012 = $130;$state$09 = 0;$p$010 = $p$010$phi;$num$07 = $num$07$phi;
     continue L2;
     break;
    }
    case 2:  {
     $81 = HEAP8[$p$010>>0]|0;
     $82 = $81 & -8;
     $83 = ($82<<24>>24)==(48);
     if ($83) {
      $86 = $81&255;
      $87 = $num$07 << 24 >> 24;
      $88 = $87 << 3;
      $89 = ((($p$010)) + 1|0);
      $90 = (($88) + 208)|0;
      $91 = (($90) + ($86))|0;
      $92 = $91&255;
      $q$012$phi = $q$012;$count$08$phi = $count$08;$num$07 = $92;$p$010 = $89;$state$09 = 2;$q$012 = $q$012$phi;$count$08 = $count$08$phi;
      continue L2;
     } else {
      $84 = ((($q$012)) + 1|0);
      HEAP8[$q$012>>0] = $num$07;
      $85 = (($count$08) + 1)|0;
      $p$010$phi = $p$010;$num$07$phi = $num$07;$count$08 = $85;$q$012 = $84;$state$09 = 0;$p$010 = $p$010$phi;$num$07 = $num$07$phi;
      continue L2;
     }
     break;
    }
    case 0:  {
     $67 = HEAP8[$p$010>>0]|0;
     $68 = $67 << 24 >> 24;
     if ((($68|0) == 0) | (($68|0) == 58)) {
      $count$0$lcssa = $count$08;$p$0$lcssa = $p$010;$q$0$lcssa = $q$012;$state$0$lcssa = 1;
      break L1;
     } else if ((($68|0) == 94)) {
      $70 = ((($p$010)) + 1|0);
      $q$012$phi = $q$012;$num$07$phi = $num$07;$count$08$phi = $count$08;$p$010 = $70;$state$09 = 4;$q$012 = $q$012$phi;$num$07 = $num$07$phi;$count$08 = $count$08$phi;
      continue L2;
     } else if ((($68|0) == 92)) {
      $69 = ((($p$010)) + 1|0);
      $q$012$phi = $q$012;$num$07$phi = $num$07;$count$08$phi = $count$08;$p$010 = $69;$state$09 = 1;$q$012 = $q$012$phi;$num$07 = $num$07$phi;$count$08 = $count$08$phi;
      continue L2;
     } else {
      $71 = ((($p$010)) + 1|0);
      $72 = ((($q$012)) + 1|0);
      HEAP8[$q$012>>0] = $67;
      $73 = (($count$08) + 1)|0;
      $num$07$phi = $num$07;$count$08 = $73;$p$010 = $71;$q$012 = $72;$state$09 = 0;$num$07 = $num$07$phi;
      continue L2;
     }
     break;
    }
    default: {
     $count$0$lcssa = $count$08;$p$0$lcssa = $p$010;$q$0$lcssa = $q$012;$state$0$lcssa = 0;
     break L1;
    }
    }
   }
   $128 = ((($p$010$lcssa59)) + 1|0);
   $count$0$lcssa = $count$08$lcssa60;$p$0$lcssa = $128;$q$0$lcssa = $q$012$lcssa58;$state$0$lcssa = 0;
  }
 } while(0);
 HEAP32[$dest>>2] = $q$0$lcssa;
 HEAP32[$src>>2] = $p$0$lcssa;
 HEAP32[$output_count>>2] = $count$0$lcssa;
 return ($state$0$lcssa|0);
}
function _xmalloc($bytes) {
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_malloc($bytes)|0);
 $1 = ($0|0)==(0|0);
 if ($1) {
  _memory_error_and_abort(37144);
  // unreachable;
 } else {
  return ($0|0);
 }
 return (0)|0;
}
function _xrealloc($pointer,$bytes) {
 $pointer = $pointer|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($pointer|0)==(0|0);
 if ($0) {
  $2 = (_malloc($bytes)|0);
  $4 = $2;
 } else {
  $1 = (_realloc($pointer,$bytes)|0);
  $4 = $1;
 }
 $3 = ($4|0)==(0|0);
 if ($3) {
  _memory_error_and_abort(37152);
  // unreachable;
 } else {
  return ($4|0);
 }
 return (0)|0;
}
function _memory_error_and_abort($fname) {
 $fname = $fname|0;
 var $0 = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 HEAP32[$vararg_buffer>>2] = $fname;
 (_fprintf(($0|0),(37168|0),($vararg_buffer|0))|0);
 _exit(2);
 // unreachable;
}
function _xfree($string) {
 $string = $string|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($string|0)==(0|0);
 if ($0) {
  return;
 }
 _free($string);
 return;
}
function __rl_enable_paren_matching($on_or_off) {
 $on_or_off = $on_or_off|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($on_or_off|0)==(0);
 if ($0) {
  (_rl_bind_key_in_map(41,215,22352)|0);
  (_rl_bind_key_in_map(93,215,22352)|0);
  (_rl_bind_key_in_map(125,215,22352)|0);
  return;
 } else {
  (_rl_bind_key_in_map(41,373,22352)|0);
  (_rl_bind_key_in_map(93,373,22352)|0);
  (_rl_bind_key_in_map(125,373,22352)|0);
  return;
 }
}
function _rl_insert_close($count,$invoking_key) {
 $count = $count|0;
 $invoking_key = $invoking_key|0;
 var $$0$i = 0, $$1 = 0, $$mux$i = 0, $$not$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $brmerge$i = 0, $delimiter$06$i = 0, $delimiter$12$i = 0, $i$03$i = 0;
 var $i$03$us$i = 0, $level$05$i = 0, $level$05$us$i = 0, $level$1$i = 0, $level$1$us$i = 0, $level$11$i = 0, $level$11$us$i = 0, $opener$0$i = 0, $or$cond = 0, $or$cond10 = 0, $readfds = 0, $timer = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 144|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $timer = sp + 128|0;
 $readfds = sp;
 $0 = HEAP32[13472>>2]|0;
 $1 = ($0|0)==(0);
 $2 = HEAP32[37200>>2]|0;
 $3 = ($2|0)!=(0);
 $or$cond = $1 & $3;
 if (!($or$cond)) {
  (__rl_insert_char($count,$invoking_key)|0);
  $$1 = 0;
  STACKTOP = sp;return ($$1|0);
 }
 (__rl_insert_char(1,$invoking_key)|0);
 $4 = HEAP32[32248>>2]|0;
 FUNCTION_TABLE_v[$4 & 511]();
 $5 = HEAP32[13632>>2]|0;
 $6 = HEAP32[13784>>2]|0;
 $7 = (($6) + -2)|0;
 if ((($invoking_key|0) == 125)) {
  $opener$0$i = 123;
  label = 6;
 } else if ((($invoking_key|0) == 41)) {
  $opener$0$i = 40;
  label = 6;
 } else if ((($invoking_key|0) == 93)) {
  $opener$0$i = 91;
  label = 6;
 }
 if ((label|0) == 6) {
  $8 = ($7|0)>(-1);
  if ($8) {
   $9 = HEAP32[29104>>2]|0;
   $10 = ($9|0)==(0|0);
   L11: do {
    if ($10) {
     $i$03$us$i = $7;$level$05$us$i = 1;
     while(1) {
      $11 = (($5) + ($i$03$us$i)|0);
      $12 = HEAP8[$11>>0]|0;
      $13 = $12 << 24 >> 24;
      $14 = ($13|0)==($invoking_key|0);
      if ($14) {
       $17 = (($level$05$us$i) + 1)|0;
       $level$1$us$i = $17;
       label = 11;
      } else {
       $15 = ($13|0)==($opener$0$i|0);
       $16 = (($level$05$us$i) + -1)|0;
       if ($15) {
        $level$1$us$i = $16;
        label = 11;
       } else {
        $level$11$us$i = $level$05$us$i;
       }
      }
      if ((label|0) == 11) {
       label = 0;
       $18 = ($level$1$us$i|0)==(0);
       if ($18) {
        $$0$i = $i$03$us$i;
        break L11;
       } else {
        $level$11$us$i = $level$1$us$i;
       }
      }
      $19 = (($i$03$us$i) + -1)|0;
      $20 = ($i$03$us$i|0)>(0);
      if ($20) {
       $i$03$us$i = $19;$level$05$us$i = $level$11$us$i;
      } else {
       $$0$i = $19;
       break;
      }
     }
    } else {
     $delimiter$06$i = 0;$i$03$i = $7;$level$05$i = 1;
     while(1) {
      $21 = ($delimiter$06$i|0)!=(0);
      $22 = (($5) + ($i$03$i)|0);
      $23 = HEAP8[$22>>0]|0;
      $24 = $23 << 24 >> 24;
      $25 = ($24|0)==($delimiter$06$i|0);
      $or$cond10 = $21 & $25;
      do {
       if ($or$cond10) {
        $delimiter$12$i = 0;$level$11$i = $level$05$i;
       } else {
        $26 = $23 << 24 >> 24;
        $27 = (_strchr($9,$26)|0);
        $$not$i = ($27|0)!=(0|0);
        $brmerge$i = $21 | $$not$i;
        $$mux$i = $$not$i ? $26 : $delimiter$06$i;
        if ($brmerge$i) {
         $delimiter$12$i = $$mux$i;$level$11$i = $level$05$i;
        } else {
         $28 = ($26|0)==($invoking_key|0);
         if ($28) {
          $29 = (($level$05$i) + 1)|0;
          $level$1$i = $29;
         } else {
          $30 = ($26|0)==($opener$0$i|0);
          $31 = (($level$05$i) + -1)|0;
          if ($30) {
           $level$1$i = $31;
          } else {
           $delimiter$12$i = 0;$level$11$i = $level$05$i;
           break;
          }
         }
         $32 = ($level$1$i|0)==(0);
         if ($32) {
          $$0$i = $i$03$i;
          break L11;
         } else {
          $delimiter$12$i = 0;$level$11$i = $level$1$i;
         }
        }
       }
      } while(0);
      $33 = (($i$03$i) + -1)|0;
      $34 = ($i$03$i|0)>(0);
      if ($34) {
       $delimiter$06$i = $delimiter$12$i;$i$03$i = $33;$level$05$i = $level$11$i;
      } else {
       $$0$i = $33;
       break;
      }
     }
    }
   } while(0);
   $35 = ($$0$i|0)<(0);
   if (!($35)) {
    dest=$readfds; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
    $36 = HEAP32[13504>>2]|0;
    $37 = (_fileno(($36|0))|0);
    $38 = $37 & 31;
    $39 = 1 << $38;
    $40 = HEAP32[13504>>2]|0;
    $41 = (_fileno(($40|0))|0);
    $42 = $41 >>> 5;
    $43 = (($readfds) + ($42<<2)|0);
    $44 = HEAP32[$43>>2]|0;
    $45 = $44 | $39;
    HEAP32[$43>>2] = $45;
    $46 = HEAP32[37208>>2]|0;
    $47 = (($46|0) / 1000000)&-1;
    HEAP32[$timer>>2] = $47;
    $48 = (($46|0) % 1000000)&-1;
    $49 = ((($timer)) + 4|0);
    HEAP32[$49>>2] = $48;
    $50 = HEAP32[13784>>2]|0;
    HEAP32[13784>>2] = $$0$i;
    $51 = HEAP32[32248>>2]|0;
    FUNCTION_TABLE_v[$51 & 511]();
    (_select(1,($readfds|0),(0|0),(0|0),($timer|0))|0);
    HEAP32[13784>>2] = $50;
    $$1 = 0;
    STACKTOP = sp;return ($$1|0);
   }
  }
 }
 $$1 = -1;
 STACKTOP = sp;return ($$1|0);
}
function _tgetent($bufp,$name) {
 $bufp = $bufp|0;
 $name = $name|0;
 var $$phi$trans$insert36 = 0, $$pre = 0, $$pre29 = 0, $$pre30 = 0, $$pre31 = 0, $$pre32 = 0, $$pre35 = 0, $$pre37 = 0, $$pre38 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0;
 var $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0;
 var $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0;
 var $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0;
 var $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0;
 var $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0;
 var $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $magicptr = 0, $magicptr10 = 0, $magicptr11 = 0, $magicptr12 = 0, $magicptr13 = 0, $magicptr14 = 0, $magicptr15 = 0;
 var $magicptr16 = 0, $magicptr17 = 0, $magicptr7 = 0, $magicptr8 = 0, $magicptr9 = 0, $n$027$lcssa = 0, $or$cond = 0, $or$cond40 = 0, $or$cond42 = 0, $or$cond44 = 0, $or$cond46 = 0, $phitmp = 0, $phitmp1 = 0, $phitmp2 = 0, $rc = 0, $sext$mask = 0, $sext$mask3 = 0, $storemerge$best$0$1 = 0, $storemerge$best$0$2 = 0, $storemerge$best$0$3 = 0;
 var $storemerge424 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $rc = sp;
 HEAP32[$rc>>2] = -1;
 (__nc_setupterm($name,1,$rc,1)|0);
 $0 = HEAP8[(37700)>>0]|0;
 $1 = ($0<<24>>24)!=(0);
 $2 = HEAP32[(37708)>>2]|0;
 $3 = ($2|0)==($bufp|0);
 $or$cond40 = $1 & $3;
 if ($or$cond40) {
  $n$027$lcssa = 0;
  label = 2;
 } else {
  $21 = HEAP8[(37720)>>0]|0;
  $22 = ($21<<24>>24)!=(0);
  $23 = HEAP32[(37728)>>2]|0;
  $24 = ($23|0)==($bufp|0);
  $or$cond42 = $22 & $24;
  if ($or$cond42) {
   $n$027$lcssa = 1;
   label = 2;
  } else {
   $184 = HEAP8[(37740)>>0]|0;
   $185 = ($184<<24>>24)!=(0);
   $186 = HEAP32[(37748)>>2]|0;
   $187 = ($186|0)==($bufp|0);
   $or$cond44 = $185 & $187;
   if ($or$cond44) {
    $n$027$lcssa = 2;
    label = 2;
   } else {
    $188 = HEAP8[(37760)>>0]|0;
    $189 = ($188<<24>>24)!=(0);
    $190 = HEAP32[(37768)>>2]|0;
    $191 = ($190|0)==($bufp|0);
    $or$cond46 = $189 & $191;
    if ($or$cond46) {
     $n$027$lcssa = 3;
     label = 2;
    } else {
     $192 = HEAP32[(37696)>>2]|0;
     $193 = HEAP32[(37716)>>2]|0;
     $194 = ($193|0)<($192|0);
     $storemerge$best$0$1 = $194&1;
     HEAP32[(37776)>>2] = 2;
     $195 = HEAP32[(37736)>>2]|0;
     $196 = (37696 + (($storemerge$best$0$1*20)|0)|0);
     $197 = HEAP32[$196>>2]|0;
     $198 = ($195|0)<($197|0);
     $storemerge$best$0$2 = $198 ? 2 : $storemerge$best$0$1;
     HEAP32[(37776)>>2] = 3;
     $199 = HEAP32[(37756)>>2]|0;
     $200 = (37696 + (($storemerge$best$0$2*20)|0)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = ($199|0)<($201|0);
     $storemerge$best$0$3 = $202 ? 3 : $storemerge$best$0$2;
     HEAP32[(37776)>>2] = $storemerge$best$0$3;
     $27 = $storemerge$best$0$3;
    }
   }
  }
 }
 if ((label|0) == 2) {
  HEAP32[(37776)>>2] = $n$027$lcssa;
  $4 = (((37696 + (($n$027$lcssa*20)|0)|0)) + 8|0);
  $5 = HEAP32[$4>>2]|0;
  $6 = ($5|0)==(0|0);
  if ($6) {
   $10 = $n$027$lcssa;
  } else {
   _free($5);
   $7 = HEAP32[(37776)>>2]|0;
   $8 = (((37696 + (($7*20)|0)|0)) + 8|0);
   HEAP32[$8>>2] = 0;
   $$pre = HEAP32[(37776)>>2]|0;
   $10 = $$pre;
  }
  $9 = (((37696 + (($10*20)|0)|0)) + 16|0);
  $11 = HEAP32[$9>>2]|0;
  $12 = ($11|0)==(0|0);
  $13 = HEAP32[37624>>2]|0;
  $14 = ($11|0)==($13|0);
  $or$cond = $12 | $14;
  if ($or$cond) {
   $27 = $10;
  } else {
   (_del_curterm($11)|0);
   HEAP32[(37776)>>2] = 0;
   $storemerge424 = 0;
   while(1) {
    $15 = (((37696 + (($storemerge424*20)|0)|0)) + 16|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ($16|0)==($11|0);
    if ($17) {
     HEAP32[$15>>2] = 0;
     $$pre29 = HEAP32[(37776)>>2]|0;
     $19 = $$pre29;
    } else {
     $19 = $storemerge424;
    }
    $18 = (($19) + 1)|0;
    HEAP32[(37776)>>2] = $18;
    $20 = ($18|0)<(4);
    if ($20) {
     $storemerge424 = $18;
    } else {
     break;
    }
   }
   HEAP32[(37776)>>2] = $n$027$lcssa;
   $27 = $n$027$lcssa;
  }
 }
 $25 = HEAP32[37624>>2]|0;
 $26 = (((37696 + (($27*20)|0)|0)) + 16|0);
 HEAP32[$26>>2] = $25;
 $28 = HEAP32[(37780)>>2]|0;
 $29 = (($28) + 1)|0;
 HEAP32[(37780)>>2] = $29;
 $30 = HEAP32[(37776)>>2]|0;
 $31 = (37696 + (($30*20)|0)|0);
 HEAP32[$31>>2] = $29;
 HEAP8[37296>>0] = 0;
 HEAP32[37216>>2] = 0;
 HEAP32[37224>>2] = 0;
 $32 = HEAP32[(37776)>>2]|0;
 $33 = (((37696 + (($32*20)|0)|0)) + 8|0);
 HEAP32[$33>>2] = 0;
 $34 = HEAP32[$rc>>2]|0;
 $35 = ($34|0)==(1);
 $36 = $25;
 if (!($35)) {
  $183 = HEAP32[$rc>>2]|0;
  STACKTOP = sp;return ($183|0);
 }
 $37 = ((($36)) + 16|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ((($38)) + 56|0);
 $40 = HEAP32[$39>>2]|0;
 $41 = ($40|0)==(0|0);
 if (!($41)) {
  $42 = (_strcmp($40,37232)|0);
  $43 = ($42|0)==(0);
  $44 = $43&1;
  $45 = ((($36)) + 8|0);
  $46 = HEAP32[$45>>2]|0;
  $47 = ((($46)) + 37|0);
  HEAP8[$47>>0] = $44;
  if (!($43)) {
   $48 = HEAP32[37624>>2]|0;
   $49 = ((($48)) + 16|0);
   $50 = HEAP32[$49>>2]|0;
   $51 = ((($50)) + 56|0);
   $52 = HEAP32[$51>>2]|0;
   $53 = ((($50)) + 1588|0);
   HEAP32[$53>>2] = $52;
  }
 }
 $54 = HEAP32[37624>>2]|0;
 $55 = ((($54)) + 16|0);
 $56 = HEAP32[$55>>2]|0;
 $57 = ((($56)) + 416|0);
 $58 = HEAP32[$57>>2]|0;
 $59 = ($58|0)==(0|0);
 if ($59) {
  $62 = $56;
 } else {
  $60 = HEAP8[$58>>0]|0;
  HEAP8[37296>>0] = $60;
  $$pre30 = HEAP32[$55>>2]|0;
  $62 = $$pre30;
 }
 $61 = ((($62)) + 76|0);
 $63 = HEAP32[$61>>2]|0;
 $64 = ($63|0)==(0|0);
 if ($64) {
  $66 = $62;
 } else {
  HEAP32[37216>>2] = $63;
  $$pre31 = HEAP32[$55>>2]|0;
  $66 = $$pre31;
 }
 $65 = ((($66)) + 1588|0);
 $67 = HEAP32[$65>>2]|0;
 $68 = ($67|0)==(0|0);
 if (!($68)) {
  HEAP32[37224>>2] = $67;
 }
 $69 = (__nc_trim_sgr0($54)|0);
 $70 = HEAP32[(37776)>>2]|0;
 $71 = (((37696 + (($70*20)|0)|0)) + 8|0);
 HEAP32[$71>>2] = $69;
 $72 = ($69|0)==(0|0);
 if (!($72)) {
  $73 = HEAP32[(37776)>>2]|0;
  $74 = (((37696 + (($73*20)|0)|0)) + 8|0);
  $75 = HEAP32[$74>>2]|0;
  $76 = HEAP32[37624>>2]|0;
  $77 = ((($76)) + 16|0);
  $78 = HEAP32[$77>>2]|0;
  $79 = ((($78)) + 156|0);
  $80 = HEAP32[$79>>2]|0;
  $81 = (_strcmp($75,$80)|0);
  $82 = ($81|0)==(0);
  if ($82) {
   $83 = ($75|0)==($80|0);
   if ($83) {
    $85 = $73;
   } else {
    _free($75);
    $$pre32 = HEAP32[(37776)>>2]|0;
    $85 = $$pre32;
   }
   $84 = (((37696 + (($85*20)|0)|0)) + 8|0);
   HEAP32[$84>>2] = 0;
  }
 }
 $86 = HEAP32[(37776)>>2]|0;
 $87 = (((37696 + (($86*20)|0)|0)) + 12|0);
 HEAP32[$87>>2] = $bufp;
 $88 = HEAP32[(37776)>>2]|0;
 $89 = (((37696 + (($88*20)|0)|0)) + 4|0);
 HEAP8[$89>>0] = 1;
 $90 = HEAP32[37632>>2]|0;
 __nc_set_no_padding($90);
 (_baudrate()|0);
 $91 = HEAP32[37624>>2]|0;
 $92 = ((($91)) + 16|0);
 $93 = HEAP32[$92>>2]|0;
 $94 = ((($93)) + 8|0);
 $95 = HEAP32[$94>>2]|0;
 $magicptr = $95;
 if (!((($magicptr|0) == 0) | (($magicptr|0) == -1))) {
  $96 = (_strchr($95,42)|0);
  $97 = ($96|0)==(0|0);
  if (!($97)) {
   $98 = ((($96)) + 1|0);
   $99 = (_atoi($98)|0);
   $sext$mask3 = $99 & 65535;
   $100 = ($sext$mask3|0)==(0);
   if (!($100)) {
    $101 = $99&65535;
    $102 = ((($91)) + 12|0);
    $103 = HEAP32[$102>>2]|0;
    $104 = ((($103)) + 68|0);
    HEAP16[$104>>1] = $101;
   }
  }
 }
 $105 = ((($93)) + 412|0);
 $106 = HEAP32[$105>>2]|0;
 $magicptr7 = $106;
 if (!((($magicptr7|0) == 0) | (($magicptr7|0) == -1))) {
  $107 = (_strchr($106,42)|0);
  $108 = ($107|0)==(0|0);
  if (!($108)) {
   $109 = ((($107)) + 1|0);
   $110 = (_atoi($109)|0);
   $sext$mask = $110 & 65535;
   $111 = ($sext$mask|0)==(0);
   if (!($111)) {
    $112 = $110&65535;
    $113 = ((($91)) + 12|0);
    $114 = HEAP32[$113>>2]|0;
    $115 = ((($114)) + 70|0);
    HEAP16[$115>>1] = $112;
   }
  }
 }
 $116 = ((($93)) + 1576|0);
 $117 = HEAP32[$116>>2]|0;
 $magicptr8 = $117;
 if ((($magicptr8|0) == 0) | (($magicptr8|0) == -1)) {
  $118 = ((($93)) + 200|0);
  $119 = HEAP32[$118>>2]|0;
  $magicptr9 = $119;
  if ((($magicptr9|0) == 0) | (($magicptr9|0) == -1)) {
   $125 = $93;$203 = $91;
  } else {
   HEAP32[$116>>2] = $119;
   $120 = HEAP32[37624>>2]|0;
   $121 = ((($120)) + 16|0);
   $122 = HEAP32[$121>>2]|0;
   $123 = ((($122)) + 200|0);
   HEAP32[$123>>2] = 0;
   $$pre35 = HEAP32[37624>>2]|0;
   $$phi$trans$insert36 = ((($$pre35)) + 16|0);
   $$pre37 = HEAP32[$$phi$trans$insert36>>2]|0;
   $125 = $$pre37;$203 = $$pre35;
  }
 } else {
  $125 = $93;$203 = $91;
 }
 $124 = ((($125)) + 1580|0);
 $126 = HEAP32[$124>>2]|0;
 $magicptr10 = $126;
 if ((($magicptr10|0) == 0) | (($magicptr10|0) == -1)) {
  $127 = ((($125)) + 492|0);
  $128 = HEAP32[$127>>2]|0;
  $magicptr11 = $128;
  if ((($magicptr11|0) == 0) | (($magicptr11|0) == -1)) {
   $138 = $203;
  } else {
   $129 = ((($125)) + 488|0);
   $130 = HEAP32[$129>>2]|0;
   $magicptr12 = $130;
   if ((($magicptr12|0) == 0) | (($magicptr12|0) == -1)) {
    $131 = ((($125)) + 496|0);
    $132 = HEAP32[$131>>2]|0;
    $magicptr13 = $132;
    if ((($magicptr13|0) == 0) | (($magicptr13|0) == -1)) {
     HEAP32[$124>>2] = $magicptr11;
     $133 = HEAP32[37624>>2]|0;
     $134 = ((($133)) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ((($135)) + 492|0);
     HEAP32[$136>>2] = 0;
     $$pre38 = HEAP32[37624>>2]|0;
     $138 = $$pre38;
    } else {
     $138 = $203;
    }
   } else {
    $138 = $203;
   }
  }
 } else {
  $138 = $203;
 }
 $137 = ((($138)) + 12|0);
 $139 = HEAP32[$137>>2]|0;
 $140 = ((($139)) + 66|0);
 $141 = HEAP16[$140>>1]|0;
 $142 = ($141<<16>>16)==(-1);
 if ($142) {
  $143 = ((($139)) + 8|0);
  $144 = HEAP16[$143>>1]|0;
  $145 = ($144<<16>>16)==(-1);
  if (!($145)) {
   $146 = ((($138)) + 16|0);
   $147 = HEAP32[$146>>2]|0;
   $148 = ((($147)) + 144|0);
   $149 = HEAP32[$148>>2]|0;
   $magicptr14 = $149;
   if (!((($magicptr14|0) == 0) | (($magicptr14|0) == -1))) {
    HEAP16[$140>>1] = $144;
   }
  }
 }
 $150 = ((($138)) + 16|0);
 $151 = HEAP32[$150>>2]|0;
 $152 = ((($151)) + 412|0);
 $153 = HEAP32[$152>>2]|0;
 $magicptr15 = $153;
 if ((($magicptr15|0) == 0) | (($magicptr15|0) == -1)) {
  $159 = 0;
 } else {
  $154 = (_strcmp(37240,$153)|0);
  $155 = ($154|0)==(0);
  $phitmp = $155&1;
  $159 = $phitmp;
 }
 $156 = ((($138)) + 8|0);
 $157 = HEAP32[$156>>2]|0;
 $158 = ((($157)) + 41|0);
 HEAP8[$158>>0] = $159;
 $160 = HEAP32[37624>>2]|0;
 $161 = ((($160)) + 16|0);
 $162 = HEAP32[$161>>2]|0;
 $163 = ((($162)) + 56|0);
 $164 = HEAP32[$163>>2]|0;
 $magicptr16 = $164;
 if (!((($magicptr16|0) == 0) | (($magicptr16|0) == -1))) {
  $165 = (_strchr($164,42)|0);
  $166 = ($165|0)==(0|0);
  if (!($166)) {
   $167 = ((($165)) + 1|0);
   $168 = (_atoi($167)|0);
   $phitmp2 = $168&65535;
   $169 = ($phitmp2<<16>>16)==(0);
   if (!($169)) {
    $170 = ((($160)) + 12|0);
    $171 = HEAP32[$170>>2]|0;
    $172 = ((($171)) + 72|0);
    HEAP16[$172>>1] = $phitmp2;
   }
  }
 }
 $173 = ((($162)) + 536|0);
 $174 = HEAP32[$173>>2]|0;
 $magicptr17 = $174;
 if ((($magicptr17|0) == 0) | (($magicptr17|0) == -1)) {
  $183 = HEAP32[$rc>>2]|0;
  STACKTOP = sp;return ($183|0);
 }
 $175 = (_strchr($174,42)|0);
 $176 = ($175|0)==(0|0);
 if ($176) {
  $183 = HEAP32[$rc>>2]|0;
  STACKTOP = sp;return ($183|0);
 }
 $177 = ((($175)) + 1|0);
 $178 = (_atoi($177)|0);
 $phitmp1 = $178&65535;
 $179 = ($phitmp1<<16>>16)==(0);
 if ($179) {
  $183 = HEAP32[$rc>>2]|0;
  STACKTOP = sp;return ($183|0);
 }
 $180 = ((($160)) + 12|0);
 $181 = HEAP32[$180>>2]|0;
 $182 = ((($181)) + 74|0);
 HEAP16[$182>>1] = $phitmp1;
 $183 = HEAP32[$rc>>2]|0;
 STACKTOP = sp;return ($183|0);
}
function _tgetflag($id) {
 $id = $id|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $j$0 = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $result$0 = 0;
  return ($result$0|0);
 }
 $2 = (__nc_find_type_entry($id,0,1)|0);
 $3 = ($2|0)==(0|0);
 L4: do {
  if ($3) {
   $4 = ((($0)) + 28|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5&65535)>(44);
   if (!($6)) {
    $result$0 = 0;
    return ($result$0|0);
   }
   $7 = $5&65535;
   $8 = ((($0)) + 34|0);
   $9 = ((($0)) + 24|0);
   $10 = HEAP16[$8>>1]|0;
   $11 = $10&65535;
   $12 = HEAP32[$9>>2]|0;
   $i$02 = 44;
   while(1) {
    $16 = (($i$02) - ($7))|0;
    $17 = (($16) + ($11))|0;
    $18 = (($12) + ($17<<2)|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (_strncmp($id,$19,2)|0);
    $21 = ($20|0)==(0);
    if ($21) {
     $j$0 = $i$02;
     break L4;
    }
    $22 = (($i$02) + 1)|0;
    $23 = ($22|0)<($7|0);
    if ($23) {
     $i$02 = $22;
    } else {
     $result$0 = 0;
     break;
    }
   }
   return ($result$0|0);
  } else {
   $13 = ((($2)) + 8|0);
   $14 = HEAP16[$13>>1]|0;
   $15 = $14 << 16 >> 16;
   $j$0 = $15;
  }
 } while(0);
 $24 = ($j$0|0)>(-1);
 if (!($24)) {
  $result$0 = 0;
  return ($result$0|0);
 }
 $25 = ((($0)) + 8|0);
 $26 = HEAP32[$25>>2]|0;
 $27 = (($26) + ($j$0)|0);
 $28 = HEAP8[$27>>0]|0;
 $29 = $28 << 24 >> 24;
 $result$0 = $29;
 return ($result$0|0);
}
function _tgetnum($id) {
 $id = $id|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02 = 0, $j$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  return -1;
 }
 $2 = (__nc_find_type_entry($id,1,1)|0);
 $3 = ($2|0)==(0|0);
 L4: do {
  if ($3) {
   $4 = ((($0)) + 30|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5&65535)>(39);
   if (!($6)) {
    return -1;
   }
   $7 = $5&65535;
   $8 = ((($0)) + 36|0);
   $9 = ((($0)) + 34|0);
   $10 = ((($0)) + 24|0);
   $11 = HEAP16[$8>>1]|0;
   $12 = $11&65535;
   $13 = HEAP16[$9>>1]|0;
   $14 = $13&65535;
   $15 = HEAP32[$10>>2]|0;
   $i$02 = 39;
   while(1) {
    $19 = (($i$02) - ($7))|0;
    $20 = (($19) + ($12))|0;
    $21 = (($20) + ($14))|0;
    $22 = (($15) + ($21<<2)|0);
    $23 = HEAP32[$22>>2]|0;
    $24 = (_strncmp($id,$23,2)|0);
    $25 = ($24|0)==(0);
    if ($25) {
     $j$0 = $i$02;
     break L4;
    }
    $26 = (($i$02) + 1)|0;
    $27 = ($26|0)<($7|0);
    if ($27) {
     $i$02 = $26;
    } else {
     break;
    }
   }
   return -1;
  } else {
   $16 = ((($2)) + 8|0);
   $17 = HEAP16[$16>>1]|0;
   $18 = $17 << 16 >> 16;
   $j$0 = $18;
  }
 } while(0);
 $28 = ($j$0|0)>(-1);
 if ($28) {
  $29 = ((($0)) + 12|0);
  $30 = HEAP32[$29>>2]|0;
  $31 = (($30) + ($j$0<<1)|0);
  $32 = HEAP16[$31>>1]|0;
  $33 = ($32<<16>>16)>(-1);
  $34 = $32 << 16 >> 16;
  $$ = $33 ? $34 : -1;
  return ($$|0);
 } else {
  return -1;
 }
 return (0)|0;
}
function _tgetstr($id,$area) {
 $id = $id|0;
 $area = $area|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$03 = 0, $j$0 = 0, $magicptr = 0, $result$0 = 0, $result$1 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $result$1 = 0;
  return ($result$1|0);
 }
 $2 = (__nc_find_type_entry($id,2,1)|0);
 $3 = ($2|0)==(0|0);
 L4: do {
  if ($3) {
   $4 = ((($0)) + 32|0);
   $5 = HEAP16[$4>>1]|0;
   $6 = ($5&65535)>(414);
   if (!($6)) {
    $result$1 = 0;
    return ($result$1|0);
   }
   $7 = $5&65535;
   $8 = ((($0)) + 38|0);
   $9 = ((($0)) + 36|0);
   $10 = ((($0)) + 34|0);
   $11 = ((($0)) + 24|0);
   $12 = HEAP16[$8>>1]|0;
   $13 = $12&65535;
   $14 = HEAP16[$9>>1]|0;
   $15 = $14&65535;
   $16 = HEAP16[$10>>1]|0;
   $17 = $16&65535;
   $18 = HEAP32[$11>>2]|0;
   $i$03 = 414;
   while(1) {
    $22 = (($i$03) - ($7))|0;
    $23 = (($22) + ($13))|0;
    $24 = (($23) + ($15))|0;
    $25 = (($24) + ($17))|0;
    $26 = (($18) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = (_strncmp($id,$27,2)|0);
    $29 = ($28|0)==(0);
    if ($29) {
     $j$0 = $i$03;
     break L4;
    }
    $30 = (($i$03) + 1)|0;
    $31 = ($30|0)<($7|0);
    if ($31) {
     $i$03 = $30;
    } else {
     $result$1 = 0;
     break;
    }
   }
   return ($result$1|0);
  } else {
   $19 = ((($2)) + 8|0);
   $20 = HEAP16[$19>>1]|0;
   $21 = $20 << 16 >> 16;
   $j$0 = $21;
  }
 } while(0);
 $32 = ($j$0|0)>(-1);
 if (!($32)) {
  $result$1 = 0;
  return ($result$1|0);
 }
 $33 = ((($0)) + 16|0);
 $34 = HEAP32[$33>>2]|0;
 $35 = (($34) + ($j$0<<2)|0);
 $36 = HEAP32[$35>>2]|0;
 $magicptr = $36;
 if ((($magicptr|0) == 0) | (($magicptr|0) == -1)) {
  $result$1 = $36;
  return ($result$1|0);
 }
 $37 = HEAP32[37624>>2]|0;
 $38 = ((($37)) + 16|0);
 $39 = HEAP32[$38>>2]|0;
 $40 = ((($39)) + 156|0);
 $41 = HEAP32[$40>>2]|0;
 $42 = ($36|0)==($41|0);
 if ($42) {
  $43 = HEAP32[(37776)>>2]|0;
  $44 = (((37696 + (($43*20)|0)|0)) + 8|0);
  $45 = HEAP32[$44>>2]|0;
  $46 = ($45|0)==(0|0);
  $$ = $46 ? $36 : $45;
  $result$0 = $$;
 } else {
  $result$0 = $36;
 }
 $47 = ($area|0)==(0|0);
 if ($47) {
  $result$1 = $result$0;
  return ($result$1|0);
 }
 $48 = HEAP32[$area>>2]|0;
 $49 = ($48|0)==(0|0);
 if ($49) {
  $result$1 = $result$0;
  return ($result$1|0);
 }
 (_strcpy(($48|0),($result$0|0))|0);
 $50 = HEAP32[$area>>2]|0;
 $51 = (_strlen(($50|0))|0);
 $52 = (($51) + 1)|0;
 $53 = (($50) + ($52)|0);
 HEAP32[$area>>2] = $53;
 $result$1 = $50;
 return ($result$1|0);
}
function _tgoto($string,$x,$y) {
 $string = $string|0;
 $x = $x|0;
 $y = $y|0;
 var $0 = 0, $vararg_buffer = 0, $vararg_ptr1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 HEAP32[$vararg_buffer>>2] = $y;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = $x;
 $0 = (_tparm($string,$vararg_buffer)|0);
 STACKTOP = sp;return ($0|0);
}
function __nc_tparm_analyze($string,$p_is_s,$popcount) {
 $string = $string|0;
 $p_is_s = $p_is_s|0;
 $popcount = $popcount|0;
 var $$0 = 0, $$0$be$i = 0, $$0$lcssa28$i = 0, $$0$lcssa30$i = 0, $$01$be$i = 0, $$01$be$ph$i = 0, $$013$i = 0, $$013$i$lcssa = 0, $$013$i60 = 0, $$018$i = 0, $$018$i$lcssa = 0, $$1$i = 0, $$12$i = 0, $$err$0$off0$i = 0, $$err$0$off07$i = 0, $$lcssa = 0, $$number$0 = 0, $$number$02 = 0, $$pn = 0, $0 = 0;
 var $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0;
 var $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $7 = 0, $8 = 0, $9 = 0, $allowminus$0$off0$be$i = 0, $allowminus$0$off010$i = 0, $cp$015 = 0, $cp$1 = 0, $cp$2 = 0, $cp$2$ = 0, $dot$0$off0$be$i = 0, $dot$0$off011$i = 0, $err$0$off0$be$i = 0, $err$0$off012$i = 0, $err$0$off012$i$lcssa = 0, $err$0$off012$i63 = 0, $isdigit = 0;
 var $isdigit$i = 0, $isdigittmp = 0, $isdigittmp$i = 0, $lastpop$013 = 0, $lastpop$1 = 0, $number$0$lcssa = 0, $number$014 = 0, $number$2 = 0, $value$0$be$i = 0, $value$015$i = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = ($string|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 }
 $1 = (_strlen(($string|0))|0);
 $2 = HEAP32[(38056)>>2]|0;
 $3 = ($1>>>0)>($2>>>0);
 if ($3) {
  $4 = (($1) + 2)|0;
  $5 = (($4) + ($2))|0;
  HEAP32[(38056)>>2] = $5;
  $6 = HEAP32[(38052)>>2]|0;
  $7 = (__nc_doalloc($6,$5)|0);
  HEAP32[(38052)>>2] = $7;
  $8 = ($7|0)==(0|0);
  if ($8) {
   $$0 = 0;
   return ($$0|0);
  }
 }
 dest=$p_is_s; stop=dest+36|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 HEAP32[$popcount>>2] = 0;
 $9 = $string;
 $10 = ($1|0)>(0);
 if ($10) {
  $cp$015 = $string;$lastpop$013 = -1;$number$014 = 0;
  while(1) {
   $11 = HEAP8[$cp$015>>0]|0;
   $12 = ($11<<24>>24)==(37);
   L11: do {
    if ($12) {
     $13 = ((($cp$015)) + 1|0);
     $14 = HEAP32[(38052)>>2]|0;
     $15 = ($14|0)==(0|0);
     if ($15) {
      $$1$i = $13;
     } else {
      $16 = ((($14)) + 1|0);
      HEAP8[$14>>0] = 37;
      $17 = HEAP8[$13>>0]|0;
      $18 = ($17<<24>>24)==(0);
      do {
       if ($18) {
        $$0$lcssa28$i = $13;$$12$i = $16;
       } else {
        $19 = $17 << 24 >> 24;
        $$013$i = $13;$$018$i = $16;$20 = $19;$23 = $17;$allowminus$0$off010$i = 0;$dot$0$off011$i = 0;$err$0$off012$i = 0;$value$015$i = 0;
        L17: while(1) {
         switch ($20|0) {
         case 46:  {
          $22 = ((($$018$i)) + 1|0);
          HEAP8[$$018$i>>0] = $23;
          $$err$0$off0$i = $err$0$off012$i | $dot$0$off011$i;
          $$01$be$i = $22;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = 1;$err$0$off0$be$i = $$err$0$off0$i;$value$0$be$i = 0;
          break;
         }
         case 32:  {
          $25 = ((($$018$i)) + 1|0);
          HEAP8[$$018$i>>0] = $23;
          $$01$be$i = $25;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$value$0$be$i = $value$015$i;
          break;
         }
         case 35:  {
          $24 = ((($$018$i)) + 1|0);
          HEAP8[$$018$i>>0] = $23;
          $$01$be$i = $24;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$value$0$be$i = $value$015$i;
          break;
         }
         case 45:  {
          if (!($allowminus$0$off010$i)) {
           $$01$be$ph$i = $$018$i;$$013$i60 = $$013$i;$err$0$off012$i63 = $err$0$off012$i;
           label = 18;
           break L17;
          }
          $26 = ((($$018$i)) + 1|0);
          HEAP8[$$018$i>>0] = $23;
          $$01$be$i = $26;$allowminus$0$off0$be$i = 1;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$value$0$be$i = $value$015$i;
          break;
         }
         case 58:  {
          $$01$be$i = $$018$i;$allowminus$0$off0$be$i = 1;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$value$0$be$i = $value$015$i;
          break;
         }
         case 115: case 88: case 120: case 111: case 100: case 99:  {
          $$013$i$lcssa = $$013$i;$$018$i$lcssa = $$018$i;$$lcssa = $23;$err$0$off012$i$lcssa = $err$0$off012$i;
          label = 10;
          break L17;
          break;
         }
         default: {
          $27 = $23&255;
          $isdigittmp$i = (($27) + -48)|0;
          $isdigit$i = ($isdigittmp$i>>>0)<(10);
          if (!($isdigit$i)) {
           $$01$be$ph$i = $$018$i;$$013$i60 = $$013$i;$err$0$off012$i63 = $err$0$off012$i;
           label = 18;
           break L17;
          }
          $28 = ($value$015$i*10)|0;
          $29 = (($20) + -48)|0;
          $30 = (($29) + ($28))|0;
          $31 = ($30|0)>(10000);
          $$err$0$off07$i = $err$0$off012$i | $31;
          $32 = ((($$018$i)) + 1|0);
          HEAP8[$$018$i>>0] = $23;
          $$01$be$i = $32;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $$err$0$off07$i;$value$0$be$i = $30;
         }
         }
         $$0$be$i = ((($$013$i)) + 1|0);
         $33 = HEAP8[$$0$be$i>>0]|0;
         $34 = $33 << 24 >> 24;
         $35 = ($33<<24>>24)==(0);
         if ($35) {
          label = 20;
          break;
         } else {
          $$013$i = $$0$be$i;$$018$i = $$01$be$i;$20 = $34;$23 = $33;$allowminus$0$off010$i = $allowminus$0$off0$be$i;$dot$0$off011$i = $dot$0$off0$be$i;$err$0$off012$i = $err$0$off0$be$i;$value$015$i = $value$0$be$i;
         }
        }
        if ((label|0) == 10) {
         label = 0;
         $21 = ((($$018$i$lcssa)) + 1|0);
         HEAP8[$$018$i$lcssa>>0] = $$lcssa;
         $$01$be$ph$i = $21;$$013$i60 = $$013$i$lcssa;$err$0$off012$i63 = $err$0$off012$i$lcssa;
         label = 18;
        }
        else if ((label|0) == 20) {
         label = 0;
         if ($err$0$off0$be$i) {
          $$0$lcssa30$i = $$0$be$i;
         } else {
          $$0$lcssa28$i = $$0$be$i;$$12$i = $$01$be$i;
          break;
         }
        }
        if ((label|0) == 18) {
         label = 0;
         if ($err$0$off012$i63) {
          $$0$lcssa30$i = $$013$i60;
         } else {
          $$0$lcssa28$i = $$013$i60;$$12$i = $$01$be$ph$i;
          break;
         }
        }
        HEAP8[$14>>0] = 37;
        $36 = HEAP8[$$0$lcssa30$i>>0]|0;
        $37 = ((($14)) + 2|0);
        HEAP8[$16>>0] = $36;
        $$0$lcssa28$i = $$0$lcssa30$i;$$12$i = $37;
       }
      } while(0);
      HEAP8[$$12$i>>0] = 0;
      $$1$i = $$0$lcssa28$i;
     }
     $38 = HEAP8[$$1$i>>0]|0;
     $39 = $38 << 24 >> 24;
     switch ($39|0) {
     case 115: case 108:  {
      $42 = ($lastpop$013|0)>(0);
      if ($42) {
       $43 = (($lastpop$013) + -1)|0;
       $44 = (($p_is_s) + ($43<<2)|0);
       HEAP32[$44>>2] = 37256;
      }
      $45 = (($number$014) + 1)|0;
      $cp$2 = $$1$i;$lastpop$1 = $lastpop$013;$number$2 = $45;
      break L11;
      break;
     }
     case 39:  {
      $56 = ((($$1$i)) + 2|0);
      $cp$2 = $56;$lastpop$1 = -1;$number$2 = $number$014;
      break L11;
      break;
     }
     case 112:  {
      $46 = ((($$1$i)) + 1|0);
      $47 = HEAP8[$46>>0]|0;
      $48 = $47&255;
      $49 = (($48) + -48)|0;
      $50 = ($49>>>0)<(10);
      if (!($50)) {
       $cp$2 = $46;$lastpop$1 = $lastpop$013;$number$2 = $number$014;
       break L11;
      }
      $51 = HEAP32[$popcount>>2]|0;
      $52 = ($49|0)>($51|0);
      if (!($52)) {
       $cp$2 = $46;$lastpop$1 = $49;$number$2 = $number$014;
       break L11;
      }
      HEAP32[$popcount>>2] = $49;
      $cp$2 = $46;$lastpop$1 = $49;$number$2 = $number$014;
      break L11;
      break;
     }
     case 62: case 60: case 61: case 94: case 124: case 38: case 79: case 65: case 109: case 47: case 42: case 45: case 43:  {
      $59 = (($number$014) + 2)|0;
      $cp$2 = $$1$i;$lastpop$1 = -1;$number$2 = $59;
      break L11;
      break;
     }
     case 123:  {
      $$pn = $$1$i;
      while(1) {
       $cp$1 = ((($$pn)) + 1|0);
       $57 = HEAP8[$cp$1>>0]|0;
       $58 = $57&255;
       $isdigittmp = (($58) + -48)|0;
       $isdigit = ($isdigittmp>>>0)<(10);
       if ($isdigit) {
        $$pn = $cp$1;
       } else {
        $cp$2 = $cp$1;$lastpop$1 = $lastpop$013;$number$2 = $number$014;
        break;
       }
      }
      break;
     }
     case 99: case 88: case 120: case 111: case 100:  {
      $40 = ($lastpop$013|0)<(1);
      $41 = $40&1;
      $$number$0 = (($41) + ($number$014))|0;
      $cp$2 = $$1$i;$lastpop$1 = -1;$number$2 = $$number$0;
      break L11;
      break;
     }
     case 80:  {
      $53 = (($number$014) + 1)|0;
      $54 = ((($$1$i)) + 1|0);
      $cp$2 = $54;$lastpop$1 = $lastpop$013;$number$2 = $53;
      break L11;
      break;
     }
     case 103:  {
      $55 = ((($$1$i)) + 1|0);
      $cp$2 = $55;$lastpop$1 = $lastpop$013;$number$2 = $number$014;
      break L11;
      break;
     }
     case 126: case 33:  {
      $60 = (($number$014) + 1)|0;
      $cp$2 = $$1$i;$lastpop$1 = -1;$number$2 = $60;
      break L11;
      break;
     }
     default: {
      $cp$2 = $$1$i;$lastpop$1 = $lastpop$013;$number$2 = $number$014;
      break L11;
     }
     }
    } else {
     $cp$2 = $cp$015;$lastpop$1 = $lastpop$013;$number$2 = $number$014;
    }
   } while(0);
   $61 = HEAP8[$cp$2>>0]|0;
   $62 = ($61<<24>>24)==(0);
   $63 = ((($cp$2)) + 1|0);
   $cp$2$ = $62 ? $cp$2 : $63;
   $64 = $cp$2$;
   $65 = (($64) - ($9))|0;
   $66 = ($65|0)<($1|0);
   if ($66) {
    $cp$015 = $cp$2$;$lastpop$013 = $lastpop$1;$number$014 = $number$2;
   } else {
    $number$0$lcssa = $number$2;
    break;
   }
  }
 } else {
  $number$0$lcssa = 0;
 }
 $67 = ($number$0$lcssa|0)>(9);
 $$number$02 = $67 ? 9 : $number$0$lcssa;
 $$0 = $$number$02;
 return ($$0|0);
}
function _tparm($string,$varargs) {
 $string = $string|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap = sp;
 HEAP32[37248>>2] = 0;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_tparam_internal($string,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _tparam_internal($string,$ap) {
 $string = $string|0;
 $ap = $ap|0;
 var $$ = 0, $$$i = 0, $$$i26 = 0, $$0 = 0, $$0$be$i = 0, $$0$lcssa28$i = 0, $$0$lcssa30$i = 0, $$01$be$i = 0, $$01$be$ph$i = 0, $$013$i = 0, $$013$i$lcssa = 0, $$013$i359 = 0, $$018$i = 0, $$018$i$lcssa = 0, $$1$i = 0, $$12$i = 0, $$err$0$off0$i = 0, $$err$0$off07$i = 0, $$lcssa = 0, $$off = 0;
 var $$off138 = 0, $$off139 = 0, $$off140 = 0, $$pr136217 = 0, $$pre = 0, $$pre$i = 0, $$pre$i10 = 0, $$pre$i18 = 0, $$pre$i21 = 0, $$pre$i28 = 0, $$pre$i7 = 0, $$pre2$i = 0, $$pre2$i12 = 0, $$pre2$i16 = 0, $$pre2$i23 = 0, $$pre2$i30 = 0, $$pre2$i5 = 0, $$pre228 = 0, $$sink = 0, $0 = 0;
 var $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0;
 var $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0;
 var $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0;
 var $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0;
 var $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0;
 var $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0;
 var $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0;
 var $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0;
 var $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0;
 var $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0;
 var $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0;
 var $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0;
 var $496 = 0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0;
 var $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0;
 var $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0;
 var $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0;
 var $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0;
 var $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0;
 var $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0;
 var $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0;
 var $64 = 0, $640 = 0, $641 = 0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0;
 var $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0;
 var $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0;
 var $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0;
 var $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0;
 var $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0;
 var $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0;
 var $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0;
 var $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0;
 var $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0;
 var $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0;
 var $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $allowminus$0$off0$be$i = 0, $allowminus$0$off010$i = 0, $arglist_current = 0, $arglist_current2 = 0, $arglist_next = 0, $arglist_next3 = 0, $cp$0170 = 0, $cp$1 = 0, $cp$1$lcssa = 0, $cp$1163 = 0, $cp$1167 = 0;
 var $cp$2 = 0, $cp$3 = 0, $cp$3$ = 0, $cp$4 = 0, $cp$5 = 0, $cp$5$ = 0, $cp$6 = 0, $dot$0$off0$be$i = 0, $dot$0$off0$lcssa29$i = 0, $dot$0$off0$lcssa31$i = 0, $dot$0$off011$i = 0, $dot$0$off011$i$lcssa = 0, $dot$0$off011$i365 = 0, $err$0$off0$be$i = 0, $err$0$off012$i = 0, $err$0$off012$i$lcssa = 0, $err$0$off012$i362 = 0, $expanded = 0, $expanded24 = 0, $expanded26 = 0;
 var $expanded27 = 0, $expanded28 = 0, $expanded30 = 0, $expanded31 = 0, $expanded33 = 0, $expanded34 = 0, $expanded35 = 0, $i$0177 = 0, $i$1174 = 0, $i$1174$in = 0, $isdigit = 0, $isdigit$i = 0, $isdigit165 = 0, $isdigittmp = 0, $isdigittmp$i = 0, $isdigittmp164 = 0, $isdigittmp168 = 0, $len$$i = 0, $len$op$i = 0, $level$0 = 0;
 var $level$1 = 0, $level$2 = 0, $level$3 = 0, $my_width$0$be$i = 0, $my_width$0$value$0$i = 0, $my_width$014$i = 0, $my_width$014$i$lcssa = 0, $my_width$014$i356 = 0, $my_width$2$i = 0, $my_width$2$value$1$i = 0, $number$1$lcssa = 0, $number$1166 = 0, $or$cond3 = 0, $p_is_s = 0, $param = 0, $popcount = 0, $result$0$i = 0, $result$0$i100 = 0, $result$0$i100244 = 0, $result$0$i100245 = 0;
 var $result$0$i103 = 0, $result$0$i103243 = 0, $result$0$i105 = 0, $result$0$i105239242 = 0, $result$0$i105241 = 0, $result$0$i108 = 0, $result$0$i108238 = 0, $result$0$i110 = 0, $result$0$i110234237 = 0, $result$0$i110236 = 0, $result$0$i113 = 0, $result$0$i113233 = 0, $result$0$i14 = 0, $result$0$i34 = 0, $result$0$i36 = 0, $result$0$i42 = 0, $result$0$i42229232 = 0, $result$0$i42231 = 0, $result$0$i47 = 0, $result$0$i47279 = 0;
 var $result$0$i50 = 0, $result$0$i50278 = 0, $result$0$i53 = 0, $result$0$i53277 = 0, $result$0$i55 = 0, $result$0$i55273276 = 0, $result$0$i55275 = 0, $result$0$i58 = 0, $result$0$i58272 = 0, $result$0$i60 = 0, $result$0$i60268271 = 0, $result$0$i60270 = 0, $result$0$i63 = 0, $result$0$i63267 = 0, $result$0$i65 = 0, $result$0$i65263266 = 0, $result$0$i65265 = 0, $result$0$i68 = 0, $result$0$i68262 = 0, $result$0$i70 = 0;
 var $result$0$i70258261 = 0, $result$0$i70260 = 0, $result$0$i73 = 0, $result$0$i73257 = 0, $result$0$i75 = 0, $result$0$i75253256 = 0, $result$0$i75255 = 0, $result$0$i78 = 0, $result$0$i78252 = 0, $result$0$i80 = 0, $result$0$i80248251 = 0, $result$0$i80250 = 0, $result$0$i83 = 0, $result$0$i88 = 0, $result$0$i93 = 0, $result$0$i95 = 0, $result$0$i95246 = 0, $result$0$i95247 = 0, $result$0$i98 = 0, $value$0$be$i = 0;
 var $value$015$i = 0, $value$015$i$lcssa = 0, $value$015$i353 = 0, $value$1$$i = 0, $value$1$i = 0, $vararg_buffer = 0, $vararg_buffer10 = 0, $vararg_buffer12 = 0, $vararg_buffer14 = 0, $vararg_buffer17 = 0, $vararg_buffer19 = 0, $vararg_buffer22 = 0, $vararg_buffer4 = 0, $vararg_buffer6 = 0, $vararg_buffer8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer22 = sp + 72|0;
 $vararg_buffer19 = sp + 64|0;
 $vararg_buffer17 = sp + 56|0;
 $vararg_buffer14 = sp + 48|0;
 $vararg_buffer12 = sp + 40|0;
 $vararg_buffer10 = sp + 32|0;
 $vararg_buffer8 = sp + 24|0;
 $vararg_buffer6 = sp + 16|0;
 $vararg_buffer4 = sp + 8|0;
 $vararg_buffer = sp;
 $p_is_s = sp + 116|0;
 $param = sp + 80|0;
 $popcount = sp + 76|0;
 HEAP32[$popcount>>2] = 0;
 $0 = ($string|0)==(0|0);
 if ($0) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 HEAP32[(38048)>>2] = 0;
 $1 = (_strlen(($string|0))|0);
 $2 = (__nc_tparm_analyze($string,$p_is_s,$popcount)|0);
 $3 = HEAP32[(38052)>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ($2|0)>(9);
 $$ = $5 ? 9 : $2;
 $6 = HEAP32[$popcount>>2]|0;
 $7 = ($6|0)>(9);
 if ($7) {
  HEAP32[$popcount>>2] = 9;
  $9 = 9;
 } else {
  $9 = $6;
 }
 $8 = ($9|0)<($$|0);
 $10 = $8 ? $$ : $9;
 $11 = ($10|0)>(0);
 if ($11) {
  $i$0177 = 0;
  while(1) {
   $12 = (($p_is_s) + ($i$0177<<2)|0);
   $13 = HEAP32[$12>>2]|0;
   $14 = ($13|0)==(0|0);
   if ($14) {
    $arglist_current2 = HEAP32[$ap>>2]|0;
    $22 = $arglist_current2;
    $23 = ((0) + 4|0);
    $expanded31 = $23;
    $expanded30 = (($expanded31) - 1)|0;
    $24 = (($22) + ($expanded30))|0;
    $25 = ((0) + 4|0);
    $expanded35 = $25;
    $expanded34 = (($expanded35) - 1)|0;
    $expanded33 = $expanded34 ^ -1;
    $26 = $24 & $expanded33;
    $27 = $26;
    $28 = HEAP32[$27>>2]|0;
    $arglist_next3 = ((($27)) + 4|0);
    HEAP32[$ap>>2] = $arglist_next3;
    $$sink = $28;
   } else {
    $arglist_current = HEAP32[$ap>>2]|0;
    $15 = $arglist_current;
    $16 = ((0) + 4|0);
    $expanded24 = $16;
    $expanded = (($expanded24) - 1)|0;
    $17 = (($15) + ($expanded))|0;
    $18 = ((0) + 4|0);
    $expanded28 = $18;
    $expanded27 = (($expanded28) - 1)|0;
    $expanded26 = $expanded27 ^ -1;
    $19 = $17 & $expanded26;
    $20 = $19;
    $21 = HEAP32[$20>>2]|0;
    $arglist_next = ((($20)) + 4|0);
    HEAP32[$ap>>2] = $arglist_next;
    HEAP32[$12>>2] = $21;
    $$sink = 0;
   }
   $29 = (($param) + ($i$0177<<2)|0);
   HEAP32[$29>>2] = $$sink;
   $30 = (($i$0177) + 1)|0;
   $31 = ($30|0)<($10|0);
   if ($31) {
    $i$0177 = $30;
   } else {
    break;
   }
  }
 }
 HEAP32[(38036)>>2] = 0;
 $32 = ($9|0)==(0);
 if ($32) {
  HEAP32[$popcount>>2] = $$;
  $37 = ($$|0)>(0);
  if ($37) {
   $42 = 0;$i$1174$in = $$;
   while(1) {
    $i$1174 = (($i$1174$in) + -1)|0;
    $38 = (($p_is_s) + ($i$1174<<2)|0);
    $39 = HEAP32[$38>>2]|0;
    $40 = ($39|0)==(0|0);
    $41 = ($42|0)<(20);
    do {
     if ($40) {
      if ($41) {
       $50 = (($param) + ($i$1174<<2)|0);
       $51 = HEAP32[$50>>2]|0;
       $52 = (((37876 + ($42<<3)|0)) + 4|0);
       HEAP8[$52>>0] = 1;
       $53 = (37876 + ($42<<3)|0);
       HEAP32[$53>>2] = $51;
       $54 = HEAP32[(38036)>>2]|0;
       $55 = (($54) + 1)|0;
       HEAP32[(38036)>>2] = $55;
       $815 = $55;
       break;
      } else {
       $56 = HEAP32[37248>>2]|0;
       $57 = (($56) + 1)|0;
       HEAP32[37248>>2] = $57;
       $815 = $42;
       break;
      }
     } else {
      if ($41) {
       $43 = (((37876 + ($42<<3)|0)) + 4|0);
       HEAP8[$43>>0] = 0;
       $44 = (37876 + ($42<<3)|0);
       HEAP32[$44>>2] = $39;
       $45 = HEAP32[(38036)>>2]|0;
       $46 = (($45) + 1)|0;
       HEAP32[(38036)>>2] = $46;
       $815 = $46;
       break;
      } else {
       $48 = HEAP32[37248>>2]|0;
       $49 = (($48) + 1)|0;
       HEAP32[37248>>2] = $49;
       $815 = $42;
       break;
      }
     }
    } while(0);
    $47 = ($i$1174$in|0)>(1);
    if ($47) {
     $42 = $815;$i$1174$in = $i$1174;
    } else {
     break;
    }
   }
  }
 }
 $33 = $string;
 $34 = ($1|0)>(0);
 L33: do {
  if ($34) {
   $35 = ((($p_is_s)) + 4|0);
   $36 = ((($param)) + 4|0);
   $cp$0170 = $string;
   L35: while(1) {
    $62 = HEAP8[$cp$0170>>0]|0;
    $63 = ($62<<24>>24)==(37);
    L37: do {
     if ($63) {
      $78 = ((($cp$0170)) + 1|0);
      HEAP32[(37872)>>2] = $cp$0170;
      $79 = HEAP32[(38052)>>2]|0;
      $80 = ($79|0)==(0|0);
      if ($80) {
       $$1$i = $78;$133 = 0;
      } else {
       $81 = ((($79)) + 1|0);
       HEAP8[$79>>0] = 37;
       $82 = HEAP8[$78>>0]|0;
       $83 = ($82<<24>>24)==(0);
       do {
        if ($83) {
         $$0$lcssa28$i = $78;$$12$i = $81;$dot$0$off0$lcssa29$i = 0;$my_width$2$i = 0;$value$1$i = 0;
        } else {
         $84 = $82 << 24 >> 24;
         $$013$i = $78;$$018$i = $81;$85 = $84;$88 = $82;$allowminus$0$off010$i = 0;$dot$0$off011$i = 0;$err$0$off012$i = 0;$my_width$014$i = 0;$value$015$i = 0;
         L49: while(1) {
          switch ($85|0) {
          case 58:  {
           $$01$be$i = $$018$i;$allowminus$0$off0$be$i = 1;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$my_width$0$be$i = $my_width$014$i;$value$0$be$i = $value$015$i;
           break;
          }
          case 35:  {
           $89 = ((($$018$i)) + 1|0);
           HEAP8[$$018$i>>0] = $88;
           $$01$be$i = $89;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$my_width$0$be$i = $my_width$014$i;$value$0$be$i = $value$015$i;
           break;
          }
          case 32:  {
           $90 = ((($$018$i)) + 1|0);
           HEAP8[$$018$i>>0] = $88;
           $$01$be$i = $90;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$my_width$0$be$i = $my_width$014$i;$value$0$be$i = $value$015$i;
           break;
          }
          case 45:  {
           if (!($allowminus$0$off010$i)) {
            $$01$be$ph$i = $$018$i;$$013$i359 = $$013$i;$dot$0$off011$i365 = $dot$0$off011$i;$err$0$off012$i362 = $err$0$off012$i;$my_width$014$i356 = $my_width$014$i;$value$015$i353 = $value$015$i;
            label = 42;
            break L49;
           }
           $91 = ((($$018$i)) + 1|0);
           HEAP8[$$018$i>>0] = $88;
           $$01$be$i = $91;$allowminus$0$off0$be$i = 1;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $err$0$off012$i;$my_width$0$be$i = $my_width$014$i;$value$0$be$i = $value$015$i;
           break;
          }
          case 46:  {
           $87 = ((($$018$i)) + 1|0);
           HEAP8[$$018$i>>0] = $88;
           $$err$0$off0$i = $err$0$off012$i | $dot$0$off011$i;
           $my_width$0$value$0$i = $dot$0$off011$i ? $my_width$014$i : $value$015$i;
           $$01$be$i = $87;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = 1;$err$0$off0$be$i = $$err$0$off0$i;$my_width$0$be$i = $my_width$0$value$0$i;$value$0$be$i = 0;
           break;
          }
          case 115: case 88: case 120: case 111: case 100: case 99:  {
           $$013$i$lcssa = $$013$i;$$018$i$lcssa = $$018$i;$$lcssa = $88;$dot$0$off011$i$lcssa = $dot$0$off011$i;$err$0$off012$i$lcssa = $err$0$off012$i;$my_width$014$i$lcssa = $my_width$014$i;$value$015$i$lcssa = $value$015$i;
           label = 34;
           break L49;
           break;
          }
          default: {
           $92 = $88&255;
           $isdigittmp$i = (($92) + -48)|0;
           $isdigit$i = ($isdigittmp$i>>>0)<(10);
           if (!($isdigit$i)) {
            $$01$be$ph$i = $$018$i;$$013$i359 = $$013$i;$dot$0$off011$i365 = $dot$0$off011$i;$err$0$off012$i362 = $err$0$off012$i;$my_width$014$i356 = $my_width$014$i;$value$015$i353 = $value$015$i;
            label = 42;
            break L49;
           }
           $93 = ($value$015$i*10)|0;
           $94 = (($85) + -48)|0;
           $95 = (($94) + ($93))|0;
           $96 = ($95|0)>(10000);
           $$err$0$off07$i = $err$0$off012$i | $96;
           $97 = ((($$018$i)) + 1|0);
           HEAP8[$$018$i>>0] = $88;
           $$01$be$i = $97;$allowminus$0$off0$be$i = $allowminus$0$off010$i;$dot$0$off0$be$i = $dot$0$off011$i;$err$0$off0$be$i = $$err$0$off07$i;$my_width$0$be$i = $my_width$014$i;$value$0$be$i = $95;
          }
          }
          $$0$be$i = ((($$013$i)) + 1|0);
          $98 = HEAP8[$$0$be$i>>0]|0;
          $99 = $98 << 24 >> 24;
          $100 = ($98<<24>>24)==(0);
          if ($100) {
           label = 44;
           break;
          } else {
           $$013$i = $$0$be$i;$$018$i = $$01$be$i;$85 = $99;$88 = $98;$allowminus$0$off010$i = $allowminus$0$off0$be$i;$dot$0$off011$i = $dot$0$off0$be$i;$err$0$off012$i = $err$0$off0$be$i;$my_width$014$i = $my_width$0$be$i;$value$015$i = $value$0$be$i;
          }
         }
         if ((label|0) == 34) {
          label = 0;
          $86 = ((($$018$i$lcssa)) + 1|0);
          HEAP8[$$018$i$lcssa>>0] = $$lcssa;
          $$01$be$ph$i = $86;$$013$i359 = $$013$i$lcssa;$dot$0$off011$i365 = $dot$0$off011$i$lcssa;$err$0$off012$i362 = $err$0$off012$i$lcssa;$my_width$014$i356 = $my_width$014$i$lcssa;$value$015$i353 = $value$015$i$lcssa;
          label = 42;
         }
         else if ((label|0) == 44) {
          label = 0;
          if ($err$0$off0$be$i) {
           $$0$lcssa30$i = $$0$be$i;$dot$0$off0$lcssa31$i = $dot$0$off0$be$i;
          } else {
           $$0$lcssa28$i = $$0$be$i;$$12$i = $$01$be$i;$dot$0$off0$lcssa29$i = $dot$0$off0$be$i;$my_width$2$i = $my_width$0$be$i;$value$1$i = $value$0$be$i;
           break;
          }
         }
         if ((label|0) == 42) {
          label = 0;
          if ($err$0$off012$i362) {
           $$0$lcssa30$i = $$013$i359;$dot$0$off0$lcssa31$i = $dot$0$off011$i365;
          } else {
           $$0$lcssa28$i = $$013$i359;$$12$i = $$01$be$ph$i;$dot$0$off0$lcssa29$i = $dot$0$off011$i365;$my_width$2$i = $my_width$014$i356;$value$1$i = $value$015$i353;
           break;
          }
         }
         HEAP8[$79>>0] = 37;
         $101 = HEAP8[$$0$lcssa30$i>>0]|0;
         $102 = ((($79)) + 2|0);
         HEAP8[$81>>0] = $101;
         $$0$lcssa28$i = $$0$lcssa30$i;$$12$i = $102;$dot$0$off0$lcssa29$i = $dot$0$off0$lcssa31$i;$my_width$2$i = 0;$value$1$i = 0;
        }
       } while(0);
       $my_width$2$value$1$i = $dot$0$off0$lcssa29$i ? $my_width$2$i : $value$1$i;
       $value$1$$i = $dot$0$off0$lcssa29$i ? $value$1$i : 0;
       HEAP8[$$12$i>>0] = 0;
       $103 = ($my_width$2$value$1$i|0)>($value$1$$i|0);
       $104 = $103 ? $my_width$2$value$1$i : $value$1$$i;
       $$1$i = $$0$lcssa28$i;$133 = $104;
      }
      $105 = HEAP8[$$1$i>>0]|0;
      $106 = $105 << 24 >> 24;
      do {
       switch ($106|0) {
       case 123:  {
        $cp$1163 = ((($$1$i)) + 1|0);
        $107 = HEAP8[$cp$1163>>0]|0;
        $108 = $107&255;
        $isdigittmp164 = (($108) + -48)|0;
        $isdigit165 = ($isdigittmp164>>>0)<(10);
        if ($isdigit165) {
         $cp$1167 = $cp$1163;$isdigittmp168 = $isdigittmp164;$number$1166 = 0;
         while(1) {
          $331 = ($number$1166*10)|0;
          $332 = (($isdigittmp168) + ($331))|0;
          $cp$1 = ((($cp$1167)) + 1|0);
          $333 = HEAP8[$cp$1>>0]|0;
          $334 = $333&255;
          $isdigittmp = (($334) + -48)|0;
          $isdigit = ($isdigittmp>>>0)<(10);
          if ($isdigit) {
           $cp$1167 = $cp$1;$isdigittmp168 = $isdigittmp;$number$1166 = $332;
          } else {
           $cp$1$lcssa = $cp$1;$number$1$lcssa = $332;
           break;
          }
         }
        } else {
         $cp$1$lcssa = $cp$1163;$number$1$lcssa = 0;
        }
        $335 = HEAP32[(38036)>>2]|0;
        $336 = ($335|0)<(20);
        if ($336) {
         $337 = (((37876 + ($335<<3)|0)) + 4|0);
         HEAP8[$337>>0] = 1;
         $338 = (37876 + ($335<<3)|0);
         HEAP32[$338>>2] = $number$1$lcssa;
         $339 = HEAP32[(38036)>>2]|0;
         $340 = (($339) + 1)|0;
         HEAP32[(38036)>>2] = $340;
         $cp$6 = $cp$1$lcssa;
         break L37;
        } else {
         $341 = HEAP32[37248>>2]|0;
         $342 = (($341) + 1)|0;
         HEAP32[37248>>2] = $342;
         $cp$6 = $cp$1$lcssa;
         break L37;
        }
        break;
       }
       case 37:  {
        $109 = HEAP32[(38048)>>2]|0;
        $110 = (($109) + 1)|0;
        $111 = HEAP32[(38044)>>2]|0;
        $112 = ($110>>>0)>($111>>>0);
        if ($112) {
         $113 = $110 << 1;
         HEAP32[(38044)>>2] = $113;
         $114 = HEAP32[(38040)>>2]|0;
         $115 = (__nc_doalloc($114,$113)|0);
         HEAP32[(38040)>>2] = $115;
         $116 = ($115|0)==(0|0);
         if ($116) {
          label = 53;
          break L35;
         }
         $$pre$i7 = HEAP32[(38048)>>2]|0;
         $118 = $$pre$i7;$120 = $115;
        } else {
         $$pre2$i5 = HEAP32[(38040)>>2]|0;
         $118 = $109;$120 = $$pre2$i5;
        }
        $117 = (($118) + 1)|0;
        HEAP32[(38048)>>2] = $117;
        $119 = (($120) + ($118)|0);
        HEAP8[$119>>0] = 37;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 115:  {
        $205 = HEAP32[(38052)>>2]|0;
        $206 = HEAP32[(38036)>>2]|0;
        $207 = ($206|0)>(0);
        if ($207) {
         $208 = (($206) + -1)|0;
         HEAP32[(38036)>>2] = $208;
         $209 = (((37876 + ($208<<3)|0)) + 4|0);
         $210 = HEAP8[$209>>0]|0;
         $211 = ($210<<24>>24)==(0);
         if ($211) {
          $212 = (37876 + ($208<<3)|0);
          $213 = HEAP32[$212>>2]|0;
          $214 = ($213|0)==(0|0);
          $$$i26 = $214 ? 37280 : $213;
          $217 = $$$i26;
         } else {
          $217 = 37280;
         }
        } else {
         $215 = HEAP32[37248>>2]|0;
         $216 = (($215) + 1)|0;
         HEAP32[37248>>2] = $216;
         $217 = 37280;
        }
        $218 = (_strlen(($217|0))|0);
        $219 = ($218|0)<($133|0);
        $len$$i = $219 ? $133 : $218;
        $220 = HEAP32[(38048)>>2]|0;
        $221 = (($220) + 1)|0;
        $222 = (($221) + ($len$$i))|0;
        $223 = HEAP32[(38044)>>2]|0;
        $224 = ($222>>>0)>($223>>>0);
        if ($224) {
         $225 = $222 << 1;
         HEAP32[(38044)>>2] = $225;
         $226 = HEAP32[(38040)>>2]|0;
         $227 = (__nc_doalloc($226,$225)|0);
         HEAP32[(38040)>>2] = $227;
         $228 = ($227|0)==(0|0);
         if ($228) {
          label = 93;
          break L35;
         }
         $$pre2$i30 = HEAP32[(38048)>>2]|0;
         $230 = $227;$231 = $$pre2$i30;
        } else {
         $$pre$i28 = HEAP32[(38040)>>2]|0;
         $230 = $$pre$i28;$231 = $220;
        }
        $229 = (($230) + ($231)|0);
        HEAP32[$vararg_buffer19>>2] = $217;
        (_sprintf($229,$205,$vararg_buffer19)|0);
        $232 = HEAP32[(38040)>>2]|0;
        $233 = HEAP32[(38048)>>2]|0;
        $234 = (($232) + ($233)|0);
        $235 = (_strlen(($234|0))|0);
        $236 = (($235) + ($233))|0;
        HEAP32[(38048)>>2] = $236;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 108:  {
        $176 = HEAP32[(38036)>>2]|0;
        $177 = ($176|0)>(0);
        if ($177) {
         $178 = (($176) + -1)|0;
         HEAP32[(38036)>>2] = $178;
         $179 = (((37876 + ($178<<3)|0)) + 4|0);
         $180 = HEAP8[$179>>0]|0;
         $181 = ($180<<24>>24)==(0);
         if ($181) {
          $182 = (37876 + ($178<<3)|0);
          $183 = HEAP32[$182>>2]|0;
          $184 = ($183|0)==(0|0);
          $$$i = $184 ? 37280 : $183;
          $187 = $$$i;
         } else {
          $187 = 37280;
         }
        } else {
         $185 = HEAP32[37248>>2]|0;
         $186 = (($185) + 1)|0;
         HEAP32[37248>>2] = $186;
         $187 = 37280;
        }
        $188 = (_strlen(($187|0))|0);
        $189 = HEAP32[(38048)>>2]|0;
        $190 = (($189) + 31)|0;
        $191 = HEAP32[(38044)>>2]|0;
        $192 = ($190>>>0)>($191>>>0);
        if ($192) {
         $193 = $190 << 1;
         HEAP32[(38044)>>2] = $193;
         $194 = HEAP32[(38040)>>2]|0;
         $195 = (__nc_doalloc($194,$193)|0);
         HEAP32[(38040)>>2] = $195;
         $196 = ($195|0)==(0|0);
         if ($196) {
          label = 83;
          break L35;
         }
         $$pre2$i23 = HEAP32[(38048)>>2]|0;
         $198 = $195;$199 = $$pre2$i23;
        } else {
         $$pre$i21 = HEAP32[(38040)>>2]|0;
         $198 = $$pre$i21;$199 = $189;
        }
        $197 = (($198) + ($199)|0);
        HEAP32[$vararg_buffer14>>2] = $188;
        (_sprintf($197,37288,$vararg_buffer14)|0);
        $200 = HEAP32[(38040)>>2]|0;
        $201 = HEAP32[(38048)>>2]|0;
        $202 = (($200) + ($201)|0);
        $203 = (_strlen(($202|0))|0);
        $204 = (($203) + ($201))|0;
        HEAP32[(38048)>>2] = $204;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 80:  {
        $261 = ((($$1$i)) + 1|0);
        $262 = HEAP8[$261>>0]|0;
        $$off139 = (($262) + -65)<<24>>24;
        $263 = ($$off139&255)<(26);
        if ($263) {
         $264 = $262&255;
         $265 = (($264) + -65)|0;
         $266 = HEAP32[(38036)>>2]|0;
         $267 = ($266|0)>(0);
         if ($267) {
          $268 = (($266) + -1)|0;
          HEAP32[(38036)>>2] = $268;
          $269 = (((37876 + ($268<<3)|0)) + 4|0);
          $270 = HEAP8[$269>>0]|0;
          $271 = ($270<<24>>24)==(0);
          if ($271) {
           $result$0$i34 = 0;
          } else {
           $272 = (37876 + ($268<<3)|0);
           $273 = HEAP32[$272>>2]|0;
           $result$0$i34 = $273;
          }
         } else {
          $274 = HEAP32[37248>>2]|0;
          $275 = (($274) + 1)|0;
          HEAP32[37248>>2] = $275;
          $result$0$i34 = 0;
         }
         $276 = (38164 + ($265<<2)|0);
         HEAP32[$276>>2] = $result$0$i34;
         $cp$6 = $261;
         break L37;
        }
        $$off140 = (($262) + -97)<<24>>24;
        $277 = ($$off140&255)<(26);
        if (!($277)) {
         $cp$6 = $261;
         break L37;
        }
        $278 = $262&255;
        $279 = (($278) + -97)|0;
        $280 = HEAP32[(38036)>>2]|0;
        $281 = ($280|0)>(0);
        if ($281) {
         $282 = (($280) + -1)|0;
         HEAP32[(38036)>>2] = $282;
         $283 = (((37876 + ($282<<3)|0)) + 4|0);
         $284 = HEAP8[$283>>0]|0;
         $285 = ($284<<24>>24)==(0);
         if ($285) {
          $result$0$i36 = 0;
         } else {
          $286 = (37876 + ($282<<3)|0);
          $287 = HEAP32[$286>>2]|0;
          $result$0$i36 = $287;
         }
        } else {
         $288 = HEAP32[37248>>2]|0;
         $289 = (($288) + 1)|0;
         HEAP32[37248>>2] = $289;
         $result$0$i36 = 0;
        }
        $290 = (38060 + ($279<<2)|0);
        HEAP32[$290>>2] = $result$0$i36;
        $cp$6 = $261;
        break L37;
        break;
       }
       case 109:  {
        $457 = HEAP32[(38036)>>2]|0;
        $458 = ($457|0)>(0);
        if ($458) {
         $459 = (($457) + -1)|0;
         HEAP32[(38036)>>2] = $459;
         $460 = (((37876 + ($459<<3)|0)) + 4|0);
         $461 = HEAP8[$460>>0]|0;
         $462 = ($461<<24>>24)==(0);
         if ($462) {
          $result$0$i95 = 0;
         } else {
          $463 = (37876 + ($459<<3)|0);
          $464 = HEAP32[$463>>2]|0;
          $result$0$i95 = $464;
         }
         $467 = ($457|0)>(1);
         if ($467) {
          $468 = (($457) + -2)|0;
          HEAP32[(38036)>>2] = $468;
          $469 = (((37876 + ($468<<3)|0)) + 4|0);
          $470 = HEAP8[$469>>0]|0;
          $471 = ($470<<24>>24)==(0);
          if ($471) {
           $479 = $468;$result$0$i93 = 0;$result$0$i95246 = $result$0$i95;
          } else {
           $472 = (37876 + ($468<<3)|0);
           $473 = HEAP32[$472>>2]|0;
           $479 = $468;$result$0$i93 = $473;$result$0$i95246 = $result$0$i95;
          }
         } else {
          $820 = 0;$result$0$i95247 = $result$0$i95;
          label = 184;
         }
        } else {
         $465 = HEAP32[37248>>2]|0;
         $466 = (($465) + 1)|0;
         HEAP32[37248>>2] = $466;
         $820 = $457;$result$0$i95247 = 0;
         label = 184;
        }
        if ((label|0) == 184) {
         label = 0;
         $474 = HEAP32[37248>>2]|0;
         $475 = (($474) + 1)|0;
         HEAP32[37248>>2] = $475;
         $479 = $820;$result$0$i93 = 0;$result$0$i95246 = $result$0$i95247;
        }
        $476 = ($result$0$i95246|0)==(0);
        if ($476) {
         $482 = 0;
        } else {
         $477 = (($result$0$i93|0) % ($result$0$i95246|0))&-1;
         $482 = $477;
        }
        $478 = ($479|0)<(20);
        if ($478) {
         $480 = (((37876 + ($479<<3)|0)) + 4|0);
         HEAP8[$480>>0] = 1;
         $481 = (37876 + ($479<<3)|0);
         HEAP32[$481>>2] = $482;
         $483 = HEAP32[(38036)>>2]|0;
         $484 = (($483) + 1)|0;
         HEAP32[(38036)>>2] = $484;
         $cp$6 = $$1$i;
         break L37;
        } else {
         $485 = HEAP32[37248>>2]|0;
         $486 = (($485) + 1)|0;
         HEAP32[37248>>2] = $486;
         $cp$6 = $$1$i;
         break L37;
        }
        break;
       }
       case 43:  {
        $343 = HEAP32[(38036)>>2]|0;
        $344 = ($343|0)>(0);
        if ($344) {
         $345 = (($343) + -1)|0;
         HEAP32[(38036)>>2] = $345;
         $346 = (((37876 + ($345<<3)|0)) + 4|0);
         $347 = HEAP8[$346>>0]|0;
         $348 = ($347<<24>>24)==(0);
         if ($348) {
          $result$0$i42 = 0;
         } else {
          $349 = (37876 + ($345<<3)|0);
          $350 = HEAP32[$349>>2]|0;
          $result$0$i42 = $350;
         }
         $353 = ($343|0)>(1);
         if ($353) {
          $354 = (($343) + -2)|0;
          HEAP32[(38036)>>2] = $354;
          $355 = (((37876 + ($354<<3)|0)) + 4|0);
          $356 = HEAP8[$355>>0]|0;
          $357 = ($356<<24>>24)==(0);
          if ($357) {
           $result$0$i113 = 0;
          } else {
           $358 = (37876 + ($354<<3)|0);
           $359 = HEAP32[$358>>2]|0;
           $result$0$i113 = $359;
          }
          $362 = ($354|0)<(20);
          if ($362) {
           $365 = $354;$result$0$i113233 = $result$0$i113;$result$0$i42229232 = $result$0$i42;
          } else {
           $369 = HEAP32[37248>>2]|0;
           $370 = (($369) + 1)|0;
           HEAP32[37248>>2] = $370;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $816 = 0;$result$0$i42231 = $result$0$i42;
          label = 138;
         }
        } else {
         $351 = HEAP32[37248>>2]|0;
         $352 = (($351) + 1)|0;
         HEAP32[37248>>2] = $352;
         $816 = $343;$result$0$i42231 = 0;
         label = 138;
        }
        if ((label|0) == 138) {
         label = 0;
         $360 = HEAP32[37248>>2]|0;
         $361 = (($360) + 1)|0;
         HEAP32[37248>>2] = $361;
         $365 = $816;$result$0$i113233 = 0;$result$0$i42229232 = $result$0$i42231;
        }
        $363 = (($result$0$i113233) + ($result$0$i42229232))|0;
        $364 = (((37876 + ($365<<3)|0)) + 4|0);
        HEAP8[$364>>0] = 1;
        $366 = (37876 + ($365<<3)|0);
        HEAP32[$366>>2] = $363;
        $367 = HEAP32[(38036)>>2]|0;
        $368 = (($367) + 1)|0;
        HEAP32[(38036)>>2] = $368;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 105:  {
        $760 = HEAP32[$p_is_s>>2]|0;
        $761 = ($760|0)==(0|0);
        if ($761) {
         $762 = HEAP32[$param>>2]|0;
         $763 = (($762) + 1)|0;
         HEAP32[$param>>2] = $763;
        }
        $764 = HEAP32[$35>>2]|0;
        $765 = ($764|0)==(0|0);
        if (!($765)) {
         $cp$6 = $$1$i;
         break L37;
        }
        $766 = HEAP32[$36>>2]|0;
        $767 = (($766) + 1)|0;
        HEAP32[$36>>2] = $767;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 116:  {
        $768 = HEAP32[(38036)>>2]|0;
        $769 = ($768|0)>(0);
        if ($769) {
         $770 = (($768) + -1)|0;
         HEAP32[(38036)>>2] = $770;
         $771 = (((37876 + ($770<<3)|0)) + 4|0);
         $772 = HEAP8[$771>>0]|0;
         $773 = ($772<<24>>24)==(0);
         if (!($773)) {
          $776 = (37876 + ($770<<3)|0);
          $777 = HEAP32[$776>>2]|0;
          $778 = ($777|0)==(0);
          if (!($778)) {
           $cp$6 = $$1$i;
           break L37;
          }
         }
        } else {
         $774 = HEAP32[37248>>2]|0;
         $775 = (($774) + 1)|0;
         HEAP32[37248>>2] = $775;
        }
        $779 = ((($$1$i)) + 1|0);
        $cp$2 = $779;$level$0 = 0;
        while(1) {
         $780 = HEAP8[$cp$2>>0]|0;
         do {
          if ((($780<<24>>24) == 37)) {
           $781 = ((($cp$2)) + 1|0);
           $782 = HEAP8[$781>>0]|0;
           if ((($782<<24>>24) == 63)) {
            $783 = (($level$0) + 1)|0;
            $789 = 63;$cp$3 = $781;$level$1 = $783;
            break;
           } else if ((($782<<24>>24) == 59)) {
            $784 = ($level$0|0)>(0);
            if (!($784)) {
             $cp$6 = $781;
             break L37;
            }
            $785 = (($level$0) + -1)|0;
            $789 = 59;$cp$3 = $781;$level$1 = $785;
            break;
           } else {
            $786 = ($782<<24>>24)==(101);
            $787 = ($level$0|0)==(0);
            $or$cond3 = $787 & $786;
            if ($or$cond3) {
             $cp$6 = $781;
             break L37;
            } else {
             $789 = $782;$cp$3 = $781;$level$1 = $level$0;
             break;
            }
           }
          } else if ((($780<<24>>24) == 0)) {
           $cp$6 = $cp$2;
           break L37;
          } else {
           $789 = $780;$cp$3 = $cp$2;$level$1 = $level$0;
          }
         } while(0);
         $788 = ($789<<24>>24)==(0);
         $790 = ((($cp$3)) + 1|0);
         $cp$3$ = $788 ? $cp$3 : $790;
         $cp$2 = $cp$3$;$level$0 = $level$1;
        }
        break;
       }
       case 101:  {
        $791 = ((($$1$i)) + 1|0);
        $cp$4 = $791;$level$2 = 0;
        while(1) {
         $792 = HEAP8[$cp$4>>0]|0;
         do {
          if ((($792<<24>>24) == 37)) {
           $793 = ((($cp$4)) + 1|0);
           $794 = HEAP8[$793>>0]|0;
           if ((($794<<24>>24) == 63)) {
            $795 = (($level$2) + 1)|0;
            $799 = 63;$cp$5 = $793;$level$3 = $795;
            break;
           } else if (!((($794<<24>>24) == 59))) {
            $799 = $794;$cp$5 = $793;$level$3 = $level$2;
            break;
           }
           $796 = ($level$2|0)>(0);
           if (!($796)) {
            $cp$6 = $793;
            break L37;
           }
           $797 = (($level$2) + -1)|0;
           $799 = 59;$cp$5 = $793;$level$3 = $797;
          } else if ((($792<<24>>24) == 0)) {
           $cp$6 = $cp$4;
           break L37;
          } else {
           $799 = $792;$cp$5 = $cp$4;$level$3 = $level$2;
          }
         } while(0);
         $798 = ($799<<24>>24)==(0);
         $800 = ((($cp$5)) + 1|0);
         $cp$5$ = $798 ? $cp$5 : $800;
         $cp$4 = $cp$5$;$level$2 = $level$3;
        }
        break;
       }
       case 45:  {
        $371 = HEAP32[(38036)>>2]|0;
        $372 = ($371|0)>(0);
        if ($372) {
         $373 = (($371) + -1)|0;
         HEAP32[(38036)>>2] = $373;
         $374 = (((37876 + ($373<<3)|0)) + 4|0);
         $375 = HEAP8[$374>>0]|0;
         $376 = ($375<<24>>24)==(0);
         if ($376) {
          $result$0$i110 = 0;
         } else {
          $377 = (37876 + ($373<<3)|0);
          $378 = HEAP32[$377>>2]|0;
          $result$0$i110 = $378;
         }
         $381 = ($371|0)>(1);
         if ($381) {
          $382 = (($371) + -2)|0;
          HEAP32[(38036)>>2] = $382;
          $383 = (((37876 + ($382<<3)|0)) + 4|0);
          $384 = HEAP8[$383>>0]|0;
          $385 = ($384<<24>>24)==(0);
          if ($385) {
           $result$0$i108 = 0;
          } else {
           $386 = (37876 + ($382<<3)|0);
           $387 = HEAP32[$386>>2]|0;
           $result$0$i108 = $387;
          }
          $390 = ($382|0)<(20);
          if ($390) {
           $393 = $382;$result$0$i108238 = $result$0$i108;$result$0$i110234237 = $result$0$i110;
          } else {
           $397 = HEAP32[37248>>2]|0;
           $398 = (($397) + 1)|0;
           HEAP32[37248>>2] = $398;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $817 = 0;$result$0$i110236 = $result$0$i110;
          label = 149;
         }
        } else {
         $379 = HEAP32[37248>>2]|0;
         $380 = (($379) + 1)|0;
         HEAP32[37248>>2] = $380;
         $817 = $371;$result$0$i110236 = 0;
         label = 149;
        }
        if ((label|0) == 149) {
         label = 0;
         $388 = HEAP32[37248>>2]|0;
         $389 = (($388) + 1)|0;
         HEAP32[37248>>2] = $389;
         $393 = $817;$result$0$i108238 = 0;$result$0$i110234237 = $result$0$i110236;
        }
        $391 = (($result$0$i108238) - ($result$0$i110234237))|0;
        $392 = (((37876 + ($393<<3)|0)) + 4|0);
        HEAP8[$392>>0] = 1;
        $394 = (37876 + ($393<<3)|0);
        HEAP32[$394>>2] = $391;
        $395 = HEAP32[(38036)>>2]|0;
        $396 = (($395) + 1)|0;
        HEAP32[(38036)>>2] = $396;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 88: case 120: case 111: case 100:  {
        $121 = HEAP32[(38052)>>2]|0;
        $122 = HEAP32[(38036)>>2]|0;
        $123 = ($122|0)>(0);
        if ($123) {
         $124 = (($122) + -1)|0;
         HEAP32[(38036)>>2] = $124;
         $125 = (((37876 + ($124<<3)|0)) + 4|0);
         $126 = HEAP8[$125>>0]|0;
         $127 = ($126<<24>>24)==(0);
         if ($127) {
          $result$0$i = 0;
         } else {
          $128 = (37876 + ($124<<3)|0);
          $129 = HEAP32[$128>>2]|0;
          $result$0$i = $129;
         }
        } else {
         $130 = HEAP32[37248>>2]|0;
         $131 = (($130) + 1)|0;
         HEAP32[37248>>2] = $131;
         $result$0$i = 0;
        }
        $132 = ($133|0)<(30);
        $len$op$i = (($133) + 1)|0;
        $134 = $132 ? 31 : $len$op$i;
        $135 = HEAP32[(38048)>>2]|0;
        $136 = (($135) + ($134))|0;
        $137 = HEAP32[(38044)>>2]|0;
        $138 = ($136>>>0)>($137>>>0);
        if ($138) {
         $139 = $136 << 1;
         HEAP32[(38044)>>2] = $139;
         $140 = HEAP32[(38040)>>2]|0;
         $141 = (__nc_doalloc($140,$139)|0);
         HEAP32[(38040)>>2] = $141;
         $142 = ($141|0)==(0|0);
         if ($142) {
          label = 63;
          break L35;
         }
         $$pre2$i12 = HEAP32[(38048)>>2]|0;
         $144 = $141;$145 = $$pre2$i12;
        } else {
         $$pre$i10 = HEAP32[(38040)>>2]|0;
         $144 = $$pre$i10;$145 = $135;
        }
        $143 = (($144) + ($145)|0);
        HEAP32[$vararg_buffer8>>2] = $result$0$i;
        (_sprintf($143,$121,$vararg_buffer8)|0);
        $146 = HEAP32[(38040)>>2]|0;
        $147 = HEAP32[(38048)>>2]|0;
        $148 = (($146) + ($147)|0);
        $149 = (_strlen(($148|0))|0);
        $150 = (($149) + ($147))|0;
        HEAP32[(38048)>>2] = $150;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 103:  {
        $291 = ((($$1$i)) + 1|0);
        $292 = HEAP8[$291>>0]|0;
        $$off = (($292) + -65)<<24>>24;
        $293 = ($$off&255)<(26);
        if ($293) {
         $294 = HEAP32[(38036)>>2]|0;
         $295 = ($294|0)<(20);
         if ($295) {
          $296 = $292&255;
          $297 = (($296) + -65)|0;
          $298 = (38164 + ($297<<2)|0);
          $299 = HEAP32[$298>>2]|0;
          $300 = (((37876 + ($294<<3)|0)) + 4|0);
          HEAP8[$300>>0] = 1;
          $301 = (37876 + ($294<<3)|0);
          HEAP32[$301>>2] = $299;
          $302 = HEAP32[(38036)>>2]|0;
          $303 = (($302) + 1)|0;
          HEAP32[(38036)>>2] = $303;
          $cp$6 = $291;
          break L37;
         } else {
          $304 = HEAP32[37248>>2]|0;
          $305 = (($304) + 1)|0;
          HEAP32[37248>>2] = $305;
          $cp$6 = $291;
          break L37;
         }
        }
        $$off138 = (($292) + -97)<<24>>24;
        $306 = ($$off138&255)<(26);
        if (!($306)) {
         $cp$6 = $291;
         break L37;
        }
        $307 = HEAP32[(38036)>>2]|0;
        $308 = ($307|0)<(20);
        if ($308) {
         $309 = $292&255;
         $310 = (($309) + -97)|0;
         $311 = (38060 + ($310<<2)|0);
         $312 = HEAP32[$311>>2]|0;
         $313 = (((37876 + ($307<<3)|0)) + 4|0);
         HEAP8[$313>>0] = 1;
         $314 = (37876 + ($307<<3)|0);
         HEAP32[$314>>2] = $312;
         $315 = HEAP32[(38036)>>2]|0;
         $316 = (($315) + 1)|0;
         HEAP32[(38036)>>2] = $316;
         $cp$6 = $291;
         break L37;
        } else {
         $317 = HEAP32[37248>>2]|0;
         $318 = (($317) + 1)|0;
         HEAP32[37248>>2] = $318;
         $cp$6 = $291;
         break L37;
        }
        break;
       }
       case 39:  {
        $319 = HEAP32[(38036)>>2]|0;
        $320 = ($319|0)<(20);
        if ($320) {
         $321 = ((($$1$i)) + 1|0);
         $322 = HEAP8[$321>>0]|0;
         $323 = $322&255;
         $324 = (((37876 + ($319<<3)|0)) + 4|0);
         HEAP8[$324>>0] = 1;
         $325 = (37876 + ($319<<3)|0);
         HEAP32[$325>>2] = $323;
         $326 = HEAP32[(38036)>>2]|0;
         $327 = (($326) + 1)|0;
         HEAP32[(38036)>>2] = $327;
        } else {
         $328 = HEAP32[37248>>2]|0;
         $329 = (($328) + 1)|0;
         HEAP32[37248>>2] = $329;
        }
        $330 = ((($$1$i)) + 2|0);
        $cp$6 = $330;
        break L37;
        break;
       }
       case 47:  {
        $427 = HEAP32[(38036)>>2]|0;
        $428 = ($427|0)>(0);
        if ($428) {
         $429 = (($427) + -1)|0;
         HEAP32[(38036)>>2] = $429;
         $430 = (((37876 + ($429<<3)|0)) + 4|0);
         $431 = HEAP8[$430>>0]|0;
         $432 = ($431<<24>>24)==(0);
         if ($432) {
          $result$0$i100 = 0;
         } else {
          $433 = (37876 + ($429<<3)|0);
          $434 = HEAP32[$433>>2]|0;
          $result$0$i100 = $434;
         }
         $437 = ($427|0)>(1);
         if ($437) {
          $438 = (($427) + -2)|0;
          HEAP32[(38036)>>2] = $438;
          $439 = (((37876 + ($438<<3)|0)) + 4|0);
          $440 = HEAP8[$439>>0]|0;
          $441 = ($440<<24>>24)==(0);
          if ($441) {
           $449 = $438;$result$0$i100244 = $result$0$i100;$result$0$i98 = 0;
          } else {
           $442 = (37876 + ($438<<3)|0);
           $443 = HEAP32[$442>>2]|0;
           $449 = $438;$result$0$i100244 = $result$0$i100;$result$0$i98 = $443;
          }
         } else {
          $819 = 0;$result$0$i100245 = $result$0$i100;
          label = 171;
         }
        } else {
         $435 = HEAP32[37248>>2]|0;
         $436 = (($435) + 1)|0;
         HEAP32[37248>>2] = $436;
         $819 = $427;$result$0$i100245 = 0;
         label = 171;
        }
        if ((label|0) == 171) {
         label = 0;
         $444 = HEAP32[37248>>2]|0;
         $445 = (($444) + 1)|0;
         HEAP32[37248>>2] = $445;
         $449 = $819;$result$0$i100244 = $result$0$i100245;$result$0$i98 = 0;
        }
        $446 = ($result$0$i100244|0)==(0);
        if ($446) {
         $452 = 0;
        } else {
         $447 = (($result$0$i98|0) / ($result$0$i100244|0))&-1;
         $452 = $447;
        }
        $448 = ($449|0)<(20);
        if ($448) {
         $450 = (((37876 + ($449<<3)|0)) + 4|0);
         HEAP8[$450>>0] = 1;
         $451 = (37876 + ($449<<3)|0);
         HEAP32[$451>>2] = $452;
         $453 = HEAP32[(38036)>>2]|0;
         $454 = (($453) + 1)|0;
         HEAP32[(38036)>>2] = $454;
         $cp$6 = $$1$i;
         break L37;
        } else {
         $455 = HEAP32[37248>>2]|0;
         $456 = (($455) + 1)|0;
         HEAP32[37248>>2] = $456;
         $cp$6 = $$1$i;
         break L37;
        }
        break;
       }
       case 42:  {
        $399 = HEAP32[(38036)>>2]|0;
        $400 = ($399|0)>(0);
        if ($400) {
         $401 = (($399) + -1)|0;
         HEAP32[(38036)>>2] = $401;
         $402 = (((37876 + ($401<<3)|0)) + 4|0);
         $403 = HEAP8[$402>>0]|0;
         $404 = ($403<<24>>24)==(0);
         if ($404) {
          $result$0$i105 = 0;
         } else {
          $405 = (37876 + ($401<<3)|0);
          $406 = HEAP32[$405>>2]|0;
          $result$0$i105 = $406;
         }
         $409 = ($399|0)>(1);
         if ($409) {
          $410 = (($399) + -2)|0;
          HEAP32[(38036)>>2] = $410;
          $411 = (((37876 + ($410<<3)|0)) + 4|0);
          $412 = HEAP8[$411>>0]|0;
          $413 = ($412<<24>>24)==(0);
          if ($413) {
           $result$0$i103 = 0;
          } else {
           $414 = (37876 + ($410<<3)|0);
           $415 = HEAP32[$414>>2]|0;
           $result$0$i103 = $415;
          }
          $418 = ($410|0)<(20);
          if ($418) {
           $421 = $410;$result$0$i103243 = $result$0$i103;$result$0$i105239242 = $result$0$i105;
          } else {
           $425 = HEAP32[37248>>2]|0;
           $426 = (($425) + 1)|0;
           HEAP32[37248>>2] = $426;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $818 = 0;$result$0$i105241 = $result$0$i105;
          label = 160;
         }
        } else {
         $407 = HEAP32[37248>>2]|0;
         $408 = (($407) + 1)|0;
         HEAP32[37248>>2] = $408;
         $818 = $399;$result$0$i105241 = 0;
         label = 160;
        }
        if ((label|0) == 160) {
         label = 0;
         $416 = HEAP32[37248>>2]|0;
         $417 = (($416) + 1)|0;
         HEAP32[37248>>2] = $417;
         $421 = $818;$result$0$i103243 = 0;$result$0$i105239242 = $result$0$i105241;
        }
        $419 = Math_imul($result$0$i103243, $result$0$i105239242)|0;
        $420 = (((37876 + ($421<<3)|0)) + 4|0);
        HEAP8[$420>>0] = 1;
        $422 = (37876 + ($421<<3)|0);
        HEAP32[$422>>2] = $419;
        $423 = HEAP32[(38036)>>2]|0;
        $424 = (($423) + 1)|0;
        HEAP32[(38036)>>2] = $424;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 79:  {
        $519 = HEAP32[(38036)>>2]|0;
        $520 = ($519|0)>(0);
        do {
         if ($520) {
          $521 = (($519) + -1)|0;
          HEAP32[(38036)>>2] = $521;
          $522 = (((37876 + ($521<<3)|0)) + 4|0);
          $523 = HEAP8[$522>>0]|0;
          $524 = ($523<<24>>24)==(0);
          if (!($524)) {
           $527 = (37876 + ($521<<3)|0);
           $528 = HEAP32[$527>>2]|0;
           $529 = ($528|0)==(0);
           if (!($529)) {
            $541 = $521;$543 = 1;
            break;
           }
          }
          $530 = ($519|0)>(1);
          if ($530) {
           $531 = (($519) + -2)|0;
           HEAP32[(38036)>>2] = $531;
           $532 = (((37876 + ($531<<3)|0)) + 4|0);
           $533 = HEAP8[$532>>0]|0;
           $534 = ($533<<24>>24)==(0);
           if ($534) {
            $823 = $531;$result$0$i83 = 0;
            label = 210;
           } else {
            $535 = (37876 + ($531<<3)|0);
            $536 = HEAP32[$535>>2]|0;
            $823 = $531;$result$0$i83 = $536;
            label = 210;
           }
          } else {
           $822 = 0;
           label = 209;
          }
         } else {
          $525 = HEAP32[37248>>2]|0;
          $526 = (($525) + 1)|0;
          HEAP32[37248>>2] = $526;
          $822 = $519;
          label = 209;
         }
        } while(0);
        if ((label|0) == 209) {
         label = 0;
         $537 = HEAP32[37248>>2]|0;
         $538 = (($537) + 1)|0;
         HEAP32[37248>>2] = $538;
         $823 = $822;$result$0$i83 = 0;
         label = 210;
        }
        if ((label|0) == 210) {
         label = 0;
         $539 = ($result$0$i83|0)!=(0);
         $541 = $823;$543 = $539;
        }
        $540 = ($541|0)<(20);
        if ($540) {
         $542 = $543&1;
         $544 = (((37876 + ($541<<3)|0)) + 4|0);
         HEAP8[$544>>0] = 1;
         $545 = (37876 + ($541<<3)|0);
         HEAP32[$545>>2] = $542;
         $546 = HEAP32[(38036)>>2]|0;
         $547 = (($546) + 1)|0;
         HEAP32[(38036)>>2] = $547;
         $cp$6 = $$1$i;
         break L37;
        } else {
         $548 = HEAP32[37248>>2]|0;
         $549 = (($548) + 1)|0;
         HEAP32[37248>>2] = $549;
         $cp$6 = $$1$i;
         break L37;
        }
        break;
       }
       case 65:  {
        $487 = HEAP32[(38036)>>2]|0;
        $488 = ($487|0)>(0);
        if ($488) {
         $489 = (($487) + -1)|0;
         HEAP32[(38036)>>2] = $489;
         $490 = (((37876 + ($489<<3)|0)) + 4|0);
         $491 = HEAP8[$490>>0]|0;
         $492 = ($491<<24>>24)==(0);
         if ($492) {
          $509 = $489;$821 = 0;
         } else {
          $495 = (37876 + ($489<<3)|0);
          $496 = HEAP32[$495>>2]|0;
          $497 = ($496|0)==(0);
          if ($497) {
           $509 = $489;$821 = 0;
          } else {
           $498 = ($487|0)>(1);
           if ($498) {
            $499 = (($487) + -2)|0;
            HEAP32[(38036)>>2] = $499;
            $500 = (((37876 + ($499<<3)|0)) + 4|0);
            $501 = HEAP8[$500>>0]|0;
            $502 = ($501<<24>>24)==(0);
            if ($502) {
             $$pr136217 = $499;$result$0$i88 = 0;
            } else {
             $503 = (37876 + ($499<<3)|0);
             $504 = HEAP32[$503>>2]|0;
             $$pr136217 = $499;$result$0$i88 = $504;
            }
           } else {
            $505 = HEAP32[37248>>2]|0;
            $506 = (($505) + 1)|0;
            HEAP32[37248>>2] = $506;
            $$pr136217 = $489;$result$0$i88 = 0;
           }
           $507 = ($result$0$i88|0)!=(0);
           $509 = $$pr136217;$821 = $507;
          }
         }
         $508 = ($509|0)<(20);
         if ($508) {
          $511 = $821;$513 = $509;
         } else {
          $517 = HEAP32[37248>>2]|0;
          $518 = (($517) + 1)|0;
          HEAP32[37248>>2] = $518;
          $cp$6 = $$1$i;
          break L37;
         }
        } else {
         $493 = HEAP32[37248>>2]|0;
         $494 = (($493) + 1)|0;
         HEAP32[37248>>2] = $494;
         $511 = 0;$513 = $487;
        }
        $510 = $511&1;
        $512 = (((37876 + ($513<<3)|0)) + 4|0);
        HEAP8[$512>>0] = 1;
        $514 = (37876 + ($513<<3)|0);
        HEAP32[$514>>2] = $510;
        $515 = HEAP32[(38036)>>2]|0;
        $516 = (($515) + 1)|0;
        HEAP32[(38036)>>2] = $516;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 60:  {
        $663 = HEAP32[(38036)>>2]|0;
        $664 = ($663|0)>(0);
        if ($664) {
         $665 = (($663) + -1)|0;
         HEAP32[(38036)>>2] = $665;
         $666 = (((37876 + ($665<<3)|0)) + 4|0);
         $667 = HEAP8[$666>>0]|0;
         $668 = ($667<<24>>24)==(0);
         if ($668) {
          $result$0$i60 = 0;
         } else {
          $669 = (37876 + ($665<<3)|0);
          $670 = HEAP32[$669>>2]|0;
          $result$0$i60 = $670;
         }
         $673 = ($663|0)>(1);
         if ($673) {
          $674 = (($663) + -2)|0;
          HEAP32[(38036)>>2] = $674;
          $675 = (((37876 + ($674<<3)|0)) + 4|0);
          $676 = HEAP8[$675>>0]|0;
          $677 = ($676<<24>>24)==(0);
          if ($677) {
           $result$0$i58 = 0;
          } else {
           $678 = (37876 + ($674<<3)|0);
           $679 = HEAP32[$678>>2]|0;
           $result$0$i58 = $679;
          }
          $682 = ($674|0)<(20);
          if ($682) {
           $686 = $674;$result$0$i58272 = $result$0$i58;$result$0$i60268271 = $result$0$i60;
          } else {
           $690 = HEAP32[37248>>2]|0;
           $691 = (($690) + 1)|0;
           HEAP32[37248>>2] = $691;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $828 = 0;$result$0$i60270 = $result$0$i60;
          label = 265;
         }
        } else {
         $671 = HEAP32[37248>>2]|0;
         $672 = (($671) + 1)|0;
         HEAP32[37248>>2] = $672;
         $828 = $663;$result$0$i60270 = 0;
         label = 265;
        }
        if ((label|0) == 265) {
         label = 0;
         $680 = HEAP32[37248>>2]|0;
         $681 = (($680) + 1)|0;
         HEAP32[37248>>2] = $681;
         $686 = $828;$result$0$i58272 = 0;$result$0$i60268271 = $result$0$i60270;
        }
        $683 = ($result$0$i58272|0)<($result$0$i60268271|0);
        $684 = $683&1;
        $685 = (((37876 + ($686<<3)|0)) + 4|0);
        HEAP8[$685>>0] = 1;
        $687 = (37876 + ($686<<3)|0);
        HEAP32[$687>>2] = $684;
        $688 = HEAP32[(38036)>>2]|0;
        $689 = (($688) + 1)|0;
        HEAP32[(38036)>>2] = $689;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 33:  {
        $721 = HEAP32[(38036)>>2]|0;
        $722 = ($721|0)>(0);
        if ($722) {
         $723 = (($721) + -1)|0;
         HEAP32[(38036)>>2] = $723;
         $724 = (((37876 + ($723<<3)|0)) + 4|0);
         $725 = HEAP8[$724>>0]|0;
         $726 = ($725<<24>>24)==(0);
         if ($726) {
          $result$0$i50 = 0;
         } else {
          $727 = (37876 + ($723<<3)|0);
          $728 = HEAP32[$727>>2]|0;
          $result$0$i50 = $728;
         }
         $731 = ($721|0)<(21);
         if ($731) {
          $735 = $723;$result$0$i50278 = $result$0$i50;
         } else {
          $739 = HEAP32[37248>>2]|0;
          $740 = (($739) + 1)|0;
          HEAP32[37248>>2] = $740;
          $cp$6 = $$1$i;
          break L37;
         }
        } else {
         $729 = HEAP32[37248>>2]|0;
         $730 = (($729) + 1)|0;
         HEAP32[37248>>2] = $730;
         $735 = $721;$result$0$i50278 = 0;
        }
        $732 = ($result$0$i50278|0)==(0);
        $733 = $732&1;
        $734 = (((37876 + ($735<<3)|0)) + 4|0);
        HEAP8[$734>>0] = 1;
        $736 = (37876 + ($735<<3)|0);
        HEAP32[$736>>2] = $733;
        $737 = HEAP32[(38036)>>2]|0;
        $738 = (($737) + 1)|0;
        HEAP32[(38036)>>2] = $738;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 62:  {
        $692 = HEAP32[(38036)>>2]|0;
        $693 = ($692|0)>(0);
        if ($693) {
         $694 = (($692) + -1)|0;
         HEAP32[(38036)>>2] = $694;
         $695 = (((37876 + ($694<<3)|0)) + 4|0);
         $696 = HEAP8[$695>>0]|0;
         $697 = ($696<<24>>24)==(0);
         if ($697) {
          $result$0$i55 = 0;
         } else {
          $698 = (37876 + ($694<<3)|0);
          $699 = HEAP32[$698>>2]|0;
          $result$0$i55 = $699;
         }
         $702 = ($692|0)>(1);
         if ($702) {
          $703 = (($692) + -2)|0;
          HEAP32[(38036)>>2] = $703;
          $704 = (((37876 + ($703<<3)|0)) + 4|0);
          $705 = HEAP8[$704>>0]|0;
          $706 = ($705<<24>>24)==(0);
          if ($706) {
           $result$0$i53 = 0;
          } else {
           $707 = (37876 + ($703<<3)|0);
           $708 = HEAP32[$707>>2]|0;
           $result$0$i53 = $708;
          }
          $711 = ($703|0)<(20);
          if ($711) {
           $715 = $703;$result$0$i53277 = $result$0$i53;$result$0$i55273276 = $result$0$i55;
          } else {
           $719 = HEAP32[37248>>2]|0;
           $720 = (($719) + 1)|0;
           HEAP32[37248>>2] = $720;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $829 = 0;$result$0$i55275 = $result$0$i55;
          label = 276;
         }
        } else {
         $700 = HEAP32[37248>>2]|0;
         $701 = (($700) + 1)|0;
         HEAP32[37248>>2] = $701;
         $829 = $692;$result$0$i55275 = 0;
         label = 276;
        }
        if ((label|0) == 276) {
         label = 0;
         $709 = HEAP32[37248>>2]|0;
         $710 = (($709) + 1)|0;
         HEAP32[37248>>2] = $710;
         $715 = $829;$result$0$i53277 = 0;$result$0$i55273276 = $result$0$i55275;
        }
        $712 = ($result$0$i53277|0)>($result$0$i55273276|0);
        $713 = $712&1;
        $714 = (((37876 + ($715<<3)|0)) + 4|0);
        HEAP8[$714>>0] = 1;
        $716 = (37876 + ($715<<3)|0);
        HEAP32[$716>>2] = $713;
        $717 = HEAP32[(38036)>>2]|0;
        $718 = (($717) + 1)|0;
        HEAP32[(38036)>>2] = $718;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 126:  {
        $741 = HEAP32[(38036)>>2]|0;
        $742 = ($741|0)>(0);
        if ($742) {
         $743 = (($741) + -1)|0;
         HEAP32[(38036)>>2] = $743;
         $744 = (((37876 + ($743<<3)|0)) + 4|0);
         $745 = HEAP8[$744>>0]|0;
         $746 = ($745<<24>>24)==(0);
         if ($746) {
          $result$0$i47 = 0;
         } else {
          $747 = (37876 + ($743<<3)|0);
          $748 = HEAP32[$747>>2]|0;
          $result$0$i47 = $748;
         }
         $751 = ($741|0)<(21);
         if ($751) {
          $754 = $743;$result$0$i47279 = $result$0$i47;
         } else {
          $758 = HEAP32[37248>>2]|0;
          $759 = (($758) + 1)|0;
          HEAP32[37248>>2] = $759;
          $cp$6 = $$1$i;
          break L37;
         }
        } else {
         $749 = HEAP32[37248>>2]|0;
         $750 = (($749) + 1)|0;
         HEAP32[37248>>2] = $750;
         $754 = $741;$result$0$i47279 = 0;
        }
        $752 = $result$0$i47279 ^ -1;
        $753 = (((37876 + ($754<<3)|0)) + 4|0);
        HEAP8[$753>>0] = 1;
        $755 = (37876 + ($754<<3)|0);
        HEAP32[$755>>2] = $752;
        $756 = HEAP32[(38036)>>2]|0;
        $757 = (($756) + 1)|0;
        HEAP32[(38036)>>2] = $757;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 124:  {
        $578 = HEAP32[(38036)>>2]|0;
        $579 = ($578|0)>(0);
        if ($579) {
         $580 = (($578) + -1)|0;
         HEAP32[(38036)>>2] = $580;
         $581 = (((37876 + ($580<<3)|0)) + 4|0);
         $582 = HEAP8[$581>>0]|0;
         $583 = ($582<<24>>24)==(0);
         if ($583) {
          $result$0$i75 = 0;
         } else {
          $584 = (37876 + ($580<<3)|0);
          $585 = HEAP32[$584>>2]|0;
          $result$0$i75 = $585;
         }
         $588 = ($578|0)>(1);
         if ($588) {
          $589 = (($578) + -2)|0;
          HEAP32[(38036)>>2] = $589;
          $590 = (((37876 + ($589<<3)|0)) + 4|0);
          $591 = HEAP8[$590>>0]|0;
          $592 = ($591<<24>>24)==(0);
          if ($592) {
           $result$0$i73 = 0;
          } else {
           $593 = (37876 + ($589<<3)|0);
           $594 = HEAP32[$593>>2]|0;
           $result$0$i73 = $594;
          }
          $597 = ($589|0)<(20);
          if ($597) {
           $600 = $589;$result$0$i73257 = $result$0$i73;$result$0$i75253256 = $result$0$i75;
          } else {
           $604 = HEAP32[37248>>2]|0;
           $605 = (($604) + 1)|0;
           HEAP32[37248>>2] = $605;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $825 = 0;$result$0$i75255 = $result$0$i75;
          label = 232;
         }
        } else {
         $586 = HEAP32[37248>>2]|0;
         $587 = (($586) + 1)|0;
         HEAP32[37248>>2] = $587;
         $825 = $578;$result$0$i75255 = 0;
         label = 232;
        }
        if ((label|0) == 232) {
         label = 0;
         $595 = HEAP32[37248>>2]|0;
         $596 = (($595) + 1)|0;
         HEAP32[37248>>2] = $596;
         $600 = $825;$result$0$i73257 = 0;$result$0$i75253256 = $result$0$i75255;
        }
        $598 = $result$0$i73257 | $result$0$i75253256;
        $599 = (((37876 + ($600<<3)|0)) + 4|0);
        HEAP8[$599>>0] = 1;
        $601 = (37876 + ($600<<3)|0);
        HEAP32[$601>>2] = $598;
        $602 = HEAP32[(38036)>>2]|0;
        $603 = (($602) + 1)|0;
        HEAP32[(38036)>>2] = $603;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 38:  {
        $550 = HEAP32[(38036)>>2]|0;
        $551 = ($550|0)>(0);
        if ($551) {
         $552 = (($550) + -1)|0;
         HEAP32[(38036)>>2] = $552;
         $553 = (((37876 + ($552<<3)|0)) + 4|0);
         $554 = HEAP8[$553>>0]|0;
         $555 = ($554<<24>>24)==(0);
         if ($555) {
          $result$0$i80 = 0;
         } else {
          $556 = (37876 + ($552<<3)|0);
          $557 = HEAP32[$556>>2]|0;
          $result$0$i80 = $557;
         }
         $560 = ($550|0)>(1);
         if ($560) {
          $561 = (($550) + -2)|0;
          HEAP32[(38036)>>2] = $561;
          $562 = (((37876 + ($561<<3)|0)) + 4|0);
          $563 = HEAP8[$562>>0]|0;
          $564 = ($563<<24>>24)==(0);
          if ($564) {
           $result$0$i78 = 0;
          } else {
           $565 = (37876 + ($561<<3)|0);
           $566 = HEAP32[$565>>2]|0;
           $result$0$i78 = $566;
          }
          $569 = ($561|0)<(20);
          if ($569) {
           $572 = $561;$result$0$i78252 = $result$0$i78;$result$0$i80248251 = $result$0$i80;
          } else {
           $576 = HEAP32[37248>>2]|0;
           $577 = (($576) + 1)|0;
           HEAP32[37248>>2] = $577;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $824 = 0;$result$0$i80250 = $result$0$i80;
          label = 221;
         }
        } else {
         $558 = HEAP32[37248>>2]|0;
         $559 = (($558) + 1)|0;
         HEAP32[37248>>2] = $559;
         $824 = $550;$result$0$i80250 = 0;
         label = 221;
        }
        if ((label|0) == 221) {
         label = 0;
         $567 = HEAP32[37248>>2]|0;
         $568 = (($567) + 1)|0;
         HEAP32[37248>>2] = $568;
         $572 = $824;$result$0$i78252 = 0;$result$0$i80248251 = $result$0$i80250;
        }
        $570 = $result$0$i78252 & $result$0$i80248251;
        $571 = (((37876 + ($572<<3)|0)) + 4|0);
        HEAP8[$571>>0] = 1;
        $573 = (37876 + ($572<<3)|0);
        HEAP32[$573>>2] = $570;
        $574 = HEAP32[(38036)>>2]|0;
        $575 = (($574) + 1)|0;
        HEAP32[(38036)>>2] = $575;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 112:  {
        $237 = ((($$1$i)) + 1|0);
        $238 = HEAP8[$237>>0]|0;
        $239 = $238&255;
        $240 = (($239) + -49)|0;
        $241 = ($240>>>0)<(9);
        if (!($241)) {
         $cp$6 = $237;
         break L37;
        }
        $242 = (($p_is_s) + ($240<<2)|0);
        $243 = HEAP32[$242>>2]|0;
        $244 = ($243|0)==(0|0);
        $245 = HEAP32[(38036)>>2]|0;
        $246 = ($245|0)<(20);
        if ($244) {
         if ($246) {
          $253 = (($param) + ($240<<2)|0);
          $254 = HEAP32[$253>>2]|0;
          $255 = (((37876 + ($245<<3)|0)) + 4|0);
          HEAP8[$255>>0] = 1;
          $256 = (37876 + ($245<<3)|0);
          HEAP32[$256>>2] = $254;
          $257 = HEAP32[(38036)>>2]|0;
          $258 = (($257) + 1)|0;
          HEAP32[(38036)>>2] = $258;
          $cp$6 = $237;
          break L37;
         } else {
          $259 = HEAP32[37248>>2]|0;
          $260 = (($259) + 1)|0;
          HEAP32[37248>>2] = $260;
          $cp$6 = $237;
          break L37;
         }
        } else {
         if ($246) {
          $247 = (((37876 + ($245<<3)|0)) + 4|0);
          HEAP8[$247>>0] = 0;
          $248 = (37876 + ($245<<3)|0);
          HEAP32[$248>>2] = $243;
          $249 = HEAP32[(38036)>>2]|0;
          $250 = (($249) + 1)|0;
          HEAP32[(38036)>>2] = $250;
          $cp$6 = $237;
          break L37;
         } else {
          $251 = HEAP32[37248>>2]|0;
          $252 = (($251) + 1)|0;
          HEAP32[37248>>2] = $252;
          $cp$6 = $237;
          break L37;
         }
        }
        break;
       }
       case 99:  {
        $151 = HEAP32[(38036)>>2]|0;
        $152 = ($151|0)>(0);
        if ($152) {
         $153 = (($151) + -1)|0;
         HEAP32[(38036)>>2] = $153;
         $154 = (((37876 + ($153<<3)|0)) + 4|0);
         $155 = HEAP8[$154>>0]|0;
         $156 = ($155<<24>>24)==(0);
         if ($156) {
          $result$0$i14 = 0;
         } else {
          $157 = (37876 + ($153<<3)|0);
          $158 = HEAP32[$157>>2]|0;
          $result$0$i14 = $158;
         }
        } else {
         $159 = HEAP32[37248>>2]|0;
         $160 = (($159) + 1)|0;
         HEAP32[37248>>2] = $160;
         $result$0$i14 = 0;
        }
        $161 = ($result$0$i14|0)==(0);
        $162 = HEAP32[(38048)>>2]|0;
        $163 = (($162) + 1)|0;
        $164 = HEAP32[(38044)>>2]|0;
        $165 = ($163>>>0)>($164>>>0);
        if ($165) {
         $166 = $163 << 1;
         HEAP32[(38044)>>2] = $166;
         $167 = HEAP32[(38040)>>2]|0;
         $168 = (__nc_doalloc($167,$166)|0);
         HEAP32[(38040)>>2] = $168;
         $169 = ($168|0)==(0|0);
         if ($169) {
          label = 73;
          break L35;
         }
         $$pre$i18 = HEAP32[(38048)>>2]|0;
         $173 = $$pre$i18;$175 = $168;
        } else {
         $$pre2$i16 = HEAP32[(38040)>>2]|0;
         $173 = $162;$175 = $$pre2$i16;
        }
        $170 = $result$0$i14&255;
        $171 = $161 ? -128 : $170;
        $172 = (($173) + 1)|0;
        HEAP32[(38048)>>2] = $172;
        $174 = (($175) + ($173)|0);
        HEAP8[$174>>0] = $171;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 94:  {
        $606 = HEAP32[(38036)>>2]|0;
        $607 = ($606|0)>(0);
        if ($607) {
         $608 = (($606) + -1)|0;
         HEAP32[(38036)>>2] = $608;
         $609 = (((37876 + ($608<<3)|0)) + 4|0);
         $610 = HEAP8[$609>>0]|0;
         $611 = ($610<<24>>24)==(0);
         if ($611) {
          $result$0$i70 = 0;
         } else {
          $612 = (37876 + ($608<<3)|0);
          $613 = HEAP32[$612>>2]|0;
          $result$0$i70 = $613;
         }
         $616 = ($606|0)>(1);
         if ($616) {
          $617 = (($606) + -2)|0;
          HEAP32[(38036)>>2] = $617;
          $618 = (((37876 + ($617<<3)|0)) + 4|0);
          $619 = HEAP8[$618>>0]|0;
          $620 = ($619<<24>>24)==(0);
          if ($620) {
           $result$0$i68 = 0;
          } else {
           $621 = (37876 + ($617<<3)|0);
           $622 = HEAP32[$621>>2]|0;
           $result$0$i68 = $622;
          }
          $625 = ($617|0)<(20);
          if ($625) {
           $628 = $617;$result$0$i68262 = $result$0$i68;$result$0$i70258261 = $result$0$i70;
          } else {
           $632 = HEAP32[37248>>2]|0;
           $633 = (($632) + 1)|0;
           HEAP32[37248>>2] = $633;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $826 = 0;$result$0$i70260 = $result$0$i70;
          label = 243;
         }
        } else {
         $614 = HEAP32[37248>>2]|0;
         $615 = (($614) + 1)|0;
         HEAP32[37248>>2] = $615;
         $826 = $606;$result$0$i70260 = 0;
         label = 243;
        }
        if ((label|0) == 243) {
         label = 0;
         $623 = HEAP32[37248>>2]|0;
         $624 = (($623) + 1)|0;
         HEAP32[37248>>2] = $624;
         $628 = $826;$result$0$i68262 = 0;$result$0$i70258261 = $result$0$i70260;
        }
        $626 = $result$0$i68262 ^ $result$0$i70258261;
        $627 = (((37876 + ($628<<3)|0)) + 4|0);
        HEAP8[$627>>0] = 1;
        $629 = (37876 + ($628<<3)|0);
        HEAP32[$629>>2] = $626;
        $630 = HEAP32[(38036)>>2]|0;
        $631 = (($630) + 1)|0;
        HEAP32[(38036)>>2] = $631;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       case 61:  {
        $634 = HEAP32[(38036)>>2]|0;
        $635 = ($634|0)>(0);
        if ($635) {
         $636 = (($634) + -1)|0;
         HEAP32[(38036)>>2] = $636;
         $637 = (((37876 + ($636<<3)|0)) + 4|0);
         $638 = HEAP8[$637>>0]|0;
         $639 = ($638<<24>>24)==(0);
         if ($639) {
          $result$0$i65 = 0;
         } else {
          $640 = (37876 + ($636<<3)|0);
          $641 = HEAP32[$640>>2]|0;
          $result$0$i65 = $641;
         }
         $644 = ($634|0)>(1);
         if ($644) {
          $645 = (($634) + -2)|0;
          HEAP32[(38036)>>2] = $645;
          $646 = (((37876 + ($645<<3)|0)) + 4|0);
          $647 = HEAP8[$646>>0]|0;
          $648 = ($647<<24>>24)==(0);
          if ($648) {
           $result$0$i63 = 0;
          } else {
           $649 = (37876 + ($645<<3)|0);
           $650 = HEAP32[$649>>2]|0;
           $result$0$i63 = $650;
          }
          $653 = ($645|0)<(20);
          if ($653) {
           $657 = $645;$result$0$i63267 = $result$0$i63;$result$0$i65263266 = $result$0$i65;
          } else {
           $661 = HEAP32[37248>>2]|0;
           $662 = (($661) + 1)|0;
           HEAP32[37248>>2] = $662;
           $cp$6 = $$1$i;
           break L37;
          }
         } else {
          $827 = 0;$result$0$i65265 = $result$0$i65;
          label = 254;
         }
        } else {
         $642 = HEAP32[37248>>2]|0;
         $643 = (($642) + 1)|0;
         HEAP32[37248>>2] = $643;
         $827 = $634;$result$0$i65265 = 0;
         label = 254;
        }
        if ((label|0) == 254) {
         label = 0;
         $651 = HEAP32[37248>>2]|0;
         $652 = (($651) + 1)|0;
         HEAP32[37248>>2] = $652;
         $657 = $827;$result$0$i63267 = 0;$result$0$i65263266 = $result$0$i65265;
        }
        $654 = ($result$0$i63267|0)==($result$0$i65263266|0);
        $655 = $654&1;
        $656 = (((37876 + ($657<<3)|0)) + 4|0);
        HEAP8[$656>>0] = 1;
        $658 = (37876 + ($657<<3)|0);
        HEAP32[$658>>2] = $655;
        $659 = HEAP32[(38036)>>2]|0;
        $660 = (($659) + 1)|0;
        HEAP32[(38036)>>2] = $660;
        $cp$6 = $$1$i;
        break L37;
        break;
       }
       default: {
        $cp$6 = $$1$i;
        break L37;
       }
       }
      } while(0);
     } else {
      $64 = ($62<<24>>24)==(0);
      $65 = HEAP32[(38048)>>2]|0;
      $66 = (($65) + 1)|0;
      $67 = HEAP32[(38044)>>2]|0;
      $68 = ($66>>>0)>($67>>>0);
      if ($68) {
       $69 = $66 << 1;
       HEAP32[(38044)>>2] = $69;
       $70 = HEAP32[(38040)>>2]|0;
       $71 = (__nc_doalloc($70,$69)|0);
       HEAP32[(38040)>>2] = $71;
       $72 = ($71|0)==(0|0);
       if ($72) {
        label = 28;
        break L35;
       }
       $$pre$i = HEAP32[(38048)>>2]|0;
       $75 = $$pre$i;$77 = $71;
      } else {
       $$pre2$i = HEAP32[(38040)>>2]|0;
       $75 = $65;$77 = $$pre2$i;
      }
      $73 = $64 ? -128 : $62;
      $74 = (($75) + 1)|0;
      HEAP32[(38048)>>2] = $74;
      $76 = (($77) + ($75)|0);
      HEAP8[$76>>0] = $73;
      $cp$6 = $cp$0170;
     }
    } while(0);
    $801 = HEAP8[$cp$6>>0]|0;
    $802 = ($801<<24>>24)==(0);
    $59 = ((($cp$6)) + 1|0);
    if ($802) {
     break L33;
    }
    $58 = $59;
    $60 = (($58) - ($33))|0;
    $61 = ($60|0)<($1|0);
    if ($61) {
     $cp$0170 = $59;
    } else {
     break L33;
    }
   }
   if ((label|0) == 28) {
    __nc_err_abort(37264,$vararg_buffer);
    // unreachable;
   }
   else if ((label|0) == 53) {
    __nc_err_abort(37264,$vararg_buffer4);
    // unreachable;
   }
   else if ((label|0) == 63) {
    __nc_err_abort(37264,$vararg_buffer6);
    // unreachable;
   }
   else if ((label|0) == 73) {
    __nc_err_abort(37264,$vararg_buffer10);
    // unreachable;
   }
   else if ((label|0) == 83) {
    __nc_err_abort(37264,$vararg_buffer12);
    // unreachable;
   }
   else if ((label|0) == 93) {
    __nc_err_abort(37264,$vararg_buffer17);
    // unreachable;
   }
  }
 } while(0);
 $803 = HEAP32[(38048)>>2]|0;
 $804 = (($803) + 1)|0;
 $805 = HEAP32[(38044)>>2]|0;
 $806 = ($804>>>0)>($805>>>0);
 do {
  if ($806) {
   $807 = $804 << 1;
   HEAP32[(38044)>>2] = $807;
   $808 = HEAP32[(38040)>>2]|0;
   $809 = (__nc_doalloc($808,$807)|0);
   HEAP32[(38040)>>2] = $809;
   $810 = ($809|0)==(0|0);
   if ($810) {
    __nc_err_abort(37264,$vararg_buffer22);
    // unreachable;
   } else {
    $$pre = HEAP32[(38048)>>2]|0;
    $812 = $809;$813 = $$pre;
    break;
   }
  } else {
   $$pre228 = HEAP32[(38040)>>2]|0;
   $812 = $$pre228;$813 = $803;
  }
 } while(0);
 $811 = (($812) + ($813)|0);
 HEAP8[$811>>0] = 0;
 $814 = HEAP32[(38040)>>2]|0;
 $$0 = $814;
 STACKTOP = sp;return ($$0|0);
}
function __nc_set_no_padding($sp) {
 $sp = $sp|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_getenv((37320|0))|0);
 $1 = ($0|0)!=(0|0);
 $2 = ($sp|0)==(0|0);
 if ($2) {
  $5 = $1&1;
  HEAP8[(38272)>>0] = $5;
  return;
 } else {
  $3 = ((($sp)) + 732|0);
  $4 = $1&1;
  HEAP8[$3>>0] = $4;
  return;
 }
}
function _delay_output($ms) {
 $ms = $ms|0;
 var $$0 = 0, $$in$i = 0, $$in$i1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $nullcount$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $$0 = -1;
  return ($$0|0);
 }
 $2 = ((($0)) + 8|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ((($3)) + 25|0);
 $5 = HEAP8[$4>>0]|0;
 $6 = ($5<<24>>24)==(0);
 if (!($6)) {
  $7 = HEAP32[37632>>2]|0;
  $8 = ($7|0)==(0|0);
  $9 = ((($7)) + 4|0);
  $$in$i = $8 ? _stdout : $9;
  $10 = HEAP32[$$in$i>>2]|0;
  (_fflush(($10|0))|0);
  (_napms($ms)|0);
  $$0 = 0;
  return ($$0|0);
 }
 $11 = HEAP32[37344>>2]|0;
 $12 = HEAP16[37304>>1]|0;
 $13 = $12 << 16 >> 16;
 $14 = (__nc_baudrate($13)|0);
 $15 = Math_imul($14, $ms)|0;
 $16 = (($15|0) / 9000)&-1;
 $17 = HEAP32[37312>>2]|0;
 $18 = (($17) + ($16))|0;
 HEAP32[37312>>2] = $18;
 $19 = ($15|0)>(8999);
 if ($19) {
  $nullcount$02 = $16;
  while(1) {
   $20 = HEAP8[37296>>0]|0;
   $21 = $20 << 24 >> 24;
   (FUNCTION_TABLE_ii[$11 & 511]($21)|0);
   $22 = (($nullcount$02) + -1)|0;
   $23 = ($nullcount$02|0)>(1);
   if ($23) {
    $nullcount$02 = $22;
   } else {
    break;
   }
  }
 }
 $24 = ($11|0)==(298|0);
 if (!($24)) {
  $$0 = 0;
  return ($$0|0);
 }
 $25 = HEAP32[37632>>2]|0;
 $26 = ($25|0)==(0|0);
 $27 = ((($25)) + 4|0);
 $$in$i1 = $26 ? _stdout : $27;
 $28 = HEAP32[$$in$i1>>2]|0;
 (_fflush(($28|0))|0);
 $$0 = 0;
 return ($$0|0);
}
function __nc_outch($ch) {
 $ch = $ch|0;
 var $$ = 0, $$3 = 0, $$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $or$cond = 0, $tmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $tmp = sp;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)!=(0|0);
 $2 = HEAP32[37632>>2]|0;
 $3 = ($2|0)!=(0|0);
 $or$cond = $1 & $3;
 if ($or$cond) {
  $4 = ((($2)) + 1188|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = ($5<<24>>24)==(0);
  if (!($6)) {
   $7 = $ch&255;
   HEAP8[$tmp>>0] = $7;
   $8 = ((($2)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = (_fileno(($9|0))|0);
   $11 = (_write(($10|0),($tmp|0),1)|0);
   $12 = ($11|0)==(-1);
   $$ = $12 << 31 >> 31;
   STACKTOP = sp;return ($$|0);
  }
 }
 $13 = ($2|0)==(0|0);
 $14 = ((($2)) + 4|0);
 $$in = $13 ? _stdout : $14;
 $15 = HEAP32[$$in>>2]|0;
 $16 = (_putc(($ch|0),($15|0))|0);
 $17 = ($16|0)==(-1);
 $$3 = $17 << 31 >> 31;
 STACKTOP = sp;return ($$3|0);
}
function _tputs($string,$affcnt,$outc) {
 $string = $string|0;
 $affcnt = $affcnt|0;
 $outc = $outc|0;
 var $$0 = 0, $$04 = 0, $$04$us = 0, $$1$lcssa = 0, $$1$lcssa$us = 0, $$123 = 0, $$123$us = 0, $$2 = 0, $$2$ph = 0, $$2$ph$us = 0, $$2$us = 0, $$4 = 0, $$4$lcssa = 0, $$4$lcssa73 = 0, $$4$ph14 = 0, $$4$ph14$us = 0, $$4$us = 0, $$4$us$lcssa = 0, $$4$us$lcssa69 = 0, $$5 = 0;
 var $$5$us = 0, $$lcssa = 0, $$lcssa$us = 0, $$lcssa18 = 0, $$lcssa18$us = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0;
 var $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0;
 var $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $brmerge = 0, $isdigit = 0, $isdigit$us = 0, $isdigit10 = 0, $isdigit10$us = 0, $isdigit6 = 0, $isdigit6$us = 0, $isdigit8 = 0, $isdigit8$us = 0;
 var $isdigittmp = 0, $isdigittmp$us = 0, $isdigittmp5 = 0, $isdigittmp5$us = 0, $isdigittmp7 = 0, $isdigittmp7$us = 0, $isdigittmp9 = 0, $isdigittmp9$us = 0, $magicptr = 0, $mandatory$0$off0 = 0, $mandatory$0$off0$lcssa = 0, $mandatory$0$off0$lcssa74 = 0, $mandatory$0$off0$ph = 0, $normal_delay$0$off0 = 0, $number$1$ph = 0, $number$1$ph$us = 0, $number$3$ph15 = 0, $number$3$ph15$lcssa = 0, $number$3$ph15$us = 0, $number$3$ph15$us$lcssa = 0;
 var $or$cond = 0, $or$cond12 = 0, $or$cond13 = 0, $or$cond13$us = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[9336]|0;
 $1 = HEAP32[37632>>2]|0;
 $2 = ($1|0)==(0|0);
 $3 = HEAP32[37624>>2]|0;
 $4 = ($3|0)!=(0|0);
 $or$cond = $2 | $4;
 if (!($or$cond)) {
  $$0 = -1;
  return ($$0|0);
 }
 $magicptr = $string;
 if ((($magicptr|0) == 0) | (($magicptr|0) == -1)) {
  $$0 = -1;
  return ($$0|0);
 }
 $5 = ($3|0)==(0|0);
 L7: do {
  if ($5) {
   HEAP32[37344>>2] = $outc;
   $$04$us = $string;
   label = 14;
  } else {
   $6 = ((($3)) + 16|0);
   $7 = HEAP32[$6>>2]|0;
   $8 = ((($7)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = ($9|0)==($string|0);
   if ($10) {
    $39 = 1;
   } else {
    $11 = ((($7)) + 180|0);
    $12 = HEAP32[$11>>2]|0;
    $13 = ($12|0)==($string|0);
    $39 = $13;
   }
   $14 = ((($3)) + 8|0);
   $15 = HEAP32[$14>>2]|0;
   $16 = ((($15)) + 20|0);
   $17 = HEAP8[$16>>0]|0;
   $18 = ($17<<24>>24)==(0);
   do {
    if ($18) {
     $19 = ((($3)) + 12|0);
     $20 = HEAP32[$19>>2]|0;
     $21 = ((($20)) + 10|0);
     $22 = HEAP16[$21>>1]|0;
     $23 = ($22<<16>>16)==(0);
     if ($23) {
      $normal_delay$0$off0 = 0;
     } else {
      if ($2) {
       $27 = HEAP8[(38272)>>0]|0;
       $28 = ($27<<24>>24)==(0);
       if (!($28)) {
        $normal_delay$0$off0 = 0;
        break;
       }
      } else {
       $24 = ((($1)) + 732|0);
       $25 = HEAP8[$24>>0]|0;
       $26 = ($25<<24>>24)==(0);
       if (!($26)) {
        $normal_delay$0$off0 = 0;
        break;
       }
      }
      $29 = HEAP16[37304>>1]|0;
      $30 = $29 << 16 >> 16;
      $31 = (__nc_baudrate($30)|0);
      $32 = HEAP32[37624>>2]|0;
      $33 = ((($32)) + 12|0);
      $34 = HEAP32[$33>>2]|0;
      $35 = ((($34)) + 10|0);
      $36 = HEAP16[$35>>1]|0;
      $37 = $36 << 16 >> 16;
      $38 = ($31|0)>=($37|0);
      $normal_delay$0$off0 = $38;
     }
    } else {
     $normal_delay$0$off0 = 0;
    }
   } while(0);
   HEAP32[37344>>2] = $outc;
   $brmerge = $39 | $normal_delay$0$off0;
   if ($brmerge) {
    $$04$us = $string;
    label = 14;
   } else {
    $$04 = $string;
    L20: while(1) {
     $83 = HEAP8[$$04>>0]|0;
     do {
      if ((($83<<24>>24) == 0)) {
       break L7;
      } else if ((($83<<24>>24) == 36)) {
       $85 = ((($$04)) + 1|0);
       $86 = HEAP8[$85>>0]|0;
       $87 = ($86<<24>>24)==(60);
       if (!($87)) {
        (FUNCTION_TABLE_ii[$outc & 511](36)|0);
        $88 = HEAP8[$85>>0]|0;
        $89 = ($88<<24>>24)==(0);
        if ($89) {
         $$5 = $85;
         break;
        }
        $90 = $88 << 24 >> 24;
        (FUNCTION_TABLE_ii[$outc & 511]($90)|0);
        $$5 = $85;
        break;
       }
       $91 = ((($$04)) + 2|0);
       $92 = HEAP8[$91>>0]|0;
       $93 = $92&255;
       $isdigittmp = (($93) + -48)|0;
       $isdigit = ($isdigittmp>>>0)<(10);
       $94 = ($92<<24>>24)==(46);
       $or$cond13 = $94 | $isdigit;
       if ($or$cond13) {
        $95 = (_strchr($91,62)|0);
        $96 = ($95|0)==(0|0);
        if (!($96)) {
         if ($isdigit) {
          $$123 = $91;$100 = 0;$98 = $92;
          while(1) {
           $97 = $98 << 24 >> 24;
           $99 = (($100) + -48)|0;
           $101 = (($99) + ($97))|0;
           $102 = ((($$123)) + 1|0);
           $103 = HEAP8[$102>>0]|0;
           $104 = $103&255;
           $isdigittmp5 = (($104) + -48)|0;
           $isdigit6 = ($isdigittmp5>>>0)<(10);
           $105 = ($101*10)|0;
           if ($isdigit6) {
            $$123 = $102;$100 = $105;$98 = $103;
           } else {
            $$1$lcssa = $102;$$lcssa = $103;$$lcssa18 = $105;
            break;
           }
          }
         } else {
          $$1$lcssa = $91;$$lcssa = $92;$$lcssa18 = 0;
         }
         $106 = ($$lcssa<<24>>24)==(46);
         if ($106) {
          $107 = ((($$1$lcssa)) + 1|0);
          $108 = HEAP8[$107>>0]|0;
          $109 = $108&255;
          $isdigittmp7 = (($109) + -48)|0;
          $isdigit8 = ($isdigittmp7>>>0)<(10);
          if ($isdigit8) {
           $110 = $108 << 24 >> 24;
           $111 = (($$lcssa18) + -48)|0;
           $112 = (($111) + ($110))|0;
           $113 = ((($$1$lcssa)) + 2|0);
           $$2$ph = $113;$number$1$ph = $112;
          } else {
           $$2$ph = $107;$number$1$ph = $$lcssa18;
          }
          $$2 = $$2$ph;
          while(1) {
           $114 = HEAP8[$$2>>0]|0;
           $115 = $114&255;
           $isdigittmp9 = (($115) + -48)|0;
           $isdigit10 = ($isdigittmp9>>>0)<(10);
           $116 = ((($$2)) + 1|0);
           if ($isdigit10) {
            $$2 = $116;
           } else {
            $$4$ph14 = $$2;$mandatory$0$off0$ph = 0;$number$3$ph15 = $number$1$ph;
            break;
           }
          }
         } else {
          $$4$ph14 = $$1$lcssa;$mandatory$0$off0$ph = 0;$number$3$ph15 = $$lcssa18;
         }
         L43: while(1) {
          $$4 = $$4$ph14;$mandatory$0$off0 = $mandatory$0$off0$ph;
          while(1) {
           $117 = HEAP8[$$4>>0]|0;
           if ((($117<<24>>24) == 42)) {
            $$4$lcssa73 = $$4;$mandatory$0$off0$lcssa74 = $mandatory$0$off0;
            break;
           } else if (!((($117<<24>>24) == 47))) {
            $$4$lcssa = $$4;$mandatory$0$off0$lcssa = $mandatory$0$off0;$number$3$ph15$lcssa = $number$3$ph15;
            break L43;
           }
           $120 = ((($$4)) + 1|0);
           $$4 = $120;$mandatory$0$off0 = 1;
          }
          $118 = Math_imul($number$3$ph15, $affcnt)|0;
          $119 = ((($$4$lcssa73)) + 1|0);
          $$4$ph14 = $119;$mandatory$0$off0$ph = $mandatory$0$off0$lcssa74;$number$3$ph15 = $118;
         }
         $121 = ($number$3$ph15$lcssa|0)>(0);
         $or$cond12 = $121 & $mandatory$0$off0$lcssa;
         if (!($or$cond12)) {
          $$5 = $$4$lcssa;
          break;
         }
         $122 = (($number$3$ph15$lcssa|0) / 10)&-1;
         (_delay_output($122)|0);
         $$5 = $$4$lcssa;
         break;
        }
       }
       (FUNCTION_TABLE_ii[$outc & 511](36)|0);
       (FUNCTION_TABLE_ii[$outc & 511](60)|0);
       $$04 = $91;
       continue L20;
      } else {
       $84 = $83 << 24 >> 24;
       (FUNCTION_TABLE_ii[$outc & 511]($84)|0);
       $$5 = $$04;
      }
     } while(0);
     $123 = HEAP8[$$5>>0]|0;
     $124 = ($123<<24>>24)==(0);
     if ($124) {
      break L7;
     }
     $125 = ((($$5)) + 1|0);
     $$04 = $125;
    }
   }
  }
 } while(0);
 L55: do {
  if ((label|0) == 14) {
   L56: while(1) {
    label = 0;
    $40 = HEAP8[$$04$us>>0]|0;
    do {
     if ((($40<<24>>24) == 36)) {
      $41 = ((($$04$us)) + 1|0);
      $42 = HEAP8[$41>>0]|0;
      $43 = ($42<<24>>24)==(60);
      if (!($43)) {
       (FUNCTION_TABLE_ii[$outc & 511](36)|0);
       $44 = HEAP8[$41>>0]|0;
       $45 = ($44<<24>>24)==(0);
       if ($45) {
        $$5$us = $41;
        break;
       }
       $46 = $44 << 24 >> 24;
       (FUNCTION_TABLE_ii[$outc & 511]($46)|0);
       $$5$us = $41;
       break;
      }
      $47 = ((($$04$us)) + 2|0);
      $48 = HEAP8[$47>>0]|0;
      $49 = $48&255;
      $isdigittmp$us = (($49) + -48)|0;
      $isdigit$us = ($isdigittmp$us>>>0)<(10);
      $50 = ($48<<24>>24)==(46);
      $or$cond13$us = $50 | $isdigit$us;
      if ($or$cond13$us) {
       $51 = (_strchr($47,62)|0);
       $52 = ($51|0)==(0|0);
       if (!($52)) {
        if ($isdigit$us) {
         $$123$us = $47;$71 = $48;$73 = 0;
         while(1) {
          $70 = $71 << 24 >> 24;
          $72 = (($73) + -48)|0;
          $74 = (($72) + ($70))|0;
          $75 = ((($$123$us)) + 1|0);
          $76 = HEAP8[$75>>0]|0;
          $77 = $76&255;
          $isdigittmp5$us = (($77) + -48)|0;
          $isdigit6$us = ($isdigittmp5$us>>>0)<(10);
          $78 = ($74*10)|0;
          if ($isdigit6$us) {
           $$123$us = $75;$71 = $76;$73 = $78;
          } else {
           $$1$lcssa$us = $75;$$lcssa$us = $76;$$lcssa18$us = $78;
           break;
          }
         }
        } else {
         $$1$lcssa$us = $47;$$lcssa$us = $48;$$lcssa18$us = 0;
        }
        $53 = ($$lcssa$us<<24>>24)==(46);
        if ($53) {
         $54 = ((($$1$lcssa$us)) + 1|0);
         $55 = HEAP8[$54>>0]|0;
         $56 = $55&255;
         $isdigittmp7$us = (($56) + -48)|0;
         $isdigit8$us = ($isdigittmp7$us>>>0)<(10);
         if ($isdigit8$us) {
          $57 = $55 << 24 >> 24;
          $58 = (($$lcssa18$us) + -48)|0;
          $59 = (($58) + ($57))|0;
          $60 = ((($$1$lcssa$us)) + 2|0);
          $$2$ph$us = $60;$number$1$ph$us = $59;
         } else {
          $$2$ph$us = $54;$number$1$ph$us = $$lcssa18$us;
         }
         $$2$us = $$2$ph$us;
         while(1) {
          $61 = HEAP8[$$2$us>>0]|0;
          $62 = $61&255;
          $isdigittmp9$us = (($62) + -48)|0;
          $isdigit10$us = ($isdigittmp9$us>>>0)<(10);
          $63 = ((($$2$us)) + 1|0);
          if ($isdigit10$us) {
           $$2$us = $63;
          } else {
           $$4$ph14$us = $$2$us;$number$3$ph15$us = $number$1$ph$us;
           break;
          }
         }
        } else {
         $$4$ph14$us = $$1$lcssa$us;$number$3$ph15$us = $$lcssa18$us;
        }
        L78: while(1) {
         $$4$us = $$4$ph14$us;
         while(1) {
          $64 = HEAP8[$$4$us>>0]|0;
          if ((($64<<24>>24) == 42)) {
           $$4$us$lcssa69 = $$4$us;
           break;
          } else if (!((($64<<24>>24) == 47))) {
           $$4$us$lcssa = $$4$us;$number$3$ph15$us$lcssa = $number$3$ph15$us;
           break L78;
          }
          $65 = ((($$4$us)) + 1|0);
          $$4$us = $65;
         }
         $66 = Math_imul($number$3$ph15$us, $affcnt)|0;
         $67 = ((($$4$us$lcssa69)) + 1|0);
         $$4$ph14$us = $67;$number$3$ph15$us = $66;
        }
        $68 = ($number$3$ph15$us$lcssa|0)>(0);
        if (!($68)) {
         $$5$us = $$4$us$lcssa;
         break;
        }
        $69 = (($number$3$ph15$us$lcssa|0) / 10)&-1;
        (_delay_output($69)|0);
        $$5$us = $$4$us$lcssa;
        break;
       }
      }
      (FUNCTION_TABLE_ii[$outc & 511](36)|0);
      (FUNCTION_TABLE_ii[$outc & 511](60)|0);
      $$04$us = $47;
      label = 14;
      continue L56;
     } else if ((($40<<24>>24) == 0)) {
      break L55;
     } else {
      $79 = $40 << 24 >> 24;
      (FUNCTION_TABLE_ii[$outc & 511]($79)|0);
      $$5$us = $$04$us;
     }
    } while(0);
    $80 = HEAP8[$$5$us>>0]|0;
    $81 = ($80<<24>>24)==(0);
    if ($81) {
     break L55;
    }
    $82 = ((($$5$us)) + 1|0);
    $$04$us = $82;
    label = 14;
   }
  }
 } while(0);
 HEAP32[9336] = $0;
 $$0 = 0;
 return ($$0|0);
}
function __nc_trim_sgr0($tp) {
 $tp = $tp|0;
 var $$ = 0, $$$0$i$i = 0, $$$0$i6$i = 0, $$$i = 0, $$$i8 = 0, $$0$be$i = 0, $$0$i$i = 0, $$0$i$i$lcssa = 0, $$0$i2$i = 0, $$0$i2$i$lcssa = 0, $$0$i33$ph = 0, $$01$be$i = 0, $$01$lcssa$i = 0, $$01$lcssa$i44 = 0, $$01$lcssa$i50 = 0, $$011$i = 0, $$011$i42 = 0, $$011$i48 = 0, $$0113$i = 0, $$015$i = 0;
 var $$02$i = 0, $$02$i41 = 0, $$02$i47 = 0, $$lcssa106 = 0, $$lcssa107 = 0, $$lcssa108 = 0, $$lcssa109 = 0, $$phi$trans$insert = 0, $$pre = 0, $$pre$phiZ2D = 0, $$pre76 = 0, $$pre77 = 0, $$pre78 = 0, $$pre79 = 0, $$sum = 0, $$sum57 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0;
 var $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0;
 var $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0;
 var $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $exitcond$i = 0, $exitcond$i14 = 0, $exitcond$i24 = 0, $i$066 = 0, $i$066$lcssa = 0, $i$066$us = 0, $isdigit$i$i = 0, $isdigit$i4$i = 0, $isdigittmp$i$i = 0, $isdigittmp$i3$i = 0, $magicptr = 0, $magicptr$i = 0, $magicptr$i19 = 0;
 var $magicptr$i9 = 0, $magicptr4$i = 0, $magicptr4$i10 = 0, $magicptr4$i20 = 0, $magicptr5 = 0, $n$0$lcssa$i = 0, $n$0$lcssa$i15 = 0, $n$0$lcssa$i25 = 0, $n$05$i = 0, $n$05$i13 = 0, $n$05$i23 = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i5$i = 0, $phitmp = 0, $result$0 = 0, $result$1 = 0, $result$2 = 0, $s$$i = 0, $s$$i38 = 0;
 var $tp$idx$val = 0, $tp$idx$val$idx = 0, $tp$idx$val$idx$val = 0, $used_delay$0$be$i = 0, $used_delay$017$i = 0, $used_full$0$be$i = 0, $used_full$0$be$i$lcssa = 0, $used_full$0$be$i$lcssa$lcssa = 0, $used_full$016$i = 0, $vararg_buffer = 0, $vararg_buffer9 = 0, $vararg_ptr1 = 0, $vararg_ptr12 = 0, $vararg_ptr13 = 0, $vararg_ptr14 = 0, $vararg_ptr15 = 0, $vararg_ptr16 = 0, $vararg_ptr17 = 0, $vararg_ptr18 = 0, $vararg_ptr19 = 0;
 var $vararg_ptr2 = 0, $vararg_ptr3 = 0, $vararg_ptr4 = 0, $vararg_ptr5 = 0, $vararg_ptr6 = 0, $vararg_ptr7 = 0, $vararg_ptr8 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 80|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer9 = sp + 40|0;
 $vararg_buffer = sp;
 $0 = ((($tp)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($1)) + 156|0);
 $3 = HEAP32[$2>>2]|0;
 $magicptr = $3;
 if ((($magicptr|0) == -1) | (($magicptr|0) == 0)) {
  $result$2 = $3;
  STACKTOP = sp;return ($result$2|0);
 }
 $4 = ((($1)) + 524|0);
 $5 = HEAP32[$4>>2]|0;
 $magicptr5 = $5;
 if ((($magicptr5|0) == -1) | (($magicptr5|0) == 0)) {
  $result$2 = $3;
  STACKTOP = sp;return ($result$2|0);
 }
 HEAP32[$vararg_buffer>>2] = 0;
 $vararg_ptr1 = ((($vararg_buffer)) + 4|0);
 HEAP32[$vararg_ptr1>>2] = 0;
 $vararg_ptr2 = ((($vararg_buffer)) + 8|0);
 HEAP32[$vararg_ptr2>>2] = 0;
 $vararg_ptr3 = ((($vararg_buffer)) + 12|0);
 HEAP32[$vararg_ptr3>>2] = 0;
 $vararg_ptr4 = ((($vararg_buffer)) + 16|0);
 HEAP32[$vararg_ptr4>>2] = 0;
 $vararg_ptr5 = ((($vararg_buffer)) + 20|0);
 HEAP32[$vararg_ptr5>>2] = 0;
 $vararg_ptr6 = ((($vararg_buffer)) + 24|0);
 HEAP32[$vararg_ptr6>>2] = 0;
 $vararg_ptr7 = ((($vararg_buffer)) + 28|0);
 HEAP32[$vararg_ptr7>>2] = 0;
 $vararg_ptr8 = ((($vararg_buffer)) + 32|0);
 HEAP32[$vararg_ptr8>>2] = 1;
 $6 = (_tparm($5,$vararg_buffer)|0);
 $7 = ($6|0)==(0|0);
 $$$i = $7 ? 37352 : $6;
 $8 = (___strdup($$$i)|0);
 $tp$idx$val = HEAP32[$0>>2]|0;
 $tp$idx$val$idx = ((($tp$idx$val)) + 524|0);
 $tp$idx$val$idx$val = HEAP32[$tp$idx$val$idx>>2]|0;
 HEAP32[$vararg_buffer9>>2] = 0;
 $vararg_ptr12 = ((($vararg_buffer9)) + 4|0);
 HEAP32[$vararg_ptr12>>2] = 0;
 $vararg_ptr13 = ((($vararg_buffer9)) + 8|0);
 HEAP32[$vararg_ptr13>>2] = 0;
 $vararg_ptr14 = ((($vararg_buffer9)) + 12|0);
 HEAP32[$vararg_ptr14>>2] = 0;
 $vararg_ptr15 = ((($vararg_buffer9)) + 16|0);
 HEAP32[$vararg_ptr15>>2] = 0;
 $vararg_ptr16 = ((($vararg_buffer9)) + 20|0);
 HEAP32[$vararg_ptr16>>2] = 0;
 $vararg_ptr17 = ((($vararg_buffer9)) + 24|0);
 HEAP32[$vararg_ptr17>>2] = 0;
 $vararg_ptr18 = ((($vararg_buffer9)) + 28|0);
 HEAP32[$vararg_ptr18>>2] = 0;
 $vararg_ptr19 = ((($vararg_buffer9)) + 32|0);
 HEAP32[$vararg_ptr19>>2] = 0;
 $9 = (_tparm($tp$idx$val$idx$val,$vararg_buffer9)|0);
 $10 = ($9|0)==(0|0);
 $$$i8 = $10 ? 37352 : $9;
 $11 = (___strdup($$$i8)|0);
 $12 = HEAP32[$0>>2]|0;
 $13 = ((($12)) + 156|0);
 $14 = HEAP32[$13>>2]|0;
 $15 = (___strdup($14)|0);
 $16 = HEAP32[$0>>2]|0;
 $17 = ((($16)) + 100|0);
 $18 = HEAP32[$17>>2]|0;
 $magicptr$i = $8;
 do {
  if ((($magicptr$i|0) == 0) | (($magicptr$i|0) == -1)) {
   label = 27;
  } else {
   $magicptr4$i = $18;
   if ((($magicptr4$i|0) == 0) | (($magicptr4$i|0) == -1)) {
    $33 = $16;
   } else {
    $19 = (_strlen(($8|0))|0);
    $20 = (_strlen(($18|0))|0);
    $21 = ($19>>>0)>($20>>>0);
    if ($21) {
     $22 = (_strncmp($18,$8,$20)|0);
     $23 = ($22|0)==(0);
     if ($23) {
      $24 = ($19|0)==($20|0);
      if ($24) {
       $n$0$lcssa$i = 0;
      } else {
       $25 = (($19) - ($20))|0;
       $n$05$i = 0;
       while(1) {
        $26 = (($n$05$i) + ($20))|0;
        $27 = (($8) + ($26)|0);
        $28 = HEAP8[$27>>0]|0;
        $29 = (($8) + ($n$05$i)|0);
        HEAP8[$29>>0] = $28;
        $30 = (($n$05$i) + 1)|0;
        $exitcond$i = ($30|0)==($25|0);
        if ($exitcond$i) {
         $n$0$lcssa$i = $25;
         break;
        } else {
         $n$05$i = $30;
        }
       }
      }
      $31 = (($8) + ($n$0$lcssa$i)|0);
      (_strcpy(($31|0),($18|0))|0);
      $$pre = HEAP32[$0>>2]|0;
      $33 = $$pre;
     } else {
      $33 = $16;
     }
    } else {
     $33 = $16;
    }
   }
   $32 = ((($33)) + 152|0);
   $34 = HEAP32[$32>>2]|0;
   $magicptr$i9 = $11;
   if ((($magicptr$i9|0) == 0)) {
    $result$1 = $3;
    break;
   } else if ((($magicptr$i9|0) == -1)) {
    label = 28;
    break;
   }
   $magicptr4$i10 = $34;
   if ((($magicptr4$i10|0) == 0) | (($magicptr4$i10|0) == -1)) {
    $48 = $34;
   } else {
    $35 = (_strlen(($11|0))|0);
    $36 = (_strlen(($34|0))|0);
    $37 = ($35>>>0)>($36>>>0);
    if ($37) {
     $38 = (_strncmp($34,$11,$36)|0);
     $39 = ($38|0)==(0);
     if ($39) {
      $40 = ($35|0)==($36|0);
      if ($40) {
       $n$0$lcssa$i15 = 0;
      } else {
       $41 = (($35) - ($36))|0;
       $n$05$i13 = 0;
       while(1) {
        $42 = (($n$05$i13) + ($36))|0;
        $43 = (($11) + ($42)|0);
        $44 = HEAP8[$43>>0]|0;
        $45 = (($11) + ($n$05$i13)|0);
        HEAP8[$45>>0] = $44;
        $46 = (($n$05$i13) + 1)|0;
        $exitcond$i14 = ($46|0)==($41|0);
        if ($exitcond$i14) {
         $n$0$lcssa$i15 = $41;
         break;
        } else {
         $n$05$i13 = $46;
        }
       }
      }
      $47 = (($11) + ($n$0$lcssa$i15)|0);
      (_strcpy(($47|0),($34|0))|0);
      $$pre76 = HEAP32[$0>>2]|0;
      $$phi$trans$insert = ((($$pre76)) + 152|0);
      $$pre77 = HEAP32[$$phi$trans$insert>>2]|0;
      $48 = $$pre77;
     } else {
      $48 = $34;
     }
    } else {
     $48 = $34;
    }
   }
   $magicptr$i19 = $15;
   if ((($magicptr$i19|0) == 0) | (($magicptr$i19|0) == -1)) {
    label = 27;
   } else {
    $magicptr4$i20 = $48;
    if (!((($magicptr4$i20|0) == 0) | (($magicptr4$i20|0) == -1))) {
     $49 = (_strlen(($15|0))|0);
     $50 = (_strlen(($48|0))|0);
     $51 = ($49>>>0)>($50>>>0);
     if ($51) {
      $52 = (_strncmp($48,$15,$50)|0);
      $53 = ($52|0)==(0);
      if ($53) {
       $54 = ($49|0)==($50|0);
       if ($54) {
        $n$0$lcssa$i25 = 0;
       } else {
        $55 = (($49) - ($50))|0;
        $n$05$i23 = 0;
        while(1) {
         $56 = (($n$05$i23) + ($50))|0;
         $57 = (($15) + ($56)|0);
         $58 = HEAP8[$57>>0]|0;
         $59 = (($15) + ($n$05$i23)|0);
         HEAP8[$59>>0] = $58;
         $60 = (($n$05$i23) + 1)|0;
         $exitcond$i24 = ($60|0)==($55|0);
         if ($exitcond$i24) {
          $n$0$lcssa$i25 = $55;
          break;
         } else {
          $n$05$i23 = $60;
         }
        }
       }
       $61 = (($15) + ($n$0$lcssa$i25)|0);
       (_strcpy(($61|0),($48|0))|0);
      }
     }
    }
    $63 = (_similar_sgr($11,$15)|0);
    if ($63) {
     $64 = (_similar_sgr($11,$8)|0);
     if (!($64)) {
      $65 = HEAP32[$0>>2]|0;
      $66 = ((($65)) + 152|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      L44: do {
       if ($68) {
        label = 55;
       } else {
        $69 = (_strlen(($11|0))|0);
        $70 = (_strlen(($67|0))|0);
        $71 = ($69>>>0)>($70>>>0);
        if ($71) {
         $72 = (($69) - ($70))|0;
         $73 = HEAP8[$67>>0]|0;
         $74 = ($73<<24>>24)==(0);
         if ($74) {
          $i$066$us = 0;
          while(1) {
           $75 = (($i$066$us) + 1)|0;
           $76 = ($75>>>0)>($72>>>0);
           if ($76) {
            label = 55;
            break L44;
           } else {
            $i$066$us = $75;
           }
          }
         } else {
          $i$066 = 0;
         }
         while(1) {
          $77 = (($11) + ($i$066)|0);
          $$0113$i = $77;$$015$i = $67;$80 = $73;$used_delay$017$i = 0;$used_full$016$i = 0;
          while(1) {
           $78 = HEAP8[$$0113$i>>0]|0;
           $79 = ($80<<24>>24)==($78<<24>>24);
           if (!($79)) {
            break;
           }
           $81 = (($used_full$016$i) + ($used_delay$017$i))|0;
           $82 = ($80<<24>>24)==(36);
           $83 = ((($$015$i)) + 1|0);
           do {
            if ($82) {
             $84 = HEAP8[$83>>0]|0;
             $85 = ($84<<24>>24)==(60);
             if ($85) {
              $86 = ((($$015$i)) + 2|0);
              $$0$i$i = $86;
              while(1) {
               $87 = HEAP8[$$0$i$i>>0]|0;
               $88 = $87&255;
               $isdigittmp$i$i = (($88) + -48)|0;
               $isdigit$i$i = ($isdigittmp$i$i>>>0)<(10);
               $89 = ($87<<24>>24)==(47);
               $or$cond$i$i = $89 | $isdigit$i$i;
               $90 = ((($$0$i$i)) + 1|0);
               if ($or$cond$i$i) {
                $$0$i$i = $90;
               } else {
                $$0$i$i$lcssa = $$0$i$i;$$lcssa106 = $87;$$lcssa107 = $90;
                break;
               }
              }
              $91 = ($$lcssa106<<24>>24)==(62);
              $$$0$i$i = $91 ? $$lcssa107 : $$0$i$i$lcssa;
              $102 = $$$0$i$i;
             } else {
              $102 = $$015$i;
             }
             $92 = ((($$0113$i)) + 1|0);
             $93 = HEAP8[$92>>0]|0;
             $94 = ($93<<24>>24)==(60);
             if (!($94)) {
              $$pre$phiZ2D = $92;
              label = 49;
              break;
             }
             $95 = ((($$0113$i)) + 2|0);
             $$0$i2$i = $95;
             while(1) {
              $96 = HEAP8[$$0$i2$i>>0]|0;
              $97 = $96&255;
              $isdigittmp$i3$i = (($97) + -48)|0;
              $isdigit$i4$i = ($isdigittmp$i3$i>>>0)<(10);
              $98 = ($96<<24>>24)==(47);
              $or$cond$i5$i = $98 | $isdigit$i4$i;
              $99 = ((($$0$i2$i)) + 1|0);
              if ($or$cond$i5$i) {
               $$0$i2$i = $99;
              } else {
               $$0$i2$i$lcssa = $$0$i2$i;$$lcssa108 = $96;$$lcssa109 = $99;
               break;
              }
             }
             $100 = ($$lcssa108<<24>>24)==(62);
             $$$0$i6$i = $100 ? $$lcssa109 : $$0$i2$i$lcssa;
             $101 = ($102|0)==($$015$i|0);
             $103 = ($$$0$i6$i|0)==($$0113$i|0);
             $or$cond$i = $101 | $103;
             if ($or$cond$i) {
              $$pre$phiZ2D = $92;
              label = 49;
              break;
             }
             $104 = $$$0$i6$i;
             $105 = $$0113$i;
             $106 = (($104) - ($105))|0;
             $$0$be$i = $102;$$01$be$i = $$$0$i6$i;$used_delay$0$be$i = $106;$used_full$0$be$i = $81;
            } else {
             $$pre79 = ((($$0113$i)) + 1|0);
             $$pre$phiZ2D = $$pre79;
             label = 49;
            }
           } while(0);
           if ((label|0) == 49) {
            label = 0;
            $109 = (($81) + 1)|0;
            $$0$be$i = $83;$$01$be$i = $$pre$phiZ2D;$used_delay$0$be$i = 0;$used_full$0$be$i = $109;
           }
           $107 = HEAP8[$$0$be$i>>0]|0;
           $108 = ($107<<24>>24)==(0);
           if ($108) {
            $used_full$0$be$i$lcssa = $used_full$0$be$i;
            label = 50;
            break;
           } else {
            $$0113$i = $$01$be$i;$$015$i = $$0$be$i;$80 = $107;$used_delay$017$i = $used_delay$0$be$i;$used_full$016$i = $used_full$0$be$i;
           }
          }
          if ((label|0) == 50) {
           label = 0;
           $110 = ($used_full$0$be$i$lcssa|0)==(0);
           if (!($110)) {
            $i$066$lcssa = $i$066;$used_full$0$be$i$lcssa$lcssa = $used_full$0$be$i$lcssa;
            break;
           }
          }
          $122 = (($i$066) + 1)|0;
          $123 = ($122>>>0)>($72>>>0);
          if ($123) {
           label = 55;
           break L44;
          } else {
           $i$066 = $122;
          }
         }
         $111 = (($used_full$0$be$i$lcssa$lcssa) + ($i$066$lcssa))|0;
         $112 = (($11) + ($111)|0);
         $113 = HEAP8[$112>>0]|0;
         $114 = ($113<<24>>24)==(0);
         if ($114) {
          $$01$lcssa$i = $i$066$lcssa;
         } else {
          $$011$i = $i$066$lcssa;$$02$i = $111;$118 = $113;
          while(1) {
           $115 = (($$02$i) + 1)|0;
           $116 = (($$011$i) + 1)|0;
           $117 = (($11) + ($$011$i)|0);
           HEAP8[$117>>0] = $118;
           $119 = (($11) + ($115)|0);
           $120 = HEAP8[$119>>0]|0;
           $121 = ($120<<24>>24)==(0);
           if ($121) {
            $$01$lcssa$i = $116;
            break;
           } else {
            $$011$i = $116;$$02$i = $115;$118 = $120;
           }
          }
         }
         $124 = (($11) + ($$01$lcssa$i)|0);
         HEAP8[$124>>0] = 0;
         $result$0 = $11;
        } else {
         label = 55;
        }
       }
      } while(0);
      L80: do {
       if ((label|0) == 55) {
        $125 = HEAP8[$11>>0]|0;
        if ((($125<<24>>24) == 27)) {
         $126 = ((($11)) + 1|0);
         $127 = HEAP8[$126>>0]|0;
         $128 = ($127<<24>>24)==(91);
         if ($128) {
          $$0$i33$ph = 2;
          label = 57;
         }
        } else if ((($125<<24>>24) == -23)) {
         $$0$i33$ph = 1;
         label = 57;
        }
        do {
         if ((label|0) == 57) {
          $129 = (_strlen(($11|0))|0);
          $130 = (($129) + -1)|0;
          $131 = (($11) + ($130)|0);
          $132 = HEAP8[$131>>0]|0;
          $133 = ($132<<24>>24)==(109);
          if ($133) {
           $134 = (($11) + ($$0$i33$ph)|0);
           $135 = HEAP8[$134>>0]|0;
           $136 = ($135<<24>>24)==(48);
           do {
            if ($136) {
             $$sum = (($$0$i33$ph) + 1)|0;
             $137 = (($11) + ($$sum)|0);
             $138 = HEAP8[$137>>0]|0;
             $139 = ($138<<24>>24)==(59);
             if ($139) {
              $$sum57 = (($$0$i33$ph) + 2)|0;
              $140 = (($11) + ($$sum57)|0);
              $145 = $140;
              break;
             } else {
              $141 = $138&255;
              $142 = (_isalpha($141)|0);
              $143 = ($142|0)==(0);
              $s$$i = $143 ? $134 : $137;
              $145 = $s$$i;
              break;
             }
            } else {
             $145 = $134;
            }
           } while(0);
           $144 = HEAP8[$145>>0]|0;
           $146 = ($144<<24>>24)==(49);
           if ($146) {
            $147 = ((($145)) + 1|0);
            $148 = HEAP8[$147>>0]|0;
            $149 = ($148<<24>>24)==(48);
            if ($149) {
             $150 = ((($145)) + 2|0);
             $151 = HEAP8[$150>>0]|0;
             $152 = ($151<<24>>24)==(59);
             if ($152) {
              $210 = 1;
             } else {
              $153 = $151&255;
              $154 = (_isalpha($153)|0);
              $155 = ($154|0)==(0);
              if ($155) {
               break;
              }
              $$pre78 = HEAP8[$147>>0]|0;
              $phitmp = ($$pre78<<24>>24)==(48);
              $210 = $phitmp;
             }
             $156 = $145;
             $157 = (($156) - ($magicptr$i9))|0;
             $158 = (($157) + -1)|0;
             $159 = (($11) + ($158)|0);
             $160 = HEAP8[$159>>0]|0;
             $161 = ($160<<24>>24)==(59);
             $$ = $161 ? $158 : $157;
             do {
              if ($210) {
               $162 = HEAP8[$150>>0]|0;
               $163 = ($162<<24>>24)==(59);
               if ($163) {
                $164 = ((($145)) + 3|0);
                $169 = $164;
                break;
               } else {
                $165 = $162&255;
                $166 = (_isalpha($165)|0);
                $167 = ($166|0)==(0);
                $s$$i38 = $167 ? $147 : $150;
                $169 = $s$$i38;
                break;
               }
              } else {
               $169 = $147;
              }
             } while(0);
             $168 = HEAP8[$169>>0]|0;
             $170 = ($168<<24>>24)==(0);
             if ($170) {
              $$01$lcssa$i44 = $$;
             } else {
              $171 = $169;
              $172 = (($171) - ($magicptr$i9))|0;
              $$011$i42 = $$;$$02$i41 = $172;$176 = $168;
              while(1) {
               $173 = (($$02$i41) + 1)|0;
               $174 = (($$011$i42) + 1)|0;
               $175 = (($11) + ($$011$i42)|0);
               HEAP8[$175>>0] = $176;
               $177 = (($11) + ($173)|0);
               $178 = HEAP8[$177>>0]|0;
               $179 = ($178<<24>>24)==(0);
               if ($179) {
                $$01$lcssa$i44 = $174;
                break;
               } else {
                $$011$i42 = $174;$$02$i41 = $173;$176 = $178;
               }
              }
             }
             $180 = (($11) + ($$01$lcssa$i44)|0);
             HEAP8[$180>>0] = 0;
             $result$0 = $11;
             break L80;
            }
           }
          }
         }
        } while(0);
        $181 = (_strstr($15,$11)|0);
        $182 = ($181|0)==(0|0);
        if ($182) {
         $result$0 = $11;
        } else {
         $183 = (_strcmp($15,$11)|0);
         $184 = ($183|0)==(0);
         if ($184) {
          $result$0 = $11;
         } else {
          $185 = $181;
          $186 = (($185) - ($magicptr$i19))|0;
          $187 = (_strlen(($11|0))|0);
          $188 = (___strdup($15)|0);
          $189 = (($188) + ($187)|0);
          $190 = HEAP8[$189>>0]|0;
          $191 = ($190<<24>>24)==(0);
          if ($191) {
           $$01$lcssa$i50 = $186;
          } else {
           $$011$i48 = $186;$$02$i47 = $187;$195 = $190;
           while(1) {
            $192 = (($$02$i47) + 1)|0;
            $193 = (($$011$i48) + 1)|0;
            $194 = (($188) + ($$011$i48)|0);
            HEAP8[$194>>0] = $195;
            $196 = (($188) + ($192)|0);
            $197 = HEAP8[$196>>0]|0;
            $198 = ($197<<24>>24)==(0);
            if ($198) {
             $$01$lcssa$i50 = $193;
             break;
            } else {
             $$011$i48 = $193;$$02$i47 = $192;$195 = $197;
            }
           }
          }
          $199 = (($188) + ($$01$lcssa$i50)|0);
          HEAP8[$199>>0] = 0;
          _free($11);
          $result$0 = $188;
         }
        }
       }
      } while(0);
      $200 = HEAP32[$0>>2]|0;
      $201 = ((($200)) + 156|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = (_strcmp($result$0,$202)|0);
      $204 = ($203|0)==(0);
      if (!($204)) {
       $result$1 = $result$0;
       break;
      }
      _free($result$0);
      $205 = HEAP32[$0>>2]|0;
      $206 = ((($205)) + 156|0);
      $207 = HEAP32[$206>>2]|0;
      $result$1 = $207;
      break;
     }
    }
    _free($11);
    $result$1 = $3;
   }
  }
 } while(0);
 if ((label|0) == 27) {
  $62 = ($11|0)==(0|0);
  if ($62) {
   $result$1 = $3;
  } else {
   label = 28;
  }
 }
 if ((label|0) == 28) {
  _free($11);
  $result$1 = $3;
 }
 $208 = ($15|0)==(0|0);
 if (!($208)) {
  _free($15);
 }
 $209 = ($8|0)==(0|0);
 if ($209) {
  $result$2 = $result$1;
  STACKTOP = sp;return ($result$2|0);
 }
 _free($8);
 $result$2 = $result$1;
 STACKTOP = sp;return ($result$2|0);
}
function _similar_sgr($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $$0 = 0, $$0$i = 0, $$0$i8 = 0, $$04 = 0, $$pre = 0, $$sum = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond3 = 0, $or$cond6 = 0, $result$0$off0 = 0, $s$$i = 0, $s$$i10 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$a>>0]|0;
 if ((($0<<24>>24) == -23)) {
  $$0$i = 1;
 } else if ((($0<<24>>24) == 27)) {
  $1 = ((($a)) + 1|0);
  $2 = HEAP8[$1>>0]|0;
  $3 = ($2<<24>>24)==(91);
  if ($3) {
   $$0$i = 2;
  } else {
   label = 3;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $$0$i = 0;
 }
 $4 = HEAP8[$b>>0]|0;
 if ((($4<<24>>24) == 27)) {
  $5 = ((($b)) + 1|0);
  $6 = HEAP8[$5>>0]|0;
  $7 = ($6<<24>>24)==(91);
  if ($7) {
   $$0$i8 = 2;
   label = 6;
  } else {
   $$0 = $a;$$04 = $b;
  }
 } else if ((($4<<24>>24) == -23)) {
  $$0$i8 = 1;
  label = 6;
 } else {
  $$0 = $a;$$04 = $b;
 }
 do {
  if ((label|0) == 6) {
   $8 = ($$0$i|0)!=(0);
   $9 = ($$0$i|0)==($$0$i8|0);
   $or$cond6 = $8 & $9;
   if ($or$cond6) {
    $10 = (($a) + ($$0$i)|0);
    $11 = (($b) + ($$0$i)|0);
    $12 = HEAP8[$10>>0]|0;
    $13 = HEAP8[$11>>0]|0;
    $14 = ($12<<24>>24)==($13<<24>>24);
    if ($14) {
     $$0 = $10;$$04 = $11;
    } else {
     $15 = ($12<<24>>24)==(48);
     do {
      if ($15) {
       $$sum16 = (($$0$i) + 1)|0;
       $16 = (($a) + ($$sum16)|0);
       $17 = HEAP8[$16>>0]|0;
       $18 = ($17<<24>>24)==(59);
       if ($18) {
        $$sum17 = (($$0$i) + 2)|0;
        $19 = (($a) + ($$sum17)|0);
        $24 = $13;$41 = $19;
        break;
       } else {
        $20 = $17&255;
        $21 = (_isalpha($20)|0);
        $22 = ($21|0)==(0);
        $s$$i10 = $22 ? $10 : $16;
        $$pre = HEAP8[$11>>0]|0;
        $24 = $$pre;$41 = $s$$i10;
        break;
       }
      } else {
       $24 = $13;$41 = $10;
      }
     } while(0);
     $23 = ($24<<24>>24)==(48);
     if ($23) {
      $$sum = (($$0$i) + 1)|0;
      $25 = (($b) + ($$sum)|0);
      $26 = HEAP8[$25>>0]|0;
      $27 = ($26<<24>>24)==(59);
      if ($27) {
       $$sum15 = (($$0$i) + 2)|0;
       $28 = (($b) + ($$sum15)|0);
       $$0 = $41;$$04 = $28;
       break;
      } else {
       $29 = $26&255;
       $30 = (_isalpha($29)|0);
       $31 = ($30|0)==(0);
       $s$$i = $31 ? $11 : $25;
       $$0 = $41;$$04 = $s$$i;
       break;
      }
     } else {
      $$0 = $41;$$04 = $11;
     }
    }
   } else {
    $$0 = $a;$$04 = $b;
   }
  }
 } while(0);
 $32 = (_strlen(($$0|0))|0);
 $33 = (_strlen(($$04|0))|0);
 $34 = ($32|0)!=(0);
 $35 = ($33|0)!=(0);
 $or$cond3 = $34 & $35;
 if (!($or$cond3)) {
  $result$0$off0 = 0;
  return ($result$0$off0|0);
 }
 $36 = ($32>>>0)>($33>>>0);
 if ($36) {
  $37 = (_strncmp($$0,$$04,$33)|0);
  $38 = ($37|0)==(0);
  $result$0$off0 = $38;
  return ($result$0$off0|0);
 } else {
  $39 = (_strncmp($$0,$$04,$32)|0);
  $40 = ($39|0)==(0);
  $result$0$off0 = $40;
  return ($result$0$off0|0);
 }
 return (0)|0;
}
function __nc_err_abort($fmt,$varargs) {
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $argp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $argp = sp;
 _where_is_problem();
 HEAP32[$argp>>2] = $varargs;
 $0 = HEAP32[_stderr>>2]|0;
 (_vfprintf(($0|0),($fmt|0),($argp|0))|0);
 (_fputc(10,($0|0))|0);
 _exit(1);
 // unreachable;
}
function _where_is_problem() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[_stderr>>2]|0;
 $1 = HEAP32[(37652)>>2]|0;
 $2 = ($1|0)!=(0|0);
 $3 = $2 ? $1 : 37376;
 HEAP32[$vararg_buffer>>2] = $3;
 (_fprintf(($0|0),(37384|0),($vararg_buffer|0))|0);
 $4 = HEAP32[37360>>2]|0;
 $5 = ($4|0)>(-1);
 if ($5) {
  HEAP32[$vararg_buffer1>>2] = $4;
  (_fprintf(($0|0),(37392|0),($vararg_buffer1|0))|0);
 }
 $6 = HEAP32[37368>>2]|0;
 $7 = ($6|0)>(-1);
 if ($7) {
  HEAP32[$vararg_buffer4>>2] = $6;
  (_fprintf(($0|0),(37408|0),($vararg_buffer4|0))|0);
 }
 $8 = HEAP32[(37656)>>2]|0;
 $9 = ($8|0)==(0|0);
 if ($9) {
  (_fputc(58,($0|0))|0);
  (_fputc(32,($0|0))|0);
  STACKTOP = sp;return;
 }
 $10 = HEAP8[$8>>0]|0;
 $11 = ($10<<24>>24)==(0);
 if ($11) {
  (_fputc(58,($0|0))|0);
  (_fputc(32,($0|0))|0);
  STACKTOP = sp;return;
 }
 HEAP32[$vararg_buffer7>>2] = $8;
 (_fprintf(($0|0),(37424|0),($vararg_buffer7|0))|0);
 (_fputc(58,($0|0))|0);
 (_fputc(32,($0|0))|0);
 STACKTOP = sp;return;
}
function __nc_find_type_entry($string,$type,$termcap) {
 $string = $string|0;
 $type = $type|0;
 $termcap = $termcap|0;
 var $$pn = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ptr$0 = 0, $ptr$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__nc_get_hash_info($termcap)|0);
 $1 = ((($0)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = (FUNCTION_TABLE_ii[$2 & 511]($string)|0);
 $4 = $3 << 16 >> 16;
 $5 = ((($0)) + 4|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (($6) + ($4<<1)|0);
 $8 = HEAP16[$7>>1]|0;
 $9 = ($8<<16>>16)>(-1);
 if (!($9)) {
  $ptr$1 = 0;
  return ($ptr$1|0);
 }
 $10 = (__nc_get_table($termcap)|0);
 $11 = HEAP32[$5>>2]|0;
 $12 = (($11) + ($4<<1)|0);
 $13 = HEAP16[$12>>1]|0;
 $14 = $13 << 16 >> 16;
 $15 = ((($0)) + 12|0);
 $$pn = $14;
 while(1) {
  $ptr$0 = (($10) + (($$pn*12)|0)|0);
  $16 = (((($10) + (($$pn*12)|0)|0)) + 4|0);
  $17 = HEAP32[$16>>2]|0;
  $18 = ($17|0)==($type|0);
  if ($18) {
   $19 = HEAP32[$15>>2]|0;
   $20 = HEAP32[$ptr$0>>2]|0;
   $21 = (FUNCTION_TABLE_iii[$19 & 511]($20,$string)|0);
   $22 = ($21|0)==(0);
   if (!($22)) {
    $ptr$1 = $ptr$0;
    label = 7;
    break;
   }
  }
  $23 = (((($10) + (($$pn*12)|0)|0)) + 10|0);
  $24 = HEAP16[$23>>1]|0;
  $25 = ($24<<16>>16)<(0);
  if ($25) {
   $ptr$1 = 0;
   label = 7;
   break;
  }
  $26 = $24 << 16 >> 16;
  $27 = HEAP32[$0>>2]|0;
  $28 = HEAP32[$5>>2]|0;
  $29 = (($28) + ($27<<1)|0);
  $30 = HEAP16[$29>>1]|0;
  $31 = $30 << 16 >> 16;
  $32 = (($31) + ($26))|0;
  $$pn = $32;
 }
 if ((label|0) == 7) {
  return ($ptr$1|0);
 }
 return (0)|0;
}
function __nc_doalloc($oldp,$amount) {
 $oldp = $oldp|0;
 $amount = $amount|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $newp$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldp|0)==(0|0);
 if ($0) {
  $4 = (_malloc($amount)|0);
  $newp$0 = $4;
 } else {
  $1 = (_realloc($oldp,$amount)|0);
  $2 = ($1|0)==(0|0);
  if ($2) {
   _free($oldp);
   $3 = (___errno_location()|0);
   HEAP32[$3>>2] = 12;
   $newp$0 = 0;
  } else {
   $newp$0 = $1;
  }
 }
 return ($newp$0|0);
}
function __nc_baudrate($OSpeed) {
 $OSpeed = $OSpeed|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$lcssa = 0, $not$ = 0, $result$1 = 0, $result$2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37440>>2]|0;
 $1 = ($0|0)==($OSpeed|0);
 $2 = HEAP32[37448>>2]|0;
 $3 = ($2|0)==(-1);
 $not$ = $1 ^ 1;
 $4 = $3 | $not$;
 if (!($4)) {
  $result$2 = $2;
  return ($result$2|0);
 }
 $5 = ($OSpeed|0)>(-1);
 L4: do {
  if ($5) {
   $6 = ($OSpeed|0)==(0);
   do {
    if ($6) {
     $i$02$lcssa = 0;
    } else {
     $9 = ($OSpeed|0)==(1);
     if ($9) {
      $i$02$lcssa = 1;
     } else {
      $10 = ($OSpeed|0)==(2);
      if ($10) {
       $i$02$lcssa = 2;
      } else {
       $11 = ($OSpeed|0)==(3);
       if ($11) {
        $i$02$lcssa = 3;
       } else {
        $12 = ($OSpeed|0)==(4);
        if ($12) {
         $i$02$lcssa = 4;
        } else {
         $13 = ($OSpeed|0)==(5);
         if ($13) {
          $i$02$lcssa = 5;
         } else {
          $14 = ($OSpeed|0)==(6);
          if ($14) {
           $i$02$lcssa = 6;
          } else {
           $15 = ($OSpeed|0)==(7);
           if ($15) {
            $i$02$lcssa = 7;
           } else {
            $16 = ($OSpeed|0)==(8);
            if ($16) {
             $i$02$lcssa = 8;
            } else {
             $17 = ($OSpeed|0)==(9);
             if ($17) {
              $i$02$lcssa = 9;
             } else {
              $18 = ($OSpeed|0)==(10);
              if ($18) {
               $i$02$lcssa = 10;
              } else {
               $19 = ($OSpeed|0)==(11);
               if ($19) {
                $i$02$lcssa = 11;
               } else {
                $20 = ($OSpeed|0)==(12);
                if ($20) {
                 $i$02$lcssa = 12;
                } else {
                 $21 = ($OSpeed|0)==(13);
                 if ($21) {
                  $i$02$lcssa = 13;
                 } else {
                  $22 = ($OSpeed|0)==(14);
                  if ($22) {
                   $i$02$lcssa = 14;
                  } else {
                   $23 = ($OSpeed|0)==(15);
                   if ($23) {
                    $i$02$lcssa = 15;
                   } else {
                    $24 = ($OSpeed|0)==(4097);
                    if ($24) {
                     $i$02$lcssa = 16;
                     break;
                    }
                    $25 = ($OSpeed|0)==(4098);
                    if ($25) {
                     $i$02$lcssa = 17;
                     break;
                    }
                    $26 = ($OSpeed|0)==(4099);
                    if ($26) {
                     $i$02$lcssa = 18;
                     break;
                    }
                    $27 = ($OSpeed|0)==(4100);
                    if ($27) {
                     $i$02$lcssa = 19;
                     break;
                    }
                    $28 = ($OSpeed|0)==(4103);
                    if ($28) {
                     $i$02$lcssa = 20;
                    } else {
                     $result$1 = -1;
                     break L4;
                    }
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   } while(0);
   $7 = (((37456 + ($i$02$lcssa<<3)|0)) + 4|0);
   $8 = HEAP32[$7>>2]|0;
   $result$1 = $8;
  } else {
   $result$1 = -1;
  }
 } while(0);
 if (!($1)) {
  $result$2 = $result$1;
  return ($result$2|0);
 }
 HEAP32[37440>>2] = $OSpeed;
 HEAP32[37448>>2] = $result$1;
 $result$2 = $result$1;
 return ($result$2|0);
}
function __nc_ospeed($BaudRate) {
 $BaudRate = $BaudRate|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$02$lcssa = 0, $result$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($BaudRate|0)>(-1);
 if (!($0)) {
  $result$0 = 1;
  return ($result$0|0);
 }
 $1 = ($BaudRate|0)==(0);
 do {
  if ($1) {
   $i$02$lcssa = 0;
  } else {
   $4 = ($BaudRate|0)==(50);
   if ($4) {
    $i$02$lcssa = 1;
   } else {
    $5 = ($BaudRate|0)==(75);
    if ($5) {
     $i$02$lcssa = 2;
    } else {
     $6 = ($BaudRate|0)==(110);
     if ($6) {
      $i$02$lcssa = 3;
     } else {
      $7 = ($BaudRate|0)==(134);
      if ($7) {
       $i$02$lcssa = 4;
      } else {
       $8 = ($BaudRate|0)==(150);
       if ($8) {
        $i$02$lcssa = 5;
       } else {
        $9 = ($BaudRate|0)==(200);
        if ($9) {
         $i$02$lcssa = 6;
        } else {
         $10 = ($BaudRate|0)==(300);
         if ($10) {
          $i$02$lcssa = 7;
         } else {
          $11 = ($BaudRate|0)==(600);
          if ($11) {
           $i$02$lcssa = 8;
          } else {
           $12 = ($BaudRate|0)==(1200);
           if ($12) {
            $i$02$lcssa = 9;
           } else {
            $13 = ($BaudRate|0)==(1800);
            if ($13) {
             $i$02$lcssa = 10;
            } else {
             $14 = ($BaudRate|0)==(2400);
             if ($14) {
              $i$02$lcssa = 11;
             } else {
              $15 = ($BaudRate|0)==(4800);
              if ($15) {
               $i$02$lcssa = 12;
              } else {
               $16 = ($BaudRate|0)==(9600);
               if ($16) {
                $i$02$lcssa = 13;
               } else {
                $17 = ($BaudRate|0)==(19200);
                if ($17) {
                 $i$02$lcssa = 14;
                } else {
                 $18 = ($BaudRate|0)==(38400);
                 if ($18) {
                  $i$02$lcssa = 15;
                 } else {
                  $19 = ($BaudRate|0)==(57600);
                  if ($19) {
                   $i$02$lcssa = 16;
                  } else {
                   $20 = ($BaudRate|0)==(115200);
                   if ($20) {
                    $i$02$lcssa = 17;
                   } else {
                    $21 = ($BaudRate|0)==(230400);
                    if ($21) {
                     $i$02$lcssa = 18;
                     break;
                    }
                    $22 = ($BaudRate|0)==(460800);
                    if ($22) {
                     $i$02$lcssa = 19;
                     break;
                    }
                    $23 = ($BaudRate|0)==(921600);
                    if ($23) {
                     $i$02$lcssa = 20;
                     break;
                    } else {
                     $result$0 = 1;
                    }
                    return ($result$0|0);
                   }
                  }
                 }
                }
               }
              }
             }
            }
           }
          }
         }
        }
       }
      }
     }
    }
   }
  }
 } while(0);
 $2 = (37456 + ($i$02$lcssa<<3)|0);
 $3 = HEAP32[$2>>2]|0;
 $result$0 = $3;
 return ($result$0|0);
}
function _baudrate() {
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $result$0 = 0, $sext = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $result$0 = -1;
  return ($result$0|0);
 }
 $2 = ((($0)) + 104|0);
 $3 = (_cfgetospeed(($2|0))|0);
 $4 = $3&65535;
 HEAP16[37304>>1] = $4;
 $sext = $3 << 16;
 $5 = $sext >> 16;
 $6 = (__nc_baudrate($5)|0);
 $7 = HEAP32[37624>>2]|0;
 $8 = ((($7)) + 164|0);
 HEAP32[$8>>2] = $6;
 $result$0 = $6;
 return ($result$0|0);
}
function _set_curterm($termp) {
 $termp = $termp|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = HEAP32[37632>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  $3 = ((($1)) + 20|0);
  HEAP32[$3>>2] = $termp;
 }
 HEAP32[37624>>2] = $termp;
 $4 = ($termp|0)==(0|0);
 if ($4) {
  return ($0|0);
 }
 $5 = ((($termp)) + 164|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = (__nc_ospeed($6)|0);
 $8 = $7&65535;
 HEAP16[37304>>1] = $8;
 $9 = ((($termp)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if ($11) {
  return ($0|0);
 }
 $12 = ((($10)) + 416|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if ($14) {
  $16 = 0;
 } else {
  $15 = HEAP8[$13>>0]|0;
  $16 = $15;
 }
 HEAP8[37296>>0] = $16;
 return ($0|0);
}
function _del_curterm($termp) {
 $termp = $termp|0;
 var $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $rc$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($termp|0)==(0|0);
 if ($0) {
  $rc$0 = -1;
  return ($rc$0|0);
 }
 $1 = HEAP32[37624>>2]|0;
 __nc_free_termtype($termp);
 $2 = ($1|0)==($termp|0);
 if ($2) {
  $3 = HEAP32[37632>>2]|0;
  $4 = ($3|0)==(0|0);
  if (!($4)) {
   $5 = ((($3)) + 20|0);
   HEAP32[$5>>2] = 0;
  }
  HEAP32[37624>>2] = 0;
 }
 $6 = ((($termp)) + 168|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _free($7);
 }
 $9 = HEAP32[(37788)>>2]|0;
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  _free($9);
 }
 HEAP32[(37788)>>2] = 0;
 _free($termp);
 $rc$0 = 0;
 return ($rc$0|0);
}
function _napms($ms) {
 $ms = $ms|0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 (__nc_timed_wait(0,0,$ms,0)|0);
 return 0;
}
function __nc_get_screensize($sp,$linep,$colp) {
 $sp = $sp|0;
 $linep = $linep|0;
 $colp = $colp|0;
 var $$pre = 0, $$pre1 = 0, $$pre2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $7 = 0, $8 = 0, $9 = 0, $my_tabsize$0 = 0, $size = 0, $vararg_buffer = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer = sp;
 $size = sp + 8|0;
 $0 = HEAP32[37624>>2]|0;
 $1 = ((($0)) + 12|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($2)) + 4|0);
 $4 = HEAP16[$3>>1]|0;
 $5 = $4 << 16 >> 16;
 HEAP32[$linep>>2] = $5;
 $6 = HEAP16[$2>>1]|0;
 $7 = $6 << 16 >> 16;
 HEAP32[$colp>>2] = $7;
 $8 = HEAP8[37800>>0]|0;
 $9 = ($8<<24>>24)==(0);
 if ($9) {
  $60 = $2;
  $59 = ((($60)) + 2|0);
  $61 = HEAP16[$59>>1]|0;
  $62 = ($61<<16>>16)>(-1);
  $63 = $61 << 16 >> 16;
  $my_tabsize$0 = $62 ? $63 : 8;
  HEAP32[38560>>2] = $my_tabsize$0;
  STACKTOP = sp;return;
 }
 $10 = ((($0)) + 40|0);
 $11 = HEAP16[$10>>1]|0;
 $12 = $11 << 16 >> 16;
 $13 = (_isatty(($12|0))|0);
 $14 = ($13|0)==(0);
 L4: do {
  if (!($14)) {
   $15 = (___errno_location()|0);
   HEAP32[$15>>2] = 0;
   while(1) {
    $16 = HEAP32[37624>>2]|0;
    $17 = ((($16)) + 40|0);
    $18 = HEAP16[$17>>1]|0;
    $19 = $18 << 16 >> 16;
    HEAP32[$vararg_buffer>>2] = $size;
    $20 = (_ioctl(($19|0),21523,($vararg_buffer|0))|0);
    $21 = ($20|0)>(-1);
    if ($21) {
     break;
    }
    $32 = HEAP32[$15>>2]|0;
    $33 = ($32|0)==(4);
    if (!($33)) {
     break L4;
    }
   }
   $22 = ($sp|0)==(0|0);
   if ($22) {
    label = 7;
   } else {
    $23 = ((($sp)) + 12|0);
    $24 = HEAP8[$23>>0]|0;
    $25 = ($24<<24>>24)==(0);
    if ($25) {
     label = 7;
    } else {
     $28 = 1;
    }
   }
   if ((label|0) == 7) {
    $26 = HEAP16[$size>>1]|0;
    $27 = $26&65535;
    $28 = $27;
   }
   HEAP32[$linep>>2] = $28;
   $29 = ((($size)) + 2|0);
   $30 = HEAP16[$29>>1]|0;
   $31 = $30&65535;
   HEAP32[$colp>>2] = $31;
  }
 } while(0);
 $34 = (__nc_getenv_num(38568)|0);
 $35 = ($34|0)>(0);
 if ($35) {
  HEAP32[$linep>>2] = $34;
 }
 $36 = (__nc_getenv_num(38576)|0);
 $37 = ($36|0)>(0);
 if ($37) {
  HEAP32[$colp>>2] = $36;
 }
 $38 = HEAP32[$linep>>2]|0;
 $39 = ($38|0)<(1);
 if ($39) {
  $40 = HEAP32[$1>>2]|0;
  $41 = ((($40)) + 4|0);
  $42 = HEAP16[$41>>1]|0;
  $43 = $42 << 16 >> 16;
  HEAP32[$linep>>2] = $43;
  $64 = $43;
 } else {
  $64 = $38;
 }
 $44 = HEAP32[$colp>>2]|0;
 $45 = ($44|0)<(1);
 if ($45) {
  $46 = HEAP32[$1>>2]|0;
  $47 = HEAP16[$46>>1]|0;
  $48 = $47 << 16 >> 16;
  HEAP32[$colp>>2] = $48;
  $$pre = HEAP32[$linep>>2]|0;
  $50 = $$pre;$65 = $48;
 } else {
  $50 = $64;$65 = $44;
 }
 $49 = ($50|0)<(1);
 if ($49) {
  HEAP32[$linep>>2] = 24;
  $$pre1 = HEAP32[$colp>>2]|0;
  $52 = $$pre1;$66 = 24;
 } else {
  $52 = $65;$66 = $50;
 }
 $51 = ($52|0)<(1);
 if ($51) {
  HEAP32[$colp>>2] = 80;
  $$pre2 = HEAP32[$linep>>2]|0;
  $54 = $$pre2;$58 = 80;
 } else {
  $54 = $66;$58 = $52;
 }
 $53 = $54&65535;
 $55 = HEAP32[$1>>2]|0;
 $56 = ((($55)) + 4|0);
 HEAP16[$56>>1] = $53;
 $57 = $58&65535;
 HEAP16[$55>>1] = $57;
 $60 = $55;
 $59 = ((($60)) + 2|0);
 $61 = HEAP16[$59>>1]|0;
 $62 = ($61<<16>>16)>(-1);
 $63 = $61 << 16 >> 16;
 $my_tabsize$0 = $62 ? $63 : 8;
 HEAP32[38560>>2] = $my_tabsize$0;
 STACKTOP = sp;return;
}
function __nc_setupterm($tname,$Filedes,$errret,$reuse) {
 $tname = $tname|0;
 $Filedes = $Filedes|0;
 $errret = $errret|0;
 $reuse = $reuse|0;
 var $$0 = 0, $$02 = 0, $$03 = 0, $$Filedes = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0;
 var $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0;
 var $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $9 = 0, $i$02$i = 0, $or$cond = 0, $termp$0 = 0, $tmp$01$i = 0, $vararg_buffer = 0, $vararg_buffer1 = 0, $vararg_buffer4 = 0, $vararg_buffer7 = 0, dest = 0, label = 0;
 var sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $vararg_buffer7 = sp + 24|0;
 $vararg_buffer4 = sp + 16|0;
 $vararg_buffer1 = sp + 8|0;
 $vararg_buffer = sp;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($tname|0)==(0|0);
 do {
  if ($1) {
   $2 = (_getenv((38592|0))|0);
   $3 = ($2|0)==(0|0);
   if (!($3)) {
    $4 = HEAP8[$2>>0]|0;
    $5 = ($4<<24>>24)==(0);
    if (!($5)) {
     $$02 = $2;
     break;
    }
   }
   $6 = ($errret|0)==(0|0);
   if ($6) {
    $7 = HEAP32[_stderr>>2]|0;
    (_fwrite((38600|0),35,1,($7|0))|0);
    _exit(1);
    // unreachable;
   }
   HEAP32[$errret>>2] = -1;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  } else {
   $$02 = $tname;
  }
 } while(0);
 $8 = (_strlen(($$02|0))|0);
 $9 = ($8>>>0)>(512);
 if ($9) {
  $10 = ($errret|0)==(0|0);
  if ($10) {
   $11 = HEAP32[_stderr>>2]|0;
   HEAP32[$vararg_buffer>>2] = 512;
   (_fprintf(($11|0),(38640|0),($vararg_buffer|0))|0);
   _exit(1);
   // unreachable;
  }
  HEAP32[$errret>>2] = -1;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $12 = ($Filedes|0)==(1);
 if ($12) {
  $13 = (_isatty(1)|0);
  $14 = ($13|0)==(0);
  $$Filedes = $14 ? 2 : 1;
  $$03 = $$Filedes;
 } else {
  $$03 = $Filedes;
 }
 $15 = ($0|0)!=(0|0);
 $or$cond = $15 & $reuse;
 if ($or$cond) {
  $16 = ((($0)) + 40|0);
  $17 = HEAP16[$16>>1]|0;
  $18 = $17 << 16 >> 16;
  $19 = ($18|0)==($$03|0);
  if ($19) {
   $20 = ((($0)) + 168|0);
   $21 = HEAP32[$20>>2]|0;
   $22 = ($21|0)==(0|0);
   if ($22) {
    label = 18;
   } else {
    $23 = (_strcmp($21,$$02)|0);
    $24 = ($23|0)==(0);
    if ($24) {
     $25 = HEAP32[$0>>2]|0;
     $26 = (__nc_name_match($25,$$02,58760)|0);
     $27 = ($26|0)==(0);
     if ($27) {
      label = 18;
     } else {
      $termp$0 = $0;
     }
    } else {
     label = 18;
    }
   }
  } else {
   label = 18;
  }
 } else {
  label = 18;
 }
 if ((label|0) == 18) {
  $28 = (_calloc(1,172)|0);
  $29 = ($28|0)==(0|0);
  if ($29) {
   $30 = ($errret|0)==(0|0);
   if ($30) {
    $31 = HEAP32[_stderr>>2]|0;
    (_fwrite((38688|0),48,1,($31|0))|0);
    _exit(1);
    // unreachable;
   }
   HEAP32[$errret>>2] = -1;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  $32 = (__nc_fallback($$02)|0);
  $33 = ($32|0)==(0|0);
  if ($33) {
   (_del_curterm($28)|0);
   $34 = ($errret|0)==(0|0);
   if ($34) {
    $35 = HEAP32[_stderr>>2]|0;
    HEAP32[$vararg_buffer1>>2] = $$02;
    (_fprintf(($35|0),(38744|0),($vararg_buffer1|0))|0);
    _exit(1);
    // unreachable;
   }
   HEAP32[$errret>>2] = 0;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
  dest=$28; src=$32; stop=dest+40|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
  $36 = HEAP32[$28>>2]|0;
  (_strncpy((38288|0),($36|0),255)|0);
  HEAP8[(38543)>>0] = 0;
  $37 = $$03&65535;
  $38 = ((($28)) + 40|0);
  HEAP16[$38>>1] = $37;
  $39 = (___strdup($$02)|0);
  $40 = ((($28)) + 168|0);
  HEAP32[$40>>2] = $39;
  (_set_curterm($28)|0);
  $41 = ((($28)) + 16|0);
  $42 = HEAP32[$41>>2]|0;
  $43 = ((($42)) + 36|0);
  $44 = HEAP32[$43>>2]|0;
  $45 = ($44|0)==(0|0);
  L42: do {
   if (!($45)) {
    $46 = HEAP8[$44>>0]|0;
    $47 = (_getenv((38584|0))|0);
    $48 = ($47|0)==(0|0);
    if (!($48)) {
     $49 = (_strlen(($47|0))|0);
     $50 = ($49|0)==(1);
     if ($50) {
      $51 = HEAP8[$47>>0]|0;
      $52 = ((($28)) + 32|0);
      $53 = HEAP16[$52>>1]|0;
      $54 = ($53<<16>>16)==(0);
      if (!($54)) {
       $56 = $42;$83 = $53;$i$02$i = 0;
       while(1) {
        $55 = (($56) + ($i$02$i<<2)|0);
        $57 = HEAP32[$55>>2]|0;
        $58 = HEAP8[$57>>0]|0;
        $59 = ($58<<24>>24)==(0);
        if ($59) {
         $67 = $83;
        } else {
         $61 = $58;$tmp$01$i = $57;
         while(1) {
          $60 = ($61<<24>>24)==($46<<24>>24);
          if ($60) {
           HEAP8[$tmp$01$i>>0] = $51;
          }
          $62 = ((($tmp$01$i)) + 1|0);
          $63 = HEAP8[$62>>0]|0;
          $64 = ($63<<24>>24)==(0);
          if ($64) {
           break;
          } else {
           $61 = $63;$tmp$01$i = $62;
          }
         }
         $$pre6 = HEAP16[$52>>1]|0;
         $67 = $$pre6;
        }
        $65 = (($i$02$i) + 1)|0;
        $66 = $67&65535;
        $68 = ($65>>>0)<($66>>>0);
        if (!($68)) {
         break L42;
        }
        $$pre = HEAP32[$41>>2]|0;
        $56 = $$pre;$83 = $67;$i$02$i = $65;
       }
      }
     }
    }
   }
  } while(0);
  $69 = (_isatty(($$03|0))|0);
  $70 = ($69|0)==(0);
  if ($70) {
   $termp$0 = $28;
  } else {
   (_def_prog_mode()|0);
   (_baudrate()|0);
   $termp$0 = $28;
  }
 }
 $71 = HEAP32[37632>>2]|0;
 __nc_get_screensize($71,38544,38552);
 $72 = ($errret|0)!=(0|0);
 if ($72) {
  HEAP32[$errret>>2] = 1;
 }
 $73 = ((($termp$0)) + 8|0);
 $74 = HEAP32[$73>>2]|0;
 $75 = ((($74)) + 6|0);
 $76 = HEAP8[$75>>0]|0;
 $77 = ($76<<24>>24)==(0);
 if (!($77)) {
  if (!($72)) {
   $78 = HEAP32[_stderr>>2]|0;
   HEAP32[$vararg_buffer4>>2] = $$02;
   (_fprintf(($78|0),(38776|0),($vararg_buffer4|0))|0);
   _exit(1);
   // unreachable;
  }
  HEAP32[$errret>>2] = 0;
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $79 = ((($74)) + 7|0);
 $80 = HEAP8[$79>>0]|0;
 $81 = ($80<<24>>24)==(0);
 if ($81) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 if (!($72)) {
  $82 = HEAP32[_stderr>>2]|0;
  HEAP32[$vararg_buffer7>>2] = $$02;
  (_fprintf(($82|0),(38816|0),($vararg_buffer7|0))|0);
  _exit(1);
  // unreachable;
 }
 HEAP32[$errret>>2] = 1;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _def_prog_mode() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $rc$0 = 0, dest = 0, label = 0, sp = 0;
 var stop = 0;
 sp = STACKTOP;
 $0 = HEAP32[37624>>2]|0;
 $1 = ($0|0)==(0|0);
 if ($1) {
  $rc$0 = -1;
  return ($rc$0|0);
 }
 $2 = ((($0)) + 104|0);
 $3 = HEAP32[37632>>2]|0;
 $4 = ($3|0)==(0|0);
 if ($4) {
  $rc$0 = -1;
  return ($rc$0|0);
 }
 $5 = ((($0)) + 40|0);
 while(1) {
  $6 = HEAP16[$5>>1]|0;
  $7 = $6 << 16 >> 16;
  $8 = (_tcgetattr(($7|0),($2|0))|0);
  $9 = ($8|0)==(0);
  if ($9) {
   label = 7;
   break;
  }
  $10 = (___errno_location()|0);
  $11 = HEAP32[$10>>2]|0;
  $12 = ($11|0)==(4);
  if (!($12)) {
   label = 6;
   break;
  }
 }
 if ((label|0) == 6) {
  dest=$2; stop=dest+60|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
  $rc$0 = -1;
  return ($rc$0|0);
 }
 else if ((label|0) == 7) {
  $13 = ((($0)) + 108|0);
  $14 = HEAP32[$13>>2]|0;
  $15 = $14 & -6145;
  HEAP32[$13>>2] = $15;
  $rc$0 = 0;
  return ($rc$0|0);
 }
 return (0)|0;
}
function __nc_timed_wait($sp,$mode,$milliseconds,$timeleft) {
 $sp = $sp|0;
 $mode = $mode|0;
 $milliseconds = $milliseconds|0;
 $timeleft = $timeleft|0;
 var $$ = 0, $$0 = 0, $$pre$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $8 = 0, $9 = 0, $count$0 = 0, $count$1 = 0, $not$ = 0, $ntimeout = 0, $result$0 = 0, $result$1 = 0;
 var $result$1$ = 0, $result$2 = 0, $set = 0, $t1$i = 0, $t1$i1 = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 160|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $t1$i1 = sp + 8|0;
 $t1$i = sp;
 $set = sp + 24|0;
 $ntimeout = sp + 16|0;
 (_gettimeofday(($t1$i|0),(0|0))|0);
 $0 = $t1$i;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 dest=$set; stop=dest+128|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $6 = $mode & 1;
 $7 = ($6|0)!=(0);
 if ($7) {
  $8 = HEAP32[$sp>>2]|0;
  $9 = $8 & 31;
  $10 = 1 << $9;
  $11 = $8 >>> 5;
  $12 = (($set) + ($11<<2)|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = $10 | $13;
  HEAP32[$12>>2] = $14;
  $15 = (($8) + 1)|0;
  $count$0 = $15;
 } else {
  $count$0 = 0;
 }
 $16 = $mode & 2;
 $17 = ($16|0)!=(0);
 if ($17) {
  $18 = ((($sp)) + 960|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = ($19|0)>(-1);
  if ($20) {
   $21 = $19 & 31;
   $22 = 1 << $21;
   $23 = $19 >>> 5;
   $24 = (($set) + ($23<<2)|0);
   $25 = HEAP32[$24>>2]|0;
   $26 = $25 | $22;
   HEAP32[$24>>2] = $26;
   $27 = ($19|0)<($count$0|0);
   $28 = $27 ? $count$0 : $19;
   $29 = (($28) + 1)|0;
   $count$1 = $29;
  } else {
   $count$1 = $count$0;
  }
 } else {
  $count$1 = $count$0;
 }
 $30 = ($milliseconds|0)>(-1);
 if ($30) {
  $31 = (($milliseconds|0) / 1000)&-1;
  HEAP32[$ntimeout>>2] = $31;
  $32 = (($milliseconds|0) % 1000)&-1;
  $33 = ($32*1000)|0;
  $34 = ((($ntimeout)) + 4|0);
  HEAP32[$34>>2] = $33;
  $35 = (_select(($count$1|0),($set|0),(0|0),(0|0),($ntimeout|0))|0);
  $result$0 = $35;
 } else {
  $36 = (_select(($count$1|0),($set|0),(0|0),(0|0),(0|0))|0);
  $result$0 = $36;
 }
 (_gettimeofday(($t1$i1|0),(0|0))|0);
 $37 = ((($t1$i1)) + 4|0);
 $38 = HEAP32[$37>>2]|0;
 $39 = ($5|0)>($38|0);
 if ($39) {
  $40 = (($38) + 1000000)|0;
  HEAP32[$37>>2] = $40;
  $41 = HEAP32[$t1$i1>>2]|0;
  $42 = (($41) + -1)|0;
  HEAP32[$t1$i1>>2] = $42;
  $45 = $40;$48 = $42;
 } else {
  $$pre$i = HEAP32[$t1$i1>>2]|0;
  $45 = $38;$48 = $$pre$i;
 }
 $43 = ($timeleft|0)==(0|0);
 if (!($43)) {
  $44 = (($45) - ($5))|0;
  $46 = (($44|0) / 1000)&-1;
  $47 = (($48) - ($2))|0;
  $49 = ($47*1000)|0;
  $50 = (($46) + ($49))|0;
  $51 = $30 ? $50 : 0;
  $$0 = (($milliseconds) - ($51))|0;
  HEAP32[$timeleft>>2] = $$0;
 }
 $52 = ($result$0|0)>(0);
 if (!($52)) {
  $result$2 = 0;
  STACKTOP = sp;return ($result$2|0);
 }
 if ($17) {
  $53 = ((($sp)) + 960|0);
  $54 = HEAP32[$53>>2]|0;
  $55 = ($54|0)>(-1);
  if ($55) {
   $56 = $54 >>> 5;
   $57 = (($set) + ($56<<2)|0);
   $58 = HEAP32[$57>>2]|0;
   $59 = $54 & 31;
   $60 = 1 << $59;
   $61 = $58 & $60;
   $62 = ($61|0)==(0);
   $$ = $62 ? 0 : 2;
   $result$1 = $$;
  } else {
   $result$1 = 0;
  }
 } else {
  $result$1 = 0;
 }
 if (!($7)) {
  $result$2 = $result$1;
  STACKTOP = sp;return ($result$2|0);
 }
 $63 = HEAP32[$sp>>2]|0;
 $64 = $63 >>> 5;
 $65 = (($set) + ($64<<2)|0);
 $66 = HEAP32[$65>>2]|0;
 $67 = $63 & 31;
 $68 = 1 << $67;
 $69 = $68 & $66;
 $not$ = ($69|0)!=(0);
 $70 = $not$&1;
 $result$1$ = $70 | $result$1;
 $result$2 = $result$1$;
 STACKTOP = sp;return ($result$2|0);
}
function __nc_name_match($namelst,$name,$delim) {
 $namelst = $namelst|0;
 $name = $name|0;
 $delim = $delim|0;
 var $$0 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0;
 var $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $code$019 = 0, $code$019$lcssa = 0, $code$0833 = 0, $d$01043 = 0, $s$0 = 0;
 var $s$1$lcssa = 0, $s$1944 = 0, $s$217 = 0, $s$217$lcssa = 0, $s$217$us = 0, $s$2631 = 0, $s$2634 = 0, $t$015 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($namelst|0)==(0|0);
 if ($0) {
  $$0 = 0;
  return ($$0|0);
 } else {
  $s$0 = $namelst;
 }
 while(1) {
  $1 = HEAP8[$s$0>>0]|0;
  $2 = ($1<<24>>24)==(0);
  if ($2) {
   $$0 = 0;
   label = 17;
   break;
  }
  $3 = HEAP8[$name>>0]|0;
  $4 = ($3<<24>>24)==(0);
  L6: do {
   if ($4) {
    $29 = 0;$s$1$lcssa = $s$0;
   } else {
    $5 = ($1<<24>>24)==($3<<24>>24);
    if ($5) {
     $d$01043 = $name;$s$1944 = $s$0;
     while(1) {
      $13 = ((($s$1944)) + 1|0);
      $14 = ((($d$01043)) + 1|0);
      $15 = HEAP8[$14>>0]|0;
      $16 = ($15<<24>>24)==(0);
      if ($16) {
       $29 = 0;$s$1$lcssa = $13;
       break L6;
      }
      $$pre = HEAP8[$13>>0]|0;
      $17 = ($$pre<<24>>24)==($15<<24>>24);
      if ($17) {
       $d$01043 = $14;$s$1944 = $13;
      } else {
       $29 = $15;$s$1$lcssa = $13;
       break;
      }
     }
    } else {
     $29 = $3;$s$1$lcssa = $s$0;
    }
   }
  } while(0);
  $6 = HEAP8[$s$1$lcssa>>0]|0;
  $7 = ($6<<24>>24)==(0);
  L12: do {
   if ($7) {
    $code$0833 = 1;$s$2634 = $s$1$lcssa;
    label = 15;
   } else {
    $8 = HEAP8[$delim>>0]|0;
    $9 = ($8<<24>>24)==(0);
    if ($9) {
     $s$217$us = $s$1$lcssa;
     while(1) {
      $10 = ((($s$217$us)) + 1|0);
      $11 = HEAP8[$10>>0]|0;
      $12 = ($11<<24>>24)==(0);
      if ($12) {
       $s$2631 = $10;
       break L12;
      } else {
       $s$217$us = $10;
      }
     }
    } else {
     $22 = $6;$code$019 = 1;$s$217 = $s$1$lcssa;
    }
    L17: while(1) {
     $23 = $8;$t$015 = $delim;
     while(1) {
      $21 = ($22<<24>>24)==($23<<24>>24);
      $19 = ((($t$015)) + 1|0);
      if ($21) {
       $code$019$lcssa = $code$019;$s$217$lcssa = $s$217;
       break L17;
      }
      $18 = HEAP8[$19>>0]|0;
      $20 = ($18<<24>>24)==(0);
      if ($20) {
       break;
      } else {
       $23 = $18;$t$015 = $19;
      }
     }
     $24 = ((($s$217)) + 1|0);
     $25 = HEAP8[$24>>0]|0;
     $26 = ($25<<24>>24)==(0);
     if ($26) {
      $s$2631 = $24;
      break L12;
     } else {
      $22 = $25;$code$019 = 0;$s$217 = $24;
     }
    }
    $27 = ($code$019$lcssa|0)==(0);
    if ($27) {
     $s$2631 = $s$217$lcssa;
    } else {
     $code$0833 = $code$019$lcssa;$s$2634 = $s$217$lcssa;
     label = 15;
    }
   }
  } while(0);
  if ((label|0) == 15) {
   label = 0;
   $28 = ($29<<24>>24)==(0);
   if ($28) {
    $$0 = $code$0833;
    label = 17;
    break;
   } else {
    $s$2631 = $s$2634;
   }
  }
  $30 = ((($s$2631)) + 1|0);
  $31 = HEAP8[$s$2631>>0]|0;
  $32 = ($31<<24>>24)==(0);
  if ($32) {
   $$0 = 0;
   label = 17;
   break;
  } else {
   $s$0 = $30;
  }
 }
 if ((label|0) == 17) {
  return ($$0|0);
 }
 return (0)|0;
}
function __nc_get_table($termcap) {
 $termcap = $termcap|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $exitcond$i = 0, $exitcond$i2 = 0, $n$01$i = 0, $n$01$i1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 if ($termcap) {
  $0 = HEAP32[38864>>2]|0;
  $1 = ($0|0)==(0|0);
  if (!($1)) {
   $44 = $0;
   return ($44|0);
  }
  $2 = (_calloc(497,12)|0);
  HEAP32[38864>>2] = $2;
  $3 = ($2|0)==(0|0);
  if ($3) {
   $44 = $2;
   return ($44|0);
  } else {
   $5 = 0;$7 = $2;$n$01$i = 0;
  }
  while(1) {
   $4 = (38872 + ($5)|0);
   $6 = (($7) + (($n$01$i*12)|0)|0);
   HEAP32[$6>>2] = $4;
   $8 = (((40368 + (($n$01$i*12)|0)|0)) + 4|0);
   $9 = HEAP32[$8>>2]|0;
   $10 = HEAP32[38864>>2]|0;
   $11 = (((($10) + (($n$01$i*12)|0)|0)) + 4|0);
   HEAP32[$11>>2] = $9;
   $12 = (((40368 + (($n$01$i*12)|0)|0)) + 8|0);
   $13 = HEAP16[$12>>1]|0;
   $14 = (((($10) + (($n$01$i*12)|0)|0)) + 8|0);
   HEAP16[$14>>1] = $13;
   $15 = (((40368 + (($n$01$i*12)|0)|0)) + 10|0);
   $16 = HEAP16[$15>>1]|0;
   $17 = (((($10) + (($n$01$i*12)|0)|0)) + 10|0);
   HEAP16[$17>>1] = $16;
   $18 = (_strlen(($4|0))|0);
   $19 = (($5) + 1)|0;
   $20 = (($19) + ($18))|0;
   $21 = (($n$01$i) + 1)|0;
   $exitcond$i = ($21|0)==(497);
   if ($exitcond$i) {
    $44 = $10;
    break;
   } else {
    $5 = $20;$7 = $10;$n$01$i = $21;
   }
  }
  return ($44|0);
 } else {
  $22 = HEAP32[46336>>2]|0;
  $23 = ($22|0)==(0|0);
  if (!($23)) {
   $44 = $22;
   return ($44|0);
  }
  $24 = (_calloc(497,12)|0);
  HEAP32[46336>>2] = $24;
  $25 = ($24|0)==(0|0);
  if ($25) {
   $44 = $24;
   return ($44|0);
  } else {
   $27 = 0;$29 = $24;$n$01$i1 = 0;
  }
  while(1) {
   $26 = (46344 + ($27)|0);
   $28 = (($29) + (($n$01$i1*12)|0)|0);
   HEAP32[$28>>2] = $26;
   $30 = (((48736 + (($n$01$i1*12)|0)|0)) + 4|0);
   $31 = HEAP32[$30>>2]|0;
   $32 = HEAP32[46336>>2]|0;
   $33 = (((($32) + (($n$01$i1*12)|0)|0)) + 4|0);
   HEAP32[$33>>2] = $31;
   $34 = (((48736 + (($n$01$i1*12)|0)|0)) + 8|0);
   $35 = HEAP16[$34>>1]|0;
   $36 = (((($32) + (($n$01$i1*12)|0)|0)) + 8|0);
   HEAP16[$36>>1] = $35;
   $37 = (((48736 + (($n$01$i1*12)|0)|0)) + 10|0);
   $38 = HEAP16[$37>>1]|0;
   $39 = (((($32) + (($n$01$i1*12)|0)|0)) + 10|0);
   HEAP16[$39>>1] = $38;
   $40 = (_strlen(($26|0))|0);
   $41 = (($27) + 1)|0;
   $42 = (($41) + ($40))|0;
   $43 = (($n$01$i1) + 1)|0;
   $exitcond$i2 = ($43|0)==(497);
   if ($exitcond$i2) {
    $44 = $32;
    break;
   } else {
    $27 = $42;$29 = $32;$n$01$i1 = $43;
   }
  }
  return ($44|0);
 }
 return (0)|0;
}
function __nc_get_hash_info($termcap) {
 $termcap = $termcap|0;
 var $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $termcap&1;
 $1 = (58688 + ($0<<4)|0);
 return ($1|0);
}
function _info_hash($string) {
 $string = $string|0;
 var $$01 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $phitmp = 0, $phitmp3 = 0, $sum$0$lcssa = 0, $sum$02 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$string>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $sum$0$lcssa = 0;
  return ($sum$0$lcssa|0);
 } else {
  $$01 = $string;$3 = $0;$sum$02 = 0;
 }
 while(1) {
  $2 = $3 << 24 >> 24;
  $4 = ((($$01)) + 1|0);
  $5 = HEAP8[$4>>0]|0;
  $6 = $5 << 24 >> 24;
  $7 = $6 << 8;
  $8 = (($2) + ($sum$02))|0;
  $9 = (($8) + ($7))|0;
  $10 = ($5<<24>>24)==(0);
  if ($10) {
   $$lcssa = $9;
   break;
  } else {
   $$01 = $4;$3 = $5;$sum$02 = $9;
  }
 }
 $phitmp = (($$lcssa|0) % 994)&-1;
 $phitmp3 = $phitmp&65535;
 $sum$0$lcssa = $phitmp3;
 return ($sum$0$lcssa|0);
}
function _compare_info_names($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp($a,$b)|0);
 $1 = ($0|0)==(0);
 $2 = $1&1;
 return ($2|0);
}
function _tcap_hash($string) {
 $string = $string|0;
 var $$01$i = 0, $$lcssa = 0, $$pre$phiZ2D = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0;
 var $9 = 0, $limit$1 = 0, $phitmp$i = 0, $phitmp3$i = 0, $sum$0$lcssa$i = 0, $sum$02$i = 0, $temp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $temp = sp;
 $0 = HEAP8[$string>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$pre$phiZ2D = $temp;$limit$1 = 0;
 } else {
  $2 = ((($string)) + 1|0);
  HEAP8[$temp>>0] = $0;
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if ($4) {
   $$pre$phiZ2D = $temp;$limit$1 = 1;
  } else {
   $17 = ((($temp)) + 1|0);
   HEAP8[$17>>0] = $3;
   $$pre$phiZ2D = $temp;$limit$1 = 2;
  }
 }
 $5 = (($temp) + ($limit$1)|0);
 HEAP8[$5>>0] = 0;
 $6 = HEAP8[$$pre$phiZ2D>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $sum$0$lcssa$i = 0;
  STACKTOP = sp;return ($sum$0$lcssa$i|0);
 } else {
  $$01$i = $$pre$phiZ2D;$9 = $6;$sum$02$i = 0;
 }
 while(1) {
  $8 = $9 << 24 >> 24;
  $10 = ((($$01$i)) + 1|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11 << 24 >> 24;
  $13 = $12 << 8;
  $14 = (($8) + ($sum$02$i))|0;
  $15 = (($14) + ($13))|0;
  $16 = ($11<<24>>24)==(0);
  if ($16) {
   $$lcssa = $15;
   break;
  } else {
   $$01$i = $10;$9 = $11;$sum$02$i = $15;
  }
 }
 $phitmp$i = (($$lcssa|0) % 994)&-1;
 $phitmp3$i = $phitmp$i&65535;
 $sum$0$lcssa$i = $phitmp3$i;
 STACKTOP = sp;return ($sum$0$lcssa$i|0);
}
function _compare_tcap_names($a,$b) {
 $a = $a|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strncmp($a,$b,2)|0);
 $1 = ($0|0)==(0);
 $2 = $1&1;
 return ($2|0);
}
function __nc_fallback($name) {
 $name = $name|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (__nc_name_match(58720,$name,58760)|0);
 $1 = ($0|0)==(0);
 if (!($1)) {
  $$0 = 58816;
  return ($$0|0);
 }
 $2 = (__nc_name_match(58768,$name,58760)|0);
 $3 = ($2|0)==(0);
 $$ = $3 ? 0 : (58856);
 $$0 = $$;
 return ($$0|0);
}
function __nc_free_termtype($ptr) {
 $ptr = $ptr|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, dest = 0;
 var label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 $0 = ((($ptr)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if (!($2)) {
  _free($1);
 }
 $3 = ((($ptr)) + 8|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = ($4|0)==(0|0);
 if (!($5)) {
  _free($4);
 }
 $6 = ((($ptr)) + 12|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ($7|0)==(0|0);
 if (!($8)) {
  _free($7);
 }
 $9 = ((($ptr)) + 16|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = ($10|0)==(0|0);
 if (!($11)) {
  _free($10);
 }
 $12 = ((($ptr)) + 20|0);
 $13 = HEAP32[$12>>2]|0;
 $14 = ($13|0)==(0|0);
 if (!($14)) {
  _free($13);
 }
 $15 = ((($ptr)) + 24|0);
 $16 = HEAP32[$15>>2]|0;
 $17 = ($16|0)==(0|0);
 if (!($17)) {
  _free($16);
 }
 dest=$ptr; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $18 = HEAP32[65232>>2]|0;
 __nc_free_entry($18,$ptr);
 return;
}
function __nc_getenv_num($name) {
 $name = $name|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $dst = 0, $value$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $dst = sp;
 HEAP32[$dst>>2] = 0;
 $0 = (_getenv(($name|0))|0);
 $1 = ($0|0)==(0|0);
 if (!($1)) {
  $2 = (_strtol($0,$dst,0)|0);
  $3 = ($2|0)<(0);
  if (!($3)) {
   $4 = HEAP32[$dst>>2]|0;
   $5 = ($4|0)==($0|0);
   if (!($5)) {
    $6 = HEAP8[$4>>0]|0;
    $7 = ($6<<24>>24)==(0);
    if ($7) {
     $value$0 = $2;
     STACKTOP = sp;return ($value$0|0);
    }
   }
  }
 }
 $value$0 = -1;
 STACKTOP = sp;return ($value$0|0);
}
function __nc_free_entry($headp,$tterm) {
 $headp = $headp|0;
 $tterm = $tterm|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $ep$04$i = 0, $ep$04$i$lcssa = 0, $last$05$i = 0, $last$05$i$lcssa = 0, $last$05$i$phi = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($headp|0)==(0|0);
 if ($0) {
  return;
 } else {
  $ep$04$i = $headp;$last$05$i = 0;
 }
 while(1) {
  $1 = ($ep$04$i|0)==($tterm|0);
  if ($1) {
   $ep$04$i$lcssa = $ep$04$i;$last$05$i$lcssa = $last$05$i;
   break;
  }
  $12 = ((($ep$04$i)) + 508|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ($13|0)==(0|0);
  if ($14) {
   label = 11;
   break;
  } else {
   $last$05$i$phi = $ep$04$i;$ep$04$i = $13;$last$05$i = $last$05$i$phi;
  }
 }
 if ((label|0) == 11) {
  return;
 }
 $2 = ($last$05$i$lcssa|0)==(0|0);
 if (!($2)) {
  $3 = ((($ep$04$i$lcssa)) + 508|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ((($last$05$i$lcssa)) + 508|0);
  HEAP32[$5>>2] = $4;
 }
 $6 = HEAP32[65232>>2]|0;
 $7 = ($ep$04$i$lcssa|0)==($6|0);
 if ($7) {
  $8 = ((($ep$04$i$lcssa)) + 508|0);
  $9 = HEAP32[$8>>2]|0;
  HEAP32[65232>>2] = $9;
 }
 $10 = HEAP32[65240>>2]|0;
 $11 = ($ep$04$i$lcssa|0)==($10|0);
 if ($11) {
  HEAP32[65240>>2] = $last$05$i$lcssa;
 }
 _free($ep$04$i$lcssa);
 return;
}
function _isalnum($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $isdigit = 0, $isdigittmp = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_isalpha($c)|0);
 $isdigittmp = (($c) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 $not$ = ($0|0)!=(0);
 $1 = $isdigit | $not$;
 $2 = $1&1;
 return ($2|0);
}
function _isalpha($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c | 32;
 $1 = (($0) + -97)|0;
 $2 = ($1>>>0)<(26);
 $3 = $2&1;
 return ($3|0);
}
function _iscntrl($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c>>>0)<(32);
 $1 = ($c|0)==(127);
 $2 = $0 | $1;
 $3 = $2&1;
 return ($3|0);
}
function _isgraph($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -33)|0;
 $1 = ($0>>>0)<(94);
 $2 = $1&1;
 return ($2|0);
}
function _islower($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -97)|0;
 $1 = ($0>>>0)<(26);
 $2 = $1&1;
 return ($2|0);
}
function _isprint($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -32)|0;
 $1 = ($0>>>0)<(95);
 $2 = $1&1;
 return ($2|0);
}
function _ispunct($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_isgraph($c)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $5 = 0;
 } else {
  $2 = (_isalnum($c)|0);
  $3 = ($2|0)==(0);
  $5 = $3;
 }
 $4 = $5&1;
 return ($4|0);
}
function _iswalnum($wc) {
 $wc = $wc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_iswdigit($wc)|0);
 $1 = ($0|0)==(0);
 if ($1) {
  $2 = (_iswalpha($wc)|0);
  $3 = ($2|0)!=(0);
  $5 = $3;
 } else {
  $5 = 1;
 }
 $4 = $5&1;
 return ($4|0);
}
function _iswalpha($wc) {
 $wc = $wc|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($wc>>>0)<(131072);
 if ($0) {
  $1 = $wc >>> 8;
  $2 = (65456 + ($1)|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = $3&255;
  $5 = $4 << 5;
  $6 = $wc >>> 3;
  $7 = $6 & 31;
  $8 = $5 | $7;
  $9 = (65456 + ($8)|0);
  $10 = HEAP8[$9>>0]|0;
  $11 = $10&255;
  $12 = $wc & 7;
  $13 = $11 >>> $12;
  $14 = $13 & 1;
  $$0 = $14;
  return ($$0|0);
 } else {
  $15 = ($wc>>>0)<(196606);
  $$ = $15&1;
  $$0 = $$;
  return ($$0|0);
 }
 return (0)|0;
}
function _iswdigit($wc) {
 $wc = $wc|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($wc) + -48)|0;
 $1 = ($0>>>0)<(10);
 $2 = $1&1;
 return ($2|0);
}
function _iswlower($wc) {
 $wc = $wc|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_towupper($wc)|0);
 $1 = ($0|0)!=($wc|0);
 $2 = ($wc|0)==(223);
 $3 = $2 | $1;
 $4 = $3&1;
 return ($4|0);
}
function _iswupper($wc) {
 $wc = $wc|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_towlower($wc)|0);
 $1 = ($0|0)!=($wc|0);
 $2 = $1&1;
 return ($2|0);
}
function _toupper($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_islower($c)|0);
 $1 = ($0|0)==(0);
 $2 = $c & 95;
 $$0 = $1 ? $c : $2;
 return ($$0|0);
}
function _towupper($wc) {
 $wc = $wc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___towcase($wc,0)|0);
 return ($0|0);
}
function _towlower($wc) {
 $wc = $wc|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___towcase($wc,1)|0);
 return ($0|0);
}
function _wcwidth($wc) {
 $wc = $wc|0;
 var $$ = 0, $$0 = 0, $$4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0;
 var $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($wc>>>0)<(255);
 if ($0) {
  $1 = (($wc) + 1)|0;
  $2 = $1 & 127;
  $3 = ($2>>>0)>(32);
  $4 = ($wc|0)!=(0);
  $5 = $4 << 31 >> 31;
  $6 = $3 ? 1 : $5;
  $$0 = $6;
  return ($$0|0);
 }
 $7 = $wc & -65538;
 $8 = ($7>>>0)<(65534);
 if ($8) {
  $9 = $wc >> 8;
  $10 = (68432 + ($9)|0);
  $11 = HEAP8[$10>>0]|0;
  $12 = $11&255;
  $13 = $12 << 5;
  $14 = $wc >>> 3;
  $15 = $14 & 31;
  $16 = $13 | $15;
  $17 = (68432 + ($16)|0);
  $18 = HEAP8[$17>>0]|0;
  $19 = $18&255;
  $20 = $wc & 7;
  $21 = 1 << $20;
  $22 = $19 & $21;
  $23 = ($22|0)==(0);
  if (!($23)) {
   $$0 = 0;
   return ($$0|0);
  }
  $24 = (70352 + ($9)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25&255;
  $27 = $26 << 5;
  $28 = $27 | $15;
  $29 = (70352 + ($28)|0);
  $30 = HEAP8[$29>>0]|0;
  $31 = $30&255;
  $32 = $31 & $21;
  $33 = ($32|0)==(0);
  $$ = $33 ? 1 : 2;
  $$0 = $$;
  return ($$0|0);
 }
 $34 = $wc & 65534;
 $35 = ($34|0)==(65534);
 if ($35) {
  $$0 = -1;
  return ($$0|0);
 }
 $36 = $wc & -131072;
 $37 = ($36|0)==(131072);
 if ($37) {
  $$0 = 2;
  return ($$0|0);
 } else {
  $38 = ($wc|0)==(917505);
  $39 = (($wc) + -917536)|0;
  $40 = ($39>>>0)<(95);
  $or$cond = $38 | $40;
  $41 = (($wc) + -917760)|0;
  $42 = ($41|0)<(239);
  $or$cond3 = $42 | $or$cond;
  $43 = $or$cond3&1;
  $$4 = $43 ^ 1;
  return ($$4|0);
 }
 return (0)|0;
}
function _strcoll($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcmp($l,$r)|0);
 return ($0|0);
}
function _ldexp($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_scalbn($x,$n));
 return (+$0);
}
function _mbrlen($s,$n,$st) {
 $s = $s|0;
 $n = $n|0;
 $st = $st|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($st|0)!=(0|0);
 $1 = $0 ? $st : 71408;
 $2 = (_mbrtowc(0,$s,$n,$1)|0);
 return ($2|0);
}
function _mbrtowc($wc,$src,$n,$st) {
 $wc = $wc|0;
 $src = $src|0;
 $n = $n|0;
 $st = $st|0;
 var $$0 = 0, $$023 = 0, $$1 = 0, $$lcssa = 0, $$lcssa34 = 0, $$st = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0;
 var $4 = 0, $40 = 0, $41 = 0, $42 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c$04 = 0, $c$1 = 0, $c$2 = 0, $s$05 = 0, $s$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $0 = sp;
 HEAP32[$0>>2] = $wc;
 $1 = ($st|0)==(0|0);
 $$st = $1 ? 71416 : $st;
 $2 = HEAP32[$$st>>2]|0;
 $3 = ($src|0)==(0|0);
 L1: do {
  if ($3) {
   $4 = ($2|0)==(0);
   if ($4) {
    $$0 = 0;
    STACKTOP = sp;return ($$0|0);
   }
  } else {
   $5 = ($wc|0)==(0|0);
   if ($5) {
    HEAP32[$0>>2] = $0;
    $11 = $0;
   } else {
    $11 = $wc;
   }
   $6 = ($n|0)==(0);
   if ($6) {
    $$0 = -2;
    STACKTOP = sp;return ($$0|0);
   }
   $7 = ($2|0)==(0);
   do {
    if ($7) {
     $8 = HEAP8[$src>>0]|0;
     $9 = $8&255;
     $10 = ($8<<24>>24)>(-1);
     if ($10) {
      HEAP32[$11>>2] = $9;
      $12 = ($8<<24>>24)!=(0);
      $13 = $12&1;
      $$0 = $13;
      STACKTOP = sp;return ($$0|0);
     } else {
      $14 = (($9) + -194)|0;
      $15 = ($14>>>0)>(50);
      if ($15) {
       break L1;
      }
      $16 = ((($src)) + 1|0);
      $17 = (65248 + ($14<<2)|0);
      $18 = HEAP32[$17>>2]|0;
      $19 = (($n) + -1)|0;
      $20 = ($19|0)==(0);
      if ($20) {
       $c$2 = $18;
       break;
      } else {
       $$023 = $19;$c$04 = $18;$s$05 = $16;
       label = 11;
       break;
      }
     }
    } else {
     $$023 = $n;$c$04 = $2;$s$05 = $src;
     label = 11;
    }
   } while(0);
   L16: do {
    if ((label|0) == 11) {
     $21 = HEAP8[$s$05>>0]|0;
     $22 = $21&255;
     $23 = $22 >>> 3;
     $24 = (($23) + -16)|0;
     $25 = $c$04 >> 26;
     $26 = (($23) + ($25))|0;
     $27 = $24 | $26;
     $28 = ($27>>>0)>(7);
     if ($28) {
      break L1;
     } else {
      $$1 = $$023;$32 = $21;$c$1 = $c$04;$s$1 = $s$05;
     }
     while(1) {
      $29 = $c$1 << 6;
      $30 = ((($s$1)) + 1|0);
      $31 = $32&255;
      $33 = (($31) + -128)|0;
      $34 = $33 | $29;
      $35 = (($$1) + -1)|0;
      $36 = ($34|0)<(0);
      if (!($36)) {
       $$lcssa = $34;$$lcssa34 = $35;
       break;
      }
      $38 = ($35|0)==(0);
      if ($38) {
       $c$2 = $34;
       break L16;
      }
      $39 = HEAP8[$30>>0]|0;
      $40 = $39 & -64;
      $41 = ($40<<24>>24)==(-128);
      if ($41) {
       $$1 = $35;$32 = $39;$c$1 = $34;$s$1 = $30;
      } else {
       break L1;
      }
     }
     HEAP32[$$st>>2] = 0;
     HEAP32[$11>>2] = $$lcssa;
     $37 = (($n) - ($$lcssa34))|0;
     $$0 = $37;
     STACKTOP = sp;return ($$0|0);
    }
   } while(0);
   HEAP32[$$st>>2] = $c$2;
   $$0 = -2;
   STACKTOP = sp;return ($$0|0);
  }
 } while(0);
 HEAP32[$$st>>2] = 0;
 $42 = (___errno_location()|0);
 HEAP32[$42>>2] = 84;
 $$0 = -1;
 STACKTOP = sp;return ($$0|0);
}
function _qsort($base,$nel,$width,$cmp) {
 $base = $base|0;
 $nel = $nel|0;
 $width = $width|0;
 $cmp = $cmp|0;
 var $$ = 0, $$0$be$i = 0, $$0$be$i19 = 0, $$0$i44 = 0, $$01$be$i = 0, $$01$be$i18 = 0, $$012$i = 0, $$012$i15 = 0, $$02$i$i = 0, $$02$i3$i = 0, $$02$us$i = 0, $$02$us$i30 = 0, $$03$i = 0, $$03$i14 = 0, $$66 = 0, $$67 = 0, $$lcssa = 0, $$lcssa102 = 0, $$lcssa70 = 0, $$lcssa71 = 0;
 var $$pre = 0, $$pre$i = 0, $$pre$i21 = 0, $$pre6$i = 0, $$pre6$i26 = 0, $$sum = 0, $$sum$i = 0, $$sum$i17 = 0, $$sum2 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0;
 var $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0;
 var $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0;
 var $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0;
 var $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0;
 var $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $4$phi = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0;
 var $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0;
 var $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0;
 var $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $ar$i = 0;
 var $exitcond$i = 0, $exitcond$i29 = 0, $head$0$lcssa = 0, $head$076 = 0, $head$174 = 0, $i$0 = 0, $i$0$lcssa$i = 0, $i$0$lcssa$i23 = 0, $i$01$us$i = 0, $i$01$us$i28 = 0, $i$04$i = 0, $i$04$i13 = 0, $lp = 0, $nTrailingZeros$03$i$i = 0, $nTrailingZeros$03$i2$i = 0, $nTrailingZeros$03$i2$i$lcssa = 0, $or$cond = 0, $or$cond68 = 0, $or$cond6873 = 0, $or$cond72 = 0;
 var $pshift$0$lcssa = 0, $pshift$077 = 0, $pshift$1 = 0, $pshift$275 = 0, $sum = 0, $sum$i = 0, $sum$i16 = 0, $tmp$i = 0, $tmp$i25 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 944|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $tmp$i25 = sp + 680|0;
 $tmp$i = sp + 424|0;
 $ar$i = sp + 192|0;
 $lp = sp;
 $0 = Math_imul($width, $nel)|0;
 $1 = ($0|0)==(0);
 if ($1) {
  STACKTOP = sp;return;
 }
 $$sum = (($0) - ($width))|0;
 $2 = ((($lp)) + 4|0);
 HEAP32[$2>>2] = $width;
 HEAP32[$lp>>2] = $width;
 $4 = $width;$6 = $width;$i$0 = 2;
 while(1) {
  $3 = (($4) + ($width))|0;
  $5 = (($3) + ($6))|0;
  $7 = (($lp) + ($i$0<<2)|0);
  HEAP32[$7>>2] = $5;
  $8 = ($5>>>0)<($0>>>0);
  $9 = (($i$0) + 1)|0;
  if ($8) {
   $4$phi = $6;$6 = $5;$i$0 = $9;$4 = $4$phi;
  } else {
   break;
  }
 }
 $10 = (0 - ($width))|0;
 $11 = (($base) + ($$sum)|0);
 $12 = ($$sum|0)>(0);
 if ($12) {
  $13 = ($width|0)==(0);
  $14 = $11;
  $16 = 1;$51 = 0;$head$076 = $base;$pshift$077 = 1;
  while(1) {
   $15 = $16 & 3;
   $17 = ($15|0)==(3);
   do {
    if ($17) {
     HEAP32[$ar$i>>2] = $head$076;
     $18 = ($pshift$077|0)>(1);
     L42: do {
      if ($18) {
       $$012$i = $pshift$077;$$03$i = $head$076;$24 = $head$076;$i$04$i = 1;
       while(1) {
        $19 = (($$03$i) + ($10)|0);
        $20 = (($$012$i) + -2)|0;
        $21 = (($lp) + ($20<<2)|0);
        $22 = HEAP32[$21>>2]|0;
        $sum$i = (($22) + ($width))|0;
        $$sum$i = (0 - ($sum$i))|0;
        $23 = (($$03$i) + ($$sum$i)|0);
        $25 = (FUNCTION_TABLE_iii[$cmp & 511]($24,$23)|0);
        $26 = ($25|0)>(-1);
        if ($26) {
         $27 = (FUNCTION_TABLE_iii[$cmp & 511]($24,$19)|0);
         $28 = ($27|0)>(-1);
         if ($28) {
          $i$0$lcssa$i = $i$04$i;
          break;
         }
        }
        $29 = (FUNCTION_TABLE_iii[$cmp & 511]($23,$19)|0);
        $30 = ($29|0)>(-1);
        $31 = (($i$04$i) + 1)|0;
        $32 = (($ar$i) + ($i$04$i<<2)|0);
        if ($30) {
         HEAP32[$32>>2] = $23;
         $33 = (($$012$i) + -1)|0;
         $$0$be$i = $23;$$01$be$i = $33;
        } else {
         HEAP32[$32>>2] = $19;
         $$0$be$i = $19;$$01$be$i = $20;
        }
        $34 = ($$01$be$i|0)>(1);
        if (!($34)) {
         $i$0$lcssa$i = $31;
         break;
        }
        $$pre$i = HEAP32[$ar$i>>2]|0;
        $$012$i = $$01$be$i;$$03$i = $$0$be$i;$24 = $$pre$i;$i$04$i = $31;
       }
       $35 = ($i$0$lcssa$i|0)<(2);
       if (!($35)) {
        $36 = (($ar$i) + ($i$0$lcssa$i<<2)|0);
        HEAP32[$36>>2] = $tmp$i;
        if (!($13)) {
         $$02$us$i = $width;$48 = $tmp$i;
         while(1) {
          $46 = ($$02$us$i>>>0)>(256);
          $38 = $46 ? 256 : $$02$us$i;
          $47 = HEAP32[$ar$i>>2]|0;
          _memcpy(($48|0),($47|0),($38|0))|0;
          $44 = $47;$i$01$us$i = 0;
          while(1) {
           $40 = (($ar$i) + ($i$01$us$i<<2)|0);
           $41 = (($i$01$us$i) + 1)|0;
           $42 = (($ar$i) + ($41<<2)|0);
           $43 = HEAP32[$42>>2]|0;
           _memcpy(($44|0),($43|0),($38|0))|0;
           $45 = (($44) + ($38)|0);
           HEAP32[$40>>2] = $45;
           $exitcond$i = ($41|0)==($i$0$lcssa$i|0);
           if ($exitcond$i) {
            break;
           } else {
            $44 = $43;$i$01$us$i = $41;
           }
          }
          $37 = ($$02$us$i|0)==($38|0);
          if ($37) {
           break L42;
          }
          $39 = (($$02$us$i) - ($38))|0;
          $$pre6$i = HEAP32[$36>>2]|0;
          $$02$us$i = $39;$48 = $$pre6$i;
         }
        }
       }
      } else {
      }
     } while(0);
     $49 = $16 >>> 2;
     $50 = $51 << 30;
     $52 = $49 | $50;
     $53 = $51 >>> 2;
     $54 = (($pshift$077) + 2)|0;
     $105 = $52;$168 = $53;$pshift$1 = $54;
    } else {
     $55 = (($pshift$077) + -1)|0;
     $56 = (($lp) + ($55<<2)|0);
     $57 = HEAP32[$56>>2]|0;
     $58 = $head$076;
     $59 = (($14) - ($58))|0;
     $60 = ($57>>>0)<($59>>>0);
     if ($60) {
      HEAP32[$ar$i>>2] = $head$076;
      $61 = ($pshift$077|0)>(1);
      L16: do {
       if ($61) {
        $$012$i15 = $pshift$077;$$03$i14 = $head$076;$67 = $head$076;$i$04$i13 = 1;
        while(1) {
         $62 = (($$03$i14) + ($10)|0);
         $63 = (($$012$i15) + -2)|0;
         $64 = (($lp) + ($63<<2)|0);
         $65 = HEAP32[$64>>2]|0;
         $sum$i16 = (($65) + ($width))|0;
         $$sum$i17 = (0 - ($sum$i16))|0;
         $66 = (($$03$i14) + ($$sum$i17)|0);
         $68 = (FUNCTION_TABLE_iii[$cmp & 511]($67,$66)|0);
         $69 = ($68|0)>(-1);
         if ($69) {
          $70 = (FUNCTION_TABLE_iii[$cmp & 511]($67,$62)|0);
          $71 = ($70|0)>(-1);
          if ($71) {
           $i$0$lcssa$i23 = $i$04$i13;
           break;
          }
         }
         $72 = (FUNCTION_TABLE_iii[$cmp & 511]($66,$62)|0);
         $73 = ($72|0)>(-1);
         $74 = (($i$04$i13) + 1)|0;
         $75 = (($ar$i) + ($i$04$i13<<2)|0);
         if ($73) {
          HEAP32[$75>>2] = $66;
          $76 = (($$012$i15) + -1)|0;
          $$0$be$i19 = $66;$$01$be$i18 = $76;
         } else {
          HEAP32[$75>>2] = $62;
          $$0$be$i19 = $62;$$01$be$i18 = $63;
         }
         $77 = ($$01$be$i18|0)>(1);
         if (!($77)) {
          $i$0$lcssa$i23 = $74;
          break;
         }
         $$pre$i21 = HEAP32[$ar$i>>2]|0;
         $$012$i15 = $$01$be$i18;$$03$i14 = $$0$be$i19;$67 = $$pre$i21;$i$04$i13 = $74;
        }
        $78 = ($i$0$lcssa$i23|0)<(2);
        if (!($78)) {
         $79 = (($ar$i) + ($i$0$lcssa$i23<<2)|0);
         HEAP32[$79>>2] = $tmp$i25;
         if (!($13)) {
          $$02$us$i30 = $width;$91 = $tmp$i25;
          while(1) {
           $89 = ($$02$us$i30>>>0)>(256);
           $81 = $89 ? 256 : $$02$us$i30;
           $90 = HEAP32[$ar$i>>2]|0;
           _memcpy(($91|0),($90|0),($81|0))|0;
           $87 = $90;$i$01$us$i28 = 0;
           while(1) {
            $83 = (($ar$i) + ($i$01$us$i28<<2)|0);
            $84 = (($i$01$us$i28) + 1)|0;
            $85 = (($ar$i) + ($84<<2)|0);
            $86 = HEAP32[$85>>2]|0;
            _memcpy(($87|0),($86|0),($81|0))|0;
            $88 = (($87) + ($81)|0);
            HEAP32[$83>>2] = $88;
            $exitcond$i29 = ($84|0)==($i$0$lcssa$i23|0);
            if ($exitcond$i29) {
             break;
            } else {
             $87 = $86;$i$01$us$i28 = $84;
            }
           }
           $80 = ($$02$us$i30|0)==($81|0);
           if ($80) {
            break L16;
           }
           $82 = (($$02$us$i30) - ($81))|0;
           $$pre6$i26 = HEAP32[$79>>2]|0;
           $$02$us$i30 = $82;$91 = $$pre6$i26;
          }
         }
        }
       } else {
       }
      } while(0);
     } else {
      _trinkle($head$076,$width,$cmp,$16,$51,$pshift$077,0,$lp);
     }
     $92 = ($pshift$077|0)==(1);
     if ($92) {
      $93 = $51 << 1;
      $94 = $16 >>> 31;
      $95 = $94 | $93;
      $96 = $16 << 1;
      $105 = $96;$168 = $95;$pshift$1 = 0;
      break;
     } else {
      $97 = ($55>>>0)>(31);
      $98 = (($pshift$077) + -33)|0;
      $$ = $97 ? 0 : $16;
      $$66 = $97 ? $16 : $51;
      $$67 = $97 ? $98 : $55;
      $99 = $$66 << $$67;
      $100 = (32 - ($$67))|0;
      $101 = $$ >>> $100;
      $102 = $101 | $99;
      $103 = $$ << $$67;
      $105 = $103;$168 = $102;$pshift$1 = 1;
      break;
     }
    }
   } while(0);
   $104 = $105 | 1;
   $106 = (($head$076) + ($width)|0);
   $107 = ($106>>>0)<($11>>>0);
   if ($107) {
    $16 = $104;$51 = $168;$head$076 = $106;$pshift$077 = $pshift$1;
   } else {
    $$lcssa70 = $168;$$lcssa71 = $104;$head$0$lcssa = $106;$pshift$0$lcssa = $pshift$1;
    break;
   }
  }
 } else {
  $$lcssa70 = 0;$$lcssa71 = 1;$head$0$lcssa = $base;$pshift$0$lcssa = 1;
 }
 _trinkle($head$0$lcssa,$width,$cmp,$$lcssa71,$$lcssa70,$pshift$0$lcssa,0,$lp);
 $108 = ($pshift$0$lcssa|0)==(1);
 $109 = ($$lcssa71|0)==(1);
 $or$cond72 = $109 & $108;
 $110 = ($$lcssa70|0)==(0);
 $or$cond6873 = $110 & $or$cond72;
 if ($or$cond6873) {
  STACKTOP = sp;return;
 } else {
  $113 = $$lcssa71;$123 = $$lcssa70;$head$174 = $head$0$lcssa;$pshift$275 = $pshift$0$lcssa;
 }
 while(1) {
  $111 = ($pshift$275|0)<(2);
  if (!($111)) {
   $136 = $123 << 2;
   $137 = $113 >>> 30;
   $138 = $137 | $136;
   $139 = (($pshift$275) + -2)|0;
   $140 = $113 << 1;
   $141 = $140 & 2147483646;
   $142 = $137 << 31;
   $143 = $141 | $142;
   $144 = $143 ^ 3;
   $145 = $138 >>> 1;
   $146 = (($lp) + ($139<<2)|0);
   $147 = HEAP32[$146>>2]|0;
   $sum = (($147) + ($width))|0;
   $$sum2 = (0 - ($sum))|0;
   $148 = (($head$174) + ($$sum2)|0);
   $149 = (($pshift$275) + -1)|0;
   _trinkle($148,$width,$cmp,$144,$145,$149,1,$lp);
   $150 = $145 << 1;
   $151 = $137 & 1;
   $152 = $150 | $151;
   $153 = $144 << 1;
   $154 = $153 | 1;
   $155 = (($head$174) + ($10)|0);
   _trinkle($155,$width,$cmp,$154,$152,$139,1,$lp);
   $113 = $154;$123 = $152;$head$174 = $155;$pshift$275 = $139;
   continue;
  }
  $112 = (($113) + -1)|0;
  $114 = ($112|0)==(0);
  do {
   if ($114) {
    $135 = 32;
    label = 56;
   } else {
    $115 = $112 & 1;
    $116 = ($115|0)==(0);
    if ($116) {
     $$02$i$i = $112;$nTrailingZeros$03$i$i = 0;
     while(1) {
      $117 = (($nTrailingZeros$03$i$i) + 1)|0;
      $118 = $$02$i$i >>> 1;
      $119 = $118 & 1;
      $120 = ($119|0)==(0);
      if ($120) {
       $$02$i$i = $118;$nTrailingZeros$03$i$i = $117;
      } else {
       $$lcssa = $117;
       break;
      }
     }
     $121 = ($$lcssa|0)==(0);
     if ($121) {
      label = 51;
     } else {
      $133 = $$lcssa;
     }
    } else {
     label = 51;
    }
    if ((label|0) == 51) {
     label = 0;
     $122 = ($123|0)==(0);
     if ($122) {
      $135 = 64;
      label = 56;
      break;
     }
     $124 = $123 & 1;
     $125 = ($124|0)==(0);
     if ($125) {
      $$02$i3$i = $123;$nTrailingZeros$03$i2$i = 0;
     } else {
      $$0$i44 = 0;$157 = $113;$160 = $123;$164 = 0;
      break;
     }
     while(1) {
      $126 = (($nTrailingZeros$03$i2$i) + 1)|0;
      $127 = $$02$i3$i >>> 1;
      $128 = $127 & 1;
      $129 = ($128|0)==(0);
      if ($129) {
       $$02$i3$i = $127;$nTrailingZeros$03$i2$i = $126;
      } else {
       $$lcssa102 = $126;$nTrailingZeros$03$i2$i$lcssa = $nTrailingZeros$03$i2$i;
       break;
      }
     }
     $130 = (($nTrailingZeros$03$i2$i$lcssa) + 33)|0;
     $131 = ($$lcssa102|0)==(0);
     if ($131) {
      $$0$i44 = 0;$157 = $113;$160 = $123;$164 = 0;
      break;
     } else {
      $133 = $130;
     }
    }
    $132 = ($133>>>0)>(31);
    if ($132) {
     $135 = $133;
     label = 56;
    } else {
     $$0$i44 = $133;$157 = $113;$160 = $123;$164 = $133;
    }
   }
  } while(0);
  if ((label|0) == 56) {
   label = 0;
   $134 = (($135) + -32)|0;
   $$0$i44 = $134;$157 = $123;$160 = 0;$164 = $135;
  }
  $156 = $157 >>> $$0$i44;
  $158 = (32 - ($$0$i44))|0;
  $159 = $160 << $158;
  $161 = $159 | $156;
  $162 = $160 >>> $$0$i44;
  $163 = (($164) + ($pshift$275))|0;
  $$pre = (($head$174) + ($10)|0);
  $165 = ($163|0)==(1);
  $166 = ($161|0)==(1);
  $or$cond = $166 & $165;
  $167 = ($162|0)==(0);
  $or$cond68 = $167 & $or$cond;
  if ($or$cond68) {
   break;
  } else {
   $113 = $161;$123 = $162;$head$174 = $$pre;$pshift$275 = $163;
  }
 }
 STACKTOP = sp;return;
}
function ___memrchr($m,$c,$n) {
 $m = $m|0;
 $c = $c|0;
 $n = $n|0;
 var $$0 = 0, $$01 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c&255;
 $$01 = $n;
 while(1) {
  $1 = (($$01) + -1)|0;
  $2 = ($$01|0)==(0);
  if ($2) {
   $$0 = 0;
   label = 4;
   break;
  }
  $3 = (($m) + ($1)|0);
  $4 = HEAP8[$3>>0]|0;
  $5 = ($4<<24>>24)==($0<<24>>24);
  if ($5) {
   $$0 = $3;
   label = 4;
   break;
  } else {
   $$01 = $1;
  }
 }
 if ((label|0) == 4) {
  return ($$0|0);
 }
 return (0)|0;
}
function _strchr($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (___strchrnul($s,$c)|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $c&255;
 $3 = ($1<<24>>24)==($2<<24>>24);
 $4 = $3 ? $0 : 0;
 return ($4|0);
}
function ___strchrnul($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$02$lcssa = 0, $$0211 = 0, $$1 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond5 = 0, $w$0$lcssa = 0, $w$08 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = ($0|0)==(0);
 if ($1) {
  $6 = (_strlen(($s|0))|0);
  $7 = (($s) + ($6)|0);
  $$0 = $7;
  return ($$0|0);
 }
 $2 = $s;
 $3 = $2 & 3;
 $4 = ($3|0)==(0);
 L5: do {
  if ($4) {
   $$02$lcssa = $s;
  } else {
   $5 = $c&255;
   $$0211 = $s;
   while(1) {
    $8 = HEAP8[$$0211>>0]|0;
    $9 = ($8<<24>>24)==(0);
    $10 = ($8<<24>>24)==($5<<24>>24);
    $or$cond = $9 | $10;
    if ($or$cond) {
     $$0 = $$0211;
     break;
    }
    $11 = ((($$0211)) + 1|0);
    $12 = $11;
    $13 = $12 & 3;
    $14 = ($13|0)==(0);
    if ($14) {
     $$02$lcssa = $11;
     break L5;
    } else {
     $$0211 = $11;
    }
   }
   return ($$0|0);
  }
 } while(0);
 $15 = Math_imul($0, 16843009)|0;
 $16 = HEAP32[$$02$lcssa>>2]|0;
 $17 = (($16) + -16843009)|0;
 $18 = $16 & -2139062144;
 $19 = $18 ^ -2139062144;
 $20 = $19 & $17;
 $21 = ($20|0)==(0);
 L12: do {
  if ($21) {
   $23 = $16;$w$08 = $$02$lcssa;
   while(1) {
    $22 = $23 ^ $15;
    $24 = (($22) + -16843009)|0;
    $25 = $22 & -2139062144;
    $26 = $25 ^ -2139062144;
    $27 = $26 & $24;
    $28 = ($27|0)==(0);
    if (!($28)) {
     $w$0$lcssa = $w$08;
     break L12;
    }
    $29 = ((($w$08)) + 4|0);
    $30 = HEAP32[$29>>2]|0;
    $31 = (($30) + -16843009)|0;
    $32 = $30 & -2139062144;
    $33 = $32 ^ -2139062144;
    $34 = $33 & $31;
    $35 = ($34|0)==(0);
    if ($35) {
     $23 = $30;$w$08 = $29;
    } else {
     $w$0$lcssa = $29;
     break;
    }
   }
  } else {
   $w$0$lcssa = $$02$lcssa;
  }
 } while(0);
 $36 = $c&255;
 $$1 = $w$0$lcssa;
 while(1) {
  $37 = HEAP8[$$1>>0]|0;
  $38 = ($37<<24>>24)==(0);
  $39 = ($37<<24>>24)==($36<<24>>24);
  $or$cond5 = $38 | $39;
  $40 = ((($$1)) + 1|0);
  if ($or$cond5) {
   $$0 = $$1;
   break;
  } else {
   $$1 = $40;
  }
 }
 return ($$0|0);
}
function _strcspn($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$027 = 0, $$03$lcssa = 0, $$035 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, $byteset = 0, $div = 0, $div4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $byteset = sp;
 $0 = HEAP8[$c>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if (!($1)) {
  $2 = ((($c)) + 1|0);
  $3 = HEAP8[$2>>0]|0;
  $4 = ($3<<24>>24)==(0);
  if (!($4)) {
   ;HEAP32[$byteset>>2]=0|0;HEAP32[$byteset+4>>2]=0|0;HEAP32[$byteset+8>>2]=0|0;HEAP32[$byteset+12>>2]=0|0;HEAP32[$byteset+16>>2]=0|0;HEAP32[$byteset+20>>2]=0|0;HEAP32[$byteset+24>>2]=0|0;HEAP32[$byteset+28>>2]=0|0;
   $$027 = $c;$13 = $0;
   while(1) {
    $12 = $13 & 31;
    $14 = $12&255;
    $15 = 1 << $14;
    $div4 = ($13&255) >>> 5;
    $16 = $div4&255;
    $17 = (($byteset) + ($16<<2)|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = $18 | $15;
    HEAP32[$17>>2] = $19;
    $20 = ((($$027)) + 1|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(0);
    if ($22) {
     break;
    } else {
     $$027 = $20;$13 = $21;
    }
   }
   $10 = HEAP8[$s>>0]|0;
   $11 = ($10<<24>>24)==(0);
   L7: do {
    if ($11) {
     $$03$lcssa = $s;
    } else {
     $$035 = $s;$23 = $10;
     while(1) {
      $div = ($23&255) >>> 5;
      $24 = $div&255;
      $25 = (($byteset) + ($24<<2)|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = $23 & 31;
      $28 = $27&255;
      $29 = 1 << $28;
      $30 = $26 & $29;
      $31 = ($30|0)==(0);
      if (!($31)) {
       $$03$lcssa = $$035;
       break L7;
      }
      $32 = ((($$035)) + 1|0);
      $33 = HEAP8[$32>>0]|0;
      $34 = ($33<<24>>24)==(0);
      if ($34) {
       $$03$lcssa = $32;
       break;
      } else {
       $$035 = $32;$23 = $33;
      }
     }
    }
   } while(0);
   $35 = $$03$lcssa;
   $36 = $s;
   $37 = (($35) - ($36))|0;
   $$0 = $37;
   STACKTOP = sp;return ($$0|0);
  }
 }
 $5 = $0 << 24 >> 24;
 $6 = (___strchrnul($s,$5)|0);
 $7 = $6;
 $8 = $s;
 $9 = (($7) - ($8))|0;
 $$0 = $9;
 STACKTOP = sp;return ($$0|0);
}
function ___strdup($s) {
 $s = $s|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, $3 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (($0) + 1)|0;
 $2 = (_malloc($1)|0);
 $3 = ($2|0)==(0|0);
 if ($3) {
  $$0 = 0;
  return ($$0|0);
 }
 _memcpy(($2|0),($s|0),($1|0))|0;
 $$0 = $2;
 return ($$0|0);
}
function _strpbrk($s,$b) {
 $s = $s|0;
 $b = $b|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strcspn($s,$b)|0);
 $1 = (($s) + ($0)|0);
 $2 = HEAP8[$1>>0]|0;
 $3 = ($2<<24>>24)!=(0);
 $4 = $3 ? $1 : 0;
 return ($4|0);
}
function _strrchr($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_strlen(($s|0))|0);
 $1 = (($0) + 1)|0;
 $2 = (___memrchr($s,$c,$1)|0);
 return ($2|0);
}
function _strspn($s,$c) {
 $s = $s|0;
 $c = $c|0;
 var $$0 = 0, $$028 = 0, $$03 = 0, $$03$lcssa = 0, $$1$lcssa = 0, $$16 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0;
 var $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $byteset = 0, $div = 0, $div4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 32|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $byteset = sp;
 ;HEAP32[$byteset>>2]=0|0;HEAP32[$byteset+4>>2]=0|0;HEAP32[$byteset+8>>2]=0|0;HEAP32[$byteset+12>>2]=0|0;HEAP32[$byteset+16>>2]=0|0;HEAP32[$byteset+20>>2]=0|0;HEAP32[$byteset+24>>2]=0|0;HEAP32[$byteset+28>>2]=0|0;
 $0 = HEAP8[$c>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($c)) + 1|0);
 $3 = HEAP8[$2>>0]|0;
 $4 = ($3<<24>>24)==(0);
 if ($4) {
  $$03 = $s;
  while(1) {
   $5 = HEAP8[$$03>>0]|0;
   $6 = ($5<<24>>24)==($0<<24>>24);
   $7 = ((($$03)) + 1|0);
   if ($6) {
    $$03 = $7;
   } else {
    $$03$lcssa = $$03;
    break;
   }
  }
  $8 = $$03$lcssa;
  $9 = $s;
  $10 = (($8) - ($9))|0;
  $$0 = $10;
  STACKTOP = sp;return ($$0|0);
 } else {
  $$028 = $c;$14 = $0;
 }
 while(1) {
  $13 = $14 & 31;
  $15 = $13&255;
  $16 = 1 << $15;
  $div4 = ($14&255) >>> 5;
  $17 = $div4&255;
  $18 = (($byteset) + ($17<<2)|0);
  $19 = HEAP32[$18>>2]|0;
  $20 = $19 | $16;
  HEAP32[$18>>2] = $20;
  $21 = ((($$028)) + 1|0);
  $22 = HEAP8[$21>>0]|0;
  $23 = ($22<<24>>24)==(0);
  if ($23) {
   break;
  } else {
   $$028 = $21;$14 = $22;
  }
 }
 $11 = HEAP8[$s>>0]|0;
 $12 = ($11<<24>>24)==(0);
 L12: do {
  if ($12) {
   $$1$lcssa = $s;
  } else {
   $$16 = $s;$24 = $11;
   while(1) {
    $div = ($24&255) >>> 5;
    $25 = $div&255;
    $26 = (($byteset) + ($25<<2)|0);
    $27 = HEAP32[$26>>2]|0;
    $28 = $24 & 31;
    $29 = $28&255;
    $30 = 1 << $29;
    $31 = $27 & $30;
    $32 = ($31|0)==(0);
    if ($32) {
     $$1$lcssa = $$16;
     break L12;
    }
    $33 = ((($$16)) + 1|0);
    $34 = HEAP8[$33>>0]|0;
    $35 = ($34<<24>>24)==(0);
    if ($35) {
     $$1$lcssa = $33;
     break;
    } else {
     $$16 = $33;$24 = $34;
    }
   }
  }
 } while(0);
 $36 = $$1$lcssa;
 $37 = $s;
 $38 = (($36) - ($37))|0;
 $$0 = $38;
 STACKTOP = sp;return ($$0|0);
}
function _strstr($h,$n) {
 $h = $h|0;
 $n = $n|0;
 var $$0 = 0, $$0$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i13 = 0, $$01$i = 0, $$02$i = 0, $$02$i9 = 0, $$03$i = 0, $$03$us$i = 0, $$lcssa$i = 0, $$lcssa$i12 = 0, $$lcssa$i6 = 0, $$lcssa303 = 0, $$lcssa306 = 0, $$lcssa309 = 0, $$lcssa323 = 0, $$lcssa326 = 0, $$lcssa329 = 0, $$lcssa344 = 0, $$pr$i = 0;
 var $$pr$us$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0;
 var $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0;
 var $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0;
 var $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0;
 var $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0;
 var $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0;
 var $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $281$phi = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0;
 var $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0;
 var $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0;
 var $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0;
 var $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $byteset$i = 0, $div$i = 0, $div$us$i = 0, $div4$i = 0, $hw$0$in2$i = 0, $hw$03$i = 0, $hw$03$i8 = 0, $ip$0$ph$lcssa$i = 0, $ip$0$ph$lcssa147$i = 0, $ip$0$ph76$i = 0;
 var $ip$1$ip$0$$i = 0, $ip$1$ip$0$i = 0, $ip$1$ph$lcssa$i = 0, $ip$1$ph55$i = 0, $jp$0$ph13$ph70$i = 0, $jp$0$ph1365$i = 0, $jp$0$ph1365$i$lcssa = 0, $jp$0$ph1365$i$lcssa$lcssa = 0, $jp$0$ph77$i = 0, $jp$1$ph56$i = 0, $jp$1$ph9$ph49$i = 0, $jp$1$ph944$i = 0, $jp$1$ph944$i$lcssa = 0, $jp$1$ph944$i$lcssa$lcssa = 0, $k$059$i = 0, $k$139$i = 0, $k$2$us$i = 0, $k$338$i = 0, $k$338$i$lcssa = 0, $k$338$us$i = 0;
 var $k$338$us$i$lcssa = 0, $k$4$i = 0, $k$4$us$i = 0, $l$080$i = 0, $l$080$i$lcssa343 = 0, $mem$0$us$i = 0, $or$cond$i = 0, $or$cond$i10 = 0, $or$cond5$us$i = 0, $p$0$ph$ph$lcssa32$i = 0, $p$0$ph$ph$lcssa32151$i = 0, $p$0$ph$ph71$i = 0, $p$1$p$0$i = 0, $p$1$ph$ph$lcssa23$i = 0, $p$1$ph$ph50$i = 0, $p$3155$i = 0, $shift$i = 0, $z$0$i = 0, $z$0$us$i = 0, $z$1$i = 0;
 var $z$1$us$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 1056|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $byteset$i = sp + 1024|0;
 $shift$i = sp;
 $0 = HEAP8[$n>>0]|0;
 $1 = ($0<<24>>24)==(0);
 if ($1) {
  $$0 = $h;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = $0 << 24 >> 24;
 $3 = (_strchr($h,$2)|0);
 $4 = ($3|0)==(0|0);
 if ($4) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $5 = ((($n)) + 1|0);
 $6 = HEAP8[$5>>0]|0;
 $7 = ($6<<24>>24)==(0);
 if ($7) {
  $$0 = $3;
  STACKTOP = sp;return ($$0|0);
 }
 $8 = ((($3)) + 1|0);
 $9 = HEAP8[$8>>0]|0;
 $10 = ($9<<24>>24)==(0);
 if ($10) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $11 = ((($n)) + 2|0);
 $12 = HEAP8[$11>>0]|0;
 $13 = ($12<<24>>24)==(0);
 if ($13) {
  $14 = $0&255;
  $15 = $14 << 8;
  $16 = $6&255;
  $17 = $16 | $15;
  $18 = HEAP8[$3>>0]|0;
  $19 = $18&255;
  $20 = $19 << 8;
  $21 = $9&255;
  $22 = $20 | $21;
  $$01$i = $8;$280 = $9;$281 = $3;$hw$0$in2$i = $22;
  while(1) {
   $23 = $hw$0$in2$i & 65535;
   $24 = ($23|0)==($17|0);
   if ($24) {
    $$lcssa$i = $281;$32 = $280;
    break;
   }
   $25 = $23 << 8;
   $26 = ((($$01$i)) + 1|0);
   $27 = HEAP8[$26>>0]|0;
   $28 = $27&255;
   $29 = $28 | $25;
   $30 = ($27<<24>>24)==(0);
   if ($30) {
    $$lcssa$i = $$01$i;$32 = 0;
    break;
   } else {
    $281$phi = $$01$i;$$01$i = $26;$280 = $27;$hw$0$in2$i = $29;$281 = $281$phi;
   }
  }
  $31 = ($32<<24>>24)!=(0);
  $33 = $31 ? $$lcssa$i : 0;
  $$0 = $33;
  STACKTOP = sp;return ($$0|0);
 }
 $34 = ((($3)) + 2|0);
 $35 = HEAP8[$34>>0]|0;
 $36 = ($35<<24>>24)==(0);
 if ($36) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $37 = ((($n)) + 3|0);
 $38 = HEAP8[$37>>0]|0;
 $39 = ($38<<24>>24)==(0);
 if ($39) {
  $40 = $0&255;
  $41 = $40 << 24;
  $42 = $6&255;
  $43 = $42 << 16;
  $44 = $43 | $41;
  $45 = $12&255;
  $46 = $45 << 8;
  $47 = $44 | $46;
  $48 = HEAP8[$3>>0]|0;
  $49 = $48&255;
  $50 = $49 << 24;
  $51 = $9&255;
  $52 = $51 << 16;
  $53 = $35&255;
  $54 = $53 << 8;
  $55 = $54 | $52;
  $56 = $55 | $50;
  $57 = ($56|0)==($47|0);
  if ($57) {
   $$0$lcssa$i = $34;$$lcssa$i6 = $35;
  } else {
   $$02$i = $34;$hw$03$i = $56;
   while(1) {
    $58 = ((($$02$i)) + 1|0);
    $59 = HEAP8[$58>>0]|0;
    $60 = $59&255;
    $61 = $60 | $hw$03$i;
    $62 = $61 << 8;
    $63 = ($59<<24>>24)==(0);
    $64 = ($62|0)==($47|0);
    $or$cond$i = $63 | $64;
    if ($or$cond$i) {
     $$0$lcssa$i = $58;$$lcssa$i6 = $59;
     break;
    } else {
     $$02$i = $58;$hw$03$i = $62;
    }
   }
  }
  $65 = ($$lcssa$i6<<24>>24)!=(0);
  $66 = ((($$0$lcssa$i)) + -2|0);
  $67 = $65 ? $66 : 0;
  $$0 = $67;
  STACKTOP = sp;return ($$0|0);
 }
 $68 = ((($3)) + 3|0);
 $69 = HEAP8[$68>>0]|0;
 $70 = ($69<<24>>24)==(0);
 if ($70) {
  $$0 = 0;
  STACKTOP = sp;return ($$0|0);
 }
 $71 = ((($n)) + 4|0);
 $72 = HEAP8[$71>>0]|0;
 $73 = ($72<<24>>24)==(0);
 if ($73) {
  $74 = $0&255;
  $75 = $74 << 24;
  $76 = $6&255;
  $77 = $76 << 16;
  $78 = $77 | $75;
  $79 = $12&255;
  $80 = $79 << 8;
  $81 = $78 | $80;
  $82 = $38&255;
  $83 = $81 | $82;
  $84 = HEAP8[$3>>0]|0;
  $85 = $84&255;
  $86 = $85 << 24;
  $87 = $9&255;
  $88 = $87 << 16;
  $89 = $35&255;
  $90 = $89 << 8;
  $91 = $69&255;
  $92 = $90 | $88;
  $93 = $92 | $91;
  $94 = $93 | $86;
  $95 = ($94|0)==($83|0);
  if ($95) {
   $$0$lcssa$i13 = $68;$$lcssa$i12 = $69;
  } else {
   $$02$i9 = $68;$hw$03$i8 = $94;
   while(1) {
    $96 = $hw$03$i8 << 8;
    $97 = ((($$02$i9)) + 1|0);
    $98 = HEAP8[$97>>0]|0;
    $99 = $98&255;
    $100 = $99 | $96;
    $101 = ($98<<24>>24)==(0);
    $102 = ($100|0)==($83|0);
    $or$cond$i10 = $101 | $102;
    if ($or$cond$i10) {
     $$0$lcssa$i13 = $97;$$lcssa$i12 = $98;
     break;
    } else {
     $$02$i9 = $97;$hw$03$i8 = $100;
    }
   }
  }
  $103 = ($$lcssa$i12<<24>>24)!=(0);
  $104 = ((($$0$lcssa$i13)) + -3|0);
  $105 = $103 ? $104 : 0;
  $$0 = $105;
  STACKTOP = sp;return ($$0|0);
 }
 ;HEAP32[$byteset$i>>2]=0|0;HEAP32[$byteset$i+4>>2]=0|0;HEAP32[$byteset$i+8>>2]=0|0;HEAP32[$byteset$i+12>>2]=0|0;HEAP32[$byteset$i+16>>2]=0|0;HEAP32[$byteset$i+20>>2]=0|0;HEAP32[$byteset$i+24>>2]=0|0;HEAP32[$byteset$i+28>>2]=0|0;
 $110 = $0;$l$080$i = 0;
 while(1) {
  $106 = (($3) + ($l$080$i)|0);
  $107 = HEAP8[$106>>0]|0;
  $108 = ($107<<24>>24)==(0);
  if ($108) {
   $$0$i = 0;
   break;
  }
  $109 = $110 & 31;
  $111 = $109&255;
  $112 = 1 << $111;
  $div4$i = ($110&255) >>> 5;
  $113 = $div4$i&255;
  $114 = (($byteset$i) + ($113<<2)|0);
  $115 = HEAP32[$114>>2]|0;
  $116 = $115 | $112;
  HEAP32[$114>>2] = $116;
  $117 = (($l$080$i) + 1)|0;
  $118 = $110&255;
  $119 = (($shift$i) + ($118<<2)|0);
  HEAP32[$119>>2] = $117;
  $120 = (($n) + ($117)|0);
  $121 = HEAP8[$120>>0]|0;
  $122 = ($121<<24>>24)==(0);
  if ($122) {
   $$lcssa344 = $117;$l$080$i$lcssa343 = $l$080$i;
   label = 23;
   break;
  } else {
   $110 = $121;$l$080$i = $117;
  }
 }
 L46: do {
  if ((label|0) == 23) {
   $123 = ($$lcssa344>>>0)>(1);
   L48: do {
    if ($123) {
     $282 = 1;$ip$0$ph76$i = -1;$jp$0$ph77$i = 0;
     L49: while(1) {
      $283 = $282;$jp$0$ph13$ph70$i = $jp$0$ph77$i;$p$0$ph$ph71$i = 1;
      while(1) {
       $284 = $283;$jp$0$ph1365$i = $jp$0$ph13$ph70$i;
       L53: while(1) {
        $133 = $284;$k$059$i = 1;
        while(1) {
         $129 = (($k$059$i) + ($ip$0$ph76$i))|0;
         $130 = (($n) + ($129)|0);
         $131 = HEAP8[$130>>0]|0;
         $132 = (($n) + ($133)|0);
         $134 = HEAP8[$132>>0]|0;
         $135 = ($131<<24>>24)==($134<<24>>24);
         if (!($135)) {
          $$lcssa323 = $133;$$lcssa326 = $131;$$lcssa329 = $134;$jp$0$ph1365$i$lcssa = $jp$0$ph1365$i;
          break L53;
         }
         $136 = ($k$059$i|0)==($p$0$ph$ph71$i|0);
         $127 = (($k$059$i) + 1)|0;
         if ($136) {
          break;
         }
         $126 = (($127) + ($jp$0$ph1365$i))|0;
         $128 = ($126>>>0)<($$lcssa344>>>0);
         if ($128) {
          $133 = $126;$k$059$i = $127;
         } else {
          $ip$0$ph$lcssa$i = $ip$0$ph76$i;$p$0$ph$ph$lcssa32$i = $p$0$ph$ph71$i;
          break L49;
         }
        }
        $137 = (($jp$0$ph1365$i) + ($p$0$ph$ph71$i))|0;
        $138 = (($137) + 1)|0;
        $139 = ($138>>>0)<($$lcssa344>>>0);
        if ($139) {
         $284 = $138;$jp$0$ph1365$i = $137;
        } else {
         $ip$0$ph$lcssa$i = $ip$0$ph76$i;$p$0$ph$ph$lcssa32$i = $p$0$ph$ph71$i;
         break L49;
        }
       }
       $140 = ($$lcssa326&255)>($$lcssa329&255);
       $141 = (($$lcssa323) - ($ip$0$ph76$i))|0;
       if (!($140)) {
        $jp$0$ph1365$i$lcssa$lcssa = $jp$0$ph1365$i$lcssa;
        break;
       }
       $124 = (($$lcssa323) + 1)|0;
       $125 = ($124>>>0)<($$lcssa344>>>0);
       if ($125) {
        $283 = $124;$jp$0$ph13$ph70$i = $$lcssa323;$p$0$ph$ph71$i = $141;
       } else {
        $ip$0$ph$lcssa$i = $ip$0$ph76$i;$p$0$ph$ph$lcssa32$i = $141;
        break L49;
       }
      }
      $142 = (($jp$0$ph1365$i$lcssa$lcssa) + 1)|0;
      $143 = (($jp$0$ph1365$i$lcssa$lcssa) + 2)|0;
      $144 = ($143>>>0)<($$lcssa344>>>0);
      if ($144) {
       $282 = $143;$ip$0$ph76$i = $jp$0$ph1365$i$lcssa$lcssa;$jp$0$ph77$i = $142;
      } else {
       $ip$0$ph$lcssa$i = $jp$0$ph1365$i$lcssa$lcssa;$p$0$ph$ph$lcssa32$i = 1;
       break;
      }
     }
     $285 = 1;$ip$1$ph55$i = -1;$jp$1$ph56$i = 0;
     while(1) {
      $287 = $285;$jp$1$ph9$ph49$i = $jp$1$ph56$i;$p$1$ph$ph50$i = 1;
      while(1) {
       $286 = $287;$jp$1$ph944$i = $jp$1$ph9$ph49$i;
       L68: while(1) {
        $152 = $286;$k$139$i = 1;
        while(1) {
         $148 = (($k$139$i) + ($ip$1$ph55$i))|0;
         $149 = (($n) + ($148)|0);
         $150 = HEAP8[$149>>0]|0;
         $151 = (($n) + ($152)|0);
         $153 = HEAP8[$151>>0]|0;
         $154 = ($150<<24>>24)==($153<<24>>24);
         if (!($154)) {
          $$lcssa303 = $152;$$lcssa306 = $150;$$lcssa309 = $153;$jp$1$ph944$i$lcssa = $jp$1$ph944$i;
          break L68;
         }
         $155 = ($k$139$i|0)==($p$1$ph$ph50$i|0);
         $146 = (($k$139$i) + 1)|0;
         if ($155) {
          break;
         }
         $145 = (($146) + ($jp$1$ph944$i))|0;
         $147 = ($145>>>0)<($$lcssa344>>>0);
         if ($147) {
          $152 = $145;$k$139$i = $146;
         } else {
          $ip$0$ph$lcssa147$i = $ip$0$ph$lcssa$i;$ip$1$ph$lcssa$i = $ip$1$ph55$i;$p$0$ph$ph$lcssa32151$i = $p$0$ph$ph$lcssa32$i;$p$1$ph$ph$lcssa23$i = $p$1$ph$ph50$i;
          break L48;
         }
        }
        $156 = (($jp$1$ph944$i) + ($p$1$ph$ph50$i))|0;
        $157 = (($156) + 1)|0;
        $158 = ($157>>>0)<($$lcssa344>>>0);
        if ($158) {
         $286 = $157;$jp$1$ph944$i = $156;
        } else {
         $ip$0$ph$lcssa147$i = $ip$0$ph$lcssa$i;$ip$1$ph$lcssa$i = $ip$1$ph55$i;$p$0$ph$ph$lcssa32151$i = $p$0$ph$ph$lcssa32$i;$p$1$ph$ph$lcssa23$i = $p$1$ph$ph50$i;
         break L48;
        }
       }
       $159 = ($$lcssa306&255)<($$lcssa309&255);
       $160 = (($$lcssa303) - ($ip$1$ph55$i))|0;
       if (!($159)) {
        $jp$1$ph944$i$lcssa$lcssa = $jp$1$ph944$i$lcssa;
        break;
       }
       $164 = (($$lcssa303) + 1)|0;
       $165 = ($164>>>0)<($$lcssa344>>>0);
       if ($165) {
        $287 = $164;$jp$1$ph9$ph49$i = $$lcssa303;$p$1$ph$ph50$i = $160;
       } else {
        $ip$0$ph$lcssa147$i = $ip$0$ph$lcssa$i;$ip$1$ph$lcssa$i = $ip$1$ph55$i;$p$0$ph$ph$lcssa32151$i = $p$0$ph$ph$lcssa32$i;$p$1$ph$ph$lcssa23$i = $160;
        break L48;
       }
      }
      $161 = (($jp$1$ph944$i$lcssa$lcssa) + 1)|0;
      $162 = (($jp$1$ph944$i$lcssa$lcssa) + 2)|0;
      $163 = ($162>>>0)<($$lcssa344>>>0);
      if ($163) {
       $285 = $162;$ip$1$ph55$i = $jp$1$ph944$i$lcssa$lcssa;$jp$1$ph56$i = $161;
      } else {
       $ip$0$ph$lcssa147$i = $ip$0$ph$lcssa$i;$ip$1$ph$lcssa$i = $jp$1$ph944$i$lcssa$lcssa;$p$0$ph$ph$lcssa32151$i = $p$0$ph$ph$lcssa32$i;$p$1$ph$ph$lcssa23$i = 1;
       break;
      }
     }
    } else {
     $ip$0$ph$lcssa147$i = -1;$ip$1$ph$lcssa$i = -1;$p$0$ph$ph$lcssa32151$i = 1;$p$1$ph$ph$lcssa23$i = 1;
    }
   } while(0);
   $166 = (($ip$1$ph$lcssa$i) + 1)|0;
   $167 = (($ip$0$ph$lcssa147$i) + 1)|0;
   $168 = ($166>>>0)>($167>>>0);
   $p$1$p$0$i = $168 ? $p$1$ph$ph$lcssa23$i : $p$0$ph$ph$lcssa32151$i;
   $ip$1$ip$0$i = $168 ? $ip$1$ph$lcssa$i : $ip$0$ph$lcssa147$i;
   $169 = (($n) + ($p$1$p$0$i)|0);
   $170 = (($ip$1$ip$0$i) + 1)|0;
   $171 = (_memcmp($n,$169,$170)|0);
   $172 = ($171|0)==(0);
   if ($172) {
    $178 = (($$lcssa344) - ($p$1$p$0$i))|0;
    $179 = $$lcssa344 | 63;
    $180 = ($$lcssa344|0)==($p$1$p$0$i|0);
    if ($180) {
     $237 = $179;$p$3155$i = $$lcssa344;
    } else {
     $$03$us$i = $3;$mem$0$us$i = 0;$z$0$us$i = $3;
     L81: while(1) {
      $182 = $z$0$us$i;
      $183 = $$03$us$i;
      $184 = (($182) - ($183))|0;
      $185 = ($184>>>0)<($$lcssa344>>>0);
      do {
       if ($185) {
        $186 = (_memchr($z$0$us$i,0,$179)|0);
        $187 = ($186|0)==(0|0);
        if ($187) {
         $191 = (($z$0$us$i) + ($179)|0);
         $z$1$us$i = $191;
         break;
        } else {
         $188 = $186;
         $189 = (($188) - ($183))|0;
         $190 = ($189>>>0)<($$lcssa344>>>0);
         if ($190) {
          $$0$i = 0;
          break L46;
         } else {
          $z$1$us$i = $186;
          break;
         }
        }
       } else {
        $z$1$us$i = $z$0$us$i;
       }
      } while(0);
      $192 = (($$03$us$i) + ($l$080$i$lcssa343)|0);
      $193 = HEAP8[$192>>0]|0;
      $div$us$i = ($193&255) >>> 5;
      $194 = $div$us$i&255;
      $195 = (($byteset$i) + ($194<<2)|0);
      $196 = HEAP32[$195>>2]|0;
      $197 = $193 & 31;
      $198 = $197&255;
      $199 = 1 << $198;
      $200 = $199 & $196;
      $201 = ($200|0)==(0);
      if ($201) {
       $232 = (($$03$us$i) + ($$lcssa344)|0);
       $$03$us$i = $232;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
       continue;
      }
      $202 = $193&255;
      $203 = (($shift$i) + ($202<<2)|0);
      $204 = HEAP32[$203>>2]|0;
      $205 = (($$lcssa344) - ($204))|0;
      $206 = ($$lcssa344|0)==($204|0);
      if (!($206)) {
       $207 = ($mem$0$us$i|0)!=(0);
       $208 = ($205>>>0)<($p$1$p$0$i>>>0);
       $or$cond5$us$i = $207 & $208;
       $k$2$us$i = $or$cond5$us$i ? $178 : $205;
       $209 = (($$03$us$i) + ($k$2$us$i)|0);
       $$03$us$i = $209;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
       continue;
      }
      $210 = ($170>>>0)>($mem$0$us$i>>>0);
      $211 = $210 ? $170 : $mem$0$us$i;
      $212 = (($n) + ($211)|0);
      $213 = HEAP8[$212>>0]|0;
      $214 = ($213<<24>>24)==(0);
      L95: do {
       if ($214) {
        $k$4$us$i = $170;
       } else {
        $$pr$us$i = $213;$k$338$us$i = $211;
        while(1) {
         $215 = (($$03$us$i) + ($k$338$us$i)|0);
         $216 = HEAP8[$215>>0]|0;
         $217 = ($$pr$us$i<<24>>24)==($216<<24>>24);
         if (!($217)) {
          $k$338$us$i$lcssa = $k$338$us$i;
          break;
         }
         $220 = (($k$338$us$i) + 1)|0;
         $221 = (($n) + ($220)|0);
         $222 = HEAP8[$221>>0]|0;
         $223 = ($222<<24>>24)==(0);
         if ($223) {
          $k$4$us$i = $170;
          break L95;
         } else {
          $$pr$us$i = $222;$k$338$us$i = $220;
         }
        }
        $218 = (($k$338$us$i$lcssa) - ($ip$1$ip$0$i))|0;
        $219 = (($$03$us$i) + ($218)|0);
        $$03$us$i = $219;$mem$0$us$i = 0;$z$0$us$i = $z$1$us$i;
        continue L81;
       }
      } while(0);
      while(1) {
       $224 = ($k$4$us$i>>>0)>($mem$0$us$i>>>0);
       if (!($224)) {
        $$0$i = $$03$us$i;
        break L46;
       }
       $225 = (($k$4$us$i) + -1)|0;
       $226 = (($n) + ($225)|0);
       $227 = HEAP8[$226>>0]|0;
       $228 = (($$03$us$i) + ($225)|0);
       $229 = HEAP8[$228>>0]|0;
       $230 = ($227<<24>>24)==($229<<24>>24);
       if ($230) {
        $k$4$us$i = $225;
       } else {
        break;
       }
      }
      $231 = (($$03$us$i) + ($p$1$p$0$i)|0);
      $$03$us$i = $231;$mem$0$us$i = $178;$z$0$us$i = $z$1$us$i;
     }
    }
   } else {
    $173 = (($$lcssa344) - ($ip$1$ip$0$i))|0;
    $174 = (($173) + -1)|0;
    $175 = ($ip$1$ip$0$i>>>0)>($174>>>0);
    $ip$1$ip$0$$i = $175 ? $ip$1$ip$0$i : $174;
    $176 = (($ip$1$ip$0$$i) + 1)|0;
    $177 = $$lcssa344 | 63;
    $237 = $177;$p$3155$i = $176;
   }
   $181 = (($n) + ($170)|0);
   $$03$i = $3;$z$0$i = $3;
   L106: while(1) {
    $233 = $z$0$i;
    $234 = $$03$i;
    $235 = (($233) - ($234))|0;
    $236 = ($235>>>0)<($$lcssa344>>>0);
    do {
     if ($236) {
      $238 = (_memchr($z$0$i,0,$237)|0);
      $239 = ($238|0)==(0|0);
      if ($239) {
       $243 = (($z$0$i) + ($237)|0);
       $z$1$i = $243;
       break;
      } else {
       $240 = $238;
       $241 = (($240) - ($234))|0;
       $242 = ($241>>>0)<($$lcssa344>>>0);
       if ($242) {
        $$0$i = 0;
        break L46;
       } else {
        $z$1$i = $238;
        break;
       }
      }
     } else {
      $z$1$i = $z$0$i;
     }
    } while(0);
    $244 = (($$03$i) + ($l$080$i$lcssa343)|0);
    $245 = HEAP8[$244>>0]|0;
    $div$i = ($245&255) >>> 5;
    $246 = $div$i&255;
    $247 = (($byteset$i) + ($246<<2)|0);
    $248 = HEAP32[$247>>2]|0;
    $249 = $245 & 31;
    $250 = $249&255;
    $251 = 1 << $250;
    $252 = $251 & $248;
    $253 = ($252|0)==(0);
    if ($253) {
     $260 = (($$03$i) + ($$lcssa344)|0);
     $$03$i = $260;$z$0$i = $z$1$i;
     continue;
    }
    $254 = $245&255;
    $255 = (($shift$i) + ($254<<2)|0);
    $256 = HEAP32[$255>>2]|0;
    $257 = ($$lcssa344|0)==($256|0);
    if (!($257)) {
     $258 = (($$lcssa344) - ($256))|0;
     $259 = (($$03$i) + ($258)|0);
     $$03$i = $259;$z$0$i = $z$1$i;
     continue;
    }
    $261 = HEAP8[$181>>0]|0;
    $262 = ($261<<24>>24)==(0);
    L120: do {
     if ($262) {
      $k$4$i = $170;
     } else {
      $$pr$i = $261;$k$338$i = $170;
      while(1) {
       $263 = (($$03$i) + ($k$338$i)|0);
       $264 = HEAP8[$263>>0]|0;
       $265 = ($$pr$i<<24>>24)==($264<<24>>24);
       if (!($265)) {
        $k$338$i$lcssa = $k$338$i;
        break;
       }
       $266 = (($k$338$i) + 1)|0;
       $267 = (($n) + ($266)|0);
       $268 = HEAP8[$267>>0]|0;
       $269 = ($268<<24>>24)==(0);
       if ($269) {
        $k$4$i = $170;
        break L120;
       } else {
        $$pr$i = $268;$k$338$i = $266;
       }
      }
      $270 = (($k$338$i$lcssa) - ($ip$1$ip$0$i))|0;
      $271 = (($$03$i) + ($270)|0);
      $$03$i = $271;$z$0$i = $z$1$i;
      continue L106;
     }
    } while(0);
    while(1) {
     $272 = ($k$4$i|0)==(0);
     if ($272) {
      $$0$i = $$03$i;
      break L46;
     }
     $273 = (($k$4$i) + -1)|0;
     $274 = (($n) + ($273)|0);
     $275 = HEAP8[$274>>0]|0;
     $276 = (($$03$i) + ($273)|0);
     $277 = HEAP8[$276>>0]|0;
     $278 = ($275<<24>>24)==($277<<24>>24);
     if ($278) {
      $k$4$i = $273;
     } else {
      break;
     }
    }
    $279 = (($$03$i) + ($p$3155$i)|0);
    $$03$i = $279;$z$0$i = $z$1$i;
   }
  }
 } while(0);
 $$0 = $$0$i;
 STACKTOP = sp;return ($$0|0);
}
function ___towcase($wc,$lower) {
 $wc = $wc|0;
 $lower = $lower|0;
 var $$0 = 0, $$lcssa = 0, $$lcssa52 = 0, $$neg19 = 0, $$neg19$lcssa = 0, $$neg22 = 0, $$not = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0;
 var $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0;
 var $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0;
 var $57 = 0, $58 = 0, $59 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$028 = 0, $i$127 = 0, $i$127$lcssa = 0, $or$cond = 0, $or$cond11 = 0, $or$cond13 = 0, $or$cond15 = 0, $or$cond9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $lower << 1;
 $1 = (($0) + -1)|0;
 $2 = (($lower) + -1)|0;
 $3 = (_iswalpha($wc)|0);
 $4 = ($3|0)==(0);
 $5 = (($wc) + -1536)|0;
 $6 = ($5>>>0)<(2560);
 $or$cond9 = $6 | $4;
 $7 = (($wc) + -11776)|0;
 $8 = ($7>>>0)<(30784);
 $or$cond11 = $8 | $or$cond9;
 $9 = (($wc) + -43008)|0;
 $10 = ($9>>>0)<(22272);
 $or$cond13 = $10 | $or$cond11;
 if ($or$cond13) {
  $$0 = $wc;
  return ($$0|0);
 }
 $11 = ($lower|0)!=(0);
 $12 = (($wc) + -4256)|0;
 $13 = ($12>>>0)<(46);
 $or$cond15 = $11 & $13;
 if ($or$cond15) {
  $14 = ($wc|0)>(4293);
  if ($14) {
   if (!((($wc|0) == 4295) | (($wc|0) == 4301))) {
    $$0 = $wc;
    return ($$0|0);
   }
  }
  $15 = (($wc) + 7264)|0;
  $$0 = $15;
  return ($$0|0);
 }
 $$not = $11 ^ 1;
 $16 = (($wc) + -11520)|0;
 $17 = ($16>>>0)<(38);
 $or$cond = $17 & $$not;
 if ($or$cond) {
  $18 = ($wc|0)>(11557);
  if ($18) {
   if (!((($wc|0) == 11559) | (($wc|0) == 11565))) {
    $$0 = $wc;
    return ($$0|0);
   }
  }
  $19 = (($wc) + -7264)|0;
  $$0 = $19;
  return ($$0|0);
 } else {
  $i$028 = 0;
 }
 while(1) {
  $26 = (((71920 + ($i$028<<2)|0)) + 3|0);
  $27 = HEAP8[$26>>0]|0;
  $28 = (71920 + ($i$028<<2)|0);
  $29 = HEAP16[$28>>1]|0;
  $30 = $29&65535;
  $31 = (((71920 + ($i$028<<2)|0)) + 2|0);
  $32 = HEAP8[$31>>0]|0;
  $33 = $32 << 24 >> 24;
  $34 = $33 & $2;
  $$neg19 = (($wc) - ($30))|0;
  $35 = (($$neg19) - ($34))|0;
  $36 = $27&255;
  $37 = ($35>>>0)<($36>>>0);
  $21 = (($i$028) + 1)|0;
  if ($37) {
   $$lcssa = $32;$$lcssa52 = $33;$$neg19$lcssa = $$neg19;
   label = 13;
   break;
  }
  $20 = ($21|0)==(61);
  if ($20) {
   break;
  } else {
   $i$028 = $21;
  }
 }
 if ((label|0) == 13) {
  $38 = ($$lcssa<<24>>24)==(1);
  if ($38) {
   $39 = (($lower) + ($wc))|0;
   $40 = $$neg19$lcssa & 1;
   $41 = (($39) - ($40))|0;
   $$0 = $41;
   return ($$0|0);
  } else {
   $42 = Math_imul($$lcssa52, $1)|0;
   $43 = (($42) + ($wc))|0;
   $$0 = $43;
   return ($$0|0);
  }
 }
 $22 = (1 - ($lower))|0;
 $23 = (71424 + ($22<<1)|0);
 $24 = HEAP16[$23>>1]|0;
 $25 = ($24<<16>>16)==(0);
 L30: do {
  if (!($25)) {
   $45 = $24;$i$127 = 0;
   while(1) {
    $44 = $45&65535;
    $46 = ($44|0)==($wc|0);
    if ($46) {
     $i$127$lcssa = $i$127;
     break;
    }
    $50 = (($i$127) + 1)|0;
    $51 = ((71424 + ($50<<2)|0) + ($22<<1)|0);
    $52 = HEAP16[$51>>1]|0;
    $53 = ($52<<16>>16)==(0);
    if ($53) {
     break L30;
    } else {
     $45 = $52;$i$127 = $50;
    }
   }
   $47 = ((71424 + ($i$127$lcssa<<2)|0) + ($lower<<1)|0);
   $48 = HEAP16[$47>>1]|0;
   $49 = $48&65535;
   $$0 = $49;
   return ($$0|0);
  }
 } while(0);
 $54 = ($lower*40)|0;
 $$neg22 = (($wc) + -66600)|0;
 $55 = (($$neg22) + ($54))|0;
 $56 = ($55>>>0)<(40);
 if (!($56)) {
  $$0 = $wc;
  return ($$0|0);
 }
 $57 = (($wc) + -40)|0;
 $58 = ($lower*80)|0;
 $59 = (($57) + ($58))|0;
 $$0 = $59;
 return ($$0|0);
}
function _trinkle($head,$width,$cmp,$pp$val,$pp$1$val,$pshift,$trusty,$lp) {
 $head = $head|0;
 $width = $width|0;
 $cmp = $cmp|0;
 $pp$val = $pp$val|0;
 $pp$1$val = $pp$1$val|0;
 $pshift = $pshift|0;
 $trusty = $trusty|0;
 $lp = $lp|0;
 var $$0$be$i = 0, $$0$i = 0, $$0$lcssa = 0, $$0$lcssa49 = 0, $$01$be$i = 0, $$01162 = 0, $$01162$phi = 0, $$012$i = 0, $$02$i$i = 0, $$02$i3$i = 0, $$02$lcssa = 0, $$02$lcssa51 = 0, $$02$us$i = 0, $$02$us$i10 = 0, $$02964 = 0, $$03$i = 0, $$03$lcssa = 0, $$03865 = 0, $$lcssa = 0, $$lcssa76 = 0;
 var $$pre = 0, $$pre$i = 0, $$pre6$i = 0, $$pre6$i6 = 0, $$sum = 0, $$sum$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0;
 var $110 = 0, $111 = 0, $112 = 0, $113 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0;
 var $ar = 0, $ar$i = 0, $exitcond$i = 0, $exitcond$i9 = 0, $i$0$lcssa = 0, $i$0$lcssa$i = 0, $i$0$lcssa50 = 0, $i$01$us$i = 0, $i$01$us$i8 = 0, $i$01063 = 0, $i$04$i = 0, $nTrailingZeros$03$i$i = 0, $nTrailingZeros$03$i2$i = 0, $nTrailingZeros$03$i2$i$lcssa = 0, $or$cond = 0, $pp$val1666 = 0, $sum = 0, $sum$i = 0, $tmp$i = 0, $tmp$i5 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 976|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $tmp$i5 = sp + 712|0;
 $tmp$i = sp + 456|0;
 $ar$i = sp + 228|0;
 $ar = sp;
 HEAP32[$ar>>2] = $head;
 $0 = (0 - ($width))|0;
 $1 = ($pp$val|0)!=(1);
 $2 = ($pp$1$val|0)!=(0);
 $3 = $2 | $1;
 L1: do {
  if ($3) {
   $4 = (($lp) + ($pshift<<2)|0);
   $5 = HEAP32[$4>>2]|0;
   $6 = (0 - ($5))|0;
   $7 = (($head) + ($6)|0);
   $8 = (FUNCTION_TABLE_iii[$cmp & 511]($7,$head)|0);
   $9 = ($8|0)<(1);
   if ($9) {
    $$0$lcssa = $head;$$02$lcssa = $pshift;$$03$lcssa = $trusty;$i$0$lcssa = 1;
    label = 18;
   } else {
    $$01162 = $head;$$02964 = $pshift;$$03865 = $trusty;$16 = $7;$34 = $pp$1$val;$i$01063 = 1;$pp$val1666 = $pp$val;
    while(1) {
     $10 = ($$03865|0)==(0);
     $11 = ($$02964|0)>(1);
     $or$cond = $10 & $11;
     if ($or$cond) {
      $12 = (($$01162) + ($0)|0);
      $13 = (($$02964) + -2)|0;
      $14 = (($lp) + ($13<<2)|0);
      $15 = HEAP32[$14>>2]|0;
      $17 = (FUNCTION_TABLE_iii[$cmp & 511]($12,$16)|0);
      $18 = ($17|0)>(-1);
      if ($18) {
       $$0$lcssa49 = $$01162;$$02$lcssa51 = $$02964;$i$0$lcssa50 = $i$01063;
       break L1;
      }
      $sum = (($15) + ($width))|0;
      $$sum = (0 - ($sum))|0;
      $19 = (($$01162) + ($$sum)|0);
      $20 = (FUNCTION_TABLE_iii[$cmp & 511]($19,$16)|0);
      $21 = ($20|0)>(-1);
      if ($21) {
       $$0$lcssa49 = $$01162;$$02$lcssa51 = $$02964;$i$0$lcssa50 = $i$01063;
       break L1;
      }
     }
     $22 = (($i$01063) + 1)|0;
     $23 = (($ar) + ($i$01063<<2)|0);
     HEAP32[$23>>2] = $16;
     $24 = (($pp$val1666) + -1)|0;
     $25 = ($24|0)==(0);
     do {
      if ($25) {
       $46 = 32;
       label = 15;
      } else {
       $26 = $24 & 1;
       $27 = ($26|0)==(0);
       if ($27) {
        $$02$i$i = $24;$nTrailingZeros$03$i$i = 0;
        while(1) {
         $28 = (($nTrailingZeros$03$i$i) + 1)|0;
         $29 = $$02$i$i >>> 1;
         $30 = $29 & 1;
         $31 = ($30|0)==(0);
         if ($31) {
          $$02$i$i = $29;$nTrailingZeros$03$i$i = $28;
         } else {
          $$lcssa = $28;
          break;
         }
        }
        $32 = ($$lcssa|0)==(0);
        if ($32) {
         label = 10;
        } else {
         $44 = $$lcssa;
        }
       } else {
        label = 10;
       }
       if ((label|0) == 10) {
        label = 0;
        $33 = ($34|0)==(0);
        if ($33) {
         $46 = 64;
         label = 15;
         break;
        }
        $35 = $34 & 1;
        $36 = ($35|0)==(0);
        if ($36) {
         $$02$i3$i = $34;$nTrailingZeros$03$i2$i = 0;
        } else {
         $$0$i = 0;$48 = $pp$val1666;$51 = $34;$55 = 0;
         break;
        }
        while(1) {
         $37 = (($nTrailingZeros$03$i2$i) + 1)|0;
         $38 = $$02$i3$i >>> 1;
         $39 = $38 & 1;
         $40 = ($39|0)==(0);
         if ($40) {
          $$02$i3$i = $38;$nTrailingZeros$03$i2$i = $37;
         } else {
          $$lcssa76 = $37;$nTrailingZeros$03$i2$i$lcssa = $nTrailingZeros$03$i2$i;
          break;
         }
        }
        $41 = (($nTrailingZeros$03$i2$i$lcssa) + 33)|0;
        $42 = ($$lcssa76|0)==(0);
        if ($42) {
         $$0$i = 0;$48 = $pp$val1666;$51 = $34;$55 = 0;
         break;
        } else {
         $44 = $41;
        }
       }
       $43 = ($44>>>0)>(31);
       if ($43) {
        $46 = $44;
        label = 15;
       } else {
        $$0$i = $44;$48 = $pp$val1666;$51 = $34;$55 = $44;
       }
      }
     } while(0);
     if ((label|0) == 15) {
      label = 0;
      $45 = (($46) + -32)|0;
      $$0$i = $45;$48 = $34;$51 = 0;$55 = $46;
     }
     $47 = $48 >>> $$0$i;
     $49 = (32 - ($$0$i))|0;
     $50 = $51 << $49;
     $52 = $50 | $47;
     $53 = $51 >>> $$0$i;
     $54 = (($55) + ($$02964))|0;
     $56 = ($52|0)!=(1);
     $57 = ($53|0)!=(0);
     $58 = $57 | $56;
     if (!($58)) {
      $$0$lcssa49 = $16;$$02$lcssa51 = $54;$i$0$lcssa50 = $22;
      break L1;
     }
     $$pre = HEAP32[$ar>>2]|0;
     $59 = (($lp) + ($54<<2)|0);
     $60 = HEAP32[$59>>2]|0;
     $61 = (0 - ($60))|0;
     $62 = (($16) + ($61)|0);
     $63 = (FUNCTION_TABLE_iii[$cmp & 511]($62,$$pre)|0);
     $64 = ($63|0)<(1);
     if ($64) {
      $$0$lcssa = $16;$$02$lcssa = $54;$$03$lcssa = 0;$i$0$lcssa = $22;
      label = 18;
      break;
     } else {
      $$01162$phi = $16;$$02964 = $54;$$03865 = 0;$16 = $62;$34 = $53;$i$01063 = $22;$pp$val1666 = $52;$$01162 = $$01162$phi;
     }
    }
   }
  } else {
   $$0$lcssa = $head;$$02$lcssa = $pshift;$$03$lcssa = $trusty;$i$0$lcssa = 1;
   label = 18;
  }
 } while(0);
 if ((label|0) == 18) {
  $65 = ($$03$lcssa|0)==(0);
  if ($65) {
   $$0$lcssa49 = $$0$lcssa;$$02$lcssa51 = $$02$lcssa;$i$0$lcssa50 = $i$0$lcssa;
  } else {
   STACKTOP = sp;return;
  }
 }
 $66 = ($i$0$lcssa50|0)<(2);
 L30: do {
  if (!($66)) {
   $67 = (($ar) + ($i$0$lcssa50<<2)|0);
   HEAP32[$67>>2] = $tmp$i5;
   $68 = ($width|0)==(0);
   if (!($68)) {
    $$02$us$i10 = $width;$80 = $tmp$i5;
    while(1) {
     $78 = ($$02$us$i10>>>0)>(256);
     $70 = $78 ? 256 : $$02$us$i10;
     $79 = HEAP32[$ar>>2]|0;
     _memcpy(($80|0),($79|0),($70|0))|0;
     $76 = $79;$i$01$us$i8 = 0;
     while(1) {
      $72 = (($ar) + ($i$01$us$i8<<2)|0);
      $73 = (($i$01$us$i8) + 1)|0;
      $74 = (($ar) + ($73<<2)|0);
      $75 = HEAP32[$74>>2]|0;
      _memcpy(($76|0),($75|0),($70|0))|0;
      $77 = (($76) + ($70)|0);
      HEAP32[$72>>2] = $77;
      $exitcond$i9 = ($73|0)==($i$0$lcssa50|0);
      if ($exitcond$i9) {
       break;
      } else {
       $76 = $75;$i$01$us$i8 = $73;
      }
     }
     $69 = ($$02$us$i10|0)==($70|0);
     if ($69) {
      break L30;
     }
     $71 = (($$02$us$i10) - ($70))|0;
     $$pre6$i6 = HEAP32[$67>>2]|0;
     $$02$us$i10 = $71;$80 = $$pre6$i6;
    }
   }
  }
 } while(0);
 HEAP32[$ar$i>>2] = $$0$lcssa49;
 $81 = ($$02$lcssa51|0)>(1);
 L39: do {
  if ($81) {
   $$012$i = $$02$lcssa51;$$03$i = $$0$lcssa49;$87 = $$0$lcssa49;$i$04$i = 1;
   while(1) {
    $82 = (($$03$i) + ($0)|0);
    $83 = (($$012$i) + -2)|0;
    $84 = (($lp) + ($83<<2)|0);
    $85 = HEAP32[$84>>2]|0;
    $sum$i = (($85) + ($width))|0;
    $$sum$i = (0 - ($sum$i))|0;
    $86 = (($$03$i) + ($$sum$i)|0);
    $88 = (FUNCTION_TABLE_iii[$cmp & 511]($87,$86)|0);
    $89 = ($88|0)>(-1);
    if ($89) {
     $90 = (FUNCTION_TABLE_iii[$cmp & 511]($87,$82)|0);
     $91 = ($90|0)>(-1);
     if ($91) {
      $i$0$lcssa$i = $i$04$i;
      break;
     }
    }
    $92 = (FUNCTION_TABLE_iii[$cmp & 511]($86,$82)|0);
    $93 = ($92|0)>(-1);
    $94 = (($i$04$i) + 1)|0;
    $95 = (($ar$i) + ($i$04$i<<2)|0);
    if ($93) {
     HEAP32[$95>>2] = $86;
     $96 = (($$012$i) + -1)|0;
     $$0$be$i = $86;$$01$be$i = $96;
    } else {
     HEAP32[$95>>2] = $82;
     $$0$be$i = $82;$$01$be$i = $83;
    }
    $97 = ($$01$be$i|0)>(1);
    if (!($97)) {
     $i$0$lcssa$i = $94;
     break;
    }
    $$pre$i = HEAP32[$ar$i>>2]|0;
    $$012$i = $$01$be$i;$$03$i = $$0$be$i;$87 = $$pre$i;$i$04$i = $94;
   }
   $98 = ($i$0$lcssa$i|0)<(2);
   if ($98) {
    $113 = $tmp$i;
   } else {
    $99 = (($ar$i) + ($i$0$lcssa$i<<2)|0);
    HEAP32[$99>>2] = $tmp$i;
    $100 = ($width|0)==(0);
    if ($100) {
     $113 = $tmp$i;
    } else {
     $$02$us$i = $width;$112 = $tmp$i;
     while(1) {
      $110 = ($$02$us$i>>>0)>(256);
      $102 = $110 ? 256 : $$02$us$i;
      $111 = HEAP32[$ar$i>>2]|0;
      _memcpy(($112|0),($111|0),($102|0))|0;
      $108 = $111;$i$01$us$i = 0;
      while(1) {
       $104 = (($ar$i) + ($i$01$us$i<<2)|0);
       $105 = (($i$01$us$i) + 1)|0;
       $106 = (($ar$i) + ($105<<2)|0);
       $107 = HEAP32[$106>>2]|0;
       _memcpy(($108|0),($107|0),($102|0))|0;
       $109 = (($108) + ($102)|0);
       HEAP32[$104>>2] = $109;
       $exitcond$i = ($105|0)==($i$0$lcssa$i|0);
       if ($exitcond$i) {
        break;
       } else {
        $108 = $107;$i$01$us$i = $105;
       }
      }
      $101 = ($$02$us$i|0)==($102|0);
      if ($101) {
       $113 = $tmp$i;
       break L39;
      }
      $103 = (($$02$us$i) - ($102))|0;
      $$pre6$i = HEAP32[$99>>2]|0;
      $$02$us$i = $103;$112 = $$pre6$i;
     }
    }
   }
  } else {
   $113 = $tmp$i;
  }
 } while(0);
 STACKTOP = sp;return;
}
function _isspace($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($c|0)==(32);
 $1 = (($c) + -9)|0;
 $2 = ($1>>>0)<(5);
 $3 = $0 | $2;
 $4 = $3&1;
 return ($4|0);
}
function _isupper($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($c) + -65)|0;
 $1 = ($0>>>0)<(26);
 $2 = $1&1;
 return ($2|0);
}
function _isxdigit($c) {
 $c = $c|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $isdigit = 0, $isdigittmp = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $isdigittmp = (($c) + -48)|0;
 $isdigit = ($isdigittmp>>>0)<(10);
 if ($isdigit) {
  $4 = 1;
  $3 = $4&1;
  return ($3|0);
 }
 $0 = $c | 32;
 $1 = (($0) + -97)|0;
 $2 = ($1>>>0)<(6);
 $4 = $2;
 $3 = $4&1;
 return ($3|0);
}
function _tolower($c) {
 $c = $c|0;
 var $$0 = 0, $0 = 0, $1 = 0, $2 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_isupper($c)|0);
 $1 = ($0|0)==(0);
 $2 = $c | 32;
 $$0 = $1 ? $c : $2;
 return ($$0|0);
}
function ___intscan($f,$base,$pok,$0,$1) {
 $f = $f|0;
 $base = $base|0;
 $pok = $pok|0;
 $0 = $0|0;
 $1 = $1|0;
 var $$1 = 0, $$122 = 0, $$123 = 0, $$base21 = 0, $$lcssa = 0, $$lcssa130 = 0, $$lcssa131 = 0, $$lcssa132 = 0, $$lcssa133 = 0, $$lcssa134 = 0, $$lcssa135 = 0, $$sum = 0, $$sum14 = 0, $$sum1445 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum18 = 0, $$sum1865 = 0, $$sum19 = 0;
 var $$sum20 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0;
 var $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0;
 var $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0;
 var $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0;
 var $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0;
 var $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0;
 var $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0;
 var $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0;
 var $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0;
 var $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0;
 var $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0;
 var $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0;
 var $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0;
 var $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0;
 var $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $c$0 = 0, $c$1 = 0, $c$124 = 0, $c$2$be = 0, $c$2$be$lcssa = 0, $c$2$lcssa = 0, $c$3$be = 0, $c$3$lcssa = 0, $c$371 = 0;
 var $c$4$be = 0, $c$4$be$lcssa = 0, $c$4$lcssa = 0, $c$5$be = 0, $c$6$be = 0, $c$6$be$lcssa = 0, $c$6$lcssa = 0, $c$7$be = 0, $c$753 = 0, $c$8 = 0, $c$9$be = 0, $neg$0 = 0, $or$cond = 0, $or$cond12 = 0, $or$cond40 = 0, $or$cond5 = 0, $or$cond7 = 0, $x$082 = 0, $x$146 = 0, $x$266 = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 $2 = ($base>>>0)>(36);
 if ($2) {
  $5 = (___errno_location()|0);
  HEAP32[$5>>2] = 22;
  $282 = 0;$283 = 0;
  tempRet0 = ($282);
  return ($283|0);
 }
 $3 = ((($f)) + 4|0);
 $4 = ((($f)) + 100|0);
 while(1) {
  $6 = HEAP32[$3>>2]|0;
  $7 = HEAP32[$4>>2]|0;
  $8 = ($6>>>0)<($7>>>0);
  if ($8) {
   $9 = ((($6)) + 1|0);
   HEAP32[$3>>2] = $9;
   $10 = HEAP8[$6>>0]|0;
   $11 = $10&255;
   $13 = $11;
  } else {
   $12 = (___shgetc($f)|0);
   $13 = $12;
  }
  $14 = (_isspace($13)|0);
  $15 = ($14|0)==(0);
  if ($15) {
   $$lcssa135 = $13;
   break;
  }
 }
 $16 = ($$lcssa135|0)==(45);
 do {
  if ((($$lcssa135|0) == 43) | (($$lcssa135|0) == 45)) {
   $17 = $16 << 31 >> 31;
   $18 = HEAP32[$3>>2]|0;
   $19 = HEAP32[$4>>2]|0;
   $20 = ($18>>>0)<($19>>>0);
   if ($20) {
    $21 = ((($18)) + 1|0);
    HEAP32[$3>>2] = $21;
    $22 = HEAP8[$18>>0]|0;
    $23 = $22&255;
    $c$0 = $23;$neg$0 = $17;
    break;
   } else {
    $24 = (___shgetc($f)|0);
    $c$0 = $24;$neg$0 = $17;
    break;
   }
  } else {
   $c$0 = $$lcssa135;$neg$0 = 0;
  }
 } while(0);
 $25 = ($base|0)==(0);
 $26 = $base & -17;
 $27 = ($26|0)==(0);
 $28 = ($c$0|0)==(48);
 $or$cond5 = $27 & $28;
 do {
  if ($or$cond5) {
   $29 = HEAP32[$3>>2]|0;
   $30 = HEAP32[$4>>2]|0;
   $31 = ($29>>>0)<($30>>>0);
   if ($31) {
    $32 = ((($29)) + 1|0);
    HEAP32[$3>>2] = $32;
    $33 = HEAP8[$29>>0]|0;
    $34 = $33&255;
    $37 = $34;
   } else {
    $35 = (___shgetc($f)|0);
    $37 = $35;
   }
   $36 = $37 | 32;
   $38 = ($36|0)==(120);
   if (!($38)) {
    if ($25) {
     $$123 = 8;$c$124 = $37;
     label = 46;
     break;
    } else {
     $$1 = $base;$c$1 = $37;
     label = 32;
     break;
    }
   }
   $39 = HEAP32[$3>>2]|0;
   $40 = HEAP32[$4>>2]|0;
   $41 = ($39>>>0)<($40>>>0);
   if ($41) {
    $42 = ((($39)) + 1|0);
    HEAP32[$3>>2] = $42;
    $43 = HEAP8[$39>>0]|0;
    $44 = $43&255;
    $46 = $44;
   } else {
    $45 = (___shgetc($f)|0);
    $46 = $45;
   }
   $$sum20 = (($46) + 1)|0;
   $47 = (72168 + ($$sum20)|0);
   $48 = HEAP8[$47>>0]|0;
   $49 = ($48&255)>(15);
   if ($49) {
    $50 = HEAP32[$4>>2]|0;
    $51 = ($50|0)==(0|0);
    if (!($51)) {
     $52 = HEAP32[$3>>2]|0;
     $53 = ((($52)) + -1|0);
     HEAP32[$3>>2] = $53;
    }
    $54 = ($pok|0)==(0);
    if ($54) {
     ___shlim($f,0);
     $282 = 0;$283 = 0;
     tempRet0 = ($282);
     return ($283|0);
    }
    if ($51) {
     $282 = 0;$283 = 0;
     tempRet0 = ($282);
     return ($283|0);
    }
    $55 = HEAP32[$3>>2]|0;
    $56 = ((($55)) + -1|0);
    HEAP32[$3>>2] = $56;
    $282 = 0;$283 = 0;
    tempRet0 = ($282);
    return ($283|0);
   } else {
    $$123 = 16;$c$124 = $46;
    label = 46;
   }
  } else {
   $$base21 = $25 ? 10 : $base;
   $$sum = (($c$0) + 1)|0;
   $57 = (72168 + ($$sum)|0);
   $58 = HEAP8[$57>>0]|0;
   $59 = $58&255;
   $60 = ($59>>>0)<($$base21>>>0);
   if ($60) {
    $$1 = $$base21;$c$1 = $c$0;
    label = 32;
   } else {
    $61 = HEAP32[$4>>2]|0;
    $62 = ($61|0)==(0|0);
    if (!($62)) {
     $63 = HEAP32[$3>>2]|0;
     $64 = ((($63)) + -1|0);
     HEAP32[$3>>2] = $64;
    }
    ___shlim($f,0);
    $65 = (___errno_location()|0);
    HEAP32[$65>>2] = 22;
    $282 = 0;$283 = 0;
    tempRet0 = ($282);
    return ($283|0);
   }
  }
 } while(0);
 if ((label|0) == 32) {
  $66 = ($$1|0)==(10);
  if ($66) {
   $67 = (($c$1) + -48)|0;
   $68 = ($67>>>0)<(10);
   if ($68) {
    $71 = $67;$x$082 = 0;
    while(1) {
     $69 = ($x$082*10)|0;
     $70 = (($69) + ($71))|0;
     $72 = HEAP32[$3>>2]|0;
     $73 = HEAP32[$4>>2]|0;
     $74 = ($72>>>0)<($73>>>0);
     if ($74) {
      $75 = ((($72)) + 1|0);
      HEAP32[$3>>2] = $75;
      $76 = HEAP8[$72>>0]|0;
      $77 = $76&255;
      $c$2$be = $77;
     } else {
      $78 = (___shgetc($f)|0);
      $c$2$be = $78;
     }
     $79 = (($c$2$be) + -48)|0;
     $80 = ($79>>>0)<(10);
     $81 = ($70>>>0)<(429496729);
     $82 = $80 & $81;
     if ($82) {
      $71 = $79;$x$082 = $70;
     } else {
      $$lcssa134 = $70;$c$2$be$lcssa = $c$2$be;
      break;
     }
    }
    $284 = $$lcssa134;$285 = 0;$c$2$lcssa = $c$2$be$lcssa;
   } else {
    $284 = 0;$285 = 0;$c$2$lcssa = $c$1;
   }
   $83 = (($c$2$lcssa) + -48)|0;
   $84 = ($83>>>0)<(10);
   if ($84) {
    $85 = $284;$86 = $285;$90 = $83;$c$371 = $c$2$lcssa;
    while(1) {
     $87 = (___muldi3(($85|0),($86|0),10,0)|0);
     $88 = tempRet0;
     $89 = ($90|0)<(0);
     $91 = $89 << 31 >> 31;
     $92 = $90 ^ -1;
     $93 = $91 ^ -1;
     $94 = ($88>>>0)>($93>>>0);
     $95 = ($87>>>0)>($92>>>0);
     $96 = ($88|0)==($93|0);
     $97 = $96 & $95;
     $98 = $94 | $97;
     if ($98) {
      $$lcssa = $90;$286 = $85;$287 = $86;$c$3$lcssa = $c$371;
      break;
     }
     $99 = (_i64Add(($87|0),($88|0),($90|0),($91|0))|0);
     $100 = tempRet0;
     $101 = HEAP32[$3>>2]|0;
     $102 = HEAP32[$4>>2]|0;
     $103 = ($101>>>0)<($102>>>0);
     if ($103) {
      $104 = ((($101)) + 1|0);
      HEAP32[$3>>2] = $104;
      $105 = HEAP8[$101>>0]|0;
      $106 = $105&255;
      $c$3$be = $106;
     } else {
      $107 = (___shgetc($f)|0);
      $c$3$be = $107;
     }
     $108 = (($c$3$be) + -48)|0;
     $109 = ($108>>>0)<(10);
     $110 = ($100>>>0)<(429496729);
     $111 = ($99>>>0)<(2576980378);
     $112 = ($100|0)==(429496729);
     $113 = $112 & $111;
     $114 = $110 | $113;
     $or$cond7 = $109 & $114;
     if ($or$cond7) {
      $85 = $99;$86 = $100;$90 = $108;$c$371 = $c$3$be;
     } else {
      $$lcssa = $108;$286 = $99;$287 = $100;$c$3$lcssa = $c$3$be;
      break;
     }
    }
    $115 = ($$lcssa>>>0)>(9);
    if ($115) {
     $256 = $287;$258 = $286;
    } else {
     $$122 = 10;$288 = $286;$289 = $287;$c$8 = $c$3$lcssa;
     label = 72;
    }
   } else {
    $256 = $285;$258 = $284;
   }
  } else {
   $$123 = $$1;$c$124 = $c$1;
   label = 46;
  }
 }
 L69: do {
  if ((label|0) == 46) {
   $116 = (($$123) + -1)|0;
   $117 = $116 & $$123;
   $118 = ($117|0)==(0);
   if ($118) {
    $123 = ($$123*23)|0;
    $124 = $123 >>> 5;
    $125 = $124 & 7;
    $126 = (72432 + ($125)|0);
    $127 = HEAP8[$126>>0]|0;
    $128 = $127 << 24 >> 24;
    $$sum1445 = (($c$124) + 1)|0;
    $129 = (72168 + ($$sum1445)|0);
    $130 = HEAP8[$129>>0]|0;
    $131 = $130&255;
    $132 = ($131>>>0)<($$123>>>0);
    if ($132) {
     $135 = $131;$x$146 = 0;
     while(1) {
      $133 = $x$146 << $128;
      $134 = $135 | $133;
      $136 = HEAP32[$3>>2]|0;
      $137 = HEAP32[$4>>2]|0;
      $138 = ($136>>>0)<($137>>>0);
      if ($138) {
       $139 = ((($136)) + 1|0);
       HEAP32[$3>>2] = $139;
       $140 = HEAP8[$136>>0]|0;
       $141 = $140&255;
       $c$4$be = $141;
      } else {
       $142 = (___shgetc($f)|0);
       $c$4$be = $142;
      }
      $$sum14 = (($c$4$be) + 1)|0;
      $143 = (72168 + ($$sum14)|0);
      $144 = HEAP8[$143>>0]|0;
      $145 = $144&255;
      $146 = ($145>>>0)<($$123>>>0);
      $147 = ($134>>>0)<(134217728);
      $148 = $147 & $146;
      if ($148) {
       $135 = $145;$x$146 = $134;
      } else {
       $$lcssa130 = $134;$$lcssa131 = $144;$c$4$be$lcssa = $c$4$be;
       break;
      }
     }
     $152 = $$lcssa131;$155 = 0;$157 = $$lcssa130;$c$4$lcssa = $c$4$be$lcssa;
    } else {
     $152 = $130;$155 = 0;$157 = 0;$c$4$lcssa = $c$124;
    }
    $149 = (_bitshift64Lshr(-1,-1,($128|0))|0);
    $150 = tempRet0;
    $151 = $152&255;
    $153 = ($151>>>0)>=($$123>>>0);
    $154 = ($155>>>0)>($150>>>0);
    $156 = ($157>>>0)>($149>>>0);
    $158 = ($155|0)==($150|0);
    $159 = $158 & $156;
    $160 = $154 | $159;
    $or$cond40 = $153 | $160;
    if ($or$cond40) {
     $$122 = $$123;$288 = $157;$289 = $155;$c$8 = $c$4$lcssa;
     label = 72;
     break;
    } else {
     $161 = $157;$162 = $155;$166 = $152;
    }
    while(1) {
     $163 = (_bitshift64Shl(($161|0),($162|0),($128|0))|0);
     $164 = tempRet0;
     $165 = $166&255;
     $167 = $165 | $163;
     $168 = HEAP32[$3>>2]|0;
     $169 = HEAP32[$4>>2]|0;
     $170 = ($168>>>0)<($169>>>0);
     if ($170) {
      $171 = ((($168)) + 1|0);
      HEAP32[$3>>2] = $171;
      $172 = HEAP8[$168>>0]|0;
      $173 = $172&255;
      $c$5$be = $173;
     } else {
      $174 = (___shgetc($f)|0);
      $c$5$be = $174;
     }
     $$sum15 = (($c$5$be) + 1)|0;
     $175 = (72168 + ($$sum15)|0);
     $176 = HEAP8[$175>>0]|0;
     $177 = $176&255;
     $178 = ($177>>>0)>=($$123>>>0);
     $179 = ($164>>>0)>($150>>>0);
     $180 = ($167>>>0)>($149>>>0);
     $181 = ($164|0)==($150|0);
     $182 = $181 & $180;
     $183 = $179 | $182;
     $or$cond = $178 | $183;
     if ($or$cond) {
      $$122 = $$123;$288 = $167;$289 = $164;$c$8 = $c$5$be;
      label = 72;
      break L69;
     } else {
      $161 = $167;$162 = $164;$166 = $176;
     }
    }
   }
   $$sum1865 = (($c$124) + 1)|0;
   $119 = (72168 + ($$sum1865)|0);
   $120 = HEAP8[$119>>0]|0;
   $121 = $120&255;
   $122 = ($121>>>0)<($$123>>>0);
   if ($122) {
    $186 = $121;$x$266 = 0;
    while(1) {
     $184 = Math_imul($x$266, $$123)|0;
     $185 = (($186) + ($184))|0;
     $187 = HEAP32[$3>>2]|0;
     $188 = HEAP32[$4>>2]|0;
     $189 = ($187>>>0)<($188>>>0);
     if ($189) {
      $190 = ((($187)) + 1|0);
      HEAP32[$3>>2] = $190;
      $191 = HEAP8[$187>>0]|0;
      $192 = $191&255;
      $c$6$be = $192;
     } else {
      $193 = (___shgetc($f)|0);
      $c$6$be = $193;
     }
     $$sum18 = (($c$6$be) + 1)|0;
     $194 = (72168 + ($$sum18)|0);
     $195 = HEAP8[$194>>0]|0;
     $196 = $195&255;
     $197 = ($196>>>0)<($$123>>>0);
     $198 = ($185>>>0)<(119304647);
     $199 = $198 & $197;
     if ($199) {
      $186 = $196;$x$266 = $185;
     } else {
      $$lcssa132 = $185;$$lcssa133 = $195;$c$6$be$lcssa = $c$6$be;
      break;
     }
    }
    $201 = $$lcssa133;$290 = $$lcssa132;$291 = 0;$c$6$lcssa = $c$6$be$lcssa;
   } else {
    $201 = $120;$290 = 0;$291 = 0;$c$6$lcssa = $c$124;
   }
   $200 = $201&255;
   $202 = ($200>>>0)<($$123>>>0);
   if ($202) {
    $203 = (___udivdi3(-1,-1,($$123|0),0)|0);
    $204 = tempRet0;
    $206 = $291;$208 = $290;$215 = $201;$c$753 = $c$6$lcssa;
    while(1) {
     $205 = ($206>>>0)>($204>>>0);
     $207 = ($208>>>0)>($203>>>0);
     $209 = ($206|0)==($204|0);
     $210 = $209 & $207;
     $211 = $205 | $210;
     if ($211) {
      $$122 = $$123;$288 = $208;$289 = $206;$c$8 = $c$753;
      label = 72;
      break L69;
     }
     $212 = (___muldi3(($208|0),($206|0),($$123|0),0)|0);
     $213 = tempRet0;
     $214 = $215&255;
     $216 = $214 ^ -1;
     $217 = ($213>>>0)>(4294967295);
     $218 = ($212>>>0)>($216>>>0);
     $219 = ($213|0)==(-1);
     $220 = $219 & $218;
     $221 = $217 | $220;
     if ($221) {
      $$122 = $$123;$288 = $208;$289 = $206;$c$8 = $c$753;
      label = 72;
      break L69;
     }
     $222 = (_i64Add(($214|0),0,($212|0),($213|0))|0);
     $223 = tempRet0;
     $224 = HEAP32[$3>>2]|0;
     $225 = HEAP32[$4>>2]|0;
     $226 = ($224>>>0)<($225>>>0);
     if ($226) {
      $227 = ((($224)) + 1|0);
      HEAP32[$3>>2] = $227;
      $228 = HEAP8[$224>>0]|0;
      $229 = $228&255;
      $c$7$be = $229;
     } else {
      $230 = (___shgetc($f)|0);
      $c$7$be = $230;
     }
     $$sum19 = (($c$7$be) + 1)|0;
     $231 = (72168 + ($$sum19)|0);
     $232 = HEAP8[$231>>0]|0;
     $233 = $232&255;
     $234 = ($233>>>0)<($$123>>>0);
     if ($234) {
      $206 = $223;$208 = $222;$215 = $232;$c$753 = $c$7$be;
     } else {
      $$122 = $$123;$288 = $222;$289 = $223;$c$8 = $c$7$be;
      label = 72;
      break;
     }
    }
   } else {
    $$122 = $$123;$288 = $290;$289 = $291;$c$8 = $c$6$lcssa;
    label = 72;
   }
  }
 } while(0);
 if ((label|0) == 72) {
  $$sum16 = (($c$8) + 1)|0;
  $235 = (72168 + ($$sum16)|0);
  $236 = HEAP8[$235>>0]|0;
  $237 = $236&255;
  $238 = ($237>>>0)<($$122>>>0);
  if ($238) {
   while(1) {
    $239 = HEAP32[$3>>2]|0;
    $240 = HEAP32[$4>>2]|0;
    $241 = ($239>>>0)<($240>>>0);
    if ($241) {
     $242 = ((($239)) + 1|0);
     HEAP32[$3>>2] = $242;
     $243 = HEAP8[$239>>0]|0;
     $244 = $243&255;
     $c$9$be = $244;
    } else {
     $245 = (___shgetc($f)|0);
     $c$9$be = $245;
    }
    $$sum17 = (($c$9$be) + 1)|0;
    $246 = (72168 + ($$sum17)|0);
    $247 = HEAP8[$246>>0]|0;
    $248 = $247&255;
    $249 = ($248>>>0)<($$122>>>0);
    if (!($249)) {
     break;
    }
   }
   $250 = (___errno_location()|0);
   HEAP32[$250>>2] = 34;
   $256 = $1;$258 = $0;
  } else {
   $256 = $289;$258 = $288;
  }
 }
 $251 = HEAP32[$4>>2]|0;
 $252 = ($251|0)==(0|0);
 if (!($252)) {
  $253 = HEAP32[$3>>2]|0;
  $254 = ((($253)) + -1|0);
  HEAP32[$3>>2] = $254;
 }
 $255 = ($256>>>0)<($1>>>0);
 $257 = ($258>>>0)<($0>>>0);
 $259 = ($256|0)==($1|0);
 $260 = $259 & $257;
 $261 = $255 | $260;
 if (!($261)) {
  $262 = $0 & 1;
  $263 = ($262|0)!=(0);
  $264 = (0)!=(0);
  $265 = $263 | $264;
  $266 = ($neg$0|0)!=(0);
  $or$cond12 = $265 | $266;
  if (!($or$cond12)) {
   $267 = (___errno_location()|0);
   HEAP32[$267>>2] = 34;
   $268 = (_i64Add(($0|0),($1|0),-1,-1)|0);
   $269 = tempRet0;
   $282 = $269;$283 = $268;
   tempRet0 = ($282);
   return ($283|0);
  }
  $270 = ($256>>>0)>($1>>>0);
  $271 = ($258>>>0)>($0>>>0);
  $272 = ($256|0)==($1|0);
  $273 = $272 & $271;
  $274 = $270 | $273;
  if ($274) {
   $275 = (___errno_location()|0);
   HEAP32[$275>>2] = 34;
   $282 = $1;$283 = $0;
   tempRet0 = ($282);
   return ($283|0);
  }
 }
 $276 = ($neg$0|0)<(0);
 $277 = $276 << 31 >> 31;
 $278 = $258 ^ $neg$0;
 $279 = $256 ^ $277;
 $280 = (_i64Subtract(($278|0),($279|0),($neg$0|0),($277|0))|0);
 $281 = tempRet0;
 $282 = $281;$283 = $280;
 tempRet0 = ($282);
 return ($283|0);
}
function ___floatscan($f,$prec,$pok) {
 $f = $f|0;
 $prec = $prec|0;
 $pok = $pok|0;
 var $$$i = 0, $$0 = 0.0, $$0$i25 = 0.0, $$010$i = 0, $$07$i = 0, $$0710$i = 0, $$0711$i = 0, $$09$i = 0, $$1$be$i = 0, $$1$ph$i = 0, $$11$i = 0, $$18$i = 0, $$2$i = 0, $$3$be$i = 0, $$3$lcssa$i = 0, $$3121$i = 0, $$in = 0, $$k$0$i = 0, $$lcssa = 0, $$lcssa288 = 0;
 var $$lcssa289 = 0, $$lcssa308 = 0, $$lcssa308$lcssa = 0, $$lcssa309 = 0, $$lcssa309$lcssa = 0, $$lcssa322 = 0, $$lcssa323 = 0, $$lcssa333 = 0, $$lcssa50$i = 0, $$lnz$0$i = 0, $$neg32$i = 0, $$not$i = 0, $$old8 = 0, $$pn$i = 0.0, $$pre$i = 0, $$pre$i17 = 0, $$pre$phi42$iZ2D = 0.0, $$pre41$i = 0.0, $$promoted = 0, $$promoted$i = 0;
 var $$promoted185 = 0, $$sink$off0$us$i = 0, $$sink$off0$us93$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0;
 var $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0.0, $177 = 0.0, $178 = 0.0, $179 = 0.0, $18 = 0, $180 = 0, $181 = 0, $182 = 0.0, $183 = 0.0, $184 = 0, $185 = 0;
 var $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0;
 var $203 = 0.0, $204 = 0.0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0;
 var $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0;
 var $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0.0, $253 = 0.0, $254 = 0, $255 = 0, $256 = 0, $257 = 0;
 var $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0.0, $262 = 0.0, $263 = 0.0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0.0, $275 = 0.0;
 var $276 = 0.0, $277 = 0, $278 = 0, $279 = 0.0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0;
 var $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0.0, $304 = 0.0, $305 = 0.0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0;
 var $311 = 0.0, $312 = 0.0, $313 = 0.0, $314 = 0.0, $315 = 0.0, $316 = 0.0, $317 = 0, $318 = 0, $319 = 0.0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0;
 var $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0;
 var $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0;
 var $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0;
 var $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0;
 var $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0.0, $419 = 0.0;
 var $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0.0, $436 = 0.0, $437 = 0.0;
 var $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0.0, $448 = 0.0, $449 = 0.0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0;
 var $456 = 0, $457 = 0, $458 = 0, $459 = 0.0, $46 = 0, $460 = 0.0, $461 = 0.0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0.0;
 var $474 = 0, $475 = 0.0, $476 = 0.0, $477 = 0, $478 = 0.0, $479 = 0, $48 = 0.0, $480 = 0.0, $481 = 0.0, $482 = 0, $483 = 0, $484 = 0, $485 = 0.0, $486 = 0.0, $487 = 0, $488 = 0, $489 = 0, $49 = 0.0, $490 = 0, $491 = 0;
 var $492 = 0.0, $493 = 0.0, $494 = 0.0, $495 = 0, $496 = 0, $497 = 0, $498 = 0.0, $499 = 0.0, $5 = 0, $50 = 0.0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0;
 var $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0;
 var $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0;
 var $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0;
 var $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0;
 var $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0;
 var $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0;
 var $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0;
 var $636 = 0, $637 = 0.0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0, $642 = 0.0, $643 = 0.0, $644 = 0.0, $645 = 0, $646 = 0.0, $647 = 0.0, $648 = 0.0, $649 = 0.0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0;
 var $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0.0, $661 = 0.0, $662 = 0.0, $663 = 0, $664 = 0.0, $665 = 0.0, $666 = 0, $667 = 0, $668 = 0, $669 = 0.0, $67 = 0, $670 = 0.0, $671 = 0.0;
 var $672 = 0.0, $673 = 0, $674 = 0, $675 = 0.0, $676 = 0, $677 = 0.0, $678 = 0.0, $679 = 0.0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0.0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0.0, $69 = 0;
 var $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0.0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0.0, $702 = 0, $703 = 0, $704 = 0.0, $705 = 0.0, $706 = 0, $707 = 0;
 var $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0;
 var $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0;
 var $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $a$0$lcssa177$i = 0, $a$0101$i = 0, $a$1$i = 0, $a$1$i$lcssa = 0, $a$2$ph38$i = 0, $a$3$i = 0;
 var $a$3$i$lcssa300 = 0, $a$3$i301 = 0, $a$3$ph$i = 0, $a$3$ph183$i = 0, $a$478$i = 0, $a$5$i = 0, $a$5$i$lcssa = 0, $a$5$i$lcssa$lcssa = 0, $bias$0$i = 0.0, $bias$0$i23 = 0.0, $bits$0$ph = 0, $brmerge = 0, $brmerge$i26 = 0, $brmerge187 = 0, $c$0 = 0, $c$0$i = 0, $c$1$lcssa = 0, $c$1$ph$i = 0, $c$185 = 0, $c$2 = 0;
 var $c$2$i = 0, $c$2$lcssa$i = 0, $c$4 = 0, $c$4$1 = 0, $c$6 = 0, $carry$0103$i = 0, $carry1$0$us$i = 0, $carry1$0$us89$i = 0, $carry1$1$lcssa$lcssa$i = 0, $carry1$1$us$i = 0, $carry1$1$us$i$lcssa = 0, $carry1$1$us94$i = 0, $carry1$1$us94$i$lcssa = 0, $carry3$081$i = 0, $cond$i = 0, $d$0$i = 0, $denormal$0$i = 0, $denormal$1$i = 0, $denormal$2$i = 0, $e2$0$ph$i = 0;
 var $e2$0$us$i = 0, $e2$0$us84$i = 0, $e2$1$i = 0, $e2$1$i298 = 0, $e2$1$ph$i = 0, $e2$1$ph182$i = 0, $e2$2$i = 0, $e2$3$i = 0, $emin$0$ph = 0, $exitcond$i = 0, $frac$0$i = 0.0, $frac$1$i = 0.0, $frac$2$i = 0.0, $gotdig$0$i = 0, $gotdig$0$i$lcssa294 = 0, $gotdig$0$i12 = 0, $gotdig$0$i12$lcssa331 = 0, $gotdig$2$i = 0, $gotdig$2$i$lcssa = 0, $gotdig$2$i13 = 0;
 var $gotdig$3$i = 0, $gotdig$3$lcssa$i = 0, $gotdig$3117$i = 0, $gotdig$3117$i$lcssa = 0, $gotdig$4$i = 0, $gotrad$0$i = 0, $gotrad$0$i$lcssa = 0, $gotrad$0$i14 = 0, $gotrad$1$i = 0, $gotrad$1$lcssa$i = 0, $gotrad$1118$i = 0, $gotrad$2$i = 0, $gottail$0$i = 0, $gottail$1$i = 0, $gottail$2$i = 0, $i$0$lcssa = 0, $i$084 = 0, $i$1 = 0, $i$4 = 0, $i$4$lcssa = 0;
 var $j$0$lcssa$i = 0, $j$0120$i = 0, $j$0120$i$lcssa = 0, $j$067$i = 0, $j$068$i = 0, $j$069$i = 0, $j$2$i = 0, $j$3110$i = 0, $k$0$lcssa$i = 0, $k$0119$i = 0, $k$0119$i$lcssa = 0, $k$063$i = 0, $k$064$i = 0, $k$065$i = 0, $k$2$i = 0, $k$3$i = 0, $k$4102$i = 0, $k$5$in$us$i = 0, $k$5$in$us88$i = 0, $k$5$us$i = 0;
 var $k$5$us90$i = 0, $k$5$z$2$us$i = 0, $k$5$z$2$us96$i = 0, $k$679$i = 0, $lnz$0$lcssa$i = 0, $lnz$0116$i = 0, $lnz$0116$i$lcssa = 0, $lnz$057$i = 0, $lnz$058$i = 0, $lnz$059$i = 0, $lnz$2$i = 0, $notlhs = 0, $notrhs = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i16 = 0, $or$cond13$i = 0, $or$cond15$i = 0, $or$cond16$i = 0, $or$cond17$us$i = 0;
 var $or$cond17$us95$i = 0, $or$cond19$i = 0, $or$cond20$i = 0, $or$cond216$i = 0, $or$cond3$i = 0, $or$cond4$i = 0, $or$cond5 = 0, $or$cond6$i = 0, $or$cond7 = 0, $or$cond8$i = 0, $or$cond9$i = 0, $or$cond9$not = 0, $rp$0$lcssa178$i = 0, $rp$0100$i = 0, $rp$1$i18 = 0, $rp$1$i18$lcssa = 0, $rp$2$ph36$i = 0, $rp$3$ph$i = 0, $rp$3$ph34$i = 0, $rp$477$i = 0;
 var $rp$5$i = 0, $rp$5$i$lcssa = 0, $rp$5$i$lcssa$lcssa = 0, $scale$0$i = 0.0, $scale$1$i = 0.0, $scale$2$i = 0.0, $sign$0 = 0, $storemerge$i = 0, $sum$i = 0, $x$0$i = 0, $x$0$i$lcssa = 0, $x$1$i = 0, $x$2$i = 0, $x$3$lcssa$i = 0, $x$324$i = 0, $x$4$lcssa$i = 0, $x$419$i = 0, $x$5$i = 0, $x$6$i = 0, $x$i = 0;
 var $y$0$i = 0.0, $y$0$i$lcssa = 0.0, $y$1$i = 0.0, $y$1$i22 = 0.0, $y$2$i = 0.0, $y$2$i24 = 0.0, $y$3$i = 0.0, $y$3$lcssa$i = 0.0, $y$320$i = 0.0, $y$4$i = 0.0, $y$5$i = 0.0, $z$0$i = 0, $z$1$ph37$i = 0, $z$1$us$i = 0, $z$1$us85$i = 0, $z$2$us$i = 0, $z$2$us87$i = 0, $z$3$lcssa$lcssa$i = 0, $z$3$us$i = 0, $z$3$us$i$lcssa = 0;
 var $z$3$us97$i = 0, $z$3$us97$i$lcssa = 0, $z$4$i = 0, $z$5$ph$i = 0, $z$7$1$i = 0, $z$7$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 512|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $x$i = sp;
 if ((($prec|0) == 2)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else if ((($prec|0) == 0)) {
  $bits$0$ph = 24;$emin$0$ph = -149;
 } else if ((($prec|0) == 1)) {
  $bits$0$ph = 53;$emin$0$ph = -1074;
 } else {
  $$0 = 0.0;
  STACKTOP = sp;return (+$$0);
 }
 $0 = ((($f)) + 4|0);
 $1 = ((($f)) + 100|0);
 while(1) {
  $2 = HEAP32[$0>>2]|0;
  $3 = HEAP32[$1>>2]|0;
  $4 = ($2>>>0)<($3>>>0);
  if ($4) {
   $5 = ((($2)) + 1|0);
   HEAP32[$0>>2] = $5;
   $6 = HEAP8[$2>>0]|0;
   $7 = $6&255;
   $9 = $7;
  } else {
   $8 = (___shgetc($f)|0);
   $9 = $8;
  }
  $10 = (_isspace($9)|0);
  $11 = ($10|0)==(0);
  if ($11) {
   $$lcssa333 = $9;
   break;
  }
 }
 $12 = ($$lcssa333|0)==(45);
 do {
  if ((($$lcssa333|0) == 43) | (($$lcssa333|0) == 45)) {
   $13 = $12&1;
   $14 = $13 << 1;
   $15 = (1 - ($14))|0;
   $16 = HEAP32[$0>>2]|0;
   $17 = HEAP32[$1>>2]|0;
   $18 = ($16>>>0)<($17>>>0);
   if ($18) {
    $19 = ((($16)) + 1|0);
    HEAP32[$0>>2] = $19;
    $20 = HEAP8[$16>>0]|0;
    $21 = $20&255;
    $c$0 = $21;$sign$0 = $15;
    break;
   } else {
    $22 = (___shgetc($f)|0);
    $c$0 = $22;$sign$0 = $15;
    break;
   }
  } else {
   $c$0 = $$lcssa333;$sign$0 = 1;
  }
 } while(0);
 $c$185 = $c$0;$i$084 = 0;
 while(1) {
  $23 = $c$185 | 32;
  $24 = (72448 + ($i$084)|0);
  $25 = HEAP8[$24>>0]|0;
  $26 = $25 << 24 >> 24;
  $27 = ($23|0)==($26|0);
  if (!($27)) {
   $c$1$lcssa = $c$185;$i$0$lcssa = $i$084;
   break;
  }
  $28 = ($i$084>>>0)<(7);
  do {
   if ($28) {
    $29 = HEAP32[$0>>2]|0;
    $30 = HEAP32[$1>>2]|0;
    $31 = ($29>>>0)<($30>>>0);
    if ($31) {
     $32 = ((($29)) + 1|0);
     HEAP32[$0>>2] = $32;
     $33 = HEAP8[$29>>0]|0;
     $34 = $33&255;
     $c$2 = $34;
     break;
    } else {
     $35 = (___shgetc($f)|0);
     $c$2 = $35;
     break;
    }
   } else {
    $c$2 = $c$185;
   }
  } while(0);
  $36 = (($i$084) + 1)|0;
  $37 = ($36>>>0)<(8);
  if ($37) {
   $c$185 = $c$2;$i$084 = $36;
  } else {
   $c$1$lcssa = $c$2;$i$0$lcssa = $36;
   break;
  }
 }
 do {
  if ((($i$0$lcssa|0) == 3)) {
   label = 23;
  } else if (!((($i$0$lcssa|0) == 8))) {
   $38 = ($i$0$lcssa>>>0)>(3);
   $39 = ($pok|0)!=(0);
   $or$cond5 = $39 & $38;
   if ($or$cond5) {
    $40 = ($i$0$lcssa|0)==(8);
    if ($40) {
     break;
    } else {
     label = 23;
     break;
    }
   }
   $51 = ($i$0$lcssa|0)==(0);
   do {
    if ($51) {
     $52 = $c$1$lcssa | 32;
     $53 = ($52|0)==(110);
     if ($53) {
      $54 = HEAP32[$0>>2]|0;
      $55 = HEAP32[$1>>2]|0;
      $56 = ($54>>>0)<($55>>>0);
      if ($56) {
       $57 = ((($54)) + 1|0);
       HEAP32[$0>>2] = $57;
       $58 = HEAP8[$54>>0]|0;
       $59 = $58&255;
       $c$4 = $59;
      } else {
       $60 = (___shgetc($f)|0);
       $c$4 = $60;
      }
      $61 = $c$4 | 32;
      $62 = ($61|0)==(97);
      if (!($62)) {
       break;
      }
      $712 = HEAP32[$0>>2]|0;
      $713 = HEAP32[$1>>2]|0;
      $714 = ($712>>>0)<($713>>>0);
      if ($714) {
       $716 = ((($712)) + 1|0);
       HEAP32[$0>>2] = $716;
       $717 = HEAP8[$712>>0]|0;
       $718 = $717&255;
       $c$4$1 = $718;
      } else {
       $715 = (___shgetc($f)|0);
       $c$4$1 = $715;
      }
      $719 = $c$4$1 | 32;
      $720 = ($719|0)==(110);
      if (!($720)) {
       break;
      }
      $63 = HEAP32[$0>>2]|0;
      $64 = HEAP32[$1>>2]|0;
      $65 = ($63>>>0)<($64>>>0);
      if ($65) {
       $66 = ((($63)) + 1|0);
       HEAP32[$0>>2] = $66;
       $67 = HEAP8[$63>>0]|0;
       $68 = $67&255;
       $71 = $68;
      } else {
       $69 = (___shgetc($f)|0);
       $71 = $69;
      }
      $70 = ($71|0)==(40);
      if ($70) {
       $i$4 = 1;
      } else {
       $72 = HEAP32[$1>>2]|0;
       $73 = ($72|0)==(0|0);
       if ($73) {
        $$0 = nan;
        STACKTOP = sp;return (+$$0);
       }
       $74 = HEAP32[$0>>2]|0;
       $75 = ((($74)) + -1|0);
       HEAP32[$0>>2] = $75;
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      while(1) {
       $76 = HEAP32[$0>>2]|0;
       $77 = HEAP32[$1>>2]|0;
       $78 = ($76>>>0)<($77>>>0);
       if ($78) {
        $79 = ((($76)) + 1|0);
        HEAP32[$0>>2] = $79;
        $80 = HEAP8[$76>>0]|0;
        $81 = $80&255;
        $84 = $81;
       } else {
        $82 = (___shgetc($f)|0);
        $84 = $82;
       }
       $83 = (($84) + -48)|0;
       $85 = ($83>>>0)<(10);
       $86 = (($84) + -65)|0;
       $87 = ($86>>>0)<(26);
       $or$cond = $85 | $87;
       if (!($or$cond)) {
        $88 = (($84) + -97)|0;
        $89 = ($88>>>0)<(26);
        $90 = ($84|0)==(95);
        $or$cond7 = $90 | $89;
        if (!($or$cond7)) {
         $$lcssa289 = $84;$i$4$lcssa = $i$4;
         break;
        }
       }
       $102 = (($i$4) + 1)|0;
       $i$4 = $102;
      }
      $91 = ($$lcssa289|0)==(41);
      if ($91) {
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      $92 = HEAP32[$1>>2]|0;
      $93 = ($92|0)==(0|0);
      if (!($93)) {
       $94 = HEAP32[$0>>2]|0;
       $95 = ((($94)) + -1|0);
       HEAP32[$0>>2] = $95;
      }
      if (!($39)) {
       $97 = (___errno_location()|0);
       HEAP32[$97>>2] = 22;
       ___shlim($f,0);
       $$0 = 0.0;
       STACKTOP = sp;return (+$$0);
      }
      $96 = ($i$4$lcssa|0)==(0);
      $brmerge187 = $96 | $93;
      if ($brmerge187) {
       $$0 = nan;
       STACKTOP = sp;return (+$$0);
      }
      $$promoted185 = HEAP32[$0>>2]|0;
      $$in = $i$4$lcssa;$100 = $$promoted185;
      while(1) {
       $98 = (($$in) + -1)|0;
       $99 = ((($100)) + -1|0);
       $101 = ($98|0)==(0);
       if ($101) {
        $$lcssa288 = $99;
        break;
       } else {
        $$in = $98;$100 = $99;
       }
      }
      HEAP32[$0>>2] = $$lcssa288;
      $$0 = nan;
      STACKTOP = sp;return (+$$0);
     }
     $108 = ($c$1$lcssa|0)==(48);
     do {
      if ($108) {
       $109 = HEAP32[$0>>2]|0;
       $110 = HEAP32[$1>>2]|0;
       $111 = ($109>>>0)<($110>>>0);
       if ($111) {
        $112 = ((($109)) + 1|0);
        HEAP32[$0>>2] = $112;
        $113 = HEAP8[$109>>0]|0;
        $114 = $113&255;
        $117 = $114;
       } else {
        $115 = (___shgetc($f)|0);
        $117 = $115;
       }
       $116 = $117 | 32;
       $118 = ($116|0)==(120);
       if (!($118)) {
        $320 = HEAP32[$1>>2]|0;
        $321 = ($320|0)==(0|0);
        if ($321) {
         $c$6 = 48;
         break;
        }
        $322 = HEAP32[$0>>2]|0;
        $323 = ((($322)) + -1|0);
        HEAP32[$0>>2] = $323;
        $c$6 = 48;
        break;
       }
       $119 = HEAP32[$0>>2]|0;
       $120 = HEAP32[$1>>2]|0;
       $121 = ($119>>>0)<($120>>>0);
       if ($121) {
        $122 = ((($119)) + 1|0);
        HEAP32[$0>>2] = $122;
        $123 = HEAP8[$119>>0]|0;
        $124 = $123&255;
        $c$0$i = $124;$gotdig$0$i = 0;
       } else {
        $125 = (___shgetc($f)|0);
        $c$0$i = $125;$gotdig$0$i = 0;
       }
       while(1) {
        if ((($c$0$i|0) == 46)) {
         $gotdig$0$i$lcssa294 = $gotdig$0$i;
         label = 71;
         break;
        } else if (!((($c$0$i|0) == 48))) {
         $163 = 0;$165 = 0;$721 = 0;$722 = 0;$c$2$i = $c$0$i;$gotdig$2$i = $gotdig$0$i;$gotrad$0$i = 0;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
         break;
        }
        $126 = HEAP32[$0>>2]|0;
        $127 = HEAP32[$1>>2]|0;
        $128 = ($126>>>0)<($127>>>0);
        if ($128) {
         $129 = ((($126)) + 1|0);
         HEAP32[$0>>2] = $129;
         $130 = HEAP8[$126>>0]|0;
         $131 = $130&255;
         $c$0$i = $131;$gotdig$0$i = 1;
         continue;
        } else {
         $132 = (___shgetc($f)|0);
         $c$0$i = $132;$gotdig$0$i = 1;
         continue;
        }
       }
       if ((label|0) == 71) {
        $133 = HEAP32[$0>>2]|0;
        $134 = HEAP32[$1>>2]|0;
        $135 = ($133>>>0)<($134>>>0);
        if ($135) {
         $136 = ((($133)) + 1|0);
         HEAP32[$0>>2] = $136;
         $137 = HEAP8[$133>>0]|0;
         $138 = $137&255;
         $c$1$ph$i = $138;
        } else {
         $139 = (___shgetc($f)|0);
         $c$1$ph$i = $139;
        }
        $140 = ($c$1$ph$i|0)==(48);
        if ($140) {
         $148 = 0;$149 = 0;
         while(1) {
          $141 = HEAP32[$0>>2]|0;
          $142 = HEAP32[$1>>2]|0;
          $143 = ($141>>>0)<($142>>>0);
          if ($143) {
           $144 = ((($141)) + 1|0);
           HEAP32[$0>>2] = $144;
           $145 = HEAP8[$141>>0]|0;
           $146 = $145&255;
           $153 = $146;
          } else {
           $147 = (___shgetc($f)|0);
           $153 = $147;
          }
          $150 = (_i64Add(($148|0),($149|0),-1,-1)|0);
          $151 = tempRet0;
          $152 = ($153|0)==(48);
          if ($152) {
           $148 = $150;$149 = $151;
          } else {
           $163 = 0;$165 = 0;$721 = $150;$722 = $151;$c$2$i = $153;$gotdig$2$i = 1;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
           break;
          }
         }
        } else {
         $163 = 0;$165 = 0;$721 = 0;$722 = 0;$c$2$i = $c$1$ph$i;$gotdig$2$i = $gotdig$0$i$lcssa294;$gotrad$0$i = 1;$gottail$0$i = 0;$scale$0$i = 1.0;$x$0$i = 0;$y$0$i = 0.0;
        }
       }
       while(1) {
        $154 = (($c$2$i) + -48)|0;
        $155 = ($154>>>0)<(10);
        $$pre$i = $c$2$i | 32;
        if ($155) {
         label = 83;
        } else {
         $156 = (($$pre$i) + -97)|0;
         $157 = ($156>>>0)<(6);
         $158 = ($c$2$i|0)==(46);
         $or$cond6$i = $158 | $157;
         if (!($or$cond6$i)) {
          $207 = $165;$208 = $721;$210 = $163;$211 = $722;$c$2$lcssa$i = $c$2$i;$gotdig$2$i$lcssa = $gotdig$2$i;$gotrad$0$i$lcssa = $gotrad$0$i;$x$0$i$lcssa = $x$0$i;$y$0$i$lcssa = $y$0$i;
          break;
         }
         if ($158) {
          $159 = ($gotrad$0$i|0)==(0);
          if ($159) {
           $723 = $165;$724 = $163;$725 = $165;$726 = $163;$gotdig$3$i = $gotdig$2$i;$gotrad$1$i = 1;$gottail$2$i = $gottail$0$i;$scale$2$i = $scale$0$i;$x$2$i = $x$0$i;$y$2$i = $y$0$i;
          } else {
           $207 = $165;$208 = $721;$210 = $163;$211 = $722;$c$2$lcssa$i = 46;$gotdig$2$i$lcssa = $gotdig$2$i;$gotrad$0$i$lcssa = $gotrad$0$i;$x$0$i$lcssa = $x$0$i;$y$0$i$lcssa = $y$0$i;
           break;
          }
         } else {
          label = 83;
         }
        }
        if ((label|0) == 83) {
         label = 0;
         $160 = ($c$2$i|0)>(57);
         $161 = (($$pre$i) + -87)|0;
         $d$0$i = $160 ? $161 : $154;
         $162 = ($163|0)<(0);
         $164 = ($165>>>0)<(8);
         $166 = ($163|0)==(0);
         $167 = $166 & $164;
         $168 = $162 | $167;
         do {
          if ($168) {
           $169 = $x$0$i << 4;
           $170 = (($d$0$i) + ($169))|0;
           $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $170;$y$1$i = $y$0$i;
          } else {
           $171 = ($163|0)<(0);
           $172 = ($165>>>0)<(14);
           $173 = ($163|0)==(0);
           $174 = $173 & $172;
           $175 = $171 | $174;
           if ($175) {
            $176 = (+($d$0$i|0));
            $177 = $scale$0$i * 0.0625;
            $178 = $177 * $176;
            $179 = $y$0$i + $178;
            $gottail$1$i = $gottail$0$i;$scale$1$i = $177;$x$1$i = $x$0$i;$y$1$i = $179;
            break;
           }
           $180 = ($d$0$i|0)==(0);
           $181 = ($gottail$0$i|0)!=(0);
           $or$cond$i = $181 | $180;
           if ($or$cond$i) {
            $gottail$1$i = $gottail$0$i;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $y$0$i;
           } else {
            $182 = $scale$0$i * 0.5;
            $183 = $y$0$i + $182;
            $gottail$1$i = 1;$scale$1$i = $scale$0$i;$x$1$i = $x$0$i;$y$1$i = $183;
           }
          }
         } while(0);
         $184 = (_i64Add(($165|0),($163|0),1,0)|0);
         $185 = tempRet0;
         $723 = $721;$724 = $722;$725 = $184;$726 = $185;$gotdig$3$i = 1;$gotrad$1$i = $gotrad$0$i;$gottail$2$i = $gottail$1$i;$scale$2$i = $scale$1$i;$x$2$i = $x$1$i;$y$2$i = $y$1$i;
        }
        $186 = HEAP32[$0>>2]|0;
        $187 = HEAP32[$1>>2]|0;
        $188 = ($186>>>0)<($187>>>0);
        if ($188) {
         $189 = ((($186)) + 1|0);
         HEAP32[$0>>2] = $189;
         $190 = HEAP8[$186>>0]|0;
         $191 = $190&255;
         $163 = $726;$165 = $725;$721 = $723;$722 = $724;$c$2$i = $191;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
         continue;
        } else {
         $192 = (___shgetc($f)|0);
         $163 = $726;$165 = $725;$721 = $723;$722 = $724;$c$2$i = $192;$gotdig$2$i = $gotdig$3$i;$gotrad$0$i = $gotrad$1$i;$gottail$0$i = $gottail$2$i;$scale$0$i = $scale$2$i;$x$0$i = $x$2$i;$y$0$i = $y$2$i;
         continue;
        }
       }
       $193 = ($gotdig$2$i$lcssa|0)==(0);
       if ($193) {
        $194 = HEAP32[$1>>2]|0;
        $195 = ($194|0)==(0|0);
        if (!($195)) {
         $196 = HEAP32[$0>>2]|0;
         $197 = ((($196)) + -1|0);
         HEAP32[$0>>2] = $197;
        }
        $198 = ($pok|0)==(0);
        if ($198) {
         ___shlim($f,0);
        } else {
         if (!($195)) {
          $199 = HEAP32[$0>>2]|0;
          $200 = ((($199)) + -1|0);
          HEAP32[$0>>2] = $200;
          $201 = ($gotrad$0$i$lcssa|0)==(0);
          if (!($201)) {
           $202 = ((($199)) + -2|0);
           HEAP32[$0>>2] = $202;
          }
         }
        }
        $203 = (+($sign$0|0));
        $204 = $203 * 0.0;
        $$0 = $204;
        STACKTOP = sp;return (+$$0);
       }
       $205 = ($gotrad$0$i$lcssa|0)==(0);
       $206 = $205 ? $207 : $208;
       $209 = $205 ? $210 : $211;
       $212 = ($210|0)<(0);
       $213 = ($207>>>0)<(8);
       $214 = ($210|0)==(0);
       $215 = $214 & $213;
       $216 = $212 | $215;
       if ($216) {
        $218 = $207;$219 = $210;$x$324$i = $x$0$i$lcssa;
        while(1) {
         $217 = $x$324$i << 4;
         $220 = (_i64Add(($218|0),($219|0),1,0)|0);
         $221 = tempRet0;
         $222 = ($221|0)<(0);
         $223 = ($220>>>0)<(8);
         $224 = ($221|0)==(0);
         $225 = $224 & $223;
         $226 = $222 | $225;
         if ($226) {
          $218 = $220;$219 = $221;$x$324$i = $217;
         } else {
          $x$3$lcssa$i = $217;
          break;
         }
        }
       } else {
        $x$3$lcssa$i = $x$0$i$lcssa;
       }
       $227 = $c$2$lcssa$i | 32;
       $228 = ($227|0)==(112);
       do {
        if ($228) {
         $229 = (_scanexp($f,$pok)|0);
         $230 = tempRet0;
         $231 = ($229|0)==(0);
         $232 = ($230|0)==(-2147483648);
         $233 = $231 & $232;
         if ($233) {
          $234 = ($pok|0)==(0);
          if ($234) {
           ___shlim($f,0);
           $$0 = 0.0;
           STACKTOP = sp;return (+$$0);
          } else {
           $235 = HEAP32[$1>>2]|0;
           $236 = ($235|0)==(0|0);
           if ($236) {
            $247 = 0;$248 = 0;
            break;
           }
           $237 = HEAP32[$0>>2]|0;
           $238 = ((($237)) + -1|0);
           HEAP32[$0>>2] = $238;
           $247 = 0;$248 = 0;
           break;
          }
         } else {
          $247 = $229;$248 = $230;
         }
        } else {
         $239 = HEAP32[$1>>2]|0;
         $240 = ($239|0)==(0|0);
         if ($240) {
          $247 = 0;$248 = 0;
         } else {
          $241 = HEAP32[$0>>2]|0;
          $242 = ((($241)) + -1|0);
          HEAP32[$0>>2] = $242;
          $247 = 0;$248 = 0;
         }
        }
       } while(0);
       $243 = (_bitshift64Shl(($206|0),($209|0),2)|0);
       $244 = tempRet0;
       $245 = (_i64Add(($243|0),($244|0),-32,-1)|0);
       $246 = tempRet0;
       $249 = (_i64Add(($245|0),($246|0),($247|0),($248|0))|0);
       $250 = tempRet0;
       $251 = ($x$3$lcssa$i|0)==(0);
       if ($251) {
        $252 = (+($sign$0|0));
        $253 = $252 * 0.0;
        $$0 = $253;
        STACKTOP = sp;return (+$$0);
       }
       $254 = (0 - ($emin$0$ph))|0;
       $255 = ($250|0)>(0);
       $256 = ($249>>>0)>($254>>>0);
       $257 = ($250|0)==(0);
       $258 = $257 & $256;
       $259 = $255 | $258;
       if ($259) {
        $260 = (___errno_location()|0);
        HEAP32[$260>>2] = 34;
        $261 = (+($sign$0|0));
        $262 = $261 * 1.7976931348623157E+308;
        $263 = $262 * 1.7976931348623157E+308;
        $$0 = $263;
        STACKTOP = sp;return (+$$0);
       }
       $264 = (($emin$0$ph) + -106)|0;
       $265 = ($264|0)<(0);
       $266 = $265 << 31 >> 31;
       $267 = ($250|0)<($266|0);
       $268 = ($249>>>0)<($264>>>0);
       $269 = ($250|0)==($266|0);
       $270 = $269 & $268;
       $271 = $267 | $270;
       if ($271) {
        $273 = (___errno_location()|0);
        HEAP32[$273>>2] = 34;
        $274 = (+($sign$0|0));
        $275 = $274 * 2.2250738585072014E-308;
        $276 = $275 * 2.2250738585072014E-308;
        $$0 = $276;
        STACKTOP = sp;return (+$$0);
       }
       $272 = ($x$3$lcssa$i|0)>(-1);
       if ($272) {
        $282 = $249;$283 = $250;$x$419$i = $x$3$lcssa$i;$y$320$i = $y$0$i$lcssa;
        while(1) {
         $277 = !($y$320$i >= 0.5);
         $278 = $x$419$i << 1;
         $279 = $y$320$i + -1.0;
         $280 = $277&1;
         $281 = $280 | $278;
         $x$5$i = $281 ^ 1;
         $$pn$i = $277 ? $y$320$i : $279;
         $y$4$i = $y$320$i + $$pn$i;
         $284 = (_i64Add(($282|0),($283|0),-1,-1)|0);
         $285 = tempRet0;
         $286 = ($281|0)>(-1);
         if ($286) {
          $282 = $284;$283 = $285;$x$419$i = $x$5$i;$y$320$i = $y$4$i;
         } else {
          $291 = $284;$292 = $285;$x$4$lcssa$i = $x$5$i;$y$3$lcssa$i = $y$4$i;
          break;
         }
        }
       } else {
        $291 = $249;$292 = $250;$x$4$lcssa$i = $x$3$lcssa$i;$y$3$lcssa$i = $y$0$i$lcssa;
       }
       $287 = ($emin$0$ph|0)<(0);
       $288 = $287 << 31 >> 31;
       $289 = (_i64Subtract(32,0,($emin$0$ph|0),($288|0))|0);
       $290 = tempRet0;
       $293 = (_i64Add(($291|0),($292|0),($289|0),($290|0))|0);
       $294 = tempRet0;
       $295 = (0)>($294|0);
       $296 = ($bits$0$ph>>>0)>($293>>>0);
       $297 = (0)==($294|0);
       $298 = $297 & $296;
       $299 = $295 | $298;
       if ($299) {
        $300 = ($293|0)<(0);
        if ($300) {
         $$0710$i = 0;
         label = 124;
        } else {
         $$07$i = $293;
         label = 122;
        }
       } else {
        $$07$i = $bits$0$ph;
        label = 122;
       }
       do {
        if ((label|0) == 122) {
         $301 = ($$07$i|0)<(53);
         if ($301) {
          $$0710$i = $$07$i;
          label = 124;
          break;
         }
         $$pre41$i = (+($sign$0|0));
         $$0711$i = $$07$i;$$pre$phi42$iZ2D = $$pre41$i;$bias$0$i = 0.0;
        }
       } while(0);
       if ((label|0) == 124) {
        $302 = (84 - ($$0710$i))|0;
        $303 = (+_scalbn(1.0,$302));
        $304 = (+($sign$0|0));
        $305 = (+_copysignl($303,$304));
        $$0711$i = $$0710$i;$$pre$phi42$iZ2D = $304;$bias$0$i = $305;
       }
       $306 = ($$0711$i|0)<(32);
       $307 = $y$3$lcssa$i != 0.0;
       $or$cond4$i = $307 & $306;
       $308 = $x$4$lcssa$i & 1;
       $309 = ($308|0)==(0);
       $or$cond9$i = $309 & $or$cond4$i;
       $310 = $or$cond9$i&1;
       $x$6$i = (($310) + ($x$4$lcssa$i))|0;
       $y$5$i = $or$cond9$i ? 0.0 : $y$3$lcssa$i;
       $311 = (+($x$6$i>>>0));
       $312 = $$pre$phi42$iZ2D * $311;
       $313 = $bias$0$i + $312;
       $314 = $$pre$phi42$iZ2D * $y$5$i;
       $315 = $314 + $313;
       $316 = $315 - $bias$0$i;
       $317 = $316 != 0.0;
       if (!($317)) {
        $318 = (___errno_location()|0);
        HEAP32[$318>>2] = 34;
       }
       $319 = (+_scalbnl($316,$291));
       $$0 = $319;
       STACKTOP = sp;return (+$$0);
      } else {
       $c$6 = $c$1$lcssa;
      }
     } while(0);
     $sum$i = (($emin$0$ph) + ($bits$0$ph))|0;
     $324 = (0 - ($sum$i))|0;
     $$09$i = $c$6;$gotdig$0$i12 = 0;
     while(1) {
      if ((($$09$i|0) == 46)) {
       $gotdig$0$i12$lcssa331 = $gotdig$0$i12;
       label = 135;
       break;
      } else if (!((($$09$i|0) == 48))) {
       $$2$i = $$09$i;$727 = 0;$728 = 0;$gotdig$2$i13 = $gotdig$0$i12;$gotrad$0$i14 = 0;
       break;
      }
      $325 = HEAP32[$0>>2]|0;
      $326 = HEAP32[$1>>2]|0;
      $327 = ($325>>>0)<($326>>>0);
      if ($327) {
       $328 = ((($325)) + 1|0);
       HEAP32[$0>>2] = $328;
       $329 = HEAP8[$325>>0]|0;
       $330 = $329&255;
       $$09$i = $330;$gotdig$0$i12 = 1;
       continue;
      } else {
       $331 = (___shgetc($f)|0);
       $$09$i = $331;$gotdig$0$i12 = 1;
       continue;
      }
     }
     if ((label|0) == 135) {
      $332 = HEAP32[$0>>2]|0;
      $333 = HEAP32[$1>>2]|0;
      $334 = ($332>>>0)<($333>>>0);
      if ($334) {
       $335 = ((($332)) + 1|0);
       HEAP32[$0>>2] = $335;
       $336 = HEAP8[$332>>0]|0;
       $337 = $336&255;
       $$1$ph$i = $337;
      } else {
       $338 = (___shgetc($f)|0);
       $$1$ph$i = $338;
      }
      $339 = ($$1$ph$i|0)==(48);
      if ($339) {
       $340 = 0;$341 = 0;
       while(1) {
        $342 = (_i64Add(($340|0),($341|0),-1,-1)|0);
        $343 = tempRet0;
        $344 = HEAP32[$0>>2]|0;
        $345 = HEAP32[$1>>2]|0;
        $346 = ($344>>>0)<($345>>>0);
        if ($346) {
         $347 = ((($344)) + 1|0);
         HEAP32[$0>>2] = $347;
         $348 = HEAP8[$344>>0]|0;
         $349 = $348&255;
         $$1$be$i = $349;
        } else {
         $350 = (___shgetc($f)|0);
         $$1$be$i = $350;
        }
        $351 = ($$1$be$i|0)==(48);
        if ($351) {
         $340 = $342;$341 = $343;
        } else {
         $$2$i = $$1$be$i;$727 = $342;$728 = $343;$gotdig$2$i13 = 1;$gotrad$0$i14 = 1;
         break;
        }
       }
      } else {
       $$2$i = $$1$ph$i;$727 = 0;$728 = 0;$gotdig$2$i13 = $gotdig$0$i12$lcssa331;$gotrad$0$i14 = 1;
      }
     }
     HEAP32[$x$i>>2] = 0;
     $352 = (($$2$i) + -48)|0;
     $353 = ($352>>>0)<(10);
     $354 = ($$2$i|0)==(46);
     $355 = $354 | $353;
     L214: do {
      if ($355) {
       $356 = ((($x$i)) + 496|0);
       $$3121$i = $$2$i;$359 = 0;$360 = 0;$729 = $354;$730 = $352;$731 = $727;$732 = $728;$gotdig$3117$i = $gotdig$2$i13;$gotrad$1118$i = $gotrad$0$i14;$j$0120$i = 0;$k$0119$i = 0;$lnz$0116$i = 0;
       L216: while(1) {
        do {
         if ($729) {
          $cond$i = ($gotrad$1118$i|0)==(0);
          if ($cond$i) {
           $733 = $359;$734 = $360;$735 = $359;$736 = $360;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = 1;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
          } else {
           $737 = $731;$738 = $732;$739 = $359;$740 = $360;$gotdig$3117$i$lcssa = $gotdig$3117$i;$j$0120$i$lcssa = $j$0120$i;$k$0119$i$lcssa = $k$0119$i;$lnz$0116$i$lcssa = $lnz$0116$i;
           break L216;
          }
         } else {
          $358 = ($k$0119$i|0)<(125);
          $361 = (_i64Add(($359|0),($360|0),1,0)|0);
          $362 = tempRet0;
          $363 = ($$3121$i|0)!=(48);
          if (!($358)) {
           if (!($363)) {
            $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
            break;
           }
           $373 = HEAP32[$356>>2]|0;
           $374 = $373 | 1;
           HEAP32[$356>>2] = $374;
           $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = $gotdig$3117$i;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $j$0120$i;$k$2$i = $k$0119$i;$lnz$2$i = $lnz$0116$i;
           break;
          }
          $$lnz$0$i = $363 ? $361 : $lnz$0116$i;
          $364 = ($j$0120$i|0)==(0);
          $365 = (($x$i) + ($k$0119$i<<2)|0);
          if ($364) {
           $storemerge$i = $730;
          } else {
           $366 = HEAP32[$365>>2]|0;
           $367 = ($366*10)|0;
           $368 = (($$3121$i) + -48)|0;
           $369 = (($368) + ($367))|0;
           $storemerge$i = $369;
          }
          HEAP32[$365>>2] = $storemerge$i;
          $370 = (($j$0120$i) + 1)|0;
          $371 = ($370|0)==(9);
          $372 = $371&1;
          $$k$0$i = (($372) + ($k$0119$i))|0;
          $$11$i = $371 ? 0 : $370;
          $733 = $731;$734 = $732;$735 = $361;$736 = $362;$gotdig$4$i = 1;$gotrad$2$i = $gotrad$1118$i;$j$2$i = $$11$i;$k$2$i = $$k$0$i;$lnz$2$i = $$lnz$0$i;
         }
        } while(0);
        $375 = HEAP32[$0>>2]|0;
        $376 = HEAP32[$1>>2]|0;
        $377 = ($375>>>0)<($376>>>0);
        if ($377) {
         $378 = ((($375)) + 1|0);
         HEAP32[$0>>2] = $378;
         $379 = HEAP8[$375>>0]|0;
         $380 = $379&255;
         $$3$be$i = $380;
        } else {
         $381 = (___shgetc($f)|0);
         $$3$be$i = $381;
        }
        $382 = (($$3$be$i) + -48)|0;
        $383 = ($382>>>0)<(10);
        $384 = ($$3$be$i|0)==(46);
        $385 = $384 | $383;
        if ($385) {
         $$3121$i = $$3$be$i;$359 = $735;$360 = $736;$729 = $384;$730 = $382;$731 = $733;$732 = $734;$gotdig$3117$i = $gotdig$4$i;$gotrad$1118$i = $gotrad$2$i;$j$0120$i = $j$2$i;$k$0119$i = $k$2$i;$lnz$0116$i = $lnz$2$i;
        } else {
         $$3$lcssa$i = $$3$be$i;$388 = $735;$389 = $733;$391 = $736;$392 = $734;$gotdig$3$lcssa$i = $gotdig$4$i;$gotrad$1$lcssa$i = $gotrad$2$i;$j$0$lcssa$i = $j$2$i;$k$0$lcssa$i = $k$2$i;$lnz$0$lcssa$i = $lnz$2$i;
         label = 158;
         break L214;
        }
       }
       $357 = ($gotdig$3117$i$lcssa|0)!=(0);
       $741 = $739;$742 = $740;$743 = $737;$744 = $738;$745 = $357;$j$069$i = $j$0120$i$lcssa;$k$065$i = $k$0119$i$lcssa;$lnz$059$i = $lnz$0116$i$lcssa;
       label = 166;
      } else {
       $$3$lcssa$i = $$2$i;$388 = 0;$389 = $727;$391 = 0;$392 = $728;$gotdig$3$lcssa$i = $gotdig$2$i13;$gotrad$1$lcssa$i = $gotrad$0$i14;$j$0$lcssa$i = 0;$k$0$lcssa$i = 0;$lnz$0$lcssa$i = 0;
       label = 158;
      }
     } while(0);
     do {
      if ((label|0) == 158) {
       $386 = ($gotrad$1$lcssa$i|0)==(0);
       $387 = $386 ? $388 : $389;
       $390 = $386 ? $391 : $392;
       $393 = ($gotdig$3$lcssa$i|0)!=(0);
       $394 = $$3$lcssa$i | 32;
       $395 = ($394|0)==(101);
       $or$cond13$i = $395 & $393;
       if (!($or$cond13$i)) {
        $410 = ($$3$lcssa$i|0)>(-1);
        if ($410) {
         $741 = $388;$742 = $391;$743 = $387;$744 = $390;$745 = $393;$j$069$i = $j$0$lcssa$i;$k$065$i = $k$0$lcssa$i;$lnz$059$i = $lnz$0$lcssa$i;
         label = 166;
         break;
        } else {
         $746 = $388;$747 = $391;$748 = $393;$749 = $387;$750 = $390;$j$068$i = $j$0$lcssa$i;$k$064$i = $k$0$lcssa$i;$lnz$058$i = $lnz$0$lcssa$i;
         label = 168;
         break;
        }
       }
       $396 = (_scanexp($f,$pok)|0);
       $397 = tempRet0;
       $398 = ($396|0)==(0);
       $399 = ($397|0)==(-2147483648);
       $400 = $398 & $399;
       if ($400) {
        $401 = ($pok|0)==(0);
        if ($401) {
         ___shlim($f,0);
         $$0$i25 = 0.0;
         break;
        }
        $402 = HEAP32[$1>>2]|0;
        $403 = ($402|0)==(0|0);
        if ($403) {
         $406 = 0;$407 = 0;
        } else {
         $404 = HEAP32[$0>>2]|0;
         $405 = ((($404)) + -1|0);
         HEAP32[$0>>2] = $405;
         $406 = 0;$407 = 0;
        }
       } else {
        $406 = $396;$407 = $397;
       }
       $408 = (_i64Add(($406|0),($407|0),($387|0),($390|0))|0);
       $409 = tempRet0;
       $421 = $408;$422 = $388;$424 = $409;$425 = $391;$j$067$i = $j$0$lcssa$i;$k$063$i = $k$0$lcssa$i;$lnz$057$i = $lnz$0$lcssa$i;
       label = 170;
      }
     } while(0);
     if ((label|0) == 166) {
      $411 = HEAP32[$1>>2]|0;
      $412 = ($411|0)==(0|0);
      if ($412) {
       $746 = $741;$747 = $742;$748 = $745;$749 = $743;$750 = $744;$j$068$i = $j$069$i;$k$064$i = $k$065$i;$lnz$058$i = $lnz$059$i;
       label = 168;
      } else {
       $413 = HEAP32[$0>>2]|0;
       $414 = ((($413)) + -1|0);
       HEAP32[$0>>2] = $414;
       if ($745) {
        $421 = $743;$422 = $741;$424 = $744;$425 = $742;$j$067$i = $j$069$i;$k$063$i = $k$065$i;$lnz$057$i = $lnz$059$i;
        label = 170;
       } else {
        label = 169;
       }
      }
     }
     if ((label|0) == 168) {
      if ($748) {
       $421 = $749;$422 = $746;$424 = $750;$425 = $747;$j$067$i = $j$068$i;$k$063$i = $k$064$i;$lnz$057$i = $lnz$058$i;
       label = 170;
      } else {
       label = 169;
      }
     }
     do {
      if ((label|0) == 169) {
       $415 = (___errno_location()|0);
       HEAP32[$415>>2] = 22;
       ___shlim($f,0);
       $$0$i25 = 0.0;
      }
      else if ((label|0) == 170) {
       $416 = HEAP32[$x$i>>2]|0;
       $417 = ($416|0)==(0);
       if ($417) {
        $418 = (+($sign$0|0));
        $419 = $418 * 0.0;
        $$0$i25 = $419;
        break;
       }
       $420 = ($421|0)==($422|0);
       $423 = ($424|0)==($425|0);
       $426 = $420 & $423;
       $427 = ($425|0)<(0);
       $428 = ($422>>>0)<(10);
       $429 = ($425|0)==(0);
       $430 = $429 & $428;
       $431 = $427 | $430;
       $or$cond$i16 = $431 & $426;
       if ($or$cond$i16) {
        $432 = ($bits$0$ph>>>0)>(30);
        $433 = $416 >>> $bits$0$ph;
        $434 = ($433|0)==(0);
        $or$cond15$i = $432 | $434;
        if ($or$cond15$i) {
         $435 = (+($sign$0|0));
         $436 = (+($416>>>0));
         $437 = $435 * $436;
         $$0$i25 = $437;
         break;
        }
       }
       $438 = (($emin$0$ph|0) / -2)&-1;
       $439 = ($438|0)<(0);
       $440 = $439 << 31 >> 31;
       $441 = ($424|0)>($440|0);
       $442 = ($421>>>0)>($438>>>0);
       $443 = ($424|0)==($440|0);
       $444 = $443 & $442;
       $445 = $441 | $444;
       if ($445) {
        $446 = (___errno_location()|0);
        HEAP32[$446>>2] = 34;
        $447 = (+($sign$0|0));
        $448 = $447 * 1.7976931348623157E+308;
        $449 = $448 * 1.7976931348623157E+308;
        $$0$i25 = $449;
        break;
       }
       $450 = (($emin$0$ph) + -106)|0;
       $451 = ($450|0)<(0);
       $452 = $451 << 31 >> 31;
       $453 = ($424|0)<($452|0);
       $454 = ($421>>>0)<($450>>>0);
       $455 = ($424|0)==($452|0);
       $456 = $455 & $454;
       $457 = $453 | $456;
       if ($457) {
        $458 = (___errno_location()|0);
        HEAP32[$458>>2] = 34;
        $459 = (+($sign$0|0));
        $460 = $459 * 2.2250738585072014E-308;
        $461 = $460 * 2.2250738585072014E-308;
        $$0$i25 = $461;
        break;
       }
       $462 = ($j$067$i|0)==(0);
       if ($462) {
        $k$3$i = $k$063$i;
       } else {
        $463 = ($j$067$i|0)<(9);
        if ($463) {
         $464 = (($x$i) + ($k$063$i<<2)|0);
         $$promoted$i = HEAP32[$464>>2]|0;
         $466 = $$promoted$i;$j$3110$i = $j$067$i;
         while(1) {
          $465 = ($466*10)|0;
          $467 = (($j$3110$i) + 1)|0;
          $exitcond$i = ($467|0)==(9);
          if ($exitcond$i) {
           $$lcssa323 = $465;
           break;
          } else {
           $466 = $465;$j$3110$i = $467;
          }
         }
         HEAP32[$464>>2] = $$lcssa323;
        }
        $468 = (($k$063$i) + 1)|0;
        $k$3$i = $468;
       }
       $469 = ($lnz$057$i|0)<(9);
       if ($469) {
        $470 = ($lnz$057$i|0)<=($421|0);
        $471 = ($421|0)<(18);
        $or$cond3$i = $470 & $471;
        if ($or$cond3$i) {
         $472 = ($421|0)==(9);
         if ($472) {
          $473 = (+($sign$0|0));
          $474 = HEAP32[$x$i>>2]|0;
          $475 = (+($474>>>0));
          $476 = $473 * $475;
          $$0$i25 = $476;
          break;
         }
         $477 = ($421|0)<(9);
         if ($477) {
          $478 = (+($sign$0|0));
          $479 = HEAP32[$x$i>>2]|0;
          $480 = (+($479>>>0));
          $481 = $478 * $480;
          $482 = (8 - ($421))|0;
          $483 = (72464 + ($482<<2)|0);
          $484 = HEAP32[$483>>2]|0;
          $485 = (+($484|0));
          $486 = $481 / $485;
          $$0$i25 = $486;
          break;
         }
         $$neg32$i = (($bits$0$ph) + 27)|0;
         $487 = Math_imul($421, -3)|0;
         $488 = (($$neg32$i) + ($487))|0;
         $489 = ($488|0)>(30);
         $$pre$i17 = HEAP32[$x$i>>2]|0;
         $490 = $$pre$i17 >>> $488;
         $491 = ($490|0)==(0);
         $or$cond216$i = $489 | $491;
         if ($or$cond216$i) {
          $492 = (+($sign$0|0));
          $493 = (+($$pre$i17>>>0));
          $494 = $492 * $493;
          $495 = (($421) + -10)|0;
          $496 = (72464 + ($495<<2)|0);
          $497 = HEAP32[$496>>2]|0;
          $498 = (+($497|0));
          $499 = $494 * $498;
          $$0$i25 = $499;
          break;
         }
        }
       }
       $500 = (($421|0) % 9)&-1;
       $501 = ($500|0)==(0);
       if ($501) {
        $a$2$ph38$i = 0;$e2$0$ph$i = 0;$rp$2$ph36$i = $421;$z$1$ph37$i = $k$3$i;
       } else {
        $502 = ($421|0)>(-1);
        $503 = (($500) + 9)|0;
        $504 = $502 ? $500 : $503;
        $505 = (8 - ($504))|0;
        $506 = (72464 + ($505<<2)|0);
        $507 = HEAP32[$506>>2]|0;
        $508 = ($k$3$i|0)==(0);
        if ($508) {
         $a$0$lcssa177$i = 0;$rp$0$lcssa178$i = $421;$z$0$i = 0;
        } else {
         $509 = (1000000000 / ($507|0))&-1;
         $a$0101$i = 0;$carry$0103$i = 0;$k$4102$i = 0;$rp$0100$i = $421;
         while(1) {
          $510 = (($x$i) + ($k$4102$i<<2)|0);
          $511 = HEAP32[$510>>2]|0;
          $512 = (($511>>>0) % ($507>>>0))&-1;
          $513 = (($511>>>0) / ($507>>>0))&-1;
          $514 = (($513) + ($carry$0103$i))|0;
          HEAP32[$510>>2] = $514;
          $515 = Math_imul($512, $509)|0;
          $516 = ($k$4102$i|0)==($a$0101$i|0);
          $517 = ($514|0)==(0);
          $or$cond16$i = $516 & $517;
          $518 = (($k$4102$i) + 1)|0;
          $519 = $518 & 127;
          $520 = (($rp$0100$i) + -9)|0;
          $rp$1$i18 = $or$cond16$i ? $520 : $rp$0100$i;
          $a$1$i = $or$cond16$i ? $519 : $a$0101$i;
          $521 = ($518|0)==($k$3$i|0);
          if ($521) {
           $$lcssa322 = $515;$a$1$i$lcssa = $a$1$i;$rp$1$i18$lcssa = $rp$1$i18;
           break;
          } else {
           $a$0101$i = $a$1$i;$carry$0103$i = $515;$k$4102$i = $518;$rp$0100$i = $rp$1$i18;
          }
         }
         $522 = ($$lcssa322|0)==(0);
         if ($522) {
          $a$0$lcssa177$i = $a$1$i$lcssa;$rp$0$lcssa178$i = $rp$1$i18$lcssa;$z$0$i = $k$3$i;
         } else {
          $523 = (($k$3$i) + 1)|0;
          $524 = (($x$i) + ($k$3$i<<2)|0);
          HEAP32[$524>>2] = $$lcssa322;
          $a$0$lcssa177$i = $a$1$i$lcssa;$rp$0$lcssa178$i = $rp$1$i18$lcssa;$z$0$i = $523;
         }
        }
        $525 = (9 - ($504))|0;
        $526 = (($525) + ($rp$0$lcssa178$i))|0;
        $a$2$ph38$i = $a$0$lcssa177$i;$e2$0$ph$i = 0;$rp$2$ph36$i = $526;$z$1$ph37$i = $z$0$i;
       }
       L296: while(1) {
        $527 = ($rp$2$ph36$i|0)<(18);
        $528 = (($x$i) + ($a$2$ph38$i<<2)|0);
        if ($527) {
         $e2$0$us$i = $e2$0$ph$i;$z$1$us$i = $z$1$ph37$i;
         while(1) {
          $530 = (($z$1$us$i) + 127)|0;
          $carry1$0$us$i = 0;$k$5$in$us$i = $530;$z$2$us$i = $z$1$us$i;
          while(1) {
           $k$5$us$i = $k$5$in$us$i & 127;
           $531 = (($x$i) + ($k$5$us$i<<2)|0);
           $532 = HEAP32[$531>>2]|0;
           $533 = (_bitshift64Shl(($532|0),0,29)|0);
           $534 = tempRet0;
           $535 = (_i64Add(($533|0),($534|0),($carry1$0$us$i|0),0)|0);
           $536 = tempRet0;
           $537 = ($536>>>0)>(0);
           $538 = ($535>>>0)>(1000000000);
           $539 = ($536|0)==(0);
           $540 = $539 & $538;
           $541 = $537 | $540;
           if ($541) {
            $542 = (___udivdi3(($535|0),($536|0),1000000000,0)|0);
            $543 = tempRet0;
            $544 = (___uremdi3(($535|0),($536|0),1000000000,0)|0);
            $545 = tempRet0;
            $$sink$off0$us$i = $544;$carry1$1$us$i = $542;
           } else {
            $$sink$off0$us$i = $535;$carry1$1$us$i = 0;
           }
           HEAP32[$531>>2] = $$sink$off0$us$i;
           $546 = (($z$2$us$i) + 127)|0;
           $547 = $546 & 127;
           $548 = ($k$5$us$i|0)!=($547|0);
           $549 = ($k$5$us$i|0)==($a$2$ph38$i|0);
           $or$cond17$us$i = $548 | $549;
           $550 = ($$sink$off0$us$i|0)==(0);
           $k$5$z$2$us$i = $550 ? $k$5$us$i : $z$2$us$i;
           $z$3$us$i = $or$cond17$us$i ? $z$2$us$i : $k$5$z$2$us$i;
           $551 = (($k$5$us$i) + -1)|0;
           if ($549) {
            $carry1$1$us$i$lcssa = $carry1$1$us$i;$z$3$us$i$lcssa = $z$3$us$i;
            break;
           } else {
            $carry1$0$us$i = $carry1$1$us$i;$k$5$in$us$i = $551;$z$2$us$i = $z$3$us$i;
           }
          }
          $552 = (($e2$0$us$i) + -29)|0;
          $553 = ($carry1$1$us$i$lcssa|0)==(0);
          if ($553) {
           $e2$0$us$i = $552;$z$1$us$i = $z$3$us$i$lcssa;
          } else {
           $$lcssa50$i = $552;$carry1$1$lcssa$lcssa$i = $carry1$1$us$i$lcssa;$z$3$lcssa$lcssa$i = $z$3$us$i$lcssa;
           break;
          }
         }
        } else {
         $529 = ($rp$2$ph36$i|0)==(18);
         if ($529) {
          $e2$0$us84$i = $e2$0$ph$i;$z$1$us85$i = $z$1$ph37$i;
         } else {
          $a$3$ph$i = $a$2$ph38$i;$e2$1$ph$i = $e2$0$ph$i;$rp$3$ph34$i = $rp$2$ph36$i;$z$5$ph$i = $z$1$ph37$i;
          break;
         }
         while(1) {
          $554 = HEAP32[$528>>2]|0;
          $555 = ($554>>>0)<(9007199);
          if (!($555)) {
           $a$3$ph$i = $a$2$ph38$i;$e2$1$ph$i = $e2$0$us84$i;$rp$3$ph34$i = 18;$z$5$ph$i = $z$1$us85$i;
           break L296;
          }
          $556 = (($z$1$us85$i) + 127)|0;
          $carry1$0$us89$i = 0;$k$5$in$us88$i = $556;$z$2$us87$i = $z$1$us85$i;
          while(1) {
           $k$5$us90$i = $k$5$in$us88$i & 127;
           $557 = (($x$i) + ($k$5$us90$i<<2)|0);
           $558 = HEAP32[$557>>2]|0;
           $559 = (_bitshift64Shl(($558|0),0,29)|0);
           $560 = tempRet0;
           $561 = (_i64Add(($559|0),($560|0),($carry1$0$us89$i|0),0)|0);
           $562 = tempRet0;
           $563 = ($562>>>0)>(0);
           $564 = ($561>>>0)>(1000000000);
           $565 = ($562|0)==(0);
           $566 = $565 & $564;
           $567 = $563 | $566;
           if ($567) {
            $568 = (___udivdi3(($561|0),($562|0),1000000000,0)|0);
            $569 = tempRet0;
            $570 = (___uremdi3(($561|0),($562|0),1000000000,0)|0);
            $571 = tempRet0;
            $$sink$off0$us93$i = $570;$carry1$1$us94$i = $568;
           } else {
            $$sink$off0$us93$i = $561;$carry1$1$us94$i = 0;
           }
           HEAP32[$557>>2] = $$sink$off0$us93$i;
           $572 = (($z$2$us87$i) + 127)|0;
           $573 = $572 & 127;
           $574 = ($k$5$us90$i|0)!=($573|0);
           $575 = ($k$5$us90$i|0)==($a$2$ph38$i|0);
           $or$cond17$us95$i = $574 | $575;
           $576 = ($$sink$off0$us93$i|0)==(0);
           $k$5$z$2$us96$i = $576 ? $k$5$us90$i : $z$2$us87$i;
           $z$3$us97$i = $or$cond17$us95$i ? $z$2$us87$i : $k$5$z$2$us96$i;
           $577 = (($k$5$us90$i) + -1)|0;
           if ($575) {
            $carry1$1$us94$i$lcssa = $carry1$1$us94$i;$z$3$us97$i$lcssa = $z$3$us97$i;
            break;
           } else {
            $carry1$0$us89$i = $carry1$1$us94$i;$k$5$in$us88$i = $577;$z$2$us87$i = $z$3$us97$i;
           }
          }
          $578 = (($e2$0$us84$i) + -29)|0;
          $579 = ($carry1$1$us94$i$lcssa|0)==(0);
          if ($579) {
           $e2$0$us84$i = $578;$z$1$us85$i = $z$3$us97$i$lcssa;
          } else {
           $$lcssa50$i = $578;$carry1$1$lcssa$lcssa$i = $carry1$1$us94$i$lcssa;$z$3$lcssa$lcssa$i = $z$3$us97$i$lcssa;
           break;
          }
         }
        }
        $580 = (($rp$2$ph36$i) + 9)|0;
        $581 = (($a$2$ph38$i) + 127)|0;
        $582 = $581 & 127;
        $583 = ($582|0)==($z$3$lcssa$lcssa$i|0);
        if ($583) {
         $584 = (($z$3$lcssa$lcssa$i) + 127)|0;
         $585 = $584 & 127;
         $586 = (($x$i) + ($585<<2)|0);
         $587 = HEAP32[$586>>2]|0;
         $588 = (($z$3$lcssa$lcssa$i) + 126)|0;
         $589 = $588 & 127;
         $590 = (($x$i) + ($589<<2)|0);
         $591 = HEAP32[$590>>2]|0;
         $592 = $591 | $587;
         HEAP32[$590>>2] = $592;
         $z$4$i = $585;
        } else {
         $z$4$i = $z$3$lcssa$lcssa$i;
        }
        $593 = (($x$i) + ($582<<2)|0);
        HEAP32[$593>>2] = $carry1$1$lcssa$lcssa$i;
        $a$2$ph38$i = $582;$e2$0$ph$i = $$lcssa50$i;$rp$2$ph36$i = $580;$z$1$ph37$i = $z$4$i;
       }
       L321: while(1) {
        $624 = (($z$5$ph$i) + 1)|0;
        $622 = $624 & 127;
        $625 = (($z$5$ph$i) + 127)|0;
        $626 = $625 & 127;
        $627 = (($x$i) + ($626<<2)|0);
        $a$3$ph183$i = $a$3$ph$i;$e2$1$ph182$i = $e2$1$ph$i;$rp$3$ph$i = $rp$3$ph34$i;
        while(1) {
         $628 = ($rp$3$ph$i|0)==(18);
         $629 = ($rp$3$ph$i|0)>(27);
         $$18$i = $629 ? 9 : 1;
         $$not$i = $628 ^ 1;
         $a$3$i = $a$3$ph183$i;$e2$1$i = $e2$1$ph182$i;
         while(1) {
          $594 = $a$3$i & 127;
          $595 = ($594|0)==($z$5$ph$i|0);
          do {
           if ($595) {
            label = 220;
           } else {
            $596 = (($x$i) + ($594<<2)|0);
            $597 = HEAP32[$596>>2]|0;
            $598 = ($597>>>0)<(9007199);
            if ($598) {
             label = 220;
             break;
            }
            $599 = ($597>>>0)>(9007199);
            if ($599) {
             break;
            }
            $600 = (($a$3$i) + 1)|0;
            $601 = $600 & 127;
            $602 = ($601|0)==($z$5$ph$i|0);
            if ($602) {
             label = 220;
             break;
            }
            $708 = (($x$i) + ($601<<2)|0);
            $709 = HEAP32[$708>>2]|0;
            $710 = ($709>>>0)<(254740991);
            if ($710) {
             label = 220;
             break;
            }
            $711 = ($709>>>0)>(254740991);
            $brmerge$i26 = $711 | $$not$i;
            if (!($brmerge$i26)) {
             $635 = $594;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $z$5$ph$i;
             break L321;
            }
           }
          } while(0);
          if ((label|0) == 220) {
           label = 0;
           if ($628) {
            label = 221;
            break L321;
           }
          }
          $603 = (($e2$1$i) + ($$18$i))|0;
          $604 = ($a$3$i|0)==($z$5$ph$i|0);
          if ($604) {
           $a$3$i = $z$5$ph$i;$e2$1$i = $603;
          } else {
           $$lcssa308 = $603;$a$3$i$lcssa300 = $a$3$i;
           break;
          }
         }
         $605 = 1 << $$18$i;
         $606 = (($605) + -1)|0;
         $607 = 1000000000 >>> $$18$i;
         $a$478$i = $a$3$i$lcssa300;$carry3$081$i = 0;$k$679$i = $a$3$i$lcssa300;$rp$477$i = $rp$3$ph$i;
         while(1) {
          $608 = (($x$i) + ($k$679$i<<2)|0);
          $609 = HEAP32[$608>>2]|0;
          $610 = $609 & $606;
          $611 = $609 >>> $$18$i;
          $612 = (($611) + ($carry3$081$i))|0;
          HEAP32[$608>>2] = $612;
          $613 = Math_imul($610, $607)|0;
          $614 = ($k$679$i|0)==($a$478$i|0);
          $615 = ($612|0)==(0);
          $or$cond19$i = $614 & $615;
          $616 = (($k$679$i) + 1)|0;
          $617 = $616 & 127;
          $618 = (($rp$477$i) + -9)|0;
          $rp$5$i = $or$cond19$i ? $618 : $rp$477$i;
          $a$5$i = $or$cond19$i ? $617 : $a$478$i;
          $619 = ($617|0)==($z$5$ph$i|0);
          if ($619) {
           $$lcssa309 = $613;$a$5$i$lcssa = $a$5$i;$rp$5$i$lcssa = $rp$5$i;
           break;
          } else {
           $a$478$i = $a$5$i;$carry3$081$i = $613;$k$679$i = $617;$rp$477$i = $rp$5$i;
          }
         }
         $620 = ($$lcssa309|0)==(0);
         if ($620) {
          $a$3$ph183$i = $a$5$i$lcssa;$e2$1$ph182$i = $$lcssa308;$rp$3$ph$i = $rp$5$i$lcssa;
          continue;
         }
         $621 = ($622|0)==($a$5$i$lcssa|0);
         if (!($621)) {
          $$lcssa308$lcssa = $$lcssa308;$$lcssa309$lcssa = $$lcssa309;$a$5$i$lcssa$lcssa = $a$5$i$lcssa;$rp$5$i$lcssa$lcssa = $rp$5$i$lcssa;
          break;
         }
         $630 = HEAP32[$627>>2]|0;
         $631 = $630 | 1;
         HEAP32[$627>>2] = $631;
         $a$3$ph183$i = $a$5$i$lcssa;$e2$1$ph182$i = $$lcssa308;$rp$3$ph$i = $rp$5$i$lcssa;
        }
        $623 = (($x$i) + ($z$5$ph$i<<2)|0);
        HEAP32[$623>>2] = $$lcssa309$lcssa;
        $a$3$ph$i = $a$5$i$lcssa$lcssa;$e2$1$ph$i = $$lcssa308$lcssa;$rp$3$ph34$i = $rp$5$i$lcssa$lcssa;$z$5$ph$i = $622;
       }
       if ((label|0) == 221) {
        if ($595) {
         $632 = (($622) + -1)|0;
         $633 = (($x$i) + ($632<<2)|0);
         HEAP32[$633>>2] = 0;
         $635 = $z$5$ph$i;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $622;
        } else {
         $635 = $594;$a$3$i301 = $a$3$i;$e2$1$i298 = $e2$1$i;$z$7$i = $z$5$ph$i;
        }
       }
       $634 = (($x$i) + ($635<<2)|0);
       $636 = HEAP32[$634>>2]|0;
       $637 = (+($636>>>0));
       $638 = (($a$3$i301) + 1)|0;
       $639 = $638 & 127;
       $640 = ($639|0)==($z$7$i|0);
       if ($640) {
        $697 = (($a$3$i301) + 2)|0;
        $698 = $697 & 127;
        $699 = (($698) + -1)|0;
        $700 = (($x$i) + ($699<<2)|0);
        HEAP32[$700>>2] = 0;
        $z$7$1$i = $698;
       } else {
        $z$7$1$i = $z$7$i;
       }
       $701 = $637 * 1.0E+9;
       $702 = (($x$i) + ($639<<2)|0);
       $703 = HEAP32[$702>>2]|0;
       $704 = (+($703>>>0));
       $705 = $701 + $704;
       $661 = (+($sign$0|0));
       $643 = $661 * $705;
       $681 = (($e2$1$i298) + 53)|0;
       $687 = (($681) - ($emin$0$ph))|0;
       $688 = ($687|0)<($bits$0$ph|0);
       $706 = ($687|0)<(0);
       $$$i = $706 ? 0 : $687;
       $denormal$0$i = $688&1;
       $$010$i = $688 ? $$$i : $bits$0$ph;
       $707 = ($$010$i|0)<(53);
       if ($707) {
        $641 = (105 - ($$010$i))|0;
        $642 = (+_scalbn(1.0,$641));
        $644 = (+_copysignl($642,$643));
        $645 = (53 - ($$010$i))|0;
        $646 = (+_scalbn(1.0,$645));
        $647 = (+_fmodl($643,$646));
        $648 = $643 - $647;
        $649 = $644 + $648;
        $bias$0$i23 = $644;$frac$0$i = $647;$y$1$i22 = $649;
       } else {
        $bias$0$i23 = 0.0;$frac$0$i = 0.0;$y$1$i22 = $643;
       }
       $650 = (($a$3$i301) + 2)|0;
       $651 = $650 & 127;
       $652 = ($651|0)==($z$7$1$i|0);
       do {
        if ($652) {
         $frac$2$i = $frac$0$i;
        } else {
         $653 = (($x$i) + ($651<<2)|0);
         $654 = HEAP32[$653>>2]|0;
         $655 = ($654>>>0)<(500000000);
         do {
          if ($655) {
           $656 = ($654|0)==(0);
           if ($656) {
            $657 = (($a$3$i301) + 3)|0;
            $658 = $657 & 127;
            $659 = ($658|0)==($z$7$1$i|0);
            if ($659) {
             $frac$1$i = $frac$0$i;
             break;
            }
           }
           $660 = $661 * 0.25;
           $662 = $660 + $frac$0$i;
           $frac$1$i = $662;
          } else {
           $663 = ($654>>>0)>(500000000);
           if ($663) {
            $664 = $661 * 0.75;
            $665 = $664 + $frac$0$i;
            $frac$1$i = $665;
            break;
           }
           $666 = (($a$3$i301) + 3)|0;
           $667 = $666 & 127;
           $668 = ($667|0)==($z$7$1$i|0);
           if ($668) {
            $669 = $661 * 0.5;
            $670 = $669 + $frac$0$i;
            $frac$1$i = $670;
            break;
           } else {
            $671 = $661 * 0.75;
            $672 = $671 + $frac$0$i;
            $frac$1$i = $672;
            break;
           }
          }
         } while(0);
         $673 = (53 - ($$010$i))|0;
         $674 = ($673|0)>(1);
         if (!($674)) {
          $frac$2$i = $frac$1$i;
          break;
         }
         $675 = (+_fmodl($frac$1$i,1.0));
         $676 = $675 != 0.0;
         if ($676) {
          $frac$2$i = $frac$1$i;
          break;
         }
         $677 = $frac$1$i + 1.0;
         $frac$2$i = $677;
        }
       } while(0);
       $678 = $y$1$i22 + $frac$2$i;
       $679 = $678 - $bias$0$i23;
       $680 = $681 & 2147483647;
       $682 = (-2 - ($sum$i))|0;
       $683 = ($680|0)>($682|0);
       do {
        if ($683) {
         $684 = (+Math_abs((+$679)));
         $685 = !($684 >= 9007199254740992.0);
         if ($685) {
          $denormal$2$i = $denormal$0$i;$e2$2$i = $e2$1$i298;$y$2$i24 = $679;
         } else {
          $686 = ($$010$i|0)==($687|0);
          $or$cond20$i = $688 & $686;
          $denormal$1$i = $or$cond20$i ? 0 : $denormal$0$i;
          $689 = $679 * 0.5;
          $690 = (($e2$1$i298) + 1)|0;
          $denormal$2$i = $denormal$1$i;$e2$2$i = $690;$y$2$i24 = $689;
         }
         $691 = (($e2$2$i) + 50)|0;
         $692 = ($691|0)>($324|0);
         if (!($692)) {
          $693 = ($denormal$2$i|0)!=(0);
          $694 = $frac$2$i != 0.0;
          $or$cond8$i = $694 & $693;
          if (!($or$cond8$i)) {
           $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
           break;
          }
         }
         $695 = (___errno_location()|0);
         HEAP32[$695>>2] = 34;
         $e2$3$i = $e2$2$i;$y$3$i = $y$2$i24;
        } else {
         $e2$3$i = $e2$1$i298;$y$3$i = $679;
        }
       } while(0);
       $696 = (+_scalbnl($y$3$i,$e2$3$i));
       $$0$i25 = $696;
      }
     } while(0);
     $$0 = $$0$i25;
     STACKTOP = sp;return (+$$0);
    }
   } while(0);
   $103 = HEAP32[$1>>2]|0;
   $104 = ($103|0)==(0|0);
   if (!($104)) {
    $105 = HEAP32[$0>>2]|0;
    $106 = ((($105)) + -1|0);
    HEAP32[$0>>2] = $106;
   }
   $107 = (___errno_location()|0);
   HEAP32[$107>>2] = 22;
   ___shlim($f,0);
   $$0 = 0.0;
   STACKTOP = sp;return (+$$0);
  }
 } while(0);
 if ((label|0) == 23) {
  $41 = HEAP32[$1>>2]|0;
  $42 = ($41|0)==(0|0);
  if (!($42)) {
   $43 = HEAP32[$0>>2]|0;
   $44 = ((($43)) + -1|0);
   HEAP32[$0>>2] = $44;
  }
  $notlhs = ($pok|0)==(0);
  $notrhs = ($i$0$lcssa>>>0)<(4);
  $or$cond9$not = $notrhs | $notlhs;
  $brmerge = $or$cond9$not | $42;
  if (!($brmerge)) {
   $$promoted = HEAP32[$0>>2]|0;
   $46 = $$promoted;$i$1 = $i$0$lcssa;
   while(1) {
    $45 = ((($46)) + -1|0);
    $47 = (($i$1) + -1)|0;
    $$old8 = ($47>>>0)>(3);
    if ($$old8) {
     $46 = $45;$i$1 = $47;
    } else {
     $$lcssa = $45;
     break;
    }
   }
   HEAP32[$0>>2] = $$lcssa;
  }
 }
 $48 = (+($sign$0|0));
 $49 = $48 * inf;
 $50 = $49;
 $$0 = $50;
 STACKTOP = sp;return (+$$0);
}
function ___shlim($f,$lim) {
 $f = $f|0;
 $lim = $lim|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 104|0);
 HEAP32[$0>>2] = $lim;
 $1 = ((($f)) + 8|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = ((($f)) + 4|0);
 $4 = HEAP32[$3>>2]|0;
 $5 = $2;
 $6 = $4;
 $7 = (($5) - ($6))|0;
 $8 = ((($f)) + 108|0);
 HEAP32[$8>>2] = $7;
 $9 = ($lim|0)!=(0);
 $10 = ($7|0)>($lim|0);
 $or$cond = $9 & $10;
 if ($or$cond) {
  $11 = (($4) + ($lim)|0);
  $12 = ((($f)) + 100|0);
  HEAP32[$12>>2] = $11;
  return;
 } else {
  $13 = ((($f)) + 100|0);
  HEAP32[$13>>2] = $5;
  return;
 }
}
function ___shgetc($f) {
 $f = $f|0;
 var $$0 = 0, $$phi$trans$insert = 0, $$phi$trans$insert3 = 0, $$pre = 0, $$pre4 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0;
 var $40 = 0, $41 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 104|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0);
 if ($2) {
  label = 3;
 } else {
  $3 = ((($f)) + 108|0);
  $4 = HEAP32[$3>>2]|0;
  $5 = ($4|0)<($1|0);
  if ($5) {
   label = 3;
  }
 }
 if ((label|0) == 3) {
  $6 = (___uflow($f)|0);
  $7 = ($6|0)<(0);
  if (!($7)) {
   $9 = HEAP32[$0>>2]|0;
   $10 = ($9|0)==(0);
   $$phi$trans$insert = ((($f)) + 8|0);
   if ($10) {
    $$pre = HEAP32[$$phi$trans$insert>>2]|0;
    $11 = $$pre;
    $26 = $$pre;$41 = $11;
    label = 9;
   } else {
    $12 = HEAP32[$$phi$trans$insert>>2]|0;
    $13 = ((($f)) + 4|0);
    $14 = HEAP32[$13>>2]|0;
    $15 = $12;
    $16 = $14;
    $17 = (($15) - ($16))|0;
    $18 = ((($f)) + 108|0);
    $19 = HEAP32[$18>>2]|0;
    $20 = (($9) - ($19))|0;
    $21 = (($20) + -1)|0;
    $22 = ($17|0)>($21|0);
    if ($22) {
     $23 = (($14) + ($21)|0);
     $24 = ((($f)) + 100|0);
     HEAP32[$24>>2] = $23;
     $28 = $12;
    } else {
     $26 = $15;$41 = $12;
     label = 9;
    }
   }
   if ((label|0) == 9) {
    $25 = ((($f)) + 100|0);
    HEAP32[$25>>2] = $26;
    $28 = $41;
   }
   $27 = ($28|0)==(0|0);
   $$phi$trans$insert3 = ((($f)) + 4|0);
   $$pre4 = HEAP32[$$phi$trans$insert3>>2]|0;
   if (!($27)) {
    $29 = $28;
    $30 = $$pre4;
    $31 = ((($f)) + 108|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = (($29) + 1)|0;
    $34 = (($33) - ($30))|0;
    $35 = (($34) + ($32))|0;
    HEAP32[$31>>2] = $35;
   }
   $36 = ((($$pre4)) + -1|0);
   $37 = HEAP8[$36>>0]|0;
   $38 = $37&255;
   $39 = ($38|0)==($6|0);
   if ($39) {
    $$0 = $6;
    return ($$0|0);
   }
   $40 = $6&255;
   HEAP8[$36>>0] = $40;
   $$0 = $6;
   return ($$0|0);
  }
 }
 $8 = ((($f)) + 100|0);
 HEAP32[$8>>2] = 0;
 $$0 = -1;
 return ($$0|0);
}
function ___expo2($x) {
 $x = +$x;
 var $0 = 0.0, $1 = 0.0, $2 = 0.0, $3 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $x + -1416.0996898839683;
 $1 = (+Math_exp((+$0)));
 $2 = $1 * 2.2471164185778949E+307;
 $3 = $2 * 2.2471164185778949E+307;
 return (+$3);
}
function _copysign($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $y;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = $1 & 2147483647;
 $5 = $3 & -2147483648;
 $6 = $5 | $4;
 HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $6;$7 = +HEAPF64[tempDoublePtr>>3];
 return (+$7);
}
function _copysignl($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_copysign($x,$y));
 return (+$0);
}
function _cosh($x) {
 $x = +$x;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0;
 var $__x = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = $1 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $2;$3 = +HEAPF64[tempDoublePtr>>3];
 $4 = ($2>>>0)<(1072049730);
 if ($4) {
  $5 = ($2>>>0)<(1045430272);
  if ($5) {
   $6 = $3 + 1.3292279957849159E+36;
   $__x = $6;
   $$0 = 1.0;
   STACKTOP = sp;return (+$$0);
  } else {
   $7 = (+_expm1($3));
   $8 = $7 * $7;
   $9 = $7 + 1.0;
   $10 = $9 * 2.0;
   $11 = $8 / $10;
   $12 = $11 + 1.0;
   $$0 = $12;
   STACKTOP = sp;return (+$$0);
  }
 } else {
  $13 = ($2>>>0)<(1082535490);
  if ($13) {
   $14 = (+Math_exp((+$3)));
   $15 = 1.0 / $14;
   $16 = $14 + $15;
   $17 = $16 * 0.5;
   $$0 = $17;
   STACKTOP = sp;return (+$$0);
  } else {
   $18 = (+___expo2($3));
   $$0 = $18;
   STACKTOP = sp;return (+$$0);
  }
 }
 return +(0.0);
}
function _expm1($x) {
 $x = +$x;
 var $$0 = 0.0, $$02 = 0.0, $$pn = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0.0, $15 = 0, $16 = 0, $17 = 0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0, $22 = 0.0, $23 = 0.0;
 var $24 = 0, $25 = 0.0, $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0, $33 = 0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0;
 var $42 = 0.0, $43 = 0.0, $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0.0, $49 = 0.0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0;
 var $60 = 0.0, $61 = 0.0, $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0.0, $71 = 0.0, $72 = 0, $73 = 0, $74 = 0, $75 = 0.0, $76 = 0, $77 = 0.0, $78 = 0.0;
 var $79 = 0, $8 = 0, $80 = 0.0, $81 = 0.0, $82 = 0.0, $83 = 0.0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0.0, $89 = 0.0, $9 = 0, $90 = 0.0, $91 = 0.0, $92 = 0.0, $93 = 0.0, $94 = 0.0, $95 = 0.0, $__x = 0.0;
 var $c$0 = 0.0, $hi$0 = 0.0, $k$0 = 0, $k$1 = 0, $lo$0 = 0.0, $y$0 = 0.0, $y$1 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = $1 & 2147483647;
 $3 = (_bitshift64Lshr(($0|0),($1|0),63)|0);
 $4 = tempRet0;
 $5 = ($2>>>0)>(1078159481);
 do {
  if ($5) {
   $6 = $1 & 2147483647;
   $7 = ($6>>>0)>(2146435072);
   $8 = ($0>>>0)>(0);
   $9 = ($6|0)==(2146435072);
   $10 = $9 & $8;
   $11 = $7 | $10;
   if ($11) {
    $$0 = $x;
    STACKTOP = sp;return (+$$0);
   }
   $12 = ($3|0)==(0);
   if (!($12)) {
    $$0 = -1.0;
    STACKTOP = sp;return (+$$0);
   }
   $13 = $x > 709.78271289338397;
   if ($13) {
    $14 = $x * 8.9884656743115795E+307;
    $$0 = $14;
    STACKTOP = sp;return (+$$0);
   } else {
    label = 11;
   }
  } else {
   $15 = ($2>>>0)>(1071001154);
   if ($15) {
    $16 = ($2>>>0)<(1072734898);
    if (!($16)) {
     label = 11;
     break;
    }
    $17 = ($3|0)==(0);
    if ($17) {
     $18 = $x + -0.69314718036912382;
     $hi$0 = $18;$k$0 = 1;$lo$0 = 1.9082149292705877E-10;
     label = 12;
     break;
    } else {
     $19 = $x + 0.69314718036912382;
     $hi$0 = $19;$k$0 = -1;$lo$0 = -1.9082149292705877E-10;
     label = 12;
     break;
    }
   }
   $32 = ($2>>>0)<(1016070144);
   if ($32) {
    $33 = ($2>>>0)<(1048576);
    if (!($33)) {
     $$0 = $x;
     STACKTOP = sp;return (+$$0);
    }
    $34 = $x;
    $__x = $34;
    $$0 = $x;
    STACKTOP = sp;return (+$$0);
   } else {
    $$02 = $x;$c$0 = 0.0;$k$1 = 0;
   }
  }
 } while(0);
 if ((label|0) == 11) {
  $20 = $x * 1.4426950408889634;
  $21 = ($3|0)!=(0);
  $22 = $21 ? -0.5 : 0.5;
  $23 = $20 + $22;
  $24 = (~~(($23)));
  $25 = (+($24|0));
  $26 = $25 * 0.69314718036912382;
  $27 = $x - $26;
  $28 = $25 * 1.9082149292705877E-10;
  $hi$0 = $27;$k$0 = $24;$lo$0 = $28;
  label = 12;
 }
 if ((label|0) == 12) {
  $29 = $hi$0 - $lo$0;
  $30 = $hi$0 - $29;
  $31 = $30 - $lo$0;
  $$02 = $29;$c$0 = $31;$k$1 = $k$0;
 }
 $35 = $$02 * 0.5;
 $36 = $$02 * $35;
 $37 = $36 * 2.0109921818362437E-7;
 $38 = 4.0082178273293624E-6 - $37;
 $39 = $36 * $38;
 $40 = $39 + -7.9365075786748794E-5;
 $41 = $36 * $40;
 $42 = $41 + 0.0015873015872548146;
 $43 = $36 * $42;
 $44 = $43 + -0.033333333333333132;
 $45 = $36 * $44;
 $46 = $45 + 1.0;
 $47 = $35 * $46;
 $48 = 3.0 - $47;
 $49 = $46 - $48;
 $50 = $$02 * $48;
 $51 = 6.0 - $50;
 $52 = $49 / $51;
 $53 = $36 * $52;
 $54 = ($k$1|0)==(0);
 if ($54) {
  $55 = $$02 * $53;
  $56 = $55 - $36;
  $57 = $$02 - $56;
  $$0 = $57;
  STACKTOP = sp;return (+$$0);
 }
 $58 = $53 - $c$0;
 $59 = $$02 * $58;
 $60 = $59 - $c$0;
 $61 = $60 - $36;
 if ((($k$1|0) == -1)) {
  $62 = $$02 - $61;
  $63 = $62 * 0.5;
  $64 = $63 + -0.5;
  $$0 = $64;
  STACKTOP = sp;return (+$$0);
 } else if ((($k$1|0) == 1)) {
  $65 = $$02 < -0.25;
  if ($65) {
   $66 = $$02 + 0.5;
   $67 = $61 - $66;
   $68 = $67 * -2.0;
   $$0 = $68;
   STACKTOP = sp;return (+$$0);
  } else {
   $69 = $$02 - $61;
   $70 = $69 * 2.0;
   $71 = $70 + 1.0;
   $$0 = $71;
   STACKTOP = sp;return (+$$0);
  }
 } else {
  $72 = (($k$1) + 1023)|0;
  $73 = (_bitshift64Shl(($72|0),0,52)|0);
  $74 = tempRet0;
  HEAP32[tempDoublePtr>>2] = $73;HEAP32[tempDoublePtr+4>>2] = $74;$75 = +HEAPF64[tempDoublePtr>>3];
  $76 = ($k$1>>>0)>(56);
  if ($76) {
   $77 = $$02 - $61;
   $78 = $77 + 1.0;
   $79 = ($k$1|0)==(1024);
   $80 = $78 * 2.0;
   $81 = $80 * 8.9884656743115795E+307;
   $82 = $75 * $78;
   $y$0 = $79 ? $81 : $82;
   $83 = $y$0 + -1.0;
   $$0 = $83;
   STACKTOP = sp;return (+$$0);
  }
  $84 = (1023 - ($k$1))|0;
  $85 = (_bitshift64Shl(($84|0),0,52)|0);
  $86 = tempRet0;
  $87 = ($k$1|0)<(20);
  if ($87) {
   $88 = $$02 - $61;
   HEAP32[tempDoublePtr>>2] = $85;HEAP32[tempDoublePtr+4>>2] = $86;$89 = +HEAPF64[tempDoublePtr>>3];
   $90 = 1.0 - $89;
   $91 = $90 + $88;
   $$pn = $91;
  } else {
   HEAP32[tempDoublePtr>>2] = $85;HEAP32[tempDoublePtr+4>>2] = $86;$92 = +HEAPF64[tempDoublePtr>>3];
   $93 = $92 + $61;
   $94 = $$02 - $93;
   $95 = $94 + 1.0;
   $$pn = $95;
  }
  $y$1 = $75 * $$pn;
  $$0 = $y$1;
  STACKTOP = sp;return (+$$0);
 }
 return +(0.0);
}
function _fmod($x,$y) {
 $x = +$x;
 $y = +$y;
 var $$0 = 0.0, $$lcssa7 = 0, $$x = 0.0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0;
 var $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0.0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0;
 var $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0;
 var $15 = 0, $150 = 0, $151 = 0.0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0;
 var $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0.0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0;
 var $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0;
 var $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0;
 var $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0.0;
 var $ex$0$lcssa = 0, $ex$026 = 0, $ex$1 = 0, $ex$2$lcssa = 0, $ex$212 = 0, $ex$3$lcssa = 0, $ex$39 = 0, $ey$0$lcssa = 0, $ey$020 = 0, $ey$1$ph = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAPF64[tempDoublePtr>>3] = $y;$2 = HEAP32[tempDoublePtr>>2]|0;
 $3 = HEAP32[tempDoublePtr+4>>2]|0;
 $4 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $5 = tempRet0;
 $6 = $4 & 2047;
 $7 = (_bitshift64Lshr(($2|0),($3|0),52)|0);
 $8 = tempRet0;
 $9 = $7 & 2047;
 $10 = $1 & -2147483648;
 $11 = (_bitshift64Shl(($2|0),($3|0),1)|0);
 $12 = tempRet0;
 $13 = ($11|0)==(0);
 $14 = ($12|0)==(0);
 $15 = $13 & $14;
 if (!($15)) {
  $16 = $3 & 2147483647;
  $17 = ($16>>>0)>(2146435072);
  $18 = ($2>>>0)>(0);
  $19 = ($16|0)==(2146435072);
  $20 = $19 & $18;
  $21 = $17 | $20;
  $22 = ($6|0)==(2047);
  $or$cond = $21 | $22;
  if (!($or$cond)) {
   $25 = (_bitshift64Shl(($0|0),($1|0),1)|0);
   $26 = tempRet0;
   $27 = ($26>>>0)>($12>>>0);
   $28 = ($25>>>0)>($11>>>0);
   $29 = ($26|0)==($12|0);
   $30 = $29 & $28;
   $31 = $27 | $30;
   if (!($31)) {
    $32 = ($25|0)==($11|0);
    $33 = ($26|0)==($12|0);
    $34 = $32 & $33;
    $35 = $x * 0.0;
    $$x = $34 ? $35 : $x;
    return (+$$x);
   }
   $36 = ($6|0)==(0);
   if ($36) {
    $37 = (_bitshift64Shl(($0|0),($1|0),12)|0);
    $38 = tempRet0;
    $39 = ($38|0)>(-1);
    $40 = ($37>>>0)>(4294967295);
    $41 = ($38|0)==(-1);
    $42 = $41 & $40;
    $43 = $39 | $42;
    if ($43) {
     $45 = $37;$46 = $38;$ex$026 = 0;
     while(1) {
      $44 = (($ex$026) + -1)|0;
      $47 = (_bitshift64Shl(($45|0),($46|0),1)|0);
      $48 = tempRet0;
      $49 = ($48|0)>(-1);
      $50 = ($47>>>0)>(4294967295);
      $51 = ($48|0)==(-1);
      $52 = $51 & $50;
      $53 = $49 | $52;
      if ($53) {
       $45 = $47;$46 = $48;$ex$026 = $44;
      } else {
       $ex$0$lcssa = $44;
       break;
      }
     }
    } else {
     $ex$0$lcssa = 0;
    }
    $54 = (1 - ($ex$0$lcssa))|0;
    $55 = (_bitshift64Shl(($0|0),($1|0),($54|0))|0);
    $56 = tempRet0;
    $83 = $55;$84 = $56;$ex$1 = $ex$0$lcssa;
   } else {
    $57 = $1 & 1048575;
    $58 = $57 | 1048576;
    $83 = $0;$84 = $58;$ex$1 = $6;
   }
   $59 = ($9|0)==(0);
   if ($59) {
    $60 = (_bitshift64Shl(($2|0),($3|0),12)|0);
    $61 = tempRet0;
    $62 = ($61|0)>(-1);
    $63 = ($60>>>0)>(4294967295);
    $64 = ($61|0)==(-1);
    $65 = $64 & $63;
    $66 = $62 | $65;
    if ($66) {
     $68 = $60;$69 = $61;$ey$020 = 0;
     while(1) {
      $67 = (($ey$020) + -1)|0;
      $70 = (_bitshift64Shl(($68|0),($69|0),1)|0);
      $71 = tempRet0;
      $72 = ($71|0)>(-1);
      $73 = ($70>>>0)>(4294967295);
      $74 = ($71|0)==(-1);
      $75 = $74 & $73;
      $76 = $72 | $75;
      if ($76) {
       $68 = $70;$69 = $71;$ey$020 = $67;
      } else {
       $ey$0$lcssa = $67;
       break;
      }
     }
    } else {
     $ey$0$lcssa = 0;
    }
    $77 = (1 - ($ey$0$lcssa))|0;
    $78 = (_bitshift64Shl(($2|0),($3|0),($77|0))|0);
    $79 = tempRet0;
    $85 = $78;$86 = $79;$ey$1$ph = $ey$0$lcssa;
   } else {
    $80 = $3 & 1048575;
    $81 = $80 | 1048576;
    $85 = $2;$86 = $81;$ey$1$ph = $9;
   }
   $82 = ($ex$1|0)>($ey$1$ph|0);
   $87 = (_i64Subtract(($83|0),($84|0),($85|0),($86|0))|0);
   $88 = tempRet0;
   $89 = ($88|0)>(-1);
   $90 = ($87>>>0)>(4294967295);
   $91 = ($88|0)==(-1);
   $92 = $91 & $90;
   $93 = $89 | $92;
   L23: do {
    if ($82) {
     $152 = $93;$153 = $87;$154 = $88;$95 = $83;$97 = $84;$ex$212 = $ex$1;
     while(1) {
      if ($152) {
       $94 = ($95|0)==($85|0);
       $96 = ($97|0)==($86|0);
       $98 = $94 & $96;
       if ($98) {
        break;
       } else {
        $100 = $153;$101 = $154;
       }
      } else {
       $100 = $95;$101 = $97;
      }
      $102 = (_bitshift64Shl(($100|0),($101|0),1)|0);
      $103 = tempRet0;
      $104 = (($ex$212) + -1)|0;
      $105 = ($104|0)>($ey$1$ph|0);
      $106 = (_i64Subtract(($102|0),($103|0),($85|0),($86|0))|0);
      $107 = tempRet0;
      $108 = ($107|0)>(-1);
      $109 = ($106>>>0)>(4294967295);
      $110 = ($107|0)==(-1);
      $111 = $110 & $109;
      $112 = $108 | $111;
      if ($105) {
       $152 = $112;$153 = $106;$154 = $107;$95 = $102;$97 = $103;$ex$212 = $104;
      } else {
       $$lcssa7 = $112;$114 = $102;$116 = $103;$155 = $106;$156 = $107;$ex$2$lcssa = $104;
       break L23;
      }
     }
     $99 = $x * 0.0;
     $$0 = $99;
     return (+$$0);
    } else {
     $$lcssa7 = $93;$114 = $83;$116 = $84;$155 = $87;$156 = $88;$ex$2$lcssa = $ex$1;
    }
   } while(0);
   if ($$lcssa7) {
    $113 = ($114|0)==($85|0);
    $115 = ($116|0)==($86|0);
    $117 = $113 & $115;
    if ($117) {
     $125 = $x * 0.0;
     $$0 = $125;
     return (+$$0);
    } else {
     $119 = $156;$121 = $155;
    }
   } else {
    $119 = $116;$121 = $114;
   }
   $118 = ($119>>>0)<(1048576);
   $120 = ($121>>>0)<(0);
   $122 = ($119|0)==(1048576);
   $123 = $122 & $120;
   $124 = $118 | $123;
   if ($124) {
    $126 = $121;$127 = $119;$ex$39 = $ex$2$lcssa;
    while(1) {
     $128 = (_bitshift64Shl(($126|0),($127|0),1)|0);
     $129 = tempRet0;
     $130 = (($ex$39) + -1)|0;
     $131 = ($129>>>0)<(1048576);
     $132 = ($128>>>0)<(0);
     $133 = ($129|0)==(1048576);
     $134 = $133 & $132;
     $135 = $131 | $134;
     if ($135) {
      $126 = $128;$127 = $129;$ex$39 = $130;
     } else {
      $137 = $128;$138 = $129;$ex$3$lcssa = $130;
      break;
     }
    }
   } else {
    $137 = $121;$138 = $119;$ex$3$lcssa = $ex$2$lcssa;
   }
   $136 = ($ex$3$lcssa|0)>(0);
   if ($136) {
    $139 = (_i64Add(($137|0),($138|0),0,-1048576)|0);
    $140 = tempRet0;
    $141 = (_bitshift64Shl(($ex$3$lcssa|0),0,52)|0);
    $142 = tempRet0;
    $143 = $139 | $141;
    $144 = $140 | $142;
    $149 = $144;$150 = $143;
   } else {
    $145 = (1 - ($ex$3$lcssa))|0;
    $146 = (_bitshift64Lshr(($137|0),($138|0),($145|0))|0);
    $147 = tempRet0;
    $149 = $147;$150 = $146;
   }
   $148 = $149 | $10;
   HEAP32[tempDoublePtr>>2] = $150;HEAP32[tempDoublePtr+4>>2] = $148;$151 = +HEAPF64[tempDoublePtr>>3];
   $$0 = $151;
   return (+$$0);
  }
 }
 $23 = $x * $y;
 $24 = $23 / $23;
 $$0 = $24;
 return (+$$0);
}
function _fmodl($x,$y) {
 $x = +$x;
 $y = +$y;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_fmod($x,$y));
 return (+$0);
}
function _frexp($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $$0 = 0.0, $$01 = 0.0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0.0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0, $9 = 0, $storemerge = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = (_bitshift64Lshr(($0|0),($1|0),52)|0);
 $3 = tempRet0;
 $4 = $2 & 2047;
 if ((($4|0) == 2047)) {
  $$0 = $x;
  return (+$$0);
 } else if ((($4|0) == 0)) {
  $5 = $x != 0.0;
  if ($5) {
   $6 = $x * 1.8446744073709552E+19;
   $7 = (+_frexp($6,$e));
   $8 = HEAP32[$e>>2]|0;
   $9 = (($8) + -64)|0;
   $$01 = $7;$storemerge = $9;
  } else {
   $$01 = $x;$storemerge = 0;
  }
  HEAP32[$e>>2] = $storemerge;
  $$0 = $$01;
  return (+$$0);
 } else {
  $10 = (($4) + -1022)|0;
  HEAP32[$e>>2] = $10;
  $11 = $1 & -2146435073;
  $12 = $11 | 1071644672;
  HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $12;$13 = +HEAPF64[tempDoublePtr>>3];
  $$0 = $13;
  return (+$$0);
 }
 return +(0.0);
}
function _frexpl($x,$e) {
 $x = +$x;
 $e = $e|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_frexp($x,$e));
 return (+$0);
}
function _log10($x) {
 $x = +$x;
 var $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0.0, $27 = 0.0, $28 = 0.0, $29 = 0.0, $3 = 0, $30 = 0.0, $31 = 0.0, $32 = 0.0, $33 = 0.0, $34 = 0.0, $35 = 0.0, $36 = 0.0, $37 = 0.0, $38 = 0.0, $39 = 0.0, $4 = 0, $40 = 0.0, $41 = 0.0, $42 = 0.0, $43 = 0.0;
 var $44 = 0.0, $45 = 0.0, $46 = 0.0, $47 = 0.0, $48 = 0, $49 = 0, $5 = 0, $50 = 0.0, $51 = 0.0, $52 = 0.0, $53 = 0.0, $54 = 0.0, $55 = 0.0, $56 = 0.0, $57 = 0.0, $58 = 0.0, $59 = 0.0, $6 = 0, $60 = 0.0, $61 = 0.0;
 var $62 = 0.0, $63 = 0.0, $64 = 0.0, $65 = 0.0, $66 = 0.0, $67 = 0.0, $68 = 0.0, $69 = 0.0, $7 = 0, $70 = 0, $8 = 0.0, $9 = 0.0, $hx$0 = 0, $k$0 = 0, $or$cond = 0, $or$cond4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = ($1>>>0)<(1048576);
 $3 = ($1|0)<(0);
 $or$cond = $3 | $2;
 do {
  if ($or$cond) {
   $4 = $1 & 2147483647;
   $5 = ($0|0)==(0);
   $6 = ($4|0)==(0);
   $7 = $5 & $6;
   if ($7) {
    $8 = $x * $x;
    $9 = -1.0 / $8;
    $$0 = $9;
    return (+$$0);
   }
   if (!($3)) {
    $12 = $x * 18014398509481984.0;
    HEAPF64[tempDoublePtr>>3] = $12;$13 = HEAP32[tempDoublePtr>>2]|0;
    $14 = HEAP32[tempDoublePtr+4>>2]|0;
    $25 = $13;$70 = $14;$hx$0 = $14;$k$0 = -1077;
    break;
   }
   $10 = $x - $x;
   $11 = $10 / 0.0;
   $$0 = $11;
   return (+$$0);
  } else {
   $15 = ($1>>>0)>(2146435071);
   if ($15) {
    $$0 = $x;
    return (+$$0);
   }
   $16 = ($1|0)==(1072693248);
   $17 = ($0|0)==(0);
   $18 = (0)==(0);
   $19 = $17 & $18;
   $or$cond4 = $19 & $16;
   if ($or$cond4) {
    $$0 = 0.0;
    return (+$$0);
   } else {
    $25 = $0;$70 = $1;$hx$0 = $1;$k$0 = -1023;
   }
  }
 } while(0);
 $20 = (($hx$0) + 614242)|0;
 $21 = $20 >>> 20;
 $22 = (($k$0) + ($21))|0;
 $23 = $20 & 1048575;
 $24 = (($23) + 1072079006)|0;
 HEAP32[tempDoublePtr>>2] = $25;HEAP32[tempDoublePtr+4>>2] = $24;$26 = +HEAPF64[tempDoublePtr>>3];
 $27 = $26 + -1.0;
 $28 = $27 * 0.5;
 $29 = $27 * $28;
 $30 = $27 + 2.0;
 $31 = $27 / $30;
 $32 = $31 * $31;
 $33 = $32 * $32;
 $34 = $33 * 0.15313837699209373;
 $35 = $34 + 0.22222198432149784;
 $36 = $33 * $35;
 $37 = $36 + 0.39999999999409419;
 $38 = $33 * $37;
 $39 = $33 * 0.14798198605116586;
 $40 = $39 + 0.1818357216161805;
 $41 = $33 * $40;
 $42 = $41 + 0.28571428743662391;
 $43 = $33 * $42;
 $44 = $43 + 0.66666666666667351;
 $45 = $32 * $44;
 $46 = $38 + $45;
 $47 = $27 - $29;
 HEAPF64[tempDoublePtr>>3] = $47;$48 = HEAP32[tempDoublePtr>>2]|0;
 $49 = HEAP32[tempDoublePtr+4>>2]|0;
 HEAP32[tempDoublePtr>>2] = 0;HEAP32[tempDoublePtr+4>>2] = $49;$50 = +HEAPF64[tempDoublePtr>>3];
 $51 = $27 - $50;
 $52 = $51 - $29;
 $53 = $29 + $46;
 $54 = $31 * $53;
 $55 = $54 + $52;
 $56 = $50 * 0.43429448187816888;
 $57 = (+($22|0));
 $58 = $57 * 0.30102999566361177;
 $59 = $57 * 3.6942390771589308E-13;
 $60 = $50 + $55;
 $61 = $60 * 2.5082946711645275E-11;
 $62 = $59 + $61;
 $63 = $55 * 0.43429448187816888;
 $64 = $63 + $62;
 $65 = $58 + $56;
 $66 = $58 - $65;
 $67 = $56 + $66;
 $68 = $67 + $64;
 $69 = $65 + $68;
 $$0 = $69;
 return (+$$0);
}
function _scalbn($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $$ = 0, $$0 = 0, $$1 = 0, $0 = 0, $1 = 0.0, $10 = 0, $11 = 0.0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0.0, $18 = 0.0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0.0, $9 = 0, $y$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)>(1023);
 if ($0) {
  $1 = $x * 8.9884656743115795E+307;
  $2 = (($n) + -1023)|0;
  $3 = ($2|0)>(1023);
  if ($3) {
   $4 = $1 * 8.9884656743115795E+307;
   $5 = (($n) + -2046)|0;
   $6 = ($5|0)>(1023);
   $$ = $6 ? 1023 : $5;
   $$0 = $$;$y$0 = $4;
  } else {
   $$0 = $2;$y$0 = $1;
  }
 } else {
  $7 = ($n|0)<(-1022);
  if ($7) {
   $8 = $x * 2.2250738585072014E-308;
   $9 = (($n) + 1022)|0;
   $10 = ($9|0)<(-1022);
   if ($10) {
    $11 = $8 * 2.2250738585072014E-308;
    $12 = (($n) + 2044)|0;
    $13 = ($12|0)<(-1022);
    $$1 = $13 ? -1022 : $12;
    $$0 = $$1;$y$0 = $11;
   } else {
    $$0 = $9;$y$0 = $8;
   }
  } else {
   $$0 = $n;$y$0 = $x;
  }
 }
 $14 = (($$0) + 1023)|0;
 $15 = (_bitshift64Shl(($14|0),0,52)|0);
 $16 = tempRet0;
 HEAP32[tempDoublePtr>>2] = $15;HEAP32[tempDoublePtr+4>>2] = $16;$17 = +HEAPF64[tempDoublePtr>>3];
 $18 = $y$0 * $17;
 return (+$18);
}
function _scalbnl($x,$n) {
 $x = +$x;
 $n = $n|0;
 var $0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (+_scalbn($x,$n));
 return (+$0);
}
function _sinh($x) {
 $x = +$x;
 var $$ = 0.0, $$0 = 0.0, $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0.0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0.0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $3 = 0, $4 = 0.0, $5 = 0;
 var $6 = 0.0, $7 = 0, $8 = 0, $9 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = ($1|0)<(0);
 $$ = $2 ? -0.5 : 0.5;
 $3 = $1 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $3;$4 = +HEAPF64[tempDoublePtr>>3];
 $5 = ($3>>>0)<(1082535490);
 if (!($5)) {
  $19 = $$ * 2.0;
  $20 = (+___expo2($4));
  $21 = $19 * $20;
  $$0 = $21;
  return (+$$0);
 }
 $6 = (+_expm1($4));
 $7 = ($3>>>0)<(1072693248);
 if (!($7)) {
  $15 = $6 + 1.0;
  $16 = $6 / $15;
  $17 = $6 + $16;
  $18 = $$ * $17;
  $$0 = $18;
  return (+$$0);
 }
 $8 = ($3>>>0)<(1045430272);
 if ($8) {
  $$0 = $x;
  return (+$$0);
 }
 $9 = $6 * 2.0;
 $10 = $6 * $6;
 $11 = $6 + 1.0;
 $12 = $10 / $11;
 $13 = $9 - $12;
 $14 = $$ * $13;
 $$0 = $14;
 return (+$$0);
}
function _tanh($x) {
 $x = +$x;
 var $0 = 0, $1 = 0, $10 = 0.0, $11 = 0.0, $12 = 0.0, $13 = 0, $14 = 0.0, $15 = 0.0, $16 = 0.0, $17 = 0.0, $18 = 0, $19 = 0.0, $2 = 0, $20 = 0.0, $21 = 0.0, $22 = 0.0, $23 = 0.0, $24 = 0.0, $25 = 0, $26 = 0.0;
 var $27 = 0.0, $3 = 0.0, $4 = 0, $5 = 0, $6 = 0.0, $7 = 0.0, $8 = 0.0, $9 = 0.0, $__x = 0.0, $t$0 = 0.0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 HEAPF64[tempDoublePtr>>3] = $x;$0 = HEAP32[tempDoublePtr>>2]|0;
 $1 = HEAP32[tempDoublePtr+4>>2]|0;
 $2 = $1 & 2147483647;
 HEAP32[tempDoublePtr>>2] = $0;HEAP32[tempDoublePtr+4>>2] = $2;$3 = +HEAPF64[tempDoublePtr>>3];
 $4 = ($2>>>0)>(1071748074);
 do {
  if ($4) {
   $5 = ($2>>>0)>(1077149696);
   if ($5) {
    $6 = 0.0 / $3;
    $7 = 1.0 - $6;
    $t$0 = $7;
    break;
   } else {
    $8 = $3 * 2.0;
    $9 = (+_expm1($8));
    $10 = $9 + 2.0;
    $11 = 2.0 / $10;
    $12 = 1.0 - $11;
    $t$0 = $12;
    break;
   }
  } else {
   $13 = ($2>>>0)>(1070618798);
   if ($13) {
    $14 = $3 * 2.0;
    $15 = (+_expm1($14));
    $16 = $15 + 2.0;
    $17 = $15 / $16;
    $t$0 = $17;
    break;
   }
   $18 = ($2>>>0)>(1048575);
   if ($18) {
    $19 = $3 * -2.0;
    $20 = (+_expm1($19));
    $21 = -$20;
    $22 = $20 + 2.0;
    $23 = $21 / $22;
    $t$0 = $23;
    break;
   } else {
    $24 = $3;
    $__x = $24;
    $t$0 = $3;
    break;
   }
  }
 } while(0);
 $25 = ($1|0)<(0);
 $26 = -$t$0;
 $27 = $25 ? $26 : $t$0;
 STACKTOP = sp;return (+$27);
}
function _wctomb($s,$wc) {
 $s = $s|0;
 $wc = $wc|0;
 var $$0 = 0, $0 = 0, $1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 0;
 } else {
  $1 = (_wcrtomb($s,$wc,0)|0);
  $$0 = $1;
 }
 return ($$0|0);
}
function _wcrtomb($s,$wc,$st) {
 $s = $s|0;
 $wc = $wc|0;
 $st = $st|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($s|0)==(0|0);
 if ($0) {
  $$0 = 1;
  return ($$0|0);
 }
 $1 = ($wc>>>0)<(128);
 if ($1) {
  $2 = $wc&255;
  HEAP8[$s>>0] = $2;
  $$0 = 1;
  return ($$0|0);
 }
 $3 = ($wc>>>0)<(2048);
 if ($3) {
  $4 = $wc >>> 6;
  $5 = $4 | 192;
  $6 = $5&255;
  $7 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $6;
  $8 = $wc & 63;
  $9 = $8 | 128;
  $10 = $9&255;
  HEAP8[$7>>0] = $10;
  $$0 = 2;
  return ($$0|0);
 }
 $11 = ($wc>>>0)<(55296);
 $12 = $wc & -8192;
 $13 = ($12|0)==(57344);
 $or$cond = $11 | $13;
 if ($or$cond) {
  $14 = $wc >>> 12;
  $15 = $14 | 224;
  $16 = $15&255;
  $17 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $16;
  $18 = $wc >>> 6;
  $19 = $18 & 63;
  $20 = $19 | 128;
  $21 = $20&255;
  $22 = ((($s)) + 2|0);
  HEAP8[$17>>0] = $21;
  $23 = $wc & 63;
  $24 = $23 | 128;
  $25 = $24&255;
  HEAP8[$22>>0] = $25;
  $$0 = 3;
  return ($$0|0);
 }
 $26 = (($wc) + -65536)|0;
 $27 = ($26>>>0)<(1048576);
 if ($27) {
  $28 = $wc >>> 18;
  $29 = $28 | 240;
  $30 = $29&255;
  $31 = ((($s)) + 1|0);
  HEAP8[$s>>0] = $30;
  $32 = $wc >>> 12;
  $33 = $32 & 63;
  $34 = $33 | 128;
  $35 = $34&255;
  $36 = ((($s)) + 2|0);
  HEAP8[$31>>0] = $35;
  $37 = $wc >>> 6;
  $38 = $37 & 63;
  $39 = $38 | 128;
  $40 = $39&255;
  $41 = ((($s)) + 3|0);
  HEAP8[$36>>0] = $40;
  $42 = $wc & 63;
  $43 = $42 | 128;
  $44 = $43&255;
  HEAP8[$41>>0] = $44;
  $$0 = 4;
  return ($$0|0);
 } else {
  $45 = (___errno_location()|0);
  HEAP32[$45>>2] = 84;
  $$0 = -1;
  return ($$0|0);
 }
 return (0)|0;
}
function _srand($s) {
 $s = $s|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($s) + -1)|0;
 $1 = 72496;
 $2 = $1;
 HEAP32[$2>>2] = $0;
 $3 = (($1) + 4)|0;
 $4 = $3;
 HEAP32[$4>>2] = 0;
 return;
}
function _rand() {
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = 72496;
 $1 = $0;
 $2 = HEAP32[$1>>2]|0;
 $3 = (($0) + 4)|0;
 $4 = $3;
 $5 = HEAP32[$4>>2]|0;
 $6 = (___muldi3(($2|0),($5|0),1284865837,1481765933)|0);
 $7 = tempRet0;
 $8 = (_i64Add(($6|0),($7|0),1,0)|0);
 $9 = tempRet0;
 $10 = 72496;
 $11 = $10;
 HEAP32[$11>>2] = $8;
 $12 = (($10) + 4)|0;
 $13 = $12;
 HEAP32[$13>>2] = $9;
 $14 = (_bitshift64Lshr(($8|0),($9|0),33)|0);
 $15 = tempRet0;
 return ($14|0);
}
function ___toread($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $3 = 0, $4 = 0;
 var $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = ((($f)) + 20|0);
 $7 = HEAP32[$6>>2]|0;
 $8 = ((($f)) + 44|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = ($7>>>0)>($9>>>0);
 if ($10) {
  $11 = ((($f)) + 36|0);
  $12 = HEAP32[$11>>2]|0;
  (FUNCTION_TABLE_iiii[$12 & 511]($f,0,0)|0);
 }
 $13 = ((($f)) + 16|0);
 HEAP32[$13>>2] = 0;
 $14 = ((($f)) + 28|0);
 HEAP32[$14>>2] = 0;
 HEAP32[$6>>2] = 0;
 $15 = HEAP32[$f>>2]|0;
 $16 = $15 & 20;
 $17 = ($16|0)==(0);
 if ($17) {
  $21 = HEAP32[$8>>2]|0;
  $22 = ((($f)) + 8|0);
  HEAP32[$22>>2] = $21;
  $23 = ((($f)) + 4|0);
  HEAP32[$23>>2] = $21;
  $$0 = 0;
  return ($$0|0);
 }
 $18 = $15 & 4;
 $19 = ($18|0)==(0);
 if ($19) {
  $$0 = -1;
  return ($$0|0);
 }
 $20 = $15 | 32;
 HEAP32[$f>>2] = $20;
 $$0 = -1;
 return ($$0|0);
}
function ___towrite($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0;
 var $8 = 0, $9 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 74|0);
 $1 = HEAP8[$0>>0]|0;
 $2 = $1 << 24 >> 24;
 $3 = (($2) + 255)|0;
 $4 = $3 | $2;
 $5 = $4&255;
 HEAP8[$0>>0] = $5;
 $6 = HEAP32[$f>>2]|0;
 $7 = $6 & 8;
 $8 = ($7|0)==(0);
 if ($8) {
  $10 = ((($f)) + 8|0);
  HEAP32[$10>>2] = 0;
  $11 = ((($f)) + 4|0);
  HEAP32[$11>>2] = 0;
  $12 = ((($f)) + 44|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = ((($f)) + 28|0);
  HEAP32[$14>>2] = $13;
  $15 = ((($f)) + 20|0);
  HEAP32[$15>>2] = $13;
  $16 = $13;
  $17 = ((($f)) + 48|0);
  $18 = HEAP32[$17>>2]|0;
  $19 = (($16) + ($18)|0);
  $20 = ((($f)) + 16|0);
  HEAP32[$20>>2] = $19;
  $$0 = 0;
  return ($$0|0);
 } else {
  $9 = $6 | 32;
  HEAP32[$f>>2] = $9;
  $$0 = -1;
  return ($$0|0);
 }
 return (0)|0;
}
function ___uflow($f) {
 $f = $f|0;
 var $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $c = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $c = sp;
 $0 = ((($f)) + 8|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 if ($2) {
  $3 = (___toread($f)|0);
  $4 = ($3|0)==(0);
  if ($4) {
   label = 3;
  } else {
   $$0 = -1;
  }
 } else {
  label = 3;
 }
 if ((label|0) == 3) {
  $5 = ((($f)) + 32|0);
  $6 = HEAP32[$5>>2]|0;
  $7 = (FUNCTION_TABLE_iiii[$6 & 511]($f,$c,1)|0);
  $8 = ($7|0)==(1);
  if ($8) {
   $9 = HEAP8[$c>>0]|0;
   $10 = $9&255;
   $$0 = $10;
  } else {
   $$0 = -1;
  }
 }
 STACKTOP = sp;return ($$0|0);
}
function ___fwritex($s,$l,$f) {
 $s = $s|0;
 $l = $l|0;
 $f = $f|0;
 var $$0 = 0, $$01 = 0, $$02 = 0, $$pre = 0, $$pre6 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0;
 var $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $i$0 = 0, $i$0$lcssa10 = 0;
 var $i$1 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ($1|0)==(0|0);
 do {
  if ($2) {
   $3 = (___towrite($f)|0);
   $4 = ($3|0)==(0);
   if ($4) {
    $$pre = HEAP32[$0>>2]|0;
    $8 = $$pre;
    break;
   } else {
    $$0 = 0;
    return ($$0|0);
   }
  } else {
   $8 = $1;
  }
 } while(0);
 $5 = ((($f)) + 20|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = $8;
 $9 = $6;
 $10 = (($7) - ($9))|0;
 $11 = ($10>>>0)<($l>>>0);
 if ($11) {
  $12 = ((($f)) + 36|0);
  $13 = HEAP32[$12>>2]|0;
  $14 = (FUNCTION_TABLE_iiii[$13 & 511]($f,$s,$l)|0);
  $$0 = $14;
  return ($$0|0);
 }
 $15 = ((($f)) + 75|0);
 $16 = HEAP8[$15>>0]|0;
 $17 = ($16<<24>>24)>(-1);
 L11: do {
  if ($17) {
   $i$0 = $l;
   while(1) {
    $18 = ($i$0|0)==(0);
    if ($18) {
     $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
     break L11;
    }
    $19 = (($i$0) + -1)|0;
    $20 = (($s) + ($19)|0);
    $21 = HEAP8[$20>>0]|0;
    $22 = ($21<<24>>24)==(10);
    if ($22) {
     $i$0$lcssa10 = $i$0;
     break;
    } else {
     $i$0 = $19;
    }
   }
   $23 = ((($f)) + 36|0);
   $24 = HEAP32[$23>>2]|0;
   $25 = (FUNCTION_TABLE_iiii[$24 & 511]($f,$s,$i$0$lcssa10)|0);
   $26 = ($25>>>0)<($i$0$lcssa10>>>0);
   if ($26) {
    $$0 = $i$0$lcssa10;
    return ($$0|0);
   } else {
    $27 = (($s) + ($i$0$lcssa10)|0);
    $28 = (($l) - ($i$0$lcssa10))|0;
    $$pre6 = HEAP32[$5>>2]|0;
    $$01 = $28;$$02 = $27;$29 = $$pre6;$i$1 = $i$0$lcssa10;
    break;
   }
  } else {
   $$01 = $l;$$02 = $s;$29 = $6;$i$1 = 0;
  }
 } while(0);
 _memcpy(($29|0),($$02|0),($$01|0))|0;
 $30 = HEAP32[$5>>2]|0;
 $31 = (($30) + ($$01)|0);
 HEAP32[$5>>2] = $31;
 $32 = (($i$1) + ($$01))|0;
 $$0 = $32;
 return ($$0|0);
}
function _snprintf($s,$n,$fmt,$varargs) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsnprintf($s,$n,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _sprintf($s,$fmt,$varargs) {
 $s = $s|0;
 $fmt = $fmt|0;
 $varargs = $varargs|0;
 var $0 = 0, $ap = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 16|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap = sp;
 HEAP32[$ap>>2] = $varargs;
 $0 = (_vsprintf($s,$fmt,$ap)|0);
 STACKTOP = sp;return ($0|0);
}
function _MUSL_vfprintf($f,$fmt,$ap) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$ = 0, $$0 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $ap2 = 0, $internal_buf = 0, $nl_arg = 0, $nl_type = 0, $ret$1 = 0, $vacopy_currentptr = 0, dest = 0, label = 0, sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 224|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $ap2 = sp + 120|0;
 $nl_type = sp + 80|0;
 $nl_arg = sp;
 $internal_buf = sp + 136|0;
 dest=$nl_type; stop=dest+40|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $vacopy_currentptr = HEAP32[$ap>>2]|0;
 HEAP32[$ap2>>2] = $vacopy_currentptr;
 $0 = (_printf_core(0,$fmt,$ap2,$nl_arg,$nl_type)|0);
 $1 = ($0|0)<(0);
 if ($1) {
  $$0 = -1;
  STACKTOP = sp;return ($$0|0);
 }
 $2 = ((($f)) + 48|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($3|0)==(0);
 if ($4) {
  $6 = ((($f)) + 44|0);
  $7 = HEAP32[$6>>2]|0;
  HEAP32[$6>>2] = $internal_buf;
  $8 = ((($f)) + 28|0);
  HEAP32[$8>>2] = $internal_buf;
  $9 = ((($f)) + 20|0);
  HEAP32[$9>>2] = $internal_buf;
  HEAP32[$2>>2] = 80;
  $10 = ((($internal_buf)) + 80|0);
  $11 = ((($f)) + 16|0);
  HEAP32[$11>>2] = $10;
  $12 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $13 = ($7|0)==(0|0);
  if ($13) {
   $ret$1 = $12;
  } else {
   $14 = ((($f)) + 36|0);
   $15 = HEAP32[$14>>2]|0;
   (FUNCTION_TABLE_iiii[$15 & 511]($f,0,0)|0);
   $16 = HEAP32[$9>>2]|0;
   $17 = ($16|0)==(0|0);
   $$ = $17 ? -1 : $12;
   HEAP32[$6>>2] = $7;
   HEAP32[$2>>2] = 0;
   HEAP32[$11>>2] = 0;
   HEAP32[$8>>2] = 0;
   HEAP32[$9>>2] = 0;
   $ret$1 = $$;
  }
 } else {
  $5 = (_printf_core($f,$fmt,$ap2,$nl_arg,$nl_type)|0);
  $ret$1 = $5;
 }
 $$0 = $ret$1;
 STACKTOP = sp;return ($$0|0);
}
function _vsnprintf($s,$n,$fmt,$ap) {
 $s = $s|0;
 $n = $n|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $$$02 = 0, $$0 = 0, $$01 = 0, $$02 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0;
 var $6 = 0, $7 = 0, $8 = 0, $9 = 0, $b = 0, $f = 0, dest = 0, label = 0, sp = 0, src = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 128|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $b = sp + 112|0;
 $f = sp;
 dest=$f; src=72504; stop=dest+112|0; do { HEAP32[dest>>2]=HEAP32[src>>2]|0; dest=dest+4|0; src=src+4|0; } while ((dest|0) < (stop|0));
 $0 = (($n) + -1)|0;
 $1 = ($0>>>0)>(2147483646);
 if ($1) {
  $2 = ($n|0)==(0);
  if ($2) {
   $$01 = $b;$$02 = 1;
  } else {
   $3 = (___errno_location()|0);
   HEAP32[$3>>2] = 75;
   $$0 = -1;
   STACKTOP = sp;return ($$0|0);
  }
 } else {
  $$01 = $s;$$02 = $n;
 }
 $4 = $$01;
 $5 = (-2 - ($4))|0;
 $6 = ($$02>>>0)>($5>>>0);
 $$$02 = $6 ? $5 : $$02;
 $7 = ((($f)) + 48|0);
 HEAP32[$7>>2] = $$$02;
 $8 = ((($f)) + 20|0);
 HEAP32[$8>>2] = $$01;
 $9 = ((($f)) + 44|0);
 HEAP32[$9>>2] = $$01;
 $10 = (($$01) + ($$$02)|0);
 $11 = ((($f)) + 16|0);
 HEAP32[$11>>2] = $10;
 $12 = ((($f)) + 28|0);
 HEAP32[$12>>2] = $10;
 $13 = (_MUSL_vfprintf($f,$fmt,$ap)|0);
 $14 = ($$$02|0)==(0);
 if ($14) {
  $$0 = $13;
  STACKTOP = sp;return ($$0|0);
 }
 $15 = HEAP32[$8>>2]|0;
 $16 = HEAP32[$11>>2]|0;
 $17 = ($15|0)==($16|0);
 $18 = $17 << 31 >> 31;
 $19 = (($15) + ($18)|0);
 HEAP8[$19>>0] = 0;
 $$0 = $13;
 STACKTOP = sp;return ($$0|0);
}
function _vsprintf($s,$fmt,$ap) {
 $s = $s|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 var $0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (_vsnprintf($s,2147483647,$fmt,$ap)|0);
 return ($0|0);
}
function _atoi($s) {
 $s = $s|0;
 var $$0 = 0, $$0$lcssa = 0, $$1$ph = 0, $$13 = 0, $$lcssa9 = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $isdigit = 0, $isdigit2 = 0, $isdigittmp = 0, $isdigittmp1 = 0, $isdigittmp5 = 0, $n$0$lcssa = 0, $n$04 = 0, $neg$0 = 0, $neg$1$ph = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $$0 = $s;
 while(1) {
  $0 = HEAP8[$$0>>0]|0;
  $1 = $0 << 24 >> 24;
  $2 = (_isspace($1)|0);
  $3 = ($2|0)==(0);
  $4 = ((($$0)) + 1|0);
  if ($3) {
   $$0$lcssa = $$0;$$lcssa9 = $4;
   break;
  } else {
   $$0 = $4;
  }
 }
 $5 = HEAP8[$$0$lcssa>>0]|0;
 $6 = $5 << 24 >> 24;
 if ((($6|0) == 43)) {
  $neg$0 = 0;
  label = 5;
 } else if ((($6|0) == 45)) {
  $neg$0 = 1;
  label = 5;
 } else {
  $$1$ph = $$0$lcssa;$8 = $5;$neg$1$ph = 0;
 }
 if ((label|0) == 5) {
  $$pre = HEAP8[$$lcssa9>>0]|0;
  $$1$ph = $$lcssa9;$8 = $$pre;$neg$1$ph = $neg$0;
 }
 $7 = $8 << 24 >> 24;
 $isdigittmp1 = (($7) + -48)|0;
 $isdigit2 = ($isdigittmp1>>>0)<(10);
 if ($isdigit2) {
  $$13 = $$1$ph;$isdigittmp5 = $isdigittmp1;$n$04 = 0;
 } else {
  $n$0$lcssa = 0;
  $14 = ($neg$1$ph|0)!=(0);
  $15 = (0 - ($n$0$lcssa))|0;
  $16 = $14 ? $n$0$lcssa : $15;
  return ($16|0);
 }
 while(1) {
  $9 = ($n$04*10)|0;
  $10 = ((($$13)) + 1|0);
  $11 = (($9) - ($isdigittmp5))|0;
  $12 = HEAP8[$10>>0]|0;
  $13 = $12 << 24 >> 24;
  $isdigittmp = (($13) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $$13 = $10;$isdigittmp5 = $isdigittmp;$n$04 = $11;
  } else {
   $n$0$lcssa = $11;
   break;
  }
 }
 $14 = ($neg$1$ph|0)!=(0);
 $15 = (0 - ($n$0$lcssa))|0;
 $16 = $14 ? $n$0$lcssa : $15;
 return ($16|0);
}
function _strtod($s,$p) {
 $s = $s|0;
 $p = $p|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0.0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$i = 0, dest = 0, label = 0;
 var sp = 0, stop = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $f$i = sp;
 dest=$f$i; stop=dest+112|0; do { HEAP32[dest>>2]=0|0; dest=dest+4|0; } while ((dest|0) < (stop|0));
 $0 = ((($f$i)) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = ((($f$i)) + 8|0);
 HEAP32[$1>>2] = (-1);
 $2 = ((($f$i)) + 44|0);
 HEAP32[$2>>2] = $s;
 $3 = ((($f$i)) + 76|0);
 HEAP32[$3>>2] = -1;
 ___shlim($f$i,0);
 $4 = (+___floatscan($f$i,1,1));
 $5 = ((($f$i)) + 108|0);
 $6 = HEAP32[$5>>2]|0;
 $7 = HEAP32[$0>>2]|0;
 $8 = HEAP32[$1>>2]|0;
 $9 = $7;
 $10 = $8;
 $11 = (($9) - ($10))|0;
 $12 = (($11) + ($6))|0;
 $13 = ($p|0)==(0|0);
 if ($13) {
  STACKTOP = sp;return (+$4);
 }
 $14 = ($12|0)!=(0);
 $15 = (($s) + ($12)|0);
 $16 = $14 ? $15 : $s;
 HEAP32[$p>>2] = $16;
 STACKTOP = sp;return (+$4);
}
function _strtol($s,$p,$base) {
 $s = $s|0;
 $p = $p|0;
 $base = $base|0;
 var $$sink$i = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $f$i = 0;
 var label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 112|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $f$i = sp;
 HEAP32[$f$i>>2] = 0;
 $0 = ((($f$i)) + 4|0);
 HEAP32[$0>>2] = $s;
 $1 = ((($f$i)) + 44|0);
 HEAP32[$1>>2] = $s;
 $2 = ($s|0)<(0|0);
 $3 = ((($s)) + 2147483647|0);
 $$sink$i = $2 ? (-1) : $3;
 $4 = ((($f$i)) + 8|0);
 HEAP32[$4>>2] = $$sink$i;
 $5 = ((($f$i)) + 76|0);
 HEAP32[$5>>2] = -1;
 ___shlim($f$i,0);
 $6 = (___intscan($f$i,$base,1,-2147483648,0)|0);
 $7 = tempRet0;
 $8 = ($p|0)==(0|0);
 if ($8) {
  STACKTOP = sp;return ($6|0);
 }
 $9 = ((($f$i)) + 108|0);
 $10 = HEAP32[$9>>2]|0;
 $11 = HEAP32[$0>>2]|0;
 $12 = HEAP32[$4>>2]|0;
 $13 = $11;
 $14 = $12;
 $15 = (($13) + ($10))|0;
 $16 = (($15) - ($14))|0;
 $17 = (($s) + ($16)|0);
 HEAP32[$p>>2] = $17;
 STACKTOP = sp;return ($6|0);
}
function _memchr($src,$c,$n) {
 $src = $src|0;
 $c = $c|0;
 $n = $n|0;
 var $$0$lcssa = 0, $$0$lcssa44 = 0, $$019 = 0, $$1$lcssa = 0, $$110 = 0, $$110$lcssa = 0, $$24 = 0, $$3 = 0, $$lcssa = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0;
 var $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond18 = 0, $s$0$lcssa = 0, $s$0$lcssa43 = 0, $s$020 = 0, $s$15 = 0, $s$2 = 0, $w$0$lcssa = 0, $w$011 = 0, $w$011$lcssa = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = $c & 255;
 $1 = $src;
 $2 = $1 & 3;
 $3 = ($2|0)!=(0);
 $4 = ($n|0)!=(0);
 $or$cond18 = $4 & $3;
 L1: do {
  if ($or$cond18) {
   $5 = $c&255;
   $$019 = $n;$s$020 = $src;
   while(1) {
    $6 = HEAP8[$s$020>>0]|0;
    $7 = ($6<<24>>24)==($5<<24>>24);
    if ($7) {
     $$0$lcssa44 = $$019;$s$0$lcssa43 = $s$020;
     label = 6;
     break L1;
    }
    $8 = ((($s$020)) + 1|0);
    $9 = (($$019) + -1)|0;
    $10 = $8;
    $11 = $10 & 3;
    $12 = ($11|0)!=(0);
    $13 = ($9|0)!=(0);
    $or$cond = $13 & $12;
    if ($or$cond) {
     $$019 = $9;$s$020 = $8;
    } else {
     $$0$lcssa = $9;$$lcssa = $13;$s$0$lcssa = $8;
     label = 5;
     break;
    }
   }
  } else {
   $$0$lcssa = $n;$$lcssa = $4;$s$0$lcssa = $src;
   label = 5;
  }
 } while(0);
 if ((label|0) == 5) {
  if ($$lcssa) {
   $$0$lcssa44 = $$0$lcssa;$s$0$lcssa43 = $s$0$lcssa;
   label = 6;
  } else {
   $$3 = 0;$s$2 = $s$0$lcssa;
  }
 }
 L8: do {
  if ((label|0) == 6) {
   $14 = HEAP8[$s$0$lcssa43>>0]|0;
   $15 = $c&255;
   $16 = ($14<<24>>24)==($15<<24>>24);
   if ($16) {
    $$3 = $$0$lcssa44;$s$2 = $s$0$lcssa43;
   } else {
    $17 = Math_imul($0, 16843009)|0;
    $18 = ($$0$lcssa44>>>0)>(3);
    L11: do {
     if ($18) {
      $$110 = $$0$lcssa44;$w$011 = $s$0$lcssa43;
      while(1) {
       $19 = HEAP32[$w$011>>2]|0;
       $20 = $19 ^ $17;
       $21 = (($20) + -16843009)|0;
       $22 = $20 & -2139062144;
       $23 = $22 ^ -2139062144;
       $24 = $23 & $21;
       $25 = ($24|0)==(0);
       if (!($25)) {
        $$110$lcssa = $$110;$w$011$lcssa = $w$011;
        break;
       }
       $26 = ((($w$011)) + 4|0);
       $27 = (($$110) + -4)|0;
       $28 = ($27>>>0)>(3);
       if ($28) {
        $$110 = $27;$w$011 = $26;
       } else {
        $$1$lcssa = $27;$w$0$lcssa = $26;
        label = 11;
        break L11;
       }
      }
      $$24 = $$110$lcssa;$s$15 = $w$011$lcssa;
     } else {
      $$1$lcssa = $$0$lcssa44;$w$0$lcssa = $s$0$lcssa43;
      label = 11;
     }
    } while(0);
    if ((label|0) == 11) {
     $29 = ($$1$lcssa|0)==(0);
     if ($29) {
      $$3 = 0;$s$2 = $w$0$lcssa;
      break;
     } else {
      $$24 = $$1$lcssa;$s$15 = $w$0$lcssa;
     }
    }
    while(1) {
     $30 = HEAP8[$s$15>>0]|0;
     $31 = ($30<<24>>24)==($15<<24>>24);
     if ($31) {
      $$3 = $$24;$s$2 = $s$15;
      break L8;
     }
     $32 = ((($s$15)) + 1|0);
     $33 = (($$24) + -1)|0;
     $34 = ($33|0)==(0);
     if ($34) {
      $$3 = 0;$s$2 = $32;
      break;
     } else {
      $$24 = $33;$s$15 = $32;
     }
    }
   }
  }
 } while(0);
 $35 = ($$3|0)!=(0);
 $36 = $35 ? $s$2 : 0;
 return ($36|0);
}
function _memcmp($vl,$vr,$n) {
 $vl = $vl|0;
 $vr = $vr|0;
 $n = $n|0;
 var $$03 = 0, $$lcssa = 0, $$lcssa19 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$04 = 0, $r$05 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $11 = 0;
  return ($11|0);
 } else {
  $$03 = $n;$l$04 = $vl;$r$05 = $vr;
 }
 while(1) {
  $1 = HEAP8[$l$04>>0]|0;
  $2 = HEAP8[$r$05>>0]|0;
  $3 = ($1<<24>>24)==($2<<24>>24);
  if (!($3)) {
   $$lcssa = $1;$$lcssa19 = $2;
   break;
  }
  $4 = (($$03) + -1)|0;
  $5 = ((($l$04)) + 1|0);
  $6 = ((($r$05)) + 1|0);
  $7 = ($4|0)==(0);
  if ($7) {
   $11 = 0;
   label = 5;
   break;
  } else {
   $$03 = $4;$l$04 = $5;$r$05 = $6;
  }
 }
 if ((label|0) == 5) {
  return ($11|0);
 }
 $8 = $$lcssa&255;
 $9 = $$lcssa19&255;
 $10 = (($8) - ($9))|0;
 $11 = $10;
 return ($11|0);
}
function _strcasecmp($_l,$_r) {
 $_l = $_l|0;
 $_r = $_r|0;
 var $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $3 = 0;
 var $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$03 = 0, $l$03$lcssa24 = 0, $r$0$lcssa = 0, $r$04 = 0, $r$04$lcssa23 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$_l>>0]|0;
 $1 = ($0<<24>>24)==(0);
 L1: do {
  if ($1) {
   $19 = 0;$r$0$lcssa = $_r;
  } else {
   $2 = $0&255;
   $6 = $0;$7 = $2;$l$03 = $_l;$r$04 = $_r;
   while(1) {
    $3 = HEAP8[$r$04>>0]|0;
    $4 = ($3<<24>>24)==(0);
    if ($4) {
     $19 = $6;$r$0$lcssa = $r$04;
     break L1;
    }
    $5 = ($6<<24>>24)==($3<<24>>24);
    if (!($5)) {
     $8 = (_tolower($7)|0);
     $9 = HEAP8[$r$04>>0]|0;
     $10 = $9&255;
     $11 = (_tolower($10)|0);
     $12 = ($8|0)==($11|0);
     if (!($12)) {
      $l$03$lcssa24 = $l$03;$r$04$lcssa23 = $r$04;
      break;
     }
    }
    $13 = ((($l$03)) + 1|0);
    $14 = ((($r$04)) + 1|0);
    $15 = HEAP8[$13>>0]|0;
    $16 = $15&255;
    $17 = ($15<<24>>24)==(0);
    if ($17) {
     $19 = 0;$r$0$lcssa = $14;
     break L1;
    } else {
     $6 = $15;$7 = $16;$l$03 = $13;$r$04 = $14;
    }
   }
   $$pre = HEAP8[$l$03$lcssa24>>0]|0;
   $19 = $$pre;$r$0$lcssa = $r$04$lcssa23;
  }
 } while(0);
 $18 = $19&255;
 $20 = (_tolower($18)|0);
 $21 = HEAP8[$r$0$lcssa>>0]|0;
 $22 = $21&255;
 $23 = (_tolower($22)|0);
 $24 = (($20) - ($23))|0;
 return ($24|0);
}
function _strcmp($l,$r) {
 $l = $l|0;
 $r = $r|0;
 var $$014 = 0, $$05 = 0, $$lcssa = 0, $$lcssa2 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $or$cond = 0, $or$cond3 = 0, label = 0;
 var sp = 0;
 sp = STACKTOP;
 $0 = HEAP8[$l>>0]|0;
 $1 = HEAP8[$r>>0]|0;
 $2 = ($0<<24>>24)!=($1<<24>>24);
 $3 = ($0<<24>>24)==(0);
 $or$cond3 = $3 | $2;
 if ($or$cond3) {
  $$lcssa = $0;$$lcssa2 = $1;
 } else {
  $$014 = $l;$$05 = $r;
  while(1) {
   $4 = ((($$014)) + 1|0);
   $5 = ((($$05)) + 1|0);
   $6 = HEAP8[$4>>0]|0;
   $7 = HEAP8[$5>>0]|0;
   $8 = ($6<<24>>24)!=($7<<24>>24);
   $9 = ($6<<24>>24)==(0);
   $or$cond = $9 | $8;
   if ($or$cond) {
    $$lcssa = $6;$$lcssa2 = $7;
    break;
   } else {
    $$014 = $4;$$05 = $5;
   }
  }
 }
 $10 = $$lcssa&255;
 $11 = $$lcssa2&255;
 $12 = (($10) - ($11))|0;
 return ($12|0);
}
function _strncasecmp($_l,$_r,$n) {
 $_l = $_l|0;
 $_r = $_r|0;
 $n = $n|0;
 var $$04 = 0, $$08 = 0, $$08$in = 0, $$pre = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0;
 var $23 = 0, $24 = 0, $25 = 0, $26 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$06 = 0, $l$06$lcssa28 = 0, $or$cond = 0, $r$0$lcssa = 0, $r$07 = 0, $r$07$lcssa27 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $$04 = 0;
  return ($$04|0);
 }
 $1 = HEAP8[$_l>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L4: do {
  if ($2) {
   $21 = 0;$r$0$lcssa = $_r;
  } else {
   $3 = $1&255;
   $$08$in = $n;$8 = $1;$9 = $3;$l$06 = $_l;$r$07 = $_r;
   while(1) {
    $$08 = (($$08$in) + -1)|0;
    $4 = HEAP8[$r$07>>0]|0;
    $5 = ($4<<24>>24)!=(0);
    $6 = ($$08|0)!=(0);
    $or$cond = $6 & $5;
    if (!($or$cond)) {
     $21 = $8;$r$0$lcssa = $r$07;
     break L4;
    }
    $7 = ($8<<24>>24)==($4<<24>>24);
    if (!($7)) {
     $10 = (_tolower($9)|0);
     $11 = HEAP8[$r$07>>0]|0;
     $12 = $11&255;
     $13 = (_tolower($12)|0);
     $14 = ($10|0)==($13|0);
     if (!($14)) {
      $l$06$lcssa28 = $l$06;$r$07$lcssa27 = $r$07;
      break;
     }
    }
    $15 = ((($l$06)) + 1|0);
    $16 = ((($r$07)) + 1|0);
    $17 = HEAP8[$15>>0]|0;
    $18 = $17&255;
    $19 = ($17<<24>>24)==(0);
    if ($19) {
     $21 = 0;$r$0$lcssa = $16;
     break L4;
    } else {
     $$08$in = $$08;$8 = $17;$9 = $18;$l$06 = $15;$r$07 = $16;
    }
   }
   $$pre = HEAP8[$l$06$lcssa28>>0]|0;
   $21 = $$pre;$r$0$lcssa = $r$07$lcssa27;
  }
 } while(0);
 $20 = $21&255;
 $22 = (_tolower($20)|0);
 $23 = HEAP8[$r$0$lcssa>>0]|0;
 $24 = $23&255;
 $25 = (_tolower($24)|0);
 $26 = (($22) - ($25))|0;
 $$04 = $26;
 return ($$04|0);
}
function _strncmp($_l,$_r,$n) {
 $_l = $_l|0;
 $_r = $_r|0;
 $n = $n|0;
 var $$03 = 0, $$08 = 0, $$08$in = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0;
 var $l$06 = 0, $or$cond = 0, $or$cond4 = 0, $r$0$lcssa = 0, $r$07 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n|0)==(0);
 if ($0) {
  $$03 = 0;
  return ($$03|0);
 }
 $1 = HEAP8[$_l>>0]|0;
 $2 = ($1<<24>>24)==(0);
 L4: do {
  if ($2) {
   $13 = 0;$r$0$lcssa = $_r;
  } else {
   $$08$in = $n;$7 = $1;$l$06 = $_l;$r$07 = $_r;
   while(1) {
    $$08 = (($$08$in) + -1)|0;
    $3 = HEAP8[$r$07>>0]|0;
    $4 = ($3<<24>>24)!=(0);
    $5 = ($$08|0)!=(0);
    $or$cond = $5 & $4;
    $6 = ($7<<24>>24)==($3<<24>>24);
    $or$cond4 = $6 & $or$cond;
    if (!($or$cond4)) {
     $13 = $7;$r$0$lcssa = $r$07;
     break L4;
    }
    $8 = ((($l$06)) + 1|0);
    $9 = ((($r$07)) + 1|0);
    $10 = HEAP8[$8>>0]|0;
    $11 = ($10<<24>>24)==(0);
    if ($11) {
     $13 = 0;$r$0$lcssa = $9;
     break;
    } else {
     $$08$in = $$08;$7 = $10;$l$06 = $8;$r$07 = $9;
    }
   }
  }
 } while(0);
 $12 = $13&255;
 $14 = HEAP8[$r$0$lcssa>>0]|0;
 $15 = $14&255;
 $16 = (($12) - ($15))|0;
 $$03 = $16;
 return ($$03|0);
}
function _scanexp($f,$pok) {
 $f = $f|0;
 $pok = $pok|0;
 var $$lcssa22 = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0;
 var $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0;
 var $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0;
 var $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0;
 var $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0;
 var $99 = 0, $c$0 = 0, $c$1$be = 0, $c$1$be$lcssa = 0, $c$112 = 0, $c$2$be = 0, $c$2$lcssa = 0, $c$27 = 0, $c$3$be = 0, $neg$0 = 0, $or$cond3 = 0, $x$013 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 100|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = ($1>>>0)<($3>>>0);
 if ($4) {
  $5 = ((($1)) + 1|0);
  HEAP32[$0>>2] = $5;
  $6 = HEAP8[$1>>0]|0;
  $7 = $6&255;
  $10 = $7;
 } else {
  $8 = (___shgetc($f)|0);
  $10 = $8;
 }
 $9 = ($10|0)==(45);
 if ((($10|0) == 43) | (($10|0) == 45)) {
  $11 = $9&1;
  $12 = HEAP32[$0>>2]|0;
  $13 = HEAP32[$2>>2]|0;
  $14 = ($12>>>0)<($13>>>0);
  if ($14) {
   $15 = ((($12)) + 1|0);
   HEAP32[$0>>2] = $15;
   $16 = HEAP8[$12>>0]|0;
   $17 = $16&255;
   $20 = $17;
  } else {
   $18 = (___shgetc($f)|0);
   $20 = $18;
  }
  $19 = (($20) + -48)|0;
  $21 = ($19>>>0)>(9);
  $22 = ($pok|0)!=(0);
  $or$cond3 = $22 & $21;
  if ($or$cond3) {
   $23 = HEAP32[$2>>2]|0;
   $24 = ($23|0)==(0|0);
   if ($24) {
    $c$0 = $20;$neg$0 = $11;
   } else {
    $25 = HEAP32[$0>>2]|0;
    $26 = ((($25)) + -1|0);
    HEAP32[$0>>2] = $26;
    $c$0 = $20;$neg$0 = $11;
   }
  } else {
   $c$0 = $20;$neg$0 = $11;
  }
 } else {
  $c$0 = $10;$neg$0 = 0;
 }
 $27 = (($c$0) + -48)|0;
 $28 = ($27>>>0)>(9);
 if ($28) {
  $29 = HEAP32[$2>>2]|0;
  $30 = ($29|0)==(0|0);
  if ($30) {
   $98 = -2147483648;$99 = 0;
   tempRet0 = ($98);
   return ($99|0);
  }
  $31 = HEAP32[$0>>2]|0;
  $32 = ((($31)) + -1|0);
  HEAP32[$0>>2] = $32;
  $98 = -2147483648;$99 = 0;
  tempRet0 = ($98);
  return ($99|0);
 } else {
  $c$112 = $c$0;$x$013 = 0;
 }
 while(1) {
  $33 = ($x$013*10)|0;
  $34 = (($c$112) + -48)|0;
  $35 = (($34) + ($33))|0;
  $36 = HEAP32[$0>>2]|0;
  $37 = HEAP32[$2>>2]|0;
  $38 = ($36>>>0)<($37>>>0);
  if ($38) {
   $39 = ((($36)) + 1|0);
   HEAP32[$0>>2] = $39;
   $40 = HEAP8[$36>>0]|0;
   $41 = $40&255;
   $c$1$be = $41;
  } else {
   $42 = (___shgetc($f)|0);
   $c$1$be = $42;
  }
  $43 = (($c$1$be) + -48)|0;
  $44 = ($43>>>0)<(10);
  $45 = ($35|0)<(214748364);
  $46 = $44 & $45;
  if ($46) {
   $c$112 = $c$1$be;$x$013 = $35;
  } else {
   $$lcssa22 = $35;$c$1$be$lcssa = $c$1$be;
   break;
  }
 }
 $47 = ($$lcssa22|0)<(0);
 $48 = $47 << 31 >> 31;
 $49 = (($c$1$be$lcssa) + -48)|0;
 $50 = ($49>>>0)<(10);
 if ($50) {
  $53 = $$lcssa22;$54 = $48;$c$27 = $c$1$be$lcssa;
  while(1) {
   $55 = (___muldi3(($53|0),($54|0),10,0)|0);
   $56 = tempRet0;
   $57 = ($c$27|0)<(0);
   $58 = $57 << 31 >> 31;
   $59 = (_i64Add(($c$27|0),($58|0),-48,-1)|0);
   $60 = tempRet0;
   $61 = (_i64Add(($59|0),($60|0),($55|0),($56|0))|0);
   $62 = tempRet0;
   $63 = HEAP32[$0>>2]|0;
   $64 = HEAP32[$2>>2]|0;
   $65 = ($63>>>0)<($64>>>0);
   if ($65) {
    $66 = ((($63)) + 1|0);
    HEAP32[$0>>2] = $66;
    $67 = HEAP8[$63>>0]|0;
    $68 = $67&255;
    $c$2$be = $68;
   } else {
    $69 = (___shgetc($f)|0);
    $c$2$be = $69;
   }
   $70 = (($c$2$be) + -48)|0;
   $71 = ($70>>>0)<(10);
   $72 = ($62|0)<(21474836);
   $73 = ($61>>>0)<(2061584302);
   $74 = ($62|0)==(21474836);
   $75 = $74 & $73;
   $76 = $72 | $75;
   $77 = $71 & $76;
   if ($77) {
    $53 = $61;$54 = $62;$c$27 = $c$2$be;
   } else {
    $92 = $61;$93 = $62;$c$2$lcssa = $c$2$be;
    break;
   }
  }
 } else {
  $92 = $$lcssa22;$93 = $48;$c$2$lcssa = $c$1$be$lcssa;
 }
 $51 = (($c$2$lcssa) + -48)|0;
 $52 = ($51>>>0)<(10);
 if ($52) {
  while(1) {
   $78 = HEAP32[$0>>2]|0;
   $79 = HEAP32[$2>>2]|0;
   $80 = ($78>>>0)<($79>>>0);
   if ($80) {
    $81 = ((($78)) + 1|0);
    HEAP32[$0>>2] = $81;
    $82 = HEAP8[$78>>0]|0;
    $83 = $82&255;
    $c$3$be = $83;
   } else {
    $84 = (___shgetc($f)|0);
    $c$3$be = $84;
   }
   $85 = (($c$3$be) + -48)|0;
   $86 = ($85>>>0)<(10);
   if (!($86)) {
    break;
   }
  }
 }
 $87 = HEAP32[$2>>2]|0;
 $88 = ($87|0)==(0|0);
 if (!($88)) {
  $89 = HEAP32[$0>>2]|0;
  $90 = ((($89)) + -1|0);
  HEAP32[$0>>2] = $90;
 }
 $91 = ($neg$0|0)!=(0);
 $94 = (_i64Subtract(0,0,($92|0),($93|0))|0);
 $95 = tempRet0;
 $96 = $91 ? $94 : $92;
 $97 = $91 ? $95 : $93;
 $98 = $97;$99 = $96;
 tempRet0 = ($98);
 return ($99|0);
}
function _printf_core($f,$fmt,$ap,$nl_arg,$nl_type) {
 $f = $f|0;
 $fmt = $fmt|0;
 $ap = $ap|0;
 $nl_arg = $nl_arg|0;
 $nl_type = $nl_type|0;
 var $$ = 0, $$$i = 0, $$0 = 0, $$0$i = 0, $$0$lcssa$i = 0, $$0$lcssa$i$i = 0, $$0$lcssa$i104$i = 0, $$0$lcssa$i128$i = 0, $$0$lcssa$i143$i = 0, $$0$lcssa$i39$i = 0, $$0$lcssa$i46 = 0, $$0$lcssa$i46$i = 0, $$0$lcssa$i48$i = 0, $$0$lcssa$i51 = 0, $$0$lcssa$i53 = 0, $$0$lcssa$i56$i = 0, $$0$lcssa$i61 = 0, $$0$lcssa$i63$i = 0, $$0$lcssa$i68 = 0, $$0$lcssa$i69$i = 0;
 var $$0$lcssa$i75 = 0, $$0$lcssa$i76$i = 0, $$0$lcssa$i84$i = 0, $$0$lcssa$i85 = 0, $$0$lcssa$i97$i = 0, $$01$i = 0, $$01$i$i = 0, $$01$i102$i = 0, $$01$i126$i = 0, $$01$i141$i = 0, $$01$i37$i = 0, $$01$i44 = 0, $$01$i44$i = 0, $$01$i54$i = 0, $$01$i59 = 0, $$01$i61$i = 0, $$01$i66 = 0, $$01$i67$i = 0, $$01$i73 = 0, $$01$i74$i = 0;
 var $$01$i83 = 0, $$01$i95$i = 0, $$01$lcssa$off0$i = 0, $$01$lcssa$off0$i$i = 0, $$01$lcssa$off0$i85$i = 0, $$012$i = 0, $$013$i = 0, $$03$i48 = 0, $$05$i = 0, $$05$i$i = 0, $$05$i79$i = 0, $$07$i = 0.0, $$1$i = 0.0, $$1$lcssa$i$i = 0, $$1$lcssa$i112$i = 0, $$114$i = 0, $$12$i = 0, $$12$i$i = 0, $$12$i110$i = 0, $$12$i119$i = 0;
 var $$12$i134$i = 0, $$12$i134$i$lcssa = 0, $$12$i87$i = 0, $$2$i = 0.0, $$2$us$i = 0.0, $$2$us$us$i = 0.0, $$20$i = 0.0, $$21$i = 0, $$210$$22$i = 0, $$210$$24$i = 0, $$210$i = 0, $$23$i = 0, $$24 = 0, $$25 = 0, $$3$i = 0.0, $$31$i = 0, $$311$i = 0, $$4$i = 0.0, $$412$lcssa$i = 0, $$412184$i = 0;
 var $$5196$i = 0, $$92 = 0, $$a$3$i = 0, $$a$3$us$i = 0, $$a$3$us303$i = 0, $$a$3$us304$i = 0, $$a$3305$i = 0, $$a$3306$i = 0, $$fl$4 = 0, $$l10n$0 = 0, $$lcssa106 = 0, $$lcssa275$i = 0, $$lcssa450 = 0, $$lcssa451 = 0, $$lcssa455 = 0, $$lcssa457 = 0, $$lcssa458 = 0, $$lcssa459 = 0, $$lcssa460 = 0, $$lcssa461 = 0;
 var $$lcssa463 = 0, $$lcssa464 = 0, $$lcssa470 = 0, $$lcssa474 = 0, $$lcssa476 = 0, $$lcssa479 = 0, $$lcssa480 = 0, $$lcssa483 = 0.0, $$lcssa484 = 0, $$lcssa487 = 0, $$lcssa491 = 0, $$mask$i = 0, $$mask$i38 = 0, $$mask1$i = 0, $$mask1$i37 = 0, $$neg151$i = 0, $$neg152$i = 0, $$p$$i = 0, $$p$5 = 0, $$p$i = 0;
 var $$pn$i = 0, $$pr$i = 0, $$pr146$i = 0, $$pre = 0, $$pre$i = 0, $$pre$phi302$iZ2D = 0, $$pre270 = 0, $$pre300$i = 0, $$pre301$i = 0, $$sum$i = 0, $$sum15$i = 0, $$sum16$i = 0, $$z$3$i = 0, $$z$4$i = 0, $$z$4$us$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0;
 var $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0, $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0;
 var $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0, $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0;
 var $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0, $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0;
 var $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0, $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $1071 = 0, $1072 = 0, $1073 = 0;
 var $1074 = 0, $1075 = 0, $1076 = 0, $1077 = 0, $1078 = 0, $1079 = 0, $108 = 0, $1080 = 0, $1081 = 0, $1082 = 0, $1083 = 0, $1084 = 0, $1085 = 0, $1086 = 0, $1087 = 0, $1088 = 0, $1089 = 0, $109 = 0, $1090 = 0, $1091 = 0;
 var $1092 = 0, $1093 = 0, $1094 = 0, $1095 = 0, $1096 = 0, $1097 = 0, $1098 = 0, $1099 = 0, $11 = 0, $110 = 0, $1100 = 0, $1101 = 0, $1102 = 0, $1103 = 0, $1104 = 0, $1105 = 0, $1106 = 0, $1107 = 0, $1108 = 0, $1109 = 0;
 var $111 = 0, $1110 = 0, $1111 = 0, $1112 = 0, $1113 = 0, $1114 = 0, $1115 = 0, $1116 = 0, $1117 = 0, $1118 = 0, $1119 = 0, $112 = 0, $1120 = 0, $1121 = 0, $1122 = 0, $1123 = 0, $1124 = 0, $1125 = 0, $1126 = 0, $1127 = 0;
 var $1128 = 0, $1129 = 0, $113 = 0, $1130 = 0, $1131 = 0, $1132 = 0, $1133 = 0, $1134 = 0, $1135 = 0, $1136 = 0, $1137 = 0, $1138 = 0, $1139 = 0, $114 = 0, $1140 = 0, $1141 = 0, $1142 = 0, $1143 = 0, $1144 = 0, $1145 = 0;
 var $1146 = 0, $1147 = 0, $1148 = 0, $1149 = 0, $115 = 0, $1150 = 0, $1151 = 0, $1152 = 0, $1153 = 0, $1154 = 0.0, $1155 = 0, $1156 = 0, $1157 = 0, $1158 = 0, $1159 = 0, $116 = 0, $1160 = 0, $1161 = 0.0, $1162 = 0, $1163 = 0;
 var $1164 = 0, $1165 = 0, $1166 = 0, $1167 = 0, $1168 = 0, $1169 = 0, $1169$phi = 0, $117 = 0, $1170 = 0, $1170$phi = 0, $1171 = 0, $1172 = 0, $1173 = 0, $1174 = 0, $1175 = 0, $1176 = 0, $1177 = 0, $1178 = 0, $1179 = 0, $118 = 0;
 var $1180 = 0, $1181 = 0, $1182 = 0, $1183 = 0, $1184 = 0, $1185 = 0, $1186 = 0, $1187 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0;
 var $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0;
 var $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0;
 var $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0;
 var $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0;
 var $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0;
 var $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0;
 var $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0.0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0.0, $253 = 0, $254 = 0, $255 = 0;
 var $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0;
 var $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0;
 var $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0;
 var $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0;
 var $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0, $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0;
 var $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0, $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0;
 var $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0, $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0;
 var $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0, $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0;
 var $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0, $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0;
 var $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0, $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0.0, $431 = 0, $432 = 0.0, $433 = 0, $434 = 0, $435 = 0;
 var $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0, $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0;
 var $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0, $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0.0;
 var $472 = 0.0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0, $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0.0, $488 = 0, $489 = 0, $49 = 0;
 var $490 = 0, $491 = 0.0, $492 = 0.0, $493 = 0.0, $494 = 0.0, $495 = 0.0, $496 = 0.0, $497 = 0, $498 = 0, $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0;
 var $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0, $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0;
 var $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0, $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0;
 var $544 = 0.0, $545 = 0.0, $546 = 0.0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0, $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0.0, $56 = 0, $560 = 0.0, $561 = 0.0;
 var $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0, $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0.0, $575 = 0.0, $576 = 0.0, $577 = 0, $578 = 0, $579 = 0, $58 = 0;
 var $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0, $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0;
 var $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0, $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0;
 var $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0, $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0.0, $632 = 0, $633 = 0;
 var $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0.0, $64 = 0, $640 = 0.0, $641 = 0.0, $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0;
 var $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0, $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0;
 var $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0, $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0;
 var $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0, $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0;
 var $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0, $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0;
 var $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0, $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0;
 var $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0, $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0;
 var $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0, $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0;
 var $779 = 0, $78 = 0, $780 = 0.0, $781 = 0.0, $782 = 0, $783 = 0.0, $784 = 0, $785 = 0, $786 = 0, $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0;
 var $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0, $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0;
 var $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0, $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0;
 var $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0, $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0;
 var $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0, $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0;
 var $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0, $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0;
 var $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0, $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0;
 var $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0, $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0;
 var $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0, $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0;
 var $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0, $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0;
 var $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0, $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0;
 var $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0, $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0;
 var $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $a$0 = 0, $a$1 = 0, $a$1$lcssa$i = 0, $a$1253$i = 0, $a$2 = 0, $a$2$ph$i = 0, $a$3$lcssa$i = 0, $a$3240$i = 0, $a$3240$us$i = 0, $a$5$lcssa$i = 0, $a$5215$i = 0, $a$6$i = 0, $a$7$i = 0, $a$8$ph$i = 0, $arglist_current = 0;
 var $arglist_current11 = 0, $arglist_current14 = 0, $arglist_current17 = 0, $arglist_current2 = 0, $arglist_current20 = 0, $arglist_current23 = 0, $arglist_current26 = 0, $arglist_current29 = 0, $arglist_current32 = 0, $arglist_current35 = 0, $arglist_current38 = 0, $arglist_current41 = 0, $arglist_current44 = 0, $arglist_current47 = 0, $arglist_current5 = 0, $arglist_current50 = 0, $arglist_current53 = 0, $arglist_current56 = 0, $arglist_current59 = 0, $arglist_current62 = 0;
 var $arglist_current8 = 0, $arglist_next = 0, $arglist_next12 = 0, $arglist_next15 = 0, $arglist_next18 = 0, $arglist_next21 = 0, $arglist_next24 = 0, $arglist_next27 = 0, $arglist_next3 = 0, $arglist_next30 = 0, $arglist_next33 = 0, $arglist_next36 = 0, $arglist_next39 = 0, $arglist_next42 = 0, $arglist_next45 = 0, $arglist_next48 = 0, $arglist_next51 = 0, $arglist_next54 = 0, $arglist_next57 = 0, $arglist_next6 = 0;
 var $arglist_next60 = 0, $arglist_next63 = 0, $arglist_next9 = 0, $argpos$0 = 0, $big$i = 0, $buf = 0, $buf$i = 0, $carry$0246$i = 0, $carry3$0234$i = 0, $carry3$0234$us$i = 0, $cnt$0 = 0, $cnt$1 = 0, $cnt$1$lcssa = 0, $d$0$i = 0, $d$0245$i = 0, $d$0247$i = 0, $d$1233$i = 0, $d$1233$us$i = 0, $d$2$lcssa$i = 0, $d$2214$i = 0;
 var $d$3$i = 0, $d$4191$i = 0, $d$5183$i = 0, $d$6195$i = 0, $e$0229$i = 0, $e$1$i = 0, $e$2210$i = 0, $e$3$i = 0, $e$4$ph$i = 0, $e2$i = 0, $ebuf0$i = 0, $estr$0$i = 0, $estr$1$lcssa$i = 0, $estr$1$ph$i = 0, $estr$1201$i = 0, $estr$2$i = 0, $exitcond$i = 0, $expanded = 0, $expanded101 = 0, $expanded102 = 0;
 var $expanded103 = 0, $expanded105 = 0, $expanded106 = 0, $expanded108 = 0, $expanded109 = 0, $expanded110 = 0, $expanded112 = 0, $expanded113 = 0, $expanded115 = 0, $expanded116 = 0, $expanded117 = 0, $expanded119 = 0, $expanded120 = 0, $expanded122 = 0, $expanded123 = 0, $expanded124 = 0, $expanded126 = 0, $expanded127 = 0, $expanded129 = 0, $expanded130 = 0;
 var $expanded131 = 0, $expanded133 = 0, $expanded134 = 0, $expanded136 = 0, $expanded137 = 0, $expanded138 = 0, $expanded140 = 0, $expanded141 = 0, $expanded143 = 0, $expanded144 = 0, $expanded145 = 0, $expanded147 = 0, $expanded148 = 0, $expanded150 = 0, $expanded151 = 0, $expanded152 = 0, $expanded154 = 0, $expanded155 = 0, $expanded157 = 0, $expanded158 = 0;
 var $expanded159 = 0, $expanded161 = 0, $expanded162 = 0, $expanded164 = 0, $expanded165 = 0, $expanded166 = 0, $expanded168 = 0, $expanded169 = 0, $expanded171 = 0, $expanded172 = 0, $expanded173 = 0, $expanded175 = 0, $expanded176 = 0, $expanded178 = 0, $expanded179 = 0, $expanded180 = 0, $expanded182 = 0, $expanded183 = 0, $expanded185 = 0, $expanded186 = 0;
 var $expanded187 = 0, $expanded189 = 0, $expanded190 = 0, $expanded192 = 0, $expanded193 = 0, $expanded194 = 0, $expanded196 = 0, $expanded197 = 0, $expanded199 = 0, $expanded200 = 0, $expanded201 = 0, $expanded203 = 0, $expanded204 = 0, $expanded206 = 0, $expanded207 = 0, $expanded208 = 0, $expanded210 = 0, $expanded211 = 0, $expanded213 = 0, $expanded214 = 0;
 var $expanded215 = 0, $expanded64 = 0, $expanded66 = 0, $expanded67 = 0, $expanded68 = 0, $expanded70 = 0, $expanded71 = 0, $expanded73 = 0, $expanded74 = 0, $expanded75 = 0, $expanded77 = 0, $expanded78 = 0, $expanded80 = 0, $expanded81 = 0, $expanded82 = 0, $expanded84 = 0, $expanded85 = 0, $expanded87 = 0, $expanded88 = 0, $expanded89 = 0;
 var $expanded91 = 0, $expanded92 = 0, $expanded94 = 0, $expanded95 = 0, $expanded96 = 0, $expanded98 = 0, $expanded99 = 0, $fl$0110 = 0, $fl$0170 = 0, $fl$1 = 0, $fl$1$ = 0, $fl$3 = 0, $fl$4 = 0, $fl$6 = 0, $i$0$lcssa = 0, $i$0$lcssa273 = 0, $i$0175 = 0, $i$0228$i = 0, $i$03$i = 0, $i$03$i30 = 0;
 var $i$1$lcssa$i = 0, $i$1186 = 0, $i$1222$i = 0, $i$2162 = 0, $i$2162$lcssa = 0, $i$2209$i = 0, $i$3160 = 0, $i$3205$i = 0, $isdigit = 0, $isdigit$i = 0, $isdigit$i32 = 0, $isdigit10 = 0, $isdigit12 = 0, $isdigit2$i = 0, $isdigit2$i28 = 0, $isdigittmp = 0, $isdigittmp$ = 0, $isdigittmp$i = 0, $isdigittmp$i31 = 0, $isdigittmp1$i = 0;
 var $isdigittmp1$i27 = 0, $isdigittmp11 = 0, $isdigittmp4$i = 0, $isdigittmp4$i29 = 0, $isdigittmp9 = 0, $j$0$i = 0, $j$0221$i = 0, $j$0223$i = 0, $j$1206$i = 0, $j$2$i = 0, $l$0 = 0, $l$0$i = 0, $l$1$i = 0, $l$1174 = 0, $l$2 = 0, $l10n$0 = 0, $l10n$0$lcssa = 0, $l10n$0$phi = 0, $l10n$1 = 0, $l10n$2 = 0;
 var $l10n$3 = 0, $mb = 0, $notlhs$us$us$i = 0, $notrhs$i = 0, $or$cond = 0, $or$cond$i = 0, $or$cond$i$i = 0, $or$cond$i100$i = 0, $or$cond$i35$i = 0, $or$cond$i42$i = 0, $or$cond$i52$i = 0, $or$cond$i57 = 0, $or$cond$i59$i = 0, $or$cond$i64 = 0, $or$cond$i71 = 0, $or$cond$i72$i = 0, $or$cond$i79 = 0, $or$cond$i81 = 0, $or$cond$i93$i = 0, $or$cond15 = 0;
 var $or$cond19 = 0, $or$cond22 = 0, $or$cond29$i = 0, $or$cond332 = 0, $or$cond6$i = 0, $p$0 = 0, $p$1 = 0, $p$2 = 0, $p$2$ = 0, $p$3 = 0, $p$4272 = 0, $p$5 = 0, $pad$i = 0, $pl$0 = 0, $pl$0$i = 0, $pl$1 = 0, $pl$1$i = 0, $pl$2 = 0, $prefix$0 = 0, $prefix$0$$i = 0;
 var $prefix$0$i = 0, $prefix$1 = 0, $prefix$2 = 0, $r$0$a$8$i = 0, $re$1179$i = 0, $round$0178$i = 0.0, $round6$1$i = 0.0, $s$0$i = 0, $s$0$us$i = 0, $s$0$us$us$i = 0, $s$1$i = 0, $s$1$lcssa$i = 0, $s$1$us$i = 0, $s$1$us$us$i = 0, $s1$0$i = 0, $s7$0188$i = 0, $s7$1$i = 0, $s8$0$lcssa$i = 0, $s8$0180$i = 0, $s9$0$i = 0;
 var $s9$1192$i = 0, $s9$2$i = 0, $sext = 0, $sext93 = 0, $small$0$i = 0.0, $small$1$i = 0.0, $st$0 = 0, $st$0$lcssa456 = 0, $storemerge = 0, $storemerge13 = 0, $storemerge8108 = 0, $storemerge8169 = 0, $t$0 = 0, $t$1 = 0, $w$$i = 0, $w$0 = 0, $w$1 = 0, $w$2 = 0, $w$30$i = 0, $wc = 0;
 var $ws$0176 = 0, $ws$1187 = 0, $y$03$i = 0, $y$03$i$i = 0, $y$03$i109$i = 0, $y$03$i118$i = 0, $y$03$i133$i = 0, $y$03$i86$i = 0, $z$0$i = 0, $z$0$lcssa = 0, $z$0163 = 0, $z$1 = 0, $z$1$lcssa$i = 0, $z$1252$i = 0, $z$2 = 0, $z$2$i = 0, $z$2$i$lcssa = 0, $z$3$lcssa$i = 0, $z$3239$i = 0, $z$3239$us$i = 0;
 var $z$4$i = 0, $z$4$us$i = 0, $z$6$$i = 0, $z$6$i = 0, $z$6$i$lcssa = 0, $z$6$ph$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 STACKTOP = STACKTOP + 864|0; if ((STACKTOP|0) >= (STACK_MAX|0)) abort();
 $big$i = sp + 16|0;
 $e2$i = sp + 8|0;
 $buf$i = sp + 836|0;
 $0 = $buf$i;
 $ebuf0$i = sp + 824|0;
 $pad$i = sp + 568|0;
 $buf = sp + 528|0;
 $wc = sp;
 $mb = sp + 520|0;
 $1 = ($f|0)!=(0|0);
 $2 = ((($buf)) + 40|0);
 $3 = $2;
 $4 = ((($buf)) + 39|0);
 $5 = ((($wc)) + 4|0);
 $6 = $wc;
 $7 = ((($ebuf0$i)) + 12|0);
 $8 = ((($ebuf0$i)) + 11|0);
 $9 = $7;
 $10 = (($9) - ($0))|0;
 $11 = (-2 - ($0))|0;
 $12 = (($9) + 2)|0;
 $13 = ((($big$i)) + 288|0);
 $14 = ((($buf$i)) + 9|0);
 $15 = $14;
 $16 = ((($buf$i)) + 8|0);
 $1169 = 0;$1170 = 0;$23 = $fmt;$cnt$0 = 0;$l$0 = 0;$l10n$0 = 0;
 L1: while(1) {
  $17 = ($cnt$0|0)>(-1);
  do {
   if ($17) {
    $18 = (2147483647 - ($cnt$0))|0;
    $19 = ($l$0|0)>($18|0);
    if ($19) {
     $20 = (___errno_location()|0);
     HEAP32[$20>>2] = 75;
     $cnt$1 = -1;
     break;
    } else {
     $21 = (($l$0) + ($cnt$0))|0;
     $cnt$1 = $21;
     break;
    }
   } else {
    $cnt$1 = $cnt$0;
   }
  } while(0);
  $22 = HEAP8[$23>>0]|0;
  $24 = ($22<<24>>24)==(0);
  if ($24) {
   $cnt$1$lcssa = $cnt$1;$l10n$0$lcssa = $l10n$0;
   label = 344;
   break;
  } else {
   $1171 = $22;$26 = $23;
  }
  while(1) {
   if ((($1171<<24>>24) == 0)) {
    $$lcssa106 = $26;$z$0$lcssa = $26;
    break;
   } else if ((($1171<<24>>24) == 37)) {
    $28 = $26;$z$0163 = $26;
    label = 9;
    break;
   }
   $25 = ((($26)) + 1|0);
   $$pre = HEAP8[$25>>0]|0;
   $1171 = $$pre;$26 = $25;
  }
  L12: do {
   if ((label|0) == 9) {
    while(1) {
     label = 0;
     $27 = ((($28)) + 1|0);
     $29 = HEAP8[$27>>0]|0;
     $30 = ($29<<24>>24)==(37);
     if (!($30)) {
      $$lcssa106 = $28;$z$0$lcssa = $z$0163;
      break L12;
     }
     $31 = ((($z$0163)) + 1|0);
     $32 = ((($28)) + 2|0);
     $33 = HEAP8[$32>>0]|0;
     $34 = ($33<<24>>24)==(37);
     if ($34) {
      $28 = $32;$z$0163 = $31;
      label = 9;
     } else {
      $$lcssa106 = $32;$z$0$lcssa = $31;
      break;
     }
    }
   }
  } while(0);
  $35 = $z$0$lcssa;
  $36 = $23;
  $37 = (($35) - ($36))|0;
  if ($1) {
   (___fwritex($23,$37,$f)|0);
  }
  $38 = ($z$0$lcssa|0)==($23|0);
  if (!($38)) {
   $l10n$0$phi = $l10n$0;$1170$phi = $1170;$1169$phi = $1169;$23 = $$lcssa106;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$0$phi;$1170 = $1170$phi;$1169 = $1169$phi;
   continue;
  }
  $39 = ((($$lcssa106)) + 1|0);
  $40 = HEAP8[$39>>0]|0;
  $41 = $40 << 24 >> 24;
  $isdigittmp = (($41) + -48)|0;
  $isdigit = ($isdigittmp>>>0)<(10);
  if ($isdigit) {
   $42 = ((($$lcssa106)) + 2|0);
   $43 = HEAP8[$42>>0]|0;
   $44 = ($43<<24>>24)==(36);
   $45 = ((($$lcssa106)) + 3|0);
   $$92 = $44 ? $45 : $39;
   $$l10n$0 = $44 ? 1 : $l10n$0;
   $isdigittmp$ = $44 ? $isdigittmp : -1;
   $$pre270 = HEAP8[$$92>>0]|0;
   $47 = $$pre270;$argpos$0 = $isdigittmp$;$l10n$1 = $$l10n$0;$storemerge = $$92;
  } else {
   $47 = $40;$argpos$0 = -1;$l10n$1 = $l10n$0;$storemerge = $39;
  }
  $46 = $47 << 24 >> 24;
  $48 = $46 & -32;
  $49 = ($48|0)==(32);
  L24: do {
   if ($49) {
    $51 = $46;$56 = $47;$fl$0170 = 0;$storemerge8169 = $storemerge;
    while(1) {
     $50 = (($51) + -32)|0;
     $52 = 1 << $50;
     $53 = $52 & 75913;
     $54 = ($53|0)==(0);
     if ($54) {
      $66 = $56;$fl$0110 = $fl$0170;$storemerge8108 = $storemerge8169;
      break L24;
     }
     $55 = $56 << 24 >> 24;
     $57 = (($55) + -32)|0;
     $58 = 1 << $57;
     $59 = $58 | $fl$0170;
     $60 = ((($storemerge8169)) + 1|0);
     $61 = HEAP8[$60>>0]|0;
     $62 = $61 << 24 >> 24;
     $63 = $62 & -32;
     $64 = ($63|0)==(32);
     if ($64) {
      $51 = $62;$56 = $61;$fl$0170 = $59;$storemerge8169 = $60;
     } else {
      $66 = $61;$fl$0110 = $59;$storemerge8108 = $60;
      break;
     }
    }
   } else {
    $66 = $47;$fl$0110 = 0;$storemerge8108 = $storemerge;
   }
  } while(0);
  $65 = ($66<<24>>24)==(42);
  do {
   if ($65) {
    $67 = ((($storemerge8108)) + 1|0);
    $68 = HEAP8[$67>>0]|0;
    $69 = $68 << 24 >> 24;
    $isdigittmp11 = (($69) + -48)|0;
    $isdigit12 = ($isdigittmp11>>>0)<(10);
    if ($isdigit12) {
     $70 = ((($storemerge8108)) + 2|0);
     $71 = HEAP8[$70>>0]|0;
     $72 = ($71<<24>>24)==(36);
     if ($72) {
      $73 = (($nl_type) + ($isdigittmp11<<2)|0);
      HEAP32[$73>>2] = 10;
      $74 = HEAP8[$67>>0]|0;
      $75 = $74 << 24 >> 24;
      $76 = (($75) + -48)|0;
      $77 = (($nl_arg) + ($76<<3)|0);
      $78 = $77;
      $79 = $78;
      $80 = HEAP32[$79>>2]|0;
      $81 = (($78) + 4)|0;
      $82 = $81;
      $83 = HEAP32[$82>>2]|0;
      $84 = ((($storemerge8108)) + 3|0);
      $l10n$2 = 1;$storemerge13 = $84;$w$0 = $80;
     } else {
      label = 23;
     }
    } else {
     label = 23;
    }
    if ((label|0) == 23) {
     label = 0;
     $85 = ($l10n$1|0)==(0);
     if (!($85)) {
      $$0 = -1;
      label = 363;
      break L1;
     }
     if (!($1)) {
      $105 = $67;$fl$1 = $fl$0110;$l10n$3 = 0;$w$1 = 0;
      break;
     }
     $arglist_current = HEAP32[$ap>>2]|0;
     $86 = $arglist_current;
     $87 = ((0) + 4|0);
     $expanded64 = $87;
     $expanded = (($expanded64) - 1)|0;
     $88 = (($86) + ($expanded))|0;
     $89 = ((0) + 4|0);
     $expanded68 = $89;
     $expanded67 = (($expanded68) - 1)|0;
     $expanded66 = $expanded67 ^ -1;
     $90 = $88 & $expanded66;
     $91 = $90;
     $92 = HEAP32[$91>>2]|0;
     $arglist_next = ((($91)) + 4|0);
     HEAP32[$ap>>2] = $arglist_next;
     $l10n$2 = 0;$storemerge13 = $67;$w$0 = $92;
    }
    $93 = ($w$0|0)<(0);
    if ($93) {
     $94 = $fl$0110 | 8192;
     $95 = (0 - ($w$0))|0;
     $105 = $storemerge13;$fl$1 = $94;$l10n$3 = $l10n$2;$w$1 = $95;
    } else {
     $105 = $storemerge13;$fl$1 = $fl$0110;$l10n$3 = $l10n$2;$w$1 = $w$0;
    }
   } else {
    $96 = $66 << 24 >> 24;
    $isdigittmp1$i = (($96) + -48)|0;
    $isdigit2$i = ($isdigittmp1$i>>>0)<(10);
    if ($isdigit2$i) {
     $100 = $storemerge8108;$i$03$i = 0;$isdigittmp4$i = $isdigittmp1$i;
     while(1) {
      $97 = ($i$03$i*10)|0;
      $98 = (($97) + ($isdigittmp4$i))|0;
      $99 = ((($100)) + 1|0);
      $101 = HEAP8[$99>>0]|0;
      $102 = $101 << 24 >> 24;
      $isdigittmp$i = (($102) + -48)|0;
      $isdigit$i = ($isdigittmp$i>>>0)<(10);
      if ($isdigit$i) {
       $100 = $99;$i$03$i = $98;$isdigittmp4$i = $isdigittmp$i;
      } else {
       $$lcssa450 = $98;$$lcssa451 = $99;
       break;
      }
     }
     $103 = ($$lcssa450|0)<(0);
     if ($103) {
      $$0 = -1;
      label = 363;
      break L1;
     } else {
      $105 = $$lcssa451;$fl$1 = $fl$0110;$l10n$3 = $l10n$1;$w$1 = $$lcssa450;
     }
    } else {
     $105 = $storemerge8108;$fl$1 = $fl$0110;$l10n$3 = $l10n$1;$w$1 = 0;
    }
   }
  } while(0);
  $104 = HEAP8[$105>>0]|0;
  $106 = ($104<<24>>24)==(46);
  L45: do {
   if ($106) {
    $107 = ((($105)) + 1|0);
    $108 = HEAP8[$107>>0]|0;
    $109 = ($108<<24>>24)==(42);
    if (!($109)) {
     $136 = $108 << 24 >> 24;
     $isdigittmp1$i27 = (($136) + -48)|0;
     $isdigit2$i28 = ($isdigittmp1$i27>>>0)<(10);
     if ($isdigit2$i28) {
      $140 = $107;$i$03$i30 = 0;$isdigittmp4$i29 = $isdigittmp1$i27;
     } else {
      $1172 = $107;$p$0 = 0;
      break;
     }
     while(1) {
      $137 = ($i$03$i30*10)|0;
      $138 = (($137) + ($isdigittmp4$i29))|0;
      $139 = ((($140)) + 1|0);
      $141 = HEAP8[$139>>0]|0;
      $142 = $141 << 24 >> 24;
      $isdigittmp$i31 = (($142) + -48)|0;
      $isdigit$i32 = ($isdigittmp$i31>>>0)<(10);
      if ($isdigit$i32) {
       $140 = $139;$i$03$i30 = $138;$isdigittmp4$i29 = $isdigittmp$i31;
      } else {
       $1172 = $139;$p$0 = $138;
       break L45;
      }
     }
    }
    $110 = ((($105)) + 2|0);
    $111 = HEAP8[$110>>0]|0;
    $112 = $111 << 24 >> 24;
    $isdigittmp9 = (($112) + -48)|0;
    $isdigit10 = ($isdigittmp9>>>0)<(10);
    if ($isdigit10) {
     $113 = ((($105)) + 3|0);
     $114 = HEAP8[$113>>0]|0;
     $115 = ($114<<24>>24)==(36);
     if ($115) {
      $116 = (($nl_type) + ($isdigittmp9<<2)|0);
      HEAP32[$116>>2] = 10;
      $117 = HEAP8[$110>>0]|0;
      $118 = $117 << 24 >> 24;
      $119 = (($118) + -48)|0;
      $120 = (($nl_arg) + ($119<<3)|0);
      $121 = $120;
      $122 = $121;
      $123 = HEAP32[$122>>2]|0;
      $124 = (($121) + 4)|0;
      $125 = $124;
      $126 = HEAP32[$125>>2]|0;
      $127 = ((($105)) + 4|0);
      $1172 = $127;$p$0 = $123;
      break;
     }
    }
    $128 = ($l10n$3|0)==(0);
    if (!($128)) {
     $$0 = -1;
     label = 363;
     break L1;
    }
    if ($1) {
     $arglist_current2 = HEAP32[$ap>>2]|0;
     $129 = $arglist_current2;
     $130 = ((0) + 4|0);
     $expanded71 = $130;
     $expanded70 = (($expanded71) - 1)|0;
     $131 = (($129) + ($expanded70))|0;
     $132 = ((0) + 4|0);
     $expanded75 = $132;
     $expanded74 = (($expanded75) - 1)|0;
     $expanded73 = $expanded74 ^ -1;
     $133 = $131 & $expanded73;
     $134 = $133;
     $135 = HEAP32[$134>>2]|0;
     $arglist_next3 = ((($134)) + 4|0);
     HEAP32[$ap>>2] = $arglist_next3;
     $1172 = $110;$p$0 = $135;
    } else {
     $1172 = $110;$p$0 = 0;
    }
   } else {
    $1172 = $105;$p$0 = -1;
   }
  } while(0);
  $144 = $1172;$st$0 = 0;
  while(1) {
   $143 = HEAP8[$144>>0]|0;
   $145 = $143 << 24 >> 24;
   $146 = (($145) + -65)|0;
   $147 = ($146>>>0)>(57);
   if ($147) {
    $$0 = -1;
    label = 363;
    break L1;
   }
   $148 = ((($144)) + 1|0);
   $149 = ((72616 + (($st$0*58)|0)|0) + ($146)|0);
   $150 = HEAP8[$149>>0]|0;
   $151 = $150&255;
   $152 = (($151) + -1)|0;
   $153 = ($152>>>0)<(8);
   if ($153) {
    $144 = $148;$st$0 = $151;
   } else {
    $$lcssa455 = $144;$$lcssa457 = $148;$$lcssa458 = $150;$$lcssa459 = $151;$st$0$lcssa456 = $st$0;
    break;
   }
  }
  $154 = ($$lcssa458<<24>>24)==(0);
  if ($154) {
   $$0 = -1;
   label = 363;
   break;
  }
  $155 = ($$lcssa458<<24>>24)==(19);
  $156 = ($argpos$0|0)>(-1);
  L64: do {
   if ($155) {
    if ($156) {
     $$0 = -1;
     label = 363;
     break L1;
    } else {
     $1173 = $1169;$1174 = $1170;
     label = 62;
    }
   } else {
    if ($156) {
     $157 = (($nl_type) + ($argpos$0<<2)|0);
     HEAP32[$157>>2] = $$lcssa459;
     $158 = (($nl_arg) + ($argpos$0<<3)|0);
     $159 = HEAP32[$158>>2]|0;
     $160 = ((($158)) + 4|0);
     $161 = HEAP32[$160>>2]|0;
     $1173 = $161;$1174 = $159;
     label = 62;
     break;
    }
    if (!($1)) {
     $$0 = 0;
     label = 363;
     break L1;
    }
    $162 = ($$lcssa458&255)>(20);
    if ($162) {
     $265 = $1170;$292 = $1169;
    } else {
     do {
      switch ($$lcssa459|0) {
      case 9:  {
       $arglist_current5 = HEAP32[$ap>>2]|0;
       $163 = $arglist_current5;
       $164 = ((0) + 4|0);
       $expanded78 = $164;
       $expanded77 = (($expanded78) - 1)|0;
       $165 = (($163) + ($expanded77))|0;
       $166 = ((0) + 4|0);
       $expanded82 = $166;
       $expanded81 = (($expanded82) - 1)|0;
       $expanded80 = $expanded81 ^ -1;
       $167 = $165 & $expanded80;
       $168 = $167;
       $169 = HEAP32[$168>>2]|0;
       $arglist_next6 = ((($168)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next6;
       $170 = $169;
       $265 = $170;$292 = $1169;
       break L64;
       break;
      }
      case 16:  {
       $arglist_current26 = HEAP32[$ap>>2]|0;
       $230 = $arglist_current26;
       $231 = ((0) + 4|0);
       $expanded127 = $231;
       $expanded126 = (($expanded127) - 1)|0;
       $232 = (($230) + ($expanded126))|0;
       $233 = ((0) + 4|0);
       $expanded131 = $233;
       $expanded130 = (($expanded131) - 1)|0;
       $expanded129 = $expanded130 ^ -1;
       $234 = $232 & $expanded129;
       $235 = $234;
       $236 = HEAP32[$235>>2]|0;
       $arglist_next27 = ((($235)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next27;
       $$mask$i38 = $236 & 255;
       $265 = $$mask$i38;$292 = 0;
       break L64;
       break;
      }
      case 10:  {
       $arglist_current8 = HEAP32[$ap>>2]|0;
       $171 = $arglist_current8;
       $172 = ((0) + 4|0);
       $expanded85 = $172;
       $expanded84 = (($expanded85) - 1)|0;
       $173 = (($171) + ($expanded84))|0;
       $174 = ((0) + 4|0);
       $expanded89 = $174;
       $expanded88 = (($expanded89) - 1)|0;
       $expanded87 = $expanded88 ^ -1;
       $175 = $173 & $expanded87;
       $176 = $175;
       $177 = HEAP32[$176>>2]|0;
       $arglist_next9 = ((($176)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next9;
       $178 = ($177|0)<(0);
       $179 = $178 << 31 >> 31;
       $265 = $177;$292 = $179;
       break L64;
       break;
      }
      case 11:  {
       $arglist_current11 = HEAP32[$ap>>2]|0;
       $180 = $arglist_current11;
       $181 = ((0) + 4|0);
       $expanded92 = $181;
       $expanded91 = (($expanded92) - 1)|0;
       $182 = (($180) + ($expanded91))|0;
       $183 = ((0) + 4|0);
       $expanded96 = $183;
       $expanded95 = (($expanded96) - 1)|0;
       $expanded94 = $expanded95 ^ -1;
       $184 = $182 & $expanded94;
       $185 = $184;
       $186 = HEAP32[$185>>2]|0;
       $arglist_next12 = ((($185)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next12;
       $265 = $186;$292 = 0;
       break L64;
       break;
      }
      case 18:  {
       $arglist_current32 = HEAP32[$ap>>2]|0;
       $246 = $arglist_current32;
       $247 = ((0) + 8|0);
       $expanded141 = $247;
       $expanded140 = (($expanded141) - 1)|0;
       $248 = (($246) + ($expanded140))|0;
       $249 = ((0) + 8|0);
       $expanded145 = $249;
       $expanded144 = (($expanded145) - 1)|0;
       $expanded143 = $expanded144 ^ -1;
       $250 = $248 & $expanded143;
       $251 = $250;
       $252 = +HEAPF64[$251>>3];
       $arglist_next33 = ((($251)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next33;
       HEAPF64[tempDoublePtr>>3] = $252;$253 = HEAP32[tempDoublePtr>>2]|0;
       $254 = HEAP32[tempDoublePtr+4>>2]|0;
       $265 = $253;$292 = $254;
       break L64;
       break;
      }
      case 13:  {
       $arglist_current17 = HEAP32[$ap>>2]|0;
       $199 = $arglist_current17;
       $200 = ((0) + 4|0);
       $expanded106 = $200;
       $expanded105 = (($expanded106) - 1)|0;
       $201 = (($199) + ($expanded105))|0;
       $202 = ((0) + 4|0);
       $expanded110 = $202;
       $expanded109 = (($expanded110) - 1)|0;
       $expanded108 = $expanded109 ^ -1;
       $203 = $201 & $expanded108;
       $204 = $203;
       $205 = HEAP32[$204>>2]|0;
       $arglist_next18 = ((($204)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next18;
       $206 = $205&65535;
       $207 = $206 << 16 >> 16;
       $208 = ($207|0)<(0);
       $209 = $208 << 31 >> 31;
       $sext93 = $205 << 16;
       $210 = $sext93 >> 16;
       $265 = $210;$292 = $209;
       break L64;
       break;
      }
      case 17:  {
       $arglist_current29 = HEAP32[$ap>>2]|0;
       $237 = $arglist_current29;
       $238 = ((0) + 8|0);
       $expanded134 = $238;
       $expanded133 = (($expanded134) - 1)|0;
       $239 = (($237) + ($expanded133))|0;
       $240 = ((0) + 8|0);
       $expanded138 = $240;
       $expanded137 = (($expanded138) - 1)|0;
       $expanded136 = $expanded137 ^ -1;
       $241 = $239 & $expanded136;
       $242 = $241;
       $243 = +HEAPF64[$242>>3];
       $arglist_next30 = ((($242)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next30;
       HEAPF64[tempDoublePtr>>3] = $243;$244 = HEAP32[tempDoublePtr>>2]|0;
       $245 = HEAP32[tempDoublePtr+4>>2]|0;
       $265 = $244;$292 = $245;
       break L64;
       break;
      }
      case 12:  {
       $arglist_current14 = HEAP32[$ap>>2]|0;
       $187 = $arglist_current14;
       $188 = ((0) + 8|0);
       $expanded99 = $188;
       $expanded98 = (($expanded99) - 1)|0;
       $189 = (($187) + ($expanded98))|0;
       $190 = ((0) + 8|0);
       $expanded103 = $190;
       $expanded102 = (($expanded103) - 1)|0;
       $expanded101 = $expanded102 ^ -1;
       $191 = $189 & $expanded101;
       $192 = $191;
       $193 = $192;
       $194 = $193;
       $195 = HEAP32[$194>>2]|0;
       $196 = (($193) + 4)|0;
       $197 = $196;
       $198 = HEAP32[$197>>2]|0;
       $arglist_next15 = ((($192)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next15;
       $265 = $195;$292 = $198;
       break L64;
       break;
      }
      case 14:  {
       $arglist_current20 = HEAP32[$ap>>2]|0;
       $211 = $arglist_current20;
       $212 = ((0) + 4|0);
       $expanded113 = $212;
       $expanded112 = (($expanded113) - 1)|0;
       $213 = (($211) + ($expanded112))|0;
       $214 = ((0) + 4|0);
       $expanded117 = $214;
       $expanded116 = (($expanded117) - 1)|0;
       $expanded115 = $expanded116 ^ -1;
       $215 = $213 & $expanded115;
       $216 = $215;
       $217 = HEAP32[$216>>2]|0;
       $arglist_next21 = ((($216)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next21;
       $$mask1$i37 = $217 & 65535;
       $265 = $$mask1$i37;$292 = 0;
       break L64;
       break;
      }
      case 15:  {
       $arglist_current23 = HEAP32[$ap>>2]|0;
       $218 = $arglist_current23;
       $219 = ((0) + 4|0);
       $expanded120 = $219;
       $expanded119 = (($expanded120) - 1)|0;
       $220 = (($218) + ($expanded119))|0;
       $221 = ((0) + 4|0);
       $expanded124 = $221;
       $expanded123 = (($expanded124) - 1)|0;
       $expanded122 = $expanded123 ^ -1;
       $222 = $220 & $expanded122;
       $223 = $222;
       $224 = HEAP32[$223>>2]|0;
       $arglist_next24 = ((($223)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next24;
       $225 = $224&255;
       $226 = $225 << 24 >> 24;
       $227 = ($226|0)<(0);
       $228 = $227 << 31 >> 31;
       $sext = $224 << 24;
       $229 = $sext >> 24;
       $265 = $229;$292 = $228;
       break L64;
       break;
      }
      default: {
       $265 = $1170;$292 = $1169;
       break L64;
      }
      }
     } while(0);
    }
   }
  } while(0);
  if ((label|0) == 62) {
   label = 0;
   if ($1) {
    $265 = $1174;$292 = $1173;
   } else {
    $1169 = $1173;$1170 = $1174;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
    continue;
   }
  }
  $255 = HEAP8[$$lcssa455>>0]|0;
  $256 = $255 << 24 >> 24;
  $257 = ($st$0$lcssa456|0)!=(0);
  $258 = $256 & 15;
  $259 = ($258|0)==(3);
  $or$cond15 = $257 & $259;
  $260 = $256 & -33;
  $t$0 = $or$cond15 ? $260 : $256;
  $261 = $fl$1 & 8192;
  $262 = ($261|0)==(0);
  $263 = $fl$1 & -65537;
  $fl$1$ = $262 ? $fl$1 : $263;
  L86: do {
   switch ($t$0|0) {
   case 111:  {
    $312 = ($265|0)==(0);
    $313 = ($292|0)==(0);
    $314 = $312 & $313;
    if ($314) {
     $$0$lcssa$i51 = $2;
    } else {
     $$03$i48 = $2;$316 = $265;$320 = $292;
     while(1) {
      $315 = $316 & 7;
      $317 = $315 | 48;
      $318 = $317&255;
      $319 = ((($$03$i48)) + -1|0);
      HEAP8[$319>>0] = $318;
      $321 = (_bitshift64Lshr(($316|0),($320|0),3)|0);
      $322 = tempRet0;
      $323 = ($321|0)==(0);
      $324 = ($322|0)==(0);
      $325 = $323 & $324;
      if ($325) {
       $$0$lcssa$i51 = $319;
       break;
      } else {
       $$03$i48 = $319;$316 = $321;$320 = $322;
      }
     }
    }
    $326 = $fl$1$ & 8;
    $327 = ($326|0)==(0);
    $or$cond19 = $327 | $314;
    $$24 = $or$cond19 ? 73096 : (73101);
    $328 = $or$cond19&1;
    $$25 = $328 ^ 1;
    $367 = $265;$369 = $292;$a$0 = $$0$lcssa$i51;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $$25;$prefix$1 = $$24;
    label = 89;
    break;
   }
   case 112:  {
    $286 = ($p$0>>>0)>(8);
    $287 = $286 ? $p$0 : 8;
    $288 = $fl$1$ | 8;
    $fl$3 = $288;$p$1 = $287;$t$1 = 120;
    label = 73;
    break;
   }
   case 117:  {
    $337 = $292;$339 = $265;$pl$0 = 0;$prefix$0 = 73096;
    label = 84;
    break;
   }
   case 105: case 100:  {
    $329 = ($292|0)<(0);
    if ($329) {
     $330 = (_i64Subtract(0,0,($265|0),($292|0))|0);
     $331 = tempRet0;
     $337 = $331;$339 = $330;$pl$0 = 1;$prefix$0 = 73096;
     label = 84;
     break L86;
    }
    $332 = $fl$1$ & 2048;
    $333 = ($332|0)==(0);
    if ($333) {
     $334 = $fl$1$ & 1;
     $335 = ($334|0)==(0);
     $$ = $335 ? 73096 : (73098);
     $337 = $292;$339 = $265;$pl$0 = $334;$prefix$0 = $$;
     label = 84;
    } else {
     $337 = $292;$339 = $265;$pl$0 = 1;$prefix$0 = (73097);
     label = 84;
    }
    break;
   }
   case 65: case 71: case 70: case 69: case 97: case 103: case 102: case 101:  {
    HEAP32[tempDoublePtr>>2] = $265;HEAP32[tempDoublePtr+4>>2] = $292;$430 = +HEAPF64[tempDoublePtr>>3];
    HEAP32[$e2$i>>2] = 0;
    $431 = ($292|0)<(0);
    if ($431) {
     $432 = -$430;
     $$07$i = $432;$pl$0$i = 1;$prefix$0$i = 73120;
    } else {
     $433 = $fl$1$ & 2048;
     $434 = ($433|0)==(0);
     if ($434) {
      $435 = $fl$1$ & 1;
      $436 = ($435|0)==(0);
      $$$i = $436 ? (73121) : (73126);
      $$07$i = $430;$pl$0$i = $435;$prefix$0$i = $$$i;
     } else {
      $$07$i = $430;$pl$0$i = 1;$prefix$0$i = (73123);
     }
    }
    HEAPF64[tempDoublePtr>>3] = $$07$i;$437 = HEAP32[tempDoublePtr>>2]|0;
    $438 = HEAP32[tempDoublePtr+4>>2]|0;
    $439 = $438 & 2146435072;
    $440 = ($439>>>0)<(2146435072);
    $441 = (0)<(0);
    $442 = ($439|0)==(2146435072);
    $443 = $442 & $441;
    $444 = $440 | $443;
    do {
     if ($444) {
      $471 = (+_frexpl($$07$i,$e2$i));
      $472 = $471 * 2.0;
      $473 = $472 != 0.0;
      if ($473) {
       $474 = HEAP32[$e2$i>>2]|0;
       $475 = (($474) + -1)|0;
       HEAP32[$e2$i>>2] = $475;
      }
      $476 = $t$0 | 32;
      $477 = ($476|0)==(97);
      if ($477) {
       $478 = $t$0 & 32;
       $479 = ($478|0)==(0);
       $480 = ((($prefix$0$i)) + 9|0);
       $prefix$0$$i = $479 ? $prefix$0$i : $480;
       $481 = $pl$0$i | 2;
       $482 = ($p$0>>>0)>(11);
       $483 = (12 - ($p$0))|0;
       $484 = ($483|0)==(0);
       $485 = $482 | $484;
       do {
        if ($485) {
         $$1$i = $472;
        } else {
         $re$1179$i = $483;$round$0178$i = 8.0;
         while(1) {
          $486 = (($re$1179$i) + -1)|0;
          $487 = $round$0178$i * 16.0;
          $488 = ($486|0)==(0);
          if ($488) {
           $$lcssa483 = $487;
           break;
          } else {
           $re$1179$i = $486;$round$0178$i = $487;
          }
         }
         $489 = HEAP8[$prefix$0$$i>>0]|0;
         $490 = ($489<<24>>24)==(45);
         if ($490) {
          $491 = -$472;
          $492 = $491 - $$lcssa483;
          $493 = $$lcssa483 + $492;
          $494 = -$493;
          $$1$i = $494;
          break;
         } else {
          $495 = $472 + $$lcssa483;
          $496 = $495 - $$lcssa483;
          $$1$i = $496;
          break;
         }
        }
       } while(0);
       $497 = HEAP32[$e2$i>>2]|0;
       $498 = ($497|0)<(0);
       $499 = (0 - ($497))|0;
       $500 = $498 ? $499 : $497;
       $501 = ($500|0)<(0);
       if ($501) {
        $502 = ($500|0)<(0);
        $503 = $502 << 31 >> 31;
        $$05$i$i = $7;$504 = $500;$505 = $503;
        while(1) {
         $506 = (___uremdi3(($504|0),($505|0),10,0)|0);
         $507 = tempRet0;
         $508 = $506 | 48;
         $509 = $508&255;
         $510 = ((($$05$i$i)) + -1|0);
         HEAP8[$510>>0] = $509;
         $511 = (___udivdi3(($504|0),($505|0),10,0)|0);
         $512 = tempRet0;
         $513 = ($505>>>0)>(9);
         $514 = ($504>>>0)>(4294967295);
         $515 = ($505|0)==(9);
         $516 = $515 & $514;
         $517 = $513 | $516;
         if ($517) {
          $$05$i$i = $510;$504 = $511;$505 = $512;
         } else {
          $$lcssa484 = $510;$1183 = $511;$1184 = $512;
          break;
         }
        }
        $$0$lcssa$i48$i = $$lcssa484;$$01$lcssa$off0$i$i = $1183;
       } else {
        $$0$lcssa$i48$i = $7;$$01$lcssa$off0$i$i = $500;
       }
       $518 = ($$01$lcssa$off0$i$i|0)==(0);
       if ($518) {
        $$1$lcssa$i$i = $$0$lcssa$i48$i;
       } else {
        $$12$i$i = $$0$lcssa$i48$i;$y$03$i$i = $$01$lcssa$off0$i$i;
        while(1) {
         $519 = (($y$03$i$i>>>0) % 10)&-1;
         $520 = $519 | 48;
         $521 = $520&255;
         $522 = ((($$12$i$i)) + -1|0);
         HEAP8[$522>>0] = $521;
         $523 = (($y$03$i$i>>>0) / 10)&-1;
         $524 = ($y$03$i$i>>>0)<(10);
         if ($524) {
          $$1$lcssa$i$i = $522;
          break;
         } else {
          $$12$i$i = $522;$y$03$i$i = $523;
         }
        }
       }
       $525 = ($$1$lcssa$i$i|0)==($7|0);
       if ($525) {
        HEAP8[$8>>0] = 48;
        $estr$0$i = $8;
       } else {
        $estr$0$i = $$1$lcssa$i$i;
       }
       $526 = HEAP32[$e2$i>>2]|0;
       $527 = $526 >> 31;
       $528 = $527 & 2;
       $529 = (($528) + 43)|0;
       $530 = $529&255;
       $531 = ((($estr$0$i)) + -1|0);
       HEAP8[$531>>0] = $530;
       $532 = (($t$0) + 15)|0;
       $533 = $532&255;
       $534 = ((($estr$0$i)) + -2|0);
       HEAP8[$534>>0] = $533;
       $535 = $fl$1$ & 8;
       $536 = ($535|0)==(0);
       if ($536) {
        $notrhs$i = ($p$0|0)<(1);
        if ($notrhs$i) {
         $$2$us$us$i = $$1$i;$s$0$us$us$i = $buf$i;
         while(1) {
          $537 = (~~(($$2$us$us$i)));
          $538 = (73080 + ($537)|0);
          $539 = HEAP8[$538>>0]|0;
          $540 = $539&255;
          $541 = $540 | $478;
          $542 = $541&255;
          $543 = ((($s$0$us$us$i)) + 1|0);
          HEAP8[$s$0$us$us$i>>0] = $542;
          $544 = (+($537|0));
          $545 = $$2$us$us$i - $544;
          $546 = $545 * 16.0;
          $547 = $543;
          $548 = (($547) - ($0))|0;
          $549 = ($548|0)!=(1);
          $notlhs$us$us$i = $546 == 0.0;
          $or$cond$i79 = $549 | $notlhs$us$us$i;
          if ($or$cond$i79) {
           $s$1$us$us$i = $543;
          } else {
           $550 = ((($s$0$us$us$i)) + 2|0);
           HEAP8[$543>>0] = 46;
           $s$1$us$us$i = $550;
          }
          $551 = $546 != 0.0;
          if ($551) {
           $$2$us$us$i = $546;$s$0$us$us$i = $s$1$us$us$i;
          } else {
           $s$1$lcssa$i = $s$1$us$us$i;
           break;
          }
         }
        } else {
         $$2$us$i = $$1$i;$s$0$us$i = $buf$i;
         while(1) {
          $552 = (~~(($$2$us$i)));
          $553 = (73080 + ($552)|0);
          $554 = HEAP8[$553>>0]|0;
          $555 = $554&255;
          $556 = $555 | $478;
          $557 = $556&255;
          $558 = ((($s$0$us$i)) + 1|0);
          HEAP8[$s$0$us$i>>0] = $557;
          $559 = (+($552|0));
          $560 = $$2$us$i - $559;
          $561 = $560 * 16.0;
          $562 = $558;
          $563 = (($562) - ($0))|0;
          $564 = ($563|0)==(1);
          if ($564) {
           $565 = ((($s$0$us$i)) + 2|0);
           HEAP8[$558>>0] = 46;
           $s$1$us$i = $565;
          } else {
           $s$1$us$i = $558;
          }
          $566 = $561 != 0.0;
          if ($566) {
           $$2$us$i = $561;$s$0$us$i = $s$1$us$i;
          } else {
           $s$1$lcssa$i = $s$1$us$i;
           break;
          }
         }
        }
       } else {
        $$2$i = $$1$i;$s$0$i = $buf$i;
        while(1) {
         $567 = (~~(($$2$i)));
         $568 = (73080 + ($567)|0);
         $569 = HEAP8[$568>>0]|0;
         $570 = $569&255;
         $571 = $570 | $478;
         $572 = $571&255;
         $573 = ((($s$0$i)) + 1|0);
         HEAP8[$s$0$i>>0] = $572;
         $574 = (+($567|0));
         $575 = $$2$i - $574;
         $576 = $575 * 16.0;
         $577 = $573;
         $578 = (($577) - ($0))|0;
         $579 = ($578|0)==(1);
         if ($579) {
          $580 = ((($s$0$i)) + 2|0);
          HEAP8[$573>>0] = 46;
          $s$1$i = $580;
         } else {
          $s$1$i = $573;
         }
         $581 = $576 != 0.0;
         if ($581) {
          $$2$i = $576;$s$0$i = $s$1$i;
         } else {
          $s$1$lcssa$i = $s$1$i;
          break;
         }
        }
       }
       $582 = ($p$0|0)!=(0);
       $$pre300$i = $s$1$lcssa$i;
       $583 = (($11) + ($$pre300$i))|0;
       $584 = ($583|0)<($p$0|0);
       $or$cond332 = $582 & $584;
       $585 = $534;
       $586 = (($12) + ($p$0))|0;
       $587 = (($586) - ($585))|0;
       $588 = $534;
       $589 = (($10) - ($588))|0;
       $590 = (($589) + ($$pre300$i))|0;
       $l$0$i = $or$cond332 ? $587 : $590;
       $591 = (($l$0$i) + ($481))|0;
       $592 = $fl$1$ & 73728;
       $593 = ($592|0)==(0);
       $594 = ($w$1|0)>($591|0);
       $or$cond$i52$i = $593 & $594;
       if ($or$cond$i52$i) {
        $595 = (($w$1) - ($591))|0;
        $596 = ($595>>>0)>(256);
        $597 = $596 ? 256 : $595;
        _memset(($pad$i|0),32,($597|0))|0;
        $598 = ($595>>>0)>(255);
        if ($598) {
         $$01$i54$i = $595;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $599 = (($$01$i54$i) + -256)|0;
          $600 = ($599>>>0)>(255);
          if ($600) {
           $$01$i54$i = $599;
          } else {
           break;
          }
         }
         $601 = $595 & 255;
         $$0$lcssa$i56$i = $601;
        } else {
         $$0$lcssa$i56$i = $595;
        }
        (___fwritex($pad$i,$$0$lcssa$i56$i,$f)|0);
       }
       (___fwritex($prefix$0$$i,$481,$f)|0);
       $602 = ($592|0)==(65536);
       $or$cond$i59$i = $602 & $594;
       if ($or$cond$i59$i) {
        $603 = (($w$1) - ($591))|0;
        $604 = ($603>>>0)>(256);
        $605 = $604 ? 256 : $603;
        _memset(($pad$i|0),48,($605|0))|0;
        $606 = ($603>>>0)>(255);
        if ($606) {
         $$01$i61$i = $603;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $607 = (($$01$i61$i) + -256)|0;
          $608 = ($607>>>0)>(255);
          if ($608) {
           $$01$i61$i = $607;
          } else {
           break;
          }
         }
         $609 = $603 & 255;
         $$0$lcssa$i63$i = $609;
        } else {
         $$0$lcssa$i63$i = $603;
        }
        (___fwritex($pad$i,$$0$lcssa$i63$i,$f)|0);
       }
       $610 = (($$pre300$i) - ($0))|0;
       (___fwritex($buf$i,$610,$f)|0);
       $611 = $534;
       $612 = (($9) - ($611))|0;
       $613 = (($l$0$i) - ($612))|0;
       $614 = (($613) - ($610))|0;
       $615 = ($614|0)>(0);
       if ($615) {
        $616 = ($614>>>0)>(256);
        $617 = $616 ? 256 : $614;
        _memset(($pad$i|0),48,($617|0))|0;
        $618 = ($614>>>0)>(255);
        if ($618) {
         $$01$i67$i = $614;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $619 = (($$01$i67$i) + -256)|0;
          $620 = ($619>>>0)>(255);
          if ($620) {
           $$01$i67$i = $619;
          } else {
           break;
          }
         }
         $621 = $614 & 255;
         $$0$lcssa$i69$i = $621;
        } else {
         $$0$lcssa$i69$i = $614;
        }
        (___fwritex($pad$i,$$0$lcssa$i69$i,$f)|0);
       }
       (___fwritex($534,$612,$f)|0);
       $622 = ($592|0)==(8192);
       $or$cond$i72$i = $622 & $594;
       if ($or$cond$i72$i) {
        $623 = (($w$1) - ($591))|0;
        $624 = ($623>>>0)>(256);
        $625 = $624 ? 256 : $623;
        _memset(($pad$i|0),32,($625|0))|0;
        $626 = ($623>>>0)>(255);
        if ($626) {
         $$01$i74$i = $623;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $627 = (($$01$i74$i) + -256)|0;
          $628 = ($627>>>0)>(255);
          if ($628) {
           $$01$i74$i = $627;
          } else {
           break;
          }
         }
         $629 = $623 & 255;
         $$0$lcssa$i76$i = $629;
        } else {
         $$0$lcssa$i76$i = $623;
        }
        (___fwritex($pad$i,$$0$lcssa$i76$i,$f)|0);
       }
       $w$$i = $594 ? $w$1 : $591;
       $$0$i = $w$$i;
       break;
      }
      $630 = ($p$0|0)<(0);
      $$p$i = $630 ? 6 : $p$0;
      if ($473) {
       $631 = $472 * 268435456.0;
       $632 = HEAP32[$e2$i>>2]|0;
       $633 = (($632) + -28)|0;
       HEAP32[$e2$i>>2] = $633;
       $$3$i = $631;$635 = $633;
      } else {
       $$pre$i = HEAP32[$e2$i>>2]|0;
       $$3$i = $472;$635 = $$pre$i;
      }
      $634 = ($635|0)<(0);
      $$31$i = $634 ? $big$i : $13;
      $636 = $$31$i;
      $$4$i = $$3$i;$z$0$i = $$31$i;
      while(1) {
       $637 = (~~(($$4$i))>>>0);
       HEAP32[$z$0$i>>2] = $637;
       $638 = ((($z$0$i)) + 4|0);
       $639 = (+($637>>>0));
       $640 = $$4$i - $639;
       $641 = $640 * 1.0E+9;
       $642 = $641 != 0.0;
       if ($642) {
        $$4$i = $641;$z$0$i = $638;
       } else {
        $$lcssa460 = $638;
        break;
       }
      }
      $$pr$i = HEAP32[$e2$i>>2]|0;
      $643 = ($$pr$i|0)>(0);
      if ($643) {
       $645 = $$pr$i;$a$1253$i = $$31$i;$z$1252$i = $$lcssa460;
       while(1) {
        $644 = ($645|0)>(29);
        $646 = $644 ? 29 : $645;
        $d$0245$i = ((($z$1252$i)) + -4|0);
        $647 = ($d$0245$i>>>0)<($a$1253$i>>>0);
        do {
         if ($647) {
          $a$2$ph$i = $a$1253$i;
         } else {
          $carry$0246$i = 0;$d$0247$i = $d$0245$i;
          while(1) {
           $648 = HEAP32[$d$0247$i>>2]|0;
           $649 = (_bitshift64Shl(($648|0),0,($646|0))|0);
           $650 = tempRet0;
           $651 = (_i64Add(($649|0),($650|0),($carry$0246$i|0),0)|0);
           $652 = tempRet0;
           $653 = (___uremdi3(($651|0),($652|0),1000000000,0)|0);
           $654 = tempRet0;
           HEAP32[$d$0247$i>>2] = $653;
           $655 = (___udivdi3(($651|0),($652|0),1000000000,0)|0);
           $656 = tempRet0;
           $d$0$i = ((($d$0247$i)) + -4|0);
           $657 = ($d$0$i>>>0)<($a$1253$i>>>0);
           if ($657) {
            $$lcssa461 = $655;
            break;
           } else {
            $carry$0246$i = $655;$d$0247$i = $d$0$i;
           }
          }
          $658 = ($$lcssa461|0)==(0);
          if ($658) {
           $a$2$ph$i = $a$1253$i;
           break;
          }
          $659 = ((($a$1253$i)) + -4|0);
          HEAP32[$659>>2] = $$lcssa461;
          $a$2$ph$i = $659;
         }
        } while(0);
        $z$2$i = $z$1252$i;
        while(1) {
         $660 = ($z$2$i>>>0)>($a$2$ph$i>>>0);
         if (!($660)) {
          $z$2$i$lcssa = $z$2$i;
          break;
         }
         $661 = ((($z$2$i)) + -4|0);
         $662 = HEAP32[$661>>2]|0;
         $663 = ($662|0)==(0);
         if ($663) {
          $z$2$i = $661;
         } else {
          $z$2$i$lcssa = $z$2$i;
          break;
         }
        }
        $664 = HEAP32[$e2$i>>2]|0;
        $665 = (($664) - ($646))|0;
        HEAP32[$e2$i>>2] = $665;
        $666 = ($665|0)>(0);
        if ($666) {
         $645 = $665;$a$1253$i = $a$2$ph$i;$z$1252$i = $z$2$i$lcssa;
        } else {
         $$pr146$i = $665;$a$1$lcssa$i = $a$2$ph$i;$z$1$lcssa$i = $z$2$i$lcssa;
         break;
        }
       }
      } else {
       $$pr146$i = $$pr$i;$a$1$lcssa$i = $$31$i;$z$1$lcssa$i = $$lcssa460;
      }
      $667 = ($$pr146$i|0)<(0);
      L206: do {
       if ($667) {
        $668 = (($$p$i) + 25)|0;
        $669 = (($668|0) / 9)&-1;
        $670 = (($669) + 1)|0;
        $671 = ($476|0)==(102);
        if (!($671)) {
         $704 = $$pr146$i;$a$3240$i = $a$1$lcssa$i;$z$3239$i = $z$1$lcssa$i;
         while(1) {
          $703 = (0 - ($704))|0;
          $705 = ($703|0)>(9);
          $706 = $705 ? 9 : $703;
          $707 = ($a$3240$i>>>0)<($z$3239$i>>>0);
          do {
           if ($707) {
            $711 = 1 << $706;
            $712 = (($711) + -1)|0;
            $713 = 1000000000 >>> $706;
            $carry3$0234$i = 0;$d$1233$i = $a$3240$i;
            while(1) {
             $714 = HEAP32[$d$1233$i>>2]|0;
             $715 = $714 & $712;
             $716 = $714 >>> $706;
             $717 = (($716) + ($carry3$0234$i))|0;
             HEAP32[$d$1233$i>>2] = $717;
             $718 = Math_imul($715, $713)|0;
             $719 = ((($d$1233$i)) + 4|0);
             $720 = ($719>>>0)<($z$3239$i>>>0);
             if ($720) {
              $carry3$0234$i = $718;$d$1233$i = $719;
             } else {
              $$lcssa463 = $718;
              break;
             }
            }
            $721 = HEAP32[$a$3240$i>>2]|0;
            $722 = ($721|0)==(0);
            $723 = ((($a$3240$i)) + 4|0);
            $$a$3$i = $722 ? $723 : $a$3240$i;
            $724 = ($$lcssa463|0)==(0);
            if ($724) {
             $$a$3306$i = $$a$3$i;$z$4$i = $z$3239$i;
             break;
            }
            $725 = ((($z$3239$i)) + 4|0);
            HEAP32[$z$3239$i>>2] = $$lcssa463;
            $$a$3306$i = $$a$3$i;$z$4$i = $725;
           } else {
            $708 = HEAP32[$a$3240$i>>2]|0;
            $709 = ($708|0)==(0);
            $710 = ((($a$3240$i)) + 4|0);
            $$a$3305$i = $709 ? $710 : $a$3240$i;
            $$a$3306$i = $$a$3305$i;$z$4$i = $z$3239$i;
           }
          } while(0);
          $726 = $z$4$i;
          $727 = $$a$3306$i;
          $728 = (($726) - ($727))|0;
          $729 = $728 >> 2;
          $730 = ($729|0)>($670|0);
          $731 = (($$a$3306$i) + ($670<<2)|0);
          $$z$4$i = $730 ? $731 : $z$4$i;
          $732 = HEAP32[$e2$i>>2]|0;
          $733 = (($732) + ($706))|0;
          HEAP32[$e2$i>>2] = $733;
          $734 = ($733|0)<(0);
          if ($734) {
           $704 = $733;$a$3240$i = $$a$3306$i;$z$3239$i = $$z$4$i;
          } else {
           $a$3$lcssa$i = $$a$3306$i;$z$3$lcssa$i = $$z$4$i;
           break L206;
          }
         }
        }
        $672 = (($$31$i) + ($670<<2)|0);
        $674 = $$pr146$i;$a$3240$us$i = $a$1$lcssa$i;$z$3239$us$i = $z$1$lcssa$i;
        while(1) {
         $673 = (0 - ($674))|0;
         $675 = ($673|0)>(9);
         $676 = $675 ? 9 : $673;
         $677 = ($a$3240$us$i>>>0)<($z$3239$us$i>>>0);
         do {
          if ($677) {
           $702 = 1 << $676;
           $695 = (($702) + -1)|0;
           $699 = 1000000000 >>> $676;
           $carry3$0234$us$i = 0;$d$1233$us$i = $a$3240$us$i;
           while(1) {
            $693 = HEAP32[$d$1233$us$i>>2]|0;
            $694 = $693 & $695;
            $696 = $693 >>> $676;
            $697 = (($696) + ($carry3$0234$us$i))|0;
            HEAP32[$d$1233$us$i>>2] = $697;
            $698 = Math_imul($694, $699)|0;
            $700 = ((($d$1233$us$i)) + 4|0);
            $701 = ($700>>>0)<($z$3239$us$i>>>0);
            if ($701) {
             $carry3$0234$us$i = $698;$d$1233$us$i = $700;
            } else {
             $$lcssa464 = $698;
             break;
            }
           }
           $681 = HEAP32[$a$3240$us$i>>2]|0;
           $682 = ($681|0)==(0);
           $683 = ((($a$3240$us$i)) + 4|0);
           $$a$3$us$i = $682 ? $683 : $a$3240$us$i;
           $684 = ($$lcssa464|0)==(0);
           if ($684) {
            $$a$3$us304$i = $$a$3$us$i;$z$4$us$i = $z$3239$us$i;
            break;
           }
           $685 = ((($z$3239$us$i)) + 4|0);
           HEAP32[$z$3239$us$i>>2] = $$lcssa464;
           $$a$3$us304$i = $$a$3$us$i;$z$4$us$i = $685;
          } else {
           $678 = HEAP32[$a$3240$us$i>>2]|0;
           $679 = ($678|0)==(0);
           $680 = ((($a$3240$us$i)) + 4|0);
           $$a$3$us303$i = $679 ? $680 : $a$3240$us$i;
           $$a$3$us304$i = $$a$3$us303$i;$z$4$us$i = $z$3239$us$i;
          }
         } while(0);
         $686 = $z$4$us$i;
         $687 = (($686) - ($636))|0;
         $688 = $687 >> 2;
         $689 = ($688|0)>($670|0);
         $$z$4$us$i = $689 ? $672 : $z$4$us$i;
         $690 = HEAP32[$e2$i>>2]|0;
         $691 = (($690) + ($676))|0;
         HEAP32[$e2$i>>2] = $691;
         $692 = ($691|0)<(0);
         if ($692) {
          $674 = $691;$a$3240$us$i = $$a$3$us304$i;$z$3239$us$i = $$z$4$us$i;
         } else {
          $a$3$lcssa$i = $$a$3$us304$i;$z$3$lcssa$i = $$z$4$us$i;
          break;
         }
        }
       } else {
        $a$3$lcssa$i = $a$1$lcssa$i;$z$3$lcssa$i = $z$1$lcssa$i;
       }
      } while(0);
      $735 = ($a$3$lcssa$i>>>0)<($z$3$lcssa$i>>>0);
      do {
       if ($735) {
        $736 = $a$3$lcssa$i;
        $737 = (($636) - ($736))|0;
        $738 = $737 >> 2;
        $739 = ($738*9)|0;
        $740 = HEAP32[$a$3$lcssa$i>>2]|0;
        $741 = ($740>>>0)<(10);
        if ($741) {
         $e$1$i = $739;
         break;
        } else {
         $e$0229$i = $739;$i$0228$i = 10;
        }
        while(1) {
         $742 = ($i$0228$i*10)|0;
         $743 = (($e$0229$i) + 1)|0;
         $744 = ($740>>>0)<($742>>>0);
         if ($744) {
          $e$1$i = $743;
          break;
         } else {
          $e$0229$i = $743;$i$0228$i = $742;
         }
        }
       } else {
        $e$1$i = 0;
       }
      } while(0);
      $745 = ($476|0)!=(102);
      $746 = $745 ? $e$1$i : 0;
      $747 = (($$p$i) - ($746))|0;
      $748 = ($476|0)==(103);
      $749 = ($$p$i|0)!=(0);
      $750 = $749 & $748;
      $$neg151$i = $750 << 31 >> 31;
      $751 = (($747) + ($$neg151$i))|0;
      $752 = $z$3$lcssa$i;
      $753 = (($752) - ($636))|0;
      $754 = $753 >> 2;
      $755 = ($754*9)|0;
      $756 = (($755) + -9)|0;
      $757 = ($751|0)<($756|0);
      if ($757) {
       $758 = (($751) + 9216)|0;
       $759 = (($758|0) / 9)&-1;
       $$sum$i = (($759) + -1023)|0;
       $760 = (($$31$i) + ($$sum$i<<2)|0);
       $761 = (($758|0) % 9)&-1;
       $j$0221$i = (($761) + 1)|0;
       $762 = ($j$0221$i|0)<(9);
       if ($762) {
        $i$1222$i = 10;$j$0223$i = $j$0221$i;
        while(1) {
         $763 = ($i$1222$i*10)|0;
         $j$0$i = (($j$0223$i) + 1)|0;
         $exitcond$i = ($j$0$i|0)==(9);
         if ($exitcond$i) {
          $i$1$lcssa$i = $763;
          break;
         } else {
          $i$1222$i = $763;$j$0223$i = $j$0$i;
         }
        }
       } else {
        $i$1$lcssa$i = 10;
       }
       $764 = HEAP32[$760>>2]|0;
       $765 = (($764>>>0) % ($i$1$lcssa$i>>>0))&-1;
       $766 = ($765|0)==(0);
       if ($766) {
        $$sum15$i = (($759) + -1022)|0;
        $767 = (($$31$i) + ($$sum15$i<<2)|0);
        $768 = ($767|0)==($z$3$lcssa$i|0);
        if ($768) {
         $a$7$i = $a$3$lcssa$i;$d$3$i = $760;$e$3$i = $e$1$i;
        } else {
         label = 221;
        }
       } else {
        label = 221;
       }
       do {
        if ((label|0) == 221) {
         label = 0;
         $769 = (($764>>>0) / ($i$1$lcssa$i>>>0))&-1;
         $770 = $769 & 1;
         $771 = ($770|0)==(0);
         $$20$i = $771 ? 9007199254740992.0 : 9007199254740994.0;
         $772 = (($i$1$lcssa$i|0) / 2)&-1;
         $773 = ($765>>>0)<($772>>>0);
         do {
          if ($773) {
           $small$0$i = 0.5;
          } else {
           $774 = ($765|0)==($772|0);
           if ($774) {
            $$sum16$i = (($759) + -1022)|0;
            $775 = (($$31$i) + ($$sum16$i<<2)|0);
            $776 = ($775|0)==($z$3$lcssa$i|0);
            if ($776) {
             $small$0$i = 1.0;
             break;
            }
           }
           $small$0$i = 1.5;
          }
         } while(0);
         $777 = ($pl$0$i|0)==(0);
         do {
          if ($777) {
           $round6$1$i = $$20$i;$small$1$i = $small$0$i;
          } else {
           $778 = HEAP8[$prefix$0$i>>0]|0;
           $779 = ($778<<24>>24)==(45);
           if (!($779)) {
            $round6$1$i = $$20$i;$small$1$i = $small$0$i;
            break;
           }
           $780 = -$$20$i;
           $781 = -$small$0$i;
           $round6$1$i = $780;$small$1$i = $781;
          }
         } while(0);
         $782 = (($764) - ($765))|0;
         HEAP32[$760>>2] = $782;
         $783 = $round6$1$i + $small$1$i;
         $784 = $783 != $round6$1$i;
         if (!($784)) {
          $a$7$i = $a$3$lcssa$i;$d$3$i = $760;$e$3$i = $e$1$i;
          break;
         }
         $785 = (($782) + ($i$1$lcssa$i))|0;
         HEAP32[$760>>2] = $785;
         $786 = ($785>>>0)>(999999999);
         if ($786) {
          $a$5215$i = $a$3$lcssa$i;$d$2214$i = $760;
          while(1) {
           $787 = ((($d$2214$i)) + -4|0);
           HEAP32[$d$2214$i>>2] = 0;
           $788 = ($787>>>0)<($a$5215$i>>>0);
           if ($788) {
            $789 = ((($a$5215$i)) + -4|0);
            HEAP32[$789>>2] = 0;
            $a$6$i = $789;
           } else {
            $a$6$i = $a$5215$i;
           }
           $790 = HEAP32[$787>>2]|0;
           $791 = (($790) + 1)|0;
           HEAP32[$787>>2] = $791;
           $792 = ($791>>>0)>(999999999);
           if ($792) {
            $a$5215$i = $a$6$i;$d$2214$i = $787;
           } else {
            $a$5$lcssa$i = $a$6$i;$d$2$lcssa$i = $787;
            break;
           }
          }
         } else {
          $a$5$lcssa$i = $a$3$lcssa$i;$d$2$lcssa$i = $760;
         }
         $793 = $a$5$lcssa$i;
         $794 = (($636) - ($793))|0;
         $795 = $794 >> 2;
         $796 = ($795*9)|0;
         $797 = HEAP32[$a$5$lcssa$i>>2]|0;
         $798 = ($797>>>0)<(10);
         if ($798) {
          $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $796;
          break;
         } else {
          $e$2210$i = $796;$i$2209$i = 10;
         }
         while(1) {
          $799 = ($i$2209$i*10)|0;
          $800 = (($e$2210$i) + 1)|0;
          $801 = ($797>>>0)<($799>>>0);
          if ($801) {
           $a$7$i = $a$5$lcssa$i;$d$3$i = $d$2$lcssa$i;$e$3$i = $800;
           break;
          } else {
           $e$2210$i = $800;$i$2209$i = $799;
          }
         }
        }
       } while(0);
       $802 = ((($d$3$i)) + 4|0);
       $803 = ($z$3$lcssa$i>>>0)>($802>>>0);
       $$z$3$i = $803 ? $802 : $z$3$lcssa$i;
       $a$8$ph$i = $a$7$i;$e$4$ph$i = $e$3$i;$z$6$ph$i = $$z$3$i;
      } else {
       $a$8$ph$i = $a$3$lcssa$i;$e$4$ph$i = $e$1$i;$z$6$ph$i = $z$3$lcssa$i;
      }
      $804 = (0 - ($e$4$ph$i))|0;
      $z$6$i = $z$6$ph$i;
      while(1) {
       $805 = ($z$6$i>>>0)>($a$8$ph$i>>>0);
       if (!($805)) {
        $$lcssa275$i = 0;$z$6$i$lcssa = $z$6$i;
        break;
       }
       $806 = ((($z$6$i)) + -4|0);
       $807 = HEAP32[$806>>2]|0;
       $808 = ($807|0)==(0);
       if ($808) {
        $z$6$i = $806;
       } else {
        $$lcssa275$i = 1;$z$6$i$lcssa = $z$6$i;
        break;
       }
      }
      do {
       if ($748) {
        $809 = $749&1;
        $810 = $809 ^ 1;
        $$p$$i = (($810) + ($$p$i))|0;
        $811 = ($$p$$i|0)>($e$4$ph$i|0);
        $812 = ($e$4$ph$i|0)>(-5);
        $or$cond6$i = $811 & $812;
        if ($or$cond6$i) {
         $813 = (($t$0) + -1)|0;
         $$neg152$i = (($$p$$i) + -1)|0;
         $814 = (($$neg152$i) - ($e$4$ph$i))|0;
         $$013$i = $813;$$210$i = $814;
        } else {
         $815 = (($t$0) + -2)|0;
         $816 = (($$p$$i) + -1)|0;
         $$013$i = $815;$$210$i = $816;
        }
        $817 = $fl$1$ & 8;
        $818 = ($817|0)==(0);
        if (!($818)) {
         $$114$i = $$013$i;$$311$i = $$210$i;$$pre$phi302$iZ2D = $817;
         break;
        }
        do {
         if ($$lcssa275$i) {
          $819 = ((($z$6$i$lcssa)) + -4|0);
          $820 = HEAP32[$819>>2]|0;
          $821 = ($820|0)==(0);
          if ($821) {
           $j$2$i = 9;
           break;
          }
          $822 = (($820>>>0) % 10)&-1;
          $823 = ($822|0)==(0);
          if ($823) {
           $i$3205$i = 10;$j$1206$i = 0;
          } else {
           $j$2$i = 0;
           break;
          }
          while(1) {
           $824 = ($i$3205$i*10)|0;
           $825 = (($j$1206$i) + 1)|0;
           $826 = (($820>>>0) % ($824>>>0))&-1;
           $827 = ($826|0)==(0);
           if ($827) {
            $i$3205$i = $824;$j$1206$i = $825;
           } else {
            $j$2$i = $825;
            break;
           }
          }
         } else {
          $j$2$i = 9;
         }
        } while(0);
        $828 = $$013$i | 32;
        $829 = ($828|0)==(102);
        $830 = $z$6$i$lcssa;
        $831 = (($830) - ($636))|0;
        $832 = $831 >> 2;
        $833 = ($832*9)|0;
        $834 = (($833) + -9)|0;
        if ($829) {
         $835 = (($834) - ($j$2$i))|0;
         $836 = ($835|0)<(0);
         $$21$i = $836 ? 0 : $835;
         $837 = ($$210$i|0)<($$21$i|0);
         $$210$$22$i = $837 ? $$210$i : $$21$i;
         $$114$i = $$013$i;$$311$i = $$210$$22$i;$$pre$phi302$iZ2D = 0;
         break;
        } else {
         $838 = (($834) + ($e$4$ph$i))|0;
         $839 = (($838) - ($j$2$i))|0;
         $840 = ($839|0)<(0);
         $$23$i = $840 ? 0 : $839;
         $841 = ($$210$i|0)<($$23$i|0);
         $$210$$24$i = $841 ? $$210$i : $$23$i;
         $$114$i = $$013$i;$$311$i = $$210$$24$i;$$pre$phi302$iZ2D = 0;
         break;
        }
       } else {
        $$pre301$i = $fl$1$ & 8;
        $$114$i = $t$0;$$311$i = $$p$i;$$pre$phi302$iZ2D = $$pre301$i;
       }
      } while(0);
      $842 = $$311$i | $$pre$phi302$iZ2D;
      $843 = ($842|0)!=(0);
      $844 = $843&1;
      $845 = $$114$i | 32;
      $846 = ($845|0)==(102);
      if ($846) {
       $847 = ($e$4$ph$i|0)>(0);
       $848 = $847 ? $e$4$ph$i : 0;
       $$pn$i = $848;$estr$2$i = 0;
      } else {
       $849 = ($e$4$ph$i|0)<(0);
       $850 = $849 ? $804 : $e$4$ph$i;
       $851 = ($850|0)<(0);
       if ($851) {
        $852 = ($850|0)<(0);
        $853 = $852 << 31 >> 31;
        $$05$i79$i = $7;$854 = $850;$855 = $853;
        while(1) {
         $856 = (___uremdi3(($854|0),($855|0),10,0)|0);
         $857 = tempRet0;
         $858 = $856 | 48;
         $859 = $858&255;
         $860 = ((($$05$i79$i)) + -1|0);
         HEAP8[$860>>0] = $859;
         $861 = (___udivdi3(($854|0),($855|0),10,0)|0);
         $862 = tempRet0;
         $863 = ($855>>>0)>(9);
         $864 = ($854>>>0)>(4294967295);
         $865 = ($855|0)==(9);
         $866 = $865 & $864;
         $867 = $863 | $866;
         if ($867) {
          $$05$i79$i = $860;$854 = $861;$855 = $862;
         } else {
          $$lcssa470 = $860;$1185 = $861;$1186 = $862;
          break;
         }
        }
        $$0$lcssa$i84$i = $$lcssa470;$$01$lcssa$off0$i85$i = $1185;
       } else {
        $$0$lcssa$i84$i = $7;$$01$lcssa$off0$i85$i = $850;
       }
       $868 = ($$01$lcssa$off0$i85$i|0)==(0);
       if ($868) {
        $estr$1$ph$i = $$0$lcssa$i84$i;
       } else {
        $$12$i87$i = $$0$lcssa$i84$i;$y$03$i86$i = $$01$lcssa$off0$i85$i;
        while(1) {
         $869 = (($y$03$i86$i>>>0) % 10)&-1;
         $870 = $869 | 48;
         $871 = $870&255;
         $872 = ((($$12$i87$i)) + -1|0);
         HEAP8[$872>>0] = $871;
         $873 = (($y$03$i86$i>>>0) / 10)&-1;
         $874 = ($y$03$i86$i>>>0)<(10);
         if ($874) {
          $estr$1$ph$i = $872;
          break;
         } else {
          $$12$i87$i = $872;$y$03$i86$i = $873;
         }
        }
       }
       $875 = $estr$1$ph$i;
       $876 = (($9) - ($875))|0;
       $877 = ($876|0)<(2);
       if ($877) {
        $estr$1201$i = $estr$1$ph$i;
        while(1) {
         $878 = ((($estr$1201$i)) + -1|0);
         HEAP8[$878>>0] = 48;
         $879 = $878;
         $880 = (($9) - ($879))|0;
         $881 = ($880|0)<(2);
         if ($881) {
          $estr$1201$i = $878;
         } else {
          $estr$1$lcssa$i = $878;
          break;
         }
        }
       } else {
        $estr$1$lcssa$i = $estr$1$ph$i;
       }
       $882 = $e$4$ph$i >> 31;
       $883 = $882 & 2;
       $884 = (($883) + 43)|0;
       $885 = $884&255;
       $886 = ((($estr$1$lcssa$i)) + -1|0);
       HEAP8[$886>>0] = $885;
       $887 = $$114$i&255;
       $888 = ((($estr$1$lcssa$i)) + -2|0);
       HEAP8[$888>>0] = $887;
       $889 = $888;
       $890 = (($9) - ($889))|0;
       $$pn$i = $890;$estr$2$i = $888;
      }
      $891 = (($pl$0$i) + 1)|0;
      $892 = (($891) + ($$311$i))|0;
      $l$1$i = (($892) + ($844))|0;
      $893 = (($l$1$i) + ($$pn$i))|0;
      $894 = $fl$1$ & 73728;
      $895 = ($894|0)==(0);
      $896 = ($w$1|0)>($893|0);
      $or$cond$i93$i = $895 & $896;
      if ($or$cond$i93$i) {
       $897 = (($w$1) - ($893))|0;
       $898 = ($897>>>0)>(256);
       $899 = $898 ? 256 : $897;
       _memset(($pad$i|0),32,($899|0))|0;
       $900 = ($897>>>0)>(255);
       if ($900) {
        $$01$i95$i = $897;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $901 = (($$01$i95$i) + -256)|0;
         $902 = ($901>>>0)>(255);
         if ($902) {
          $$01$i95$i = $901;
         } else {
          break;
         }
        }
        $903 = $897 & 255;
        $$0$lcssa$i97$i = $903;
       } else {
        $$0$lcssa$i97$i = $897;
       }
       (___fwritex($pad$i,$$0$lcssa$i97$i,$f)|0);
      }
      (___fwritex($prefix$0$i,$pl$0$i,$f)|0);
      $904 = ($894|0)==(65536);
      $or$cond$i100$i = $904 & $896;
      if ($or$cond$i100$i) {
       $905 = (($w$1) - ($893))|0;
       $906 = ($905>>>0)>(256);
       $907 = $906 ? 256 : $905;
       _memset(($pad$i|0),48,($907|0))|0;
       $908 = ($905>>>0)>(255);
       if ($908) {
        $$01$i102$i = $905;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $909 = (($$01$i102$i) + -256)|0;
         $910 = ($909>>>0)>(255);
         if ($910) {
          $$01$i102$i = $909;
         } else {
          break;
         }
        }
        $911 = $905 & 255;
        $$0$lcssa$i104$i = $911;
       } else {
        $$0$lcssa$i104$i = $905;
       }
       (___fwritex($pad$i,$$0$lcssa$i104$i,$f)|0);
      }
      if ($846) {
       $912 = ($a$8$ph$i>>>0)>($$31$i>>>0);
       $r$0$a$8$i = $912 ? $$31$i : $a$8$ph$i;
       $d$4191$i = $r$0$a$8$i;
       while(1) {
        $913 = HEAP32[$d$4191$i>>2]|0;
        $914 = ($913|0)==(0);
        if ($914) {
         $$1$lcssa$i112$i = $14;
        } else {
         $$12$i110$i = $14;$y$03$i109$i = $913;
         while(1) {
          $915 = (($y$03$i109$i>>>0) % 10)&-1;
          $916 = $915 | 48;
          $917 = $916&255;
          $918 = ((($$12$i110$i)) + -1|0);
          HEAP8[$918>>0] = $917;
          $919 = (($y$03$i109$i>>>0) / 10)&-1;
          $920 = ($y$03$i109$i>>>0)<(10);
          if ($920) {
           $$1$lcssa$i112$i = $918;
           break;
          } else {
           $$12$i110$i = $918;$y$03$i109$i = $919;
          }
         }
        }
        $921 = ($d$4191$i|0)==($r$0$a$8$i|0);
        do {
         if ($921) {
          $925 = ($$1$lcssa$i112$i|0)==($14|0);
          if (!($925)) {
           $s7$1$i = $$1$lcssa$i112$i;
           break;
          }
          HEAP8[$16>>0] = 48;
          $s7$1$i = $16;
         } else {
          $922 = ($$1$lcssa$i112$i>>>0)>($buf$i>>>0);
          if ($922) {
           $s7$0188$i = $$1$lcssa$i112$i;
          } else {
           $s7$1$i = $$1$lcssa$i112$i;
           break;
          }
          while(1) {
           $923 = ((($s7$0188$i)) + -1|0);
           HEAP8[$923>>0] = 48;
           $924 = ($923>>>0)>($buf$i>>>0);
           if ($924) {
            $s7$0188$i = $923;
           } else {
            $s7$1$i = $923;
            break;
           }
          }
         }
        } while(0);
        $926 = $s7$1$i;
        $927 = (($15) - ($926))|0;
        (___fwritex($s7$1$i,$927,$f)|0);
        $928 = ((($d$4191$i)) + 4|0);
        $929 = ($928>>>0)>($$31$i>>>0);
        if ($929) {
         $$lcssa479 = $928;
         break;
        } else {
         $d$4191$i = $928;
        }
       }
       $930 = ($842|0)==(0);
       if (!($930)) {
        (___fwritex(73176,1,$f)|0);
       }
       $931 = ($$lcssa479>>>0)<($z$6$i$lcssa>>>0);
       $932 = ($$311$i|0)>(0);
       $933 = $932 & $931;
       if ($933) {
        $$412184$i = $$311$i;$d$5183$i = $$lcssa479;
        while(1) {
         $934 = HEAP32[$d$5183$i>>2]|0;
         $935 = ($934|0)==(0);
         if ($935) {
          $s8$0180$i = $14;
          label = 289;
         } else {
          $$12$i119$i = $14;$y$03$i118$i = $934;
          while(1) {
           $936 = (($y$03$i118$i>>>0) % 10)&-1;
           $937 = $936 | 48;
           $938 = $937&255;
           $939 = ((($$12$i119$i)) + -1|0);
           HEAP8[$939>>0] = $938;
           $940 = (($y$03$i118$i>>>0) / 10)&-1;
           $941 = ($y$03$i118$i>>>0)<(10);
           if ($941) {
            $$lcssa480 = $939;
            break;
           } else {
            $$12$i119$i = $939;$y$03$i118$i = $940;
           }
          }
          $942 = ($$lcssa480>>>0)>($buf$i>>>0);
          if ($942) {
           $s8$0180$i = $$lcssa480;
           label = 289;
          } else {
           $s8$0$lcssa$i = $$lcssa480;
          }
         }
         if ((label|0) == 289) {
          while(1) {
           label = 0;
           $943 = ((($s8$0180$i)) + -1|0);
           HEAP8[$943>>0] = 48;
           $944 = ($943>>>0)>($buf$i>>>0);
           if ($944) {
            $s8$0180$i = $943;
            label = 289;
           } else {
            $s8$0$lcssa$i = $943;
            break;
           }
          }
         }
         $945 = ($$412184$i|0)>(9);
         $946 = $945 ? 9 : $$412184$i;
         (___fwritex($s8$0$lcssa$i,$946,$f)|0);
         $947 = ((($d$5183$i)) + 4|0);
         $948 = (($$412184$i) + -9)|0;
         $949 = ($947>>>0)<($z$6$i$lcssa>>>0);
         $950 = $945 & $949;
         if ($950) {
          $$412184$i = $948;$d$5183$i = $947;
         } else {
          $$412$lcssa$i = $948;
          break;
         }
        }
       } else {
        $$412$lcssa$i = $$311$i;
       }
       $951 = ($$412$lcssa$i|0)>(0);
       if ($951) {
        $952 = ($$412$lcssa$i>>>0)>(256);
        $953 = $952 ? 256 : $$412$lcssa$i;
        _memset(($pad$i|0),48,($953|0))|0;
        $954 = ($$412$lcssa$i>>>0)>(255);
        if ($954) {
         $$01$i126$i = $$412$lcssa$i;
         while(1) {
          (___fwritex($pad$i,256,$f)|0);
          $955 = (($$01$i126$i) + -256)|0;
          $956 = ($955>>>0)>(255);
          if ($956) {
           $$01$i126$i = $955;
          } else {
           break;
          }
         }
         $957 = $$412$lcssa$i & 255;
         $$0$lcssa$i128$i = $957;
        } else {
         $$0$lcssa$i128$i = $$412$lcssa$i;
        }
        (___fwritex($pad$i,$$0$lcssa$i128$i,$f)|0);
       }
      } else {
       $958 = ((($a$8$ph$i)) + 4|0);
       $z$6$$i = $$lcssa275$i ? $z$6$i$lcssa : $958;
       $959 = ($$311$i|0)>(-1);
       do {
        if ($959) {
         $960 = ($$pre$phi302$iZ2D|0)==(0);
         $$5196$i = $$311$i;$d$6195$i = $a$8$ph$i;
         while(1) {
          $961 = HEAP32[$d$6195$i>>2]|0;
          $962 = ($961|0)==(0);
          if ($962) {
           label = 303;
          } else {
           $$12$i134$i = $14;$y$03$i133$i = $961;
           while(1) {
            $963 = (($y$03$i133$i>>>0) % 10)&-1;
            $964 = $963 | 48;
            $965 = $964&255;
            $966 = ((($$12$i134$i)) + -1|0);
            HEAP8[$966>>0] = $965;
            $967 = (($y$03$i133$i>>>0) / 10)&-1;
            $968 = ($y$03$i133$i>>>0)<(10);
            if ($968) {
             $$12$i134$i$lcssa = $$12$i134$i;$$lcssa474 = $966;
             break;
            } else {
             $$12$i134$i = $966;$y$03$i133$i = $967;
            }
           }
           $969 = ($$lcssa474|0)==($14|0);
           if ($969) {
            label = 303;
           } else {
            $1187 = $$12$i134$i$lcssa;$s9$0$i = $$lcssa474;
           }
          }
          if ((label|0) == 303) {
           label = 0;
           HEAP8[$16>>0] = 48;
           $1187 = $14;$s9$0$i = $16;
          }
          $970 = ($d$6195$i|0)==($a$8$ph$i|0);
          do {
           if ($970) {
            (___fwritex($s9$0$i,1,$f)|0);
            $974 = ($$5196$i|0)<(1);
            $or$cond29$i = $960 & $974;
            if ($or$cond29$i) {
             $s9$2$i = $1187;
             break;
            }
            (___fwritex(73176,1,$f)|0);
            $s9$2$i = $1187;
           } else {
            $971 = ($s9$0$i>>>0)>($buf$i>>>0);
            if ($971) {
             $s9$1192$i = $s9$0$i;
            } else {
             $s9$2$i = $s9$0$i;
             break;
            }
            while(1) {
             $972 = ((($s9$1192$i)) + -1|0);
             HEAP8[$972>>0] = 48;
             $973 = ($972>>>0)>($buf$i>>>0);
             if ($973) {
              $s9$1192$i = $972;
             } else {
              $s9$2$i = $972;
              break;
             }
            }
           }
          } while(0);
          $975 = $s9$2$i;
          $976 = (($15) - ($975))|0;
          $977 = ($$5196$i|0)>($976|0);
          $978 = $977 ? $976 : $$5196$i;
          (___fwritex($s9$2$i,$978,$f)|0);
          $979 = (($$5196$i) - ($976))|0;
          $980 = ((($d$6195$i)) + 4|0);
          $981 = ($980>>>0)<($z$6$$i>>>0);
          $982 = ($979|0)>(-1);
          $983 = $981 & $982;
          if ($983) {
           $$5196$i = $979;$d$6195$i = $980;
          } else {
           $$lcssa476 = $979;
           break;
          }
         }
         $984 = ($$lcssa476|0)>(0);
         if (!($984)) {
          break;
         }
         $985 = ($$lcssa476>>>0)>(256);
         $986 = $985 ? 256 : $$lcssa476;
         _memset(($pad$i|0),48,($986|0))|0;
         $987 = ($$lcssa476>>>0)>(255);
         if ($987) {
          $$01$i141$i = $$lcssa476;
          while(1) {
           (___fwritex($pad$i,256,$f)|0);
           $988 = (($$01$i141$i) + -256)|0;
           $989 = ($988>>>0)>(255);
           if ($989) {
            $$01$i141$i = $988;
           } else {
            break;
           }
          }
          $990 = $$lcssa476 & 255;
          $$0$lcssa$i143$i = $990;
         } else {
          $$0$lcssa$i143$i = $$lcssa476;
         }
         (___fwritex($pad$i,$$0$lcssa$i143$i,$f)|0);
        } else {
        }
       } while(0);
       $991 = $estr$2$i;
       $992 = (($9) - ($991))|0;
       (___fwritex($estr$2$i,$992,$f)|0);
      }
      $993 = ($894|0)==(8192);
      $or$cond$i$i = $993 & $896;
      if ($or$cond$i$i) {
       $994 = (($w$1) - ($893))|0;
       $995 = ($994>>>0)>(256);
       $996 = $995 ? 256 : $994;
       _memset(($pad$i|0),32,($996|0))|0;
       $997 = ($994>>>0)>(255);
       if ($997) {
        $$01$i$i = $994;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $998 = (($$01$i$i) + -256)|0;
         $999 = ($998>>>0)>(255);
         if ($999) {
          $$01$i$i = $998;
         } else {
          break;
         }
        }
        $1000 = $994 & 255;
        $$0$lcssa$i$i = $1000;
       } else {
        $$0$lcssa$i$i = $994;
       }
       (___fwritex($pad$i,$$0$lcssa$i$i,$f)|0);
      }
      $w$30$i = $896 ? $w$1 : $893;
      $$0$i = $w$30$i;
     } else {
      $445 = $t$0 & 32;
      $446 = ($445|0)!=(0);
      $447 = $446 ? 73144 : 73152;
      $448 = ($$07$i != $$07$i) | (0.0 != 0.0);
      $449 = $446 ? 73160 : 73168;
      $pl$1$i = $448 ? 0 : $pl$0$i;
      $s1$0$i = $448 ? $449 : $447;
      $450 = (($pl$1$i) + 3)|0;
      $451 = $fl$1$ & 8192;
      $452 = ($451|0)==(0);
      $453 = ($w$1|0)>($450|0);
      $or$cond$i35$i = $452 & $453;
      if ($or$cond$i35$i) {
       $454 = (($w$1) - ($450))|0;
       $455 = ($454>>>0)>(256);
       $456 = $455 ? 256 : $454;
       _memset(($pad$i|0),32,($456|0))|0;
       $457 = ($454>>>0)>(255);
       if ($457) {
        $$01$i37$i = $454;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $458 = (($$01$i37$i) + -256)|0;
         $459 = ($458>>>0)>(255);
         if ($459) {
          $$01$i37$i = $458;
         } else {
          break;
         }
        }
        $460 = $454 & 255;
        $$0$lcssa$i39$i = $460;
       } else {
        $$0$lcssa$i39$i = $454;
       }
       (___fwritex($pad$i,$$0$lcssa$i39$i,$f)|0);
      }
      (___fwritex($prefix$0$i,$pl$1$i,$f)|0);
      (___fwritex($s1$0$i,3,$f)|0);
      $461 = $fl$1$ & 73728;
      $462 = ($461|0)==(8192);
      $or$cond$i42$i = $462 & $453;
      if ($or$cond$i42$i) {
       $463 = (($w$1) - ($450))|0;
       $464 = ($463>>>0)>(256);
       $465 = $464 ? 256 : $463;
       _memset(($pad$i|0),32,($465|0))|0;
       $466 = ($463>>>0)>(255);
       if ($466) {
        $$01$i44$i = $463;
        while(1) {
         (___fwritex($pad$i,256,$f)|0);
         $467 = (($$01$i44$i) + -256)|0;
         $468 = ($467>>>0)>(255);
         if ($468) {
          $$01$i44$i = $467;
         } else {
          break;
         }
        }
        $469 = $463 & 255;
        $$0$lcssa$i46$i = $469;
       } else {
        $$0$lcssa$i46$i = $463;
       }
       (___fwritex($pad$i,$$0$lcssa$i46$i,$f)|0);
      }
      $470 = $453 ? $w$1 : $450;
      $$0$i = $470;
     }
    } while(0);
    $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $$0$i;$l10n$0 = $l10n$3;
    continue L1;
    break;
   }
   case 110:  {
    switch ($st$0$lcssa456|0) {
    case 6:  {
     $278 = $265;
     HEAP32[$278>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 7:  {
     $279 = ($cnt$1|0)<(0);
     $280 = $279 << 31 >> 31;
     $281 = $265;
     $282 = $281;
     $283 = $282;
     HEAP32[$283>>2] = $cnt$1;
     $284 = (($282) + 4)|0;
     $285 = $284;
     HEAP32[$285>>2] = $280;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 2:  {
     $267 = ($cnt$1|0)<(0);
     $268 = $267 << 31 >> 31;
     $269 = $265;
     $270 = $269;
     $271 = $270;
     HEAP32[$271>>2] = $cnt$1;
     $272 = (($270) + 4)|0;
     $273 = $272;
     HEAP32[$273>>2] = $268;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 3:  {
     $274 = $cnt$1&65535;
     $275 = $265;
     HEAP16[$275>>1] = $274;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 4:  {
     $276 = $cnt$1&255;
     $277 = $265;
     HEAP8[$277>>0] = $276;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 0:  {
     $264 = $265;
     HEAP32[$264>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    case 1:  {
     $266 = $265;
     HEAP32[$266>>2] = $cnt$1;
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
     break;
    }
    default: {
     $1169 = $292;$1170 = $265;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $37;$l10n$0 = $l10n$3;
     continue L1;
    }
    }
    break;
   }
   case 67:  {
    HEAP32[$wc>>2] = $265;
    HEAP32[$5>>2] = 0;
    $1179 = $wc;$1180 = $6;$p$4272 = -1;
    label = 97;
    break;
   }
   case 83:  {
    $391 = $265;
    $392 = ($p$0|0)==(0);
    if ($392) {
     $1181 = $265;$1182 = $391;$i$0$lcssa273 = 0;
     label = 102;
    } else {
     $1179 = $391;$1180 = $265;$p$4272 = $p$0;
     label = 97;
    }
    break;
   }
   case 99:  {
    $378 = $265&255;
    HEAP8[$4>>0] = $378;
    $1175 = $292;$1176 = $265;$a$2 = $4;$fl$6 = $263;$p$5 = 1;$pl$2 = 0;$prefix$2 = 73096;$z$2 = $2;
    break;
   }
   case 109:  {
    $379 = (___errno_location()|0);
    $380 = HEAP32[$379>>2]|0;
    $381 = (_strerror(($380|0))|0);
    $a$1 = $381;
    label = 94;
    break;
   }
   case 115:  {
    $382 = $265;
    $383 = ($265|0)!=(0);
    $384 = $383 ? $382 : 73112;
    $a$1 = $384;
    label = 94;
    break;
   }
   case 88: case 120:  {
    $fl$3 = $fl$1$;$p$1 = $p$0;$t$1 = $t$0;
    label = 73;
    break;
   }
   default: {
    $1175 = $292;$1176 = $265;$a$2 = $23;$fl$6 = $fl$1$;$p$5 = $p$0;$pl$2 = 0;$prefix$2 = 73096;$z$2 = $2;
   }
   }
  } while(0);
  if ((label|0) == 73) {
   label = 0;
   $289 = $t$1 & 32;
   $290 = ($265|0)==(0);
   $291 = ($292|0)==(0);
   $293 = $290 & $291;
   if ($293) {
    $367 = $265;$369 = $292;$a$0 = $2;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 73096;
    label = 89;
   } else {
    $$012$i = $2;$295 = $265;$302 = $292;
    while(1) {
     $294 = $295 & 15;
     $296 = (73080 + ($294)|0);
     $297 = HEAP8[$296>>0]|0;
     $298 = $297&255;
     $299 = $298 | $289;
     $300 = $299&255;
     $301 = ((($$012$i)) + -1|0);
     HEAP8[$301>>0] = $300;
     $303 = (_bitshift64Lshr(($295|0),($302|0),4)|0);
     $304 = tempRet0;
     $305 = ($303|0)==(0);
     $306 = ($304|0)==(0);
     $307 = $305 & $306;
     if ($307) {
      $$lcssa491 = $301;
      break;
     } else {
      $$012$i = $301;$295 = $303;$302 = $304;
     }
    }
    $308 = $fl$3 & 8;
    $309 = ($308|0)==(0);
    if ($309) {
     $367 = $265;$369 = $292;$a$0 = $$lcssa491;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 0;$prefix$1 = 73096;
     label = 89;
    } else {
     $310 = $t$1 >> 4;
     $311 = (73096 + ($310)|0);
     $367 = $265;$369 = $292;$a$0 = $$lcssa491;$fl$4 = $fl$3;$p$2 = $p$1;$pl$1 = 2;$prefix$1 = $311;
     label = 89;
    }
   }
  }
  else if ((label|0) == 84) {
   label = 0;
   $336 = ($337>>>0)>(0);
   $338 = ($339>>>0)>(4294967295);
   $340 = ($337|0)==(0);
   $341 = $340 & $338;
   $342 = $336 | $341;
   if ($342) {
    $$05$i = $2;$343 = $339;$344 = $337;
    while(1) {
     $345 = (___uremdi3(($343|0),($344|0),10,0)|0);
     $346 = tempRet0;
     $347 = $345 | 48;
     $348 = $347&255;
     $349 = ((($$05$i)) + -1|0);
     HEAP8[$349>>0] = $348;
     $350 = (___udivdi3(($343|0),($344|0),10,0)|0);
     $351 = tempRet0;
     $352 = ($344>>>0)>(9);
     $353 = ($343>>>0)>(4294967295);
     $354 = ($344|0)==(9);
     $355 = $354 & $353;
     $356 = $352 | $355;
     if ($356) {
      $$05$i = $349;$343 = $350;$344 = $351;
     } else {
      $$lcssa487 = $349;$1177 = $350;$1178 = $351;
      break;
     }
    }
    $$0$lcssa$i53 = $$lcssa487;$$01$lcssa$off0$i = $1177;
   } else {
    $$0$lcssa$i53 = $2;$$01$lcssa$off0$i = $339;
   }
   $357 = ($$01$lcssa$off0$i|0)==(0);
   if ($357) {
    $367 = $339;$369 = $337;$a$0 = $$0$lcssa$i53;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
    label = 89;
   } else {
    $$12$i = $$0$lcssa$i53;$y$03$i = $$01$lcssa$off0$i;
    while(1) {
     $358 = (($y$03$i>>>0) % 10)&-1;
     $359 = $358 | 48;
     $360 = $359&255;
     $361 = ((($$12$i)) + -1|0);
     HEAP8[$361>>0] = $360;
     $362 = (($y$03$i>>>0) / 10)&-1;
     $363 = ($y$03$i>>>0)<(10);
     if ($363) {
      $367 = $339;$369 = $337;$a$0 = $361;$fl$4 = $fl$1$;$p$2 = $p$0;$pl$1 = $pl$0;$prefix$1 = $prefix$0;
      label = 89;
      break;
     } else {
      $$12$i = $361;$y$03$i = $362;
     }
    }
   }
  }
  else if ((label|0) == 94) {
   label = 0;
   $385 = (_memchr($a$1,0,$p$0)|0);
   $386 = ($385|0)==(0|0);
   $387 = $385;
   $388 = $a$1;
   $389 = (($387) - ($388))|0;
   $390 = (($a$1) + ($p$0)|0);
   $z$1 = $386 ? $390 : $385;
   $p$3 = $386 ? $p$0 : $389;
   $1175 = $292;$1176 = $265;$a$2 = $a$1;$fl$6 = $263;$p$5 = $p$3;$pl$2 = 0;$prefix$2 = 73096;$z$2 = $z$1;
  }
  else if ((label|0) == 97) {
   label = 0;
   $i$0175 = 0;$l$1174 = 0;$ws$0176 = $1179;
   while(1) {
    $393 = HEAP32[$ws$0176>>2]|0;
    $394 = ($393|0)==(0);
    if ($394) {
     $i$0$lcssa = $i$0175;$l$2 = $l$1174;
     break;
    }
    $395 = (_wctomb($mb,$393)|0);
    $396 = ($395|0)<(0);
    $397 = (($p$4272) - ($i$0175))|0;
    $398 = ($395>>>0)>($397>>>0);
    $or$cond22 = $396 | $398;
    if ($or$cond22) {
     $i$0$lcssa = $i$0175;$l$2 = $395;
     break;
    }
    $399 = ((($ws$0176)) + 4|0);
    $400 = (($395) + ($i$0175))|0;
    $401 = ($p$4272>>>0)>($400>>>0);
    if ($401) {
     $i$0175 = $400;$l$1174 = $395;$ws$0176 = $399;
    } else {
     $i$0$lcssa = $400;$l$2 = $395;
     break;
    }
   }
   $402 = ($l$2|0)<(0);
   if ($402) {
    $$0 = -1;
    label = 363;
    break;
   } else {
    $1181 = $1180;$1182 = $1179;$i$0$lcssa273 = $i$0$lcssa;
    label = 102;
   }
  }
  if ((label|0) == 89) {
   label = 0;
   $364 = ($p$2|0)>(-1);
   $365 = $fl$4 & -65537;
   $$fl$4 = $364 ? $365 : $fl$4;
   $366 = ($367|0)!=(0);
   $368 = ($369|0)!=(0);
   $370 = $366 | $368;
   $371 = ($p$2|0)!=(0);
   $or$cond = $370 | $371;
   if ($or$cond) {
    $372 = $a$0;
    $373 = (($3) - ($372))|0;
    $374 = $370&1;
    $375 = $374 ^ 1;
    $376 = (($375) + ($373))|0;
    $377 = ($p$2|0)>($376|0);
    $p$2$ = $377 ? $p$2 : $376;
    $1175 = $369;$1176 = $367;$a$2 = $a$0;$fl$6 = $$fl$4;$p$5 = $p$2$;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   } else {
    $1175 = $369;$1176 = $367;$a$2 = $2;$fl$6 = $$fl$4;$p$5 = 0;$pl$2 = $pl$1;$prefix$2 = $prefix$1;$z$2 = $2;
   }
  }
  else if ((label|0) == 102) {
   label = 0;
   $403 = $fl$1$ & 73728;
   $404 = ($403|0)==(0);
   $405 = ($w$1|0)>($i$0$lcssa273|0);
   $or$cond$i64 = $404 & $405;
   if ($or$cond$i64) {
    $406 = (($w$1) - ($i$0$lcssa273))|0;
    $407 = ($406>>>0)>(256);
    $408 = $407 ? 256 : $406;
    _memset(($pad$i|0),32,($408|0))|0;
    $409 = ($406>>>0)>(255);
    if ($409) {
     $$01$i66 = $406;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $410 = (($$01$i66) + -256)|0;
      $411 = ($410>>>0)>(255);
      if ($411) {
       $$01$i66 = $410;
      } else {
       break;
      }
     }
     $412 = $406 & 255;
     $$0$lcssa$i68 = $412;
    } else {
     $$0$lcssa$i68 = $406;
    }
    (___fwritex($pad$i,$$0$lcssa$i68,$f)|0);
   }
   $413 = ($i$0$lcssa273|0)==(0);
   L465: do {
    if (!($413)) {
     $i$1186 = 0;$ws$1187 = $1182;
     while(1) {
      $414 = HEAP32[$ws$1187>>2]|0;
      $415 = ($414|0)==(0);
      if ($415) {
       break L465;
      }
      $416 = (_wctomb($mb,$414)|0);
      $417 = (($416) + ($i$1186))|0;
      $418 = ($417|0)>($i$0$lcssa273|0);
      if ($418) {
       break L465;
      }
      $419 = ((($ws$1187)) + 4|0);
      (___fwritex($mb,$416,$f)|0);
      $420 = ($417>>>0)<($i$0$lcssa273>>>0);
      if ($420) {
       $i$1186 = $417;$ws$1187 = $419;
      } else {
       break;
      }
     }
    }
   } while(0);
   $421 = ($403|0)==(8192);
   $or$cond$i71 = $421 & $405;
   if ($or$cond$i71) {
    $422 = (($w$1) - ($i$0$lcssa273))|0;
    $423 = ($422>>>0)>(256);
    $424 = $423 ? 256 : $422;
    _memset(($pad$i|0),32,($424|0))|0;
    $425 = ($422>>>0)>(255);
    if ($425) {
     $$01$i73 = $422;
     while(1) {
      (___fwritex($pad$i,256,$f)|0);
      $426 = (($$01$i73) + -256)|0;
      $427 = ($426>>>0)>(255);
      if ($427) {
       $$01$i73 = $426;
      } else {
       break;
      }
     }
     $428 = $422 & 255;
     $$0$lcssa$i75 = $428;
    } else {
     $$0$lcssa$i75 = $422;
    }
    (___fwritex($pad$i,$$0$lcssa$i75,$f)|0);
   }
   $429 = $405 ? $w$1 : $i$0$lcssa273;
   $1169 = $292;$1170 = $1181;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $429;$l10n$0 = $l10n$3;
   continue;
  }
  $1001 = $z$2;
  $1002 = $a$2;
  $1003 = (($1001) - ($1002))|0;
  $1004 = ($p$5|0)<($1003|0);
  $$p$5 = $1004 ? $1003 : $p$5;
  $1005 = (($pl$2) + ($$p$5))|0;
  $1006 = ($w$1|0)<($1005|0);
  $w$2 = $1006 ? $1005 : $w$1;
  $1007 = $fl$6 & 73728;
  $1008 = ($1007|0)==(0);
  $1009 = ($w$2|0)>($1005|0);
  $or$cond$i81 = $1008 & $1009;
  if ($or$cond$i81) {
   $1010 = (($w$2) - ($1005))|0;
   $1011 = ($1010>>>0)>(256);
   $1012 = $1011 ? 256 : $1010;
   _memset(($pad$i|0),32,($1012|0))|0;
   $1013 = ($1010>>>0)>(255);
   if ($1013) {
    $$01$i83 = $1010;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1014 = (($$01$i83) + -256)|0;
     $1015 = ($1014>>>0)>(255);
     if ($1015) {
      $$01$i83 = $1014;
     } else {
      break;
     }
    }
    $1016 = $1010 & 255;
    $$0$lcssa$i85 = $1016;
   } else {
    $$0$lcssa$i85 = $1010;
   }
   (___fwritex($pad$i,$$0$lcssa$i85,$f)|0);
  }
  (___fwritex($prefix$2,$pl$2,$f)|0);
  $1017 = ($1007|0)==(65536);
  $or$cond$i57 = $1017 & $1009;
  if ($or$cond$i57) {
   $1018 = (($w$2) - ($1005))|0;
   $1019 = ($1018>>>0)>(256);
   $1020 = $1019 ? 256 : $1018;
   _memset(($pad$i|0),48,($1020|0))|0;
   $1021 = ($1018>>>0)>(255);
   if ($1021) {
    $$01$i59 = $1018;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1022 = (($$01$i59) + -256)|0;
     $1023 = ($1022>>>0)>(255);
     if ($1023) {
      $$01$i59 = $1022;
     } else {
      break;
     }
    }
    $1024 = $1018 & 255;
    $$0$lcssa$i61 = $1024;
   } else {
    $$0$lcssa$i61 = $1018;
   }
   (___fwritex($pad$i,$$0$lcssa$i61,$f)|0);
  }
  $1025 = ($$p$5|0)>($1003|0);
  if ($1025) {
   $1026 = (($$p$5) - ($1003))|0;
   $1027 = ($1026>>>0)>(256);
   $1028 = $1027 ? 256 : $1026;
   _memset(($pad$i|0),48,($1028|0))|0;
   $1029 = ($1026>>>0)>(255);
   if ($1029) {
    $$01$i44 = $1026;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1030 = (($$01$i44) + -256)|0;
     $1031 = ($1030>>>0)>(255);
     if ($1031) {
      $$01$i44 = $1030;
     } else {
      break;
     }
    }
    $1032 = $1026 & 255;
    $$0$lcssa$i46 = $1032;
   } else {
    $$0$lcssa$i46 = $1026;
   }
   (___fwritex($pad$i,$$0$lcssa$i46,$f)|0);
  }
  (___fwritex($a$2,$1003,$f)|0);
  $1033 = ($1007|0)==(8192);
  $or$cond$i = $1033 & $1009;
  if ($or$cond$i) {
   $1034 = (($w$2) - ($1005))|0;
   $1035 = ($1034>>>0)>(256);
   $1036 = $1035 ? 256 : $1034;
   _memset(($pad$i|0),32,($1036|0))|0;
   $1037 = ($1034>>>0)>(255);
   if ($1037) {
    $$01$i = $1034;
    while(1) {
     (___fwritex($pad$i,256,$f)|0);
     $1038 = (($$01$i) + -256)|0;
     $1039 = ($1038>>>0)>(255);
     if ($1039) {
      $$01$i = $1038;
     } else {
      break;
     }
    }
    $1040 = $1034 & 255;
    $$0$lcssa$i = $1040;
   } else {
    $$0$lcssa$i = $1034;
   }
   (___fwritex($pad$i,$$0$lcssa$i,$f)|0);
  }
  $1169 = $1175;$1170 = $1176;$23 = $$lcssa457;$cnt$0 = $cnt$1;$l$0 = $w$2;$l10n$0 = $l10n$3;
 }
 if ((label|0) == 344) {
  $1041 = ($f|0)==(0|0);
  if (!($1041)) {
   $$0 = $cnt$1$lcssa;
   STACKTOP = sp;return ($$0|0);
  }
  $1042 = ($l10n$0$lcssa|0)==(0);
  if ($1042) {
   $$0 = 0;
   STACKTOP = sp;return ($$0|0);
  } else {
   $i$2162 = 1;
  }
  while(1) {
   $1043 = (($nl_type) + ($i$2162<<2)|0);
   $1044 = HEAP32[$1043>>2]|0;
   $1045 = ($1044|0)==(0);
   if ($1045) {
    $i$2162$lcssa = $i$2162;
    break;
   }
   $1047 = (($nl_arg) + ($i$2162<<3)|0);
   $1048 = ($1044>>>0)>(20);
   L522: do {
    if (!($1048)) {
     do {
      switch ($1044|0) {
      case 9:  {
       $arglist_current35 = HEAP32[$ap>>2]|0;
       $1049 = $arglist_current35;
       $1050 = ((0) + 4|0);
       $expanded148 = $1050;
       $expanded147 = (($expanded148) - 1)|0;
       $1051 = (($1049) + ($expanded147))|0;
       $1052 = ((0) + 4|0);
       $expanded152 = $1052;
       $expanded151 = (($expanded152) - 1)|0;
       $expanded150 = $expanded151 ^ -1;
       $1053 = $1051 & $expanded150;
       $1054 = $1053;
       $1055 = HEAP32[$1054>>2]|0;
       $arglist_next36 = ((($1054)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next36;
       HEAP32[$1047>>2] = $1055;
       break L522;
       break;
      }
      case 10:  {
       $arglist_current38 = HEAP32[$ap>>2]|0;
       $1056 = $arglist_current38;
       $1057 = ((0) + 4|0);
       $expanded155 = $1057;
       $expanded154 = (($expanded155) - 1)|0;
       $1058 = (($1056) + ($expanded154))|0;
       $1059 = ((0) + 4|0);
       $expanded159 = $1059;
       $expanded158 = (($expanded159) - 1)|0;
       $expanded157 = $expanded158 ^ -1;
       $1060 = $1058 & $expanded157;
       $1061 = $1060;
       $1062 = HEAP32[$1061>>2]|0;
       $arglist_next39 = ((($1061)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next39;
       $1063 = ($1062|0)<(0);
       $1064 = $1063 << 31 >> 31;
       $1065 = $1047;
       $1066 = $1065;
       HEAP32[$1066>>2] = $1062;
       $1067 = (($1065) + 4)|0;
       $1068 = $1067;
       HEAP32[$1068>>2] = $1064;
       break L522;
       break;
      }
      case 11:  {
       $arglist_current41 = HEAP32[$ap>>2]|0;
       $1069 = $arglist_current41;
       $1070 = ((0) + 4|0);
       $expanded162 = $1070;
       $expanded161 = (($expanded162) - 1)|0;
       $1071 = (($1069) + ($expanded161))|0;
       $1072 = ((0) + 4|0);
       $expanded166 = $1072;
       $expanded165 = (($expanded166) - 1)|0;
       $expanded164 = $expanded165 ^ -1;
       $1073 = $1071 & $expanded164;
       $1074 = $1073;
       $1075 = HEAP32[$1074>>2]|0;
       $arglist_next42 = ((($1074)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next42;
       $1076 = $1047;
       $1077 = $1076;
       HEAP32[$1077>>2] = $1075;
       $1078 = (($1076) + 4)|0;
       $1079 = $1078;
       HEAP32[$1079>>2] = 0;
       break L522;
       break;
      }
      case 12:  {
       $arglist_current44 = HEAP32[$ap>>2]|0;
       $1080 = $arglist_current44;
       $1081 = ((0) + 8|0);
       $expanded169 = $1081;
       $expanded168 = (($expanded169) - 1)|0;
       $1082 = (($1080) + ($expanded168))|0;
       $1083 = ((0) + 8|0);
       $expanded173 = $1083;
       $expanded172 = (($expanded173) - 1)|0;
       $expanded171 = $expanded172 ^ -1;
       $1084 = $1082 & $expanded171;
       $1085 = $1084;
       $1086 = $1085;
       $1087 = $1086;
       $1088 = HEAP32[$1087>>2]|0;
       $1089 = (($1086) + 4)|0;
       $1090 = $1089;
       $1091 = HEAP32[$1090>>2]|0;
       $arglist_next45 = ((($1085)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next45;
       $1092 = $1047;
       $1093 = $1092;
       HEAP32[$1093>>2] = $1088;
       $1094 = (($1092) + 4)|0;
       $1095 = $1094;
       HEAP32[$1095>>2] = $1091;
       break L522;
       break;
      }
      case 13:  {
       $arglist_current47 = HEAP32[$ap>>2]|0;
       $1096 = $arglist_current47;
       $1097 = ((0) + 4|0);
       $expanded176 = $1097;
       $expanded175 = (($expanded176) - 1)|0;
       $1098 = (($1096) + ($expanded175))|0;
       $1099 = ((0) + 4|0);
       $expanded180 = $1099;
       $expanded179 = (($expanded180) - 1)|0;
       $expanded178 = $expanded179 ^ -1;
       $1100 = $1098 & $expanded178;
       $1101 = $1100;
       $1102 = HEAP32[$1101>>2]|0;
       $arglist_next48 = ((($1101)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next48;
       $1103 = $1102&65535;
       $1104 = $1103 << 16 >> 16;
       $1105 = ($1104|0)<(0);
       $1106 = $1105 << 31 >> 31;
       $1107 = $1047;
       $1108 = $1107;
       HEAP32[$1108>>2] = $1104;
       $1109 = (($1107) + 4)|0;
       $1110 = $1109;
       HEAP32[$1110>>2] = $1106;
       break L522;
       break;
      }
      case 14:  {
       $arglist_current50 = HEAP32[$ap>>2]|0;
       $1111 = $arglist_current50;
       $1112 = ((0) + 4|0);
       $expanded183 = $1112;
       $expanded182 = (($expanded183) - 1)|0;
       $1113 = (($1111) + ($expanded182))|0;
       $1114 = ((0) + 4|0);
       $expanded187 = $1114;
       $expanded186 = (($expanded187) - 1)|0;
       $expanded185 = $expanded186 ^ -1;
       $1115 = $1113 & $expanded185;
       $1116 = $1115;
       $1117 = HEAP32[$1116>>2]|0;
       $arglist_next51 = ((($1116)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next51;
       $$mask1$i = $1117 & 65535;
       $1118 = $1047;
       $1119 = $1118;
       HEAP32[$1119>>2] = $$mask1$i;
       $1120 = (($1118) + 4)|0;
       $1121 = $1120;
       HEAP32[$1121>>2] = 0;
       break L522;
       break;
      }
      case 15:  {
       $arglist_current53 = HEAP32[$ap>>2]|0;
       $1122 = $arglist_current53;
       $1123 = ((0) + 4|0);
       $expanded190 = $1123;
       $expanded189 = (($expanded190) - 1)|0;
       $1124 = (($1122) + ($expanded189))|0;
       $1125 = ((0) + 4|0);
       $expanded194 = $1125;
       $expanded193 = (($expanded194) - 1)|0;
       $expanded192 = $expanded193 ^ -1;
       $1126 = $1124 & $expanded192;
       $1127 = $1126;
       $1128 = HEAP32[$1127>>2]|0;
       $arglist_next54 = ((($1127)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next54;
       $1129 = $1128&255;
       $1130 = $1129 << 24 >> 24;
       $1131 = ($1130|0)<(0);
       $1132 = $1131 << 31 >> 31;
       $1133 = $1047;
       $1134 = $1133;
       HEAP32[$1134>>2] = $1130;
       $1135 = (($1133) + 4)|0;
       $1136 = $1135;
       HEAP32[$1136>>2] = $1132;
       break L522;
       break;
      }
      case 16:  {
       $arglist_current56 = HEAP32[$ap>>2]|0;
       $1137 = $arglist_current56;
       $1138 = ((0) + 4|0);
       $expanded197 = $1138;
       $expanded196 = (($expanded197) - 1)|0;
       $1139 = (($1137) + ($expanded196))|0;
       $1140 = ((0) + 4|0);
       $expanded201 = $1140;
       $expanded200 = (($expanded201) - 1)|0;
       $expanded199 = $expanded200 ^ -1;
       $1141 = $1139 & $expanded199;
       $1142 = $1141;
       $1143 = HEAP32[$1142>>2]|0;
       $arglist_next57 = ((($1142)) + 4|0);
       HEAP32[$ap>>2] = $arglist_next57;
       $$mask$i = $1143 & 255;
       $1144 = $1047;
       $1145 = $1144;
       HEAP32[$1145>>2] = $$mask$i;
       $1146 = (($1144) + 4)|0;
       $1147 = $1146;
       HEAP32[$1147>>2] = 0;
       break L522;
       break;
      }
      case 17:  {
       $arglist_current59 = HEAP32[$ap>>2]|0;
       $1148 = $arglist_current59;
       $1149 = ((0) + 8|0);
       $expanded204 = $1149;
       $expanded203 = (($expanded204) - 1)|0;
       $1150 = (($1148) + ($expanded203))|0;
       $1151 = ((0) + 8|0);
       $expanded208 = $1151;
       $expanded207 = (($expanded208) - 1)|0;
       $expanded206 = $expanded207 ^ -1;
       $1152 = $1150 & $expanded206;
       $1153 = $1152;
       $1154 = +HEAPF64[$1153>>3];
       $arglist_next60 = ((($1153)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next60;
       HEAPF64[$1047>>3] = $1154;
       break L522;
       break;
      }
      case 18:  {
       $arglist_current62 = HEAP32[$ap>>2]|0;
       $1155 = $arglist_current62;
       $1156 = ((0) + 8|0);
       $expanded211 = $1156;
       $expanded210 = (($expanded211) - 1)|0;
       $1157 = (($1155) + ($expanded210))|0;
       $1158 = ((0) + 8|0);
       $expanded215 = $1158;
       $expanded214 = (($expanded215) - 1)|0;
       $expanded213 = $expanded214 ^ -1;
       $1159 = $1157 & $expanded213;
       $1160 = $1159;
       $1161 = +HEAPF64[$1160>>3];
       $arglist_next63 = ((($1160)) + 8|0);
       HEAP32[$ap>>2] = $arglist_next63;
       HEAPF64[$1047>>3] = $1161;
       break L522;
       break;
      }
      default: {
       break L522;
      }
      }
     } while(0);
    }
   } while(0);
   $1162 = (($i$2162) + 1)|0;
   $1163 = ($1162|0)<(10);
   if ($1163) {
    $i$2162 = $1162;
   } else {
    $$0 = 1;
    label = 363;
    break;
   }
  }
  if ((label|0) == 363) {
   STACKTOP = sp;return ($$0|0);
  }
  $1046 = ($i$2162$lcssa|0)<(10);
  if ($1046) {
   $i$3160 = $i$2162$lcssa;
  } else {
   $$0 = 1;
   STACKTOP = sp;return ($$0|0);
  }
  while(1) {
   $1166 = (($nl_type) + ($i$3160<<2)|0);
   $1167 = HEAP32[$1166>>2]|0;
   $1168 = ($1167|0)==(0);
   $1165 = (($i$3160) + 1)|0;
   if (!($1168)) {
    $$0 = -1;
    label = 363;
    break;
   }
   $1164 = ($1165|0)<(10);
   if ($1164) {
    $i$3160 = $1165;
   } else {
    $$0 = 1;
    label = 363;
    break;
   }
  }
  if ((label|0) == 363) {
   STACKTOP = sp;return ($$0|0);
  }
 }
 else if ((label|0) == 363) {
  STACKTOP = sp;return ($$0|0);
 }
 return (0)|0;
}
function _sn_write($f,$s,$l) {
 $f = $f|0;
 $s = $s|0;
 $l = $l|0;
 var $0 = 0, $1 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $l$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($f)) + 16|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = ((($f)) + 20|0);
 $3 = HEAP32[$2>>2]|0;
 $4 = $1;
 $5 = $3;
 $6 = (($4) - ($5))|0;
 $7 = ($6>>>0)>($l>>>0);
 $l$ = $7 ? $l : $6;
 _memcpy(($3|0),($s|0),($l$|0))|0;
 $8 = HEAP32[$2>>2]|0;
 $9 = (($8) + ($l$)|0);
 HEAP32[$2>>2] = $9;
 return ($l|0);
}
function _malloc($bytes) {
 $bytes = $bytes|0;
 var $$3$i = 0, $$lcssa = 0, $$lcssa211 = 0, $$lcssa215 = 0, $$lcssa216 = 0, $$lcssa217 = 0, $$lcssa219 = 0, $$lcssa222 = 0, $$lcssa224 = 0, $$lcssa226 = 0, $$lcssa228 = 0, $$lcssa230 = 0, $$lcssa232 = 0, $$pre = 0, $$pre$i = 0, $$pre$i$i = 0, $$pre$i22$i = 0, $$pre$i25 = 0, $$pre$phi$i$iZ2D = 0, $$pre$phi$i23$iZ2D = 0;
 var $$pre$phi$i26Z2D = 0, $$pre$phi$iZ2D = 0, $$pre$phi58$i$iZ2D = 0, $$pre$phiZ2D = 0, $$pre105 = 0, $$pre106 = 0, $$pre14$i$i = 0, $$pre43$i = 0, $$pre56$i$i = 0, $$pre57$i$i = 0, $$pre8$i = 0, $$rsize$0$i = 0, $$rsize$3$i = 0, $$sum = 0, $$sum$i$i = 0, $$sum$i$i$i = 0, $$sum$i13$i = 0, $$sum$i14$i = 0, $$sum$i17$i = 0, $$sum$i19$i = 0;
 var $$sum$i2334 = 0, $$sum$i32 = 0, $$sum$i35 = 0, $$sum1 = 0, $$sum1$i = 0, $$sum1$i$i = 0, $$sum1$i15$i = 0, $$sum1$i20$i = 0, $$sum1$i24 = 0, $$sum10 = 0, $$sum10$i = 0, $$sum10$i$i = 0, $$sum11$i = 0, $$sum11$i$i = 0, $$sum1112 = 0, $$sum112$i = 0, $$sum113$i = 0, $$sum114$i = 0, $$sum115$i = 0, $$sum116$i = 0;
 var $$sum117$i = 0, $$sum118$i = 0, $$sum119$i = 0, $$sum12$i = 0, $$sum12$i$i = 0, $$sum120$i = 0, $$sum121$i = 0, $$sum122$i = 0, $$sum123$i = 0, $$sum124$i = 0, $$sum125$i = 0, $$sum13$i = 0, $$sum13$i$i = 0, $$sum14$i$i = 0, $$sum15$i = 0, $$sum15$i$i = 0, $$sum16$i = 0, $$sum16$i$i = 0, $$sum17$i = 0, $$sum17$i$i = 0;
 var $$sum18$i = 0, $$sum1819$i$i = 0, $$sum2 = 0, $$sum2$i = 0, $$sum2$i$i = 0, $$sum2$i$i$i = 0, $$sum2$i16$i = 0, $$sum2$i18$i = 0, $$sum2$i21$i = 0, $$sum20$i$i = 0, $$sum21$i$i = 0, $$sum22$i$i = 0, $$sum23$i$i = 0, $$sum24$i$i = 0, $$sum25$i$i = 0, $$sum27$i$i = 0, $$sum28$i$i = 0, $$sum29$i$i = 0, $$sum3$i = 0, $$sum3$i27 = 0;
 var $$sum30$i$i = 0, $$sum3132$i$i = 0, $$sum34$i$i = 0, $$sum3536$i$i = 0, $$sum3738$i$i = 0, $$sum39$i$i = 0, $$sum4 = 0, $$sum4$i = 0, $$sum4$i$i = 0, $$sum4$i28 = 0, $$sum40$i$i = 0, $$sum41$i$i = 0, $$sum42$i$i = 0, $$sum5$i = 0, $$sum5$i$i = 0, $$sum56 = 0, $$sum6$i = 0, $$sum67$i$i = 0, $$sum7$i = 0, $$sum8$i = 0;
 var $$sum9 = 0, $$sum9$i = 0, $$sum9$i$i = 0, $$tsize$1$i = 0, $$v$0$i = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $1000 = 0, $1001 = 0, $1002 = 0, $1003 = 0, $1004 = 0, $1005 = 0, $1006 = 0, $1007 = 0, $1008 = 0, $1009 = 0, $101 = 0;
 var $1010 = 0, $1011 = 0, $1012 = 0, $1013 = 0, $1014 = 0, $1015 = 0, $1016 = 0, $1017 = 0, $1018 = 0, $1019 = 0, $102 = 0, $1020 = 0, $1021 = 0, $1022 = 0, $1023 = 0, $1024 = 0, $1025 = 0, $1026 = 0, $1027 = 0, $1028 = 0;
 var $1029 = 0, $103 = 0, $1030 = 0, $1031 = 0, $1032 = 0, $1033 = 0, $1034 = 0, $1035 = 0, $1036 = 0, $1037 = 0, $1038 = 0, $1039 = 0, $104 = 0, $1040 = 0, $1041 = 0, $1042 = 0, $1043 = 0, $1044 = 0, $1045 = 0, $1046 = 0;
 var $1047 = 0, $1048 = 0, $1049 = 0, $105 = 0, $1050 = 0, $1051 = 0, $1052 = 0, $1053 = 0, $1054 = 0, $1055 = 0, $1056 = 0, $1057 = 0, $1058 = 0, $1059 = 0, $106 = 0, $1060 = 0, $1061 = 0, $1062 = 0, $1063 = 0, $1064 = 0;
 var $1065 = 0, $1066 = 0, $1067 = 0, $1068 = 0, $1069 = 0, $107 = 0, $1070 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0;
 var $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0;
 var $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0;
 var $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0;
 var $174 = 0, $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0;
 var $192 = 0, $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0;
 var $21 = 0, $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0;
 var $228 = 0, $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0;
 var $246 = 0, $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0;
 var $264 = 0, $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0;
 var $282 = 0, $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0;
 var $30 = 0, $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0;
 var $318 = 0, $319 = 0, $32 = 0, $320 = 0, $321 = 0, $322 = 0, $323 = 0, $324 = 0, $325 = 0, $326 = 0, $327 = 0, $328 = 0, $329 = 0, $33 = 0, $330 = 0, $331 = 0, $332 = 0, $333 = 0, $334 = 0, $335 = 0;
 var $336 = 0, $337 = 0, $338 = 0, $339 = 0, $34 = 0, $340 = 0, $341 = 0, $342 = 0, $343 = 0, $344 = 0, $345 = 0, $346 = 0, $347 = 0, $348 = 0, $349 = 0, $35 = 0, $350 = 0, $351 = 0, $352 = 0, $353 = 0;
 var $354 = 0, $355 = 0, $356 = 0, $357 = 0, $358 = 0, $359 = 0, $36 = 0, $360 = 0, $361 = 0, $362 = 0, $363 = 0, $364 = 0, $365 = 0, $366 = 0, $367 = 0, $368 = 0, $369 = 0, $37 = 0, $370 = 0, $371 = 0;
 var $372 = 0, $373 = 0, $374 = 0, $375 = 0, $376 = 0, $377 = 0, $378 = 0, $379 = 0, $38 = 0, $380 = 0, $381 = 0, $382 = 0, $383 = 0, $384 = 0, $385 = 0, $386 = 0, $387 = 0, $388 = 0, $389 = 0, $39 = 0;
 var $390 = 0, $391 = 0, $392 = 0, $393 = 0, $394 = 0, $395 = 0, $396 = 0, $397 = 0, $398 = 0, $399 = 0, $4 = 0, $40 = 0, $400 = 0, $401 = 0, $402 = 0, $403 = 0, $404 = 0, $405 = 0, $406 = 0, $407 = 0;
 var $408 = 0, $409 = 0, $41 = 0, $410 = 0, $411 = 0, $412 = 0, $413 = 0, $414 = 0, $415 = 0, $416 = 0, $417 = 0, $418 = 0, $419 = 0, $42 = 0, $420 = 0, $421 = 0, $422 = 0, $423 = 0, $424 = 0, $425 = 0;
 var $426 = 0, $427 = 0, $428 = 0, $429 = 0, $43 = 0, $430 = 0, $431 = 0, $432 = 0, $433 = 0, $434 = 0, $435 = 0, $436 = 0, $437 = 0, $438 = 0, $439 = 0, $44 = 0, $440 = 0, $441 = 0, $442 = 0, $443 = 0;
 var $444 = 0, $445 = 0, $446 = 0, $447 = 0, $448 = 0, $449 = 0, $45 = 0, $450 = 0, $451 = 0, $452 = 0, $453 = 0, $454 = 0, $455 = 0, $456 = 0, $457 = 0, $458 = 0, $459 = 0, $46 = 0, $460 = 0, $461 = 0;
 var $462 = 0, $463 = 0, $464 = 0, $465 = 0, $466 = 0, $467 = 0, $468 = 0, $469 = 0, $47 = 0, $470 = 0, $471 = 0, $472 = 0, $473 = 0, $474 = 0, $475 = 0, $476 = 0, $477 = 0, $478 = 0, $479 = 0, $48 = 0;
 var $480 = 0, $481 = 0, $482 = 0, $483 = 0, $484 = 0, $485 = 0, $486 = 0, $487 = 0, $488 = 0, $489 = 0, $49 = 0, $490 = 0, $491 = 0, $492 = 0, $493 = 0, $494 = 0, $495 = 0, $496 = 0, $497 = 0, $498 = 0;
 var $499 = 0, $5 = 0, $50 = 0, $500 = 0, $501 = 0, $502 = 0, $503 = 0, $504 = 0, $505 = 0, $506 = 0, $507 = 0, $508 = 0, $509 = 0, $51 = 0, $510 = 0, $511 = 0, $512 = 0, $513 = 0, $514 = 0, $515 = 0;
 var $516 = 0, $517 = 0, $518 = 0, $519 = 0, $52 = 0, $520 = 0, $521 = 0, $522 = 0, $523 = 0, $524 = 0, $525 = 0, $526 = 0, $527 = 0, $528 = 0, $529 = 0, $53 = 0, $530 = 0, $531 = 0, $532 = 0, $533 = 0;
 var $534 = 0, $535 = 0, $536 = 0, $537 = 0, $538 = 0, $539 = 0, $54 = 0, $540 = 0, $541 = 0, $542 = 0, $543 = 0, $544 = 0, $545 = 0, $546 = 0, $547 = 0, $548 = 0, $549 = 0, $55 = 0, $550 = 0, $551 = 0;
 var $552 = 0, $553 = 0, $554 = 0, $555 = 0, $556 = 0, $557 = 0, $558 = 0, $559 = 0, $56 = 0, $560 = 0, $561 = 0, $562 = 0, $563 = 0, $564 = 0, $565 = 0, $566 = 0, $567 = 0, $568 = 0, $569 = 0, $57 = 0;
 var $570 = 0, $571 = 0, $572 = 0, $573 = 0, $574 = 0, $575 = 0, $576 = 0, $577 = 0, $578 = 0, $579 = 0, $58 = 0, $580 = 0, $581 = 0, $582 = 0, $583 = 0, $584 = 0, $585 = 0, $586 = 0, $587 = 0, $588 = 0;
 var $589 = 0, $59 = 0, $590 = 0, $591 = 0, $592 = 0, $593 = 0, $594 = 0, $595 = 0, $596 = 0, $597 = 0, $598 = 0, $599 = 0, $6 = 0, $60 = 0, $600 = 0, $601 = 0, $602 = 0, $603 = 0, $604 = 0, $605 = 0;
 var $606 = 0, $607 = 0, $608 = 0, $609 = 0, $61 = 0, $610 = 0, $611 = 0, $612 = 0, $613 = 0, $614 = 0, $615 = 0, $616 = 0, $617 = 0, $618 = 0, $619 = 0, $62 = 0, $620 = 0, $621 = 0, $622 = 0, $623 = 0;
 var $624 = 0, $625 = 0, $626 = 0, $627 = 0, $628 = 0, $629 = 0, $63 = 0, $630 = 0, $631 = 0, $632 = 0, $633 = 0, $634 = 0, $635 = 0, $636 = 0, $637 = 0, $638 = 0, $639 = 0, $64 = 0, $640 = 0, $641 = 0;
 var $642 = 0, $643 = 0, $644 = 0, $645 = 0, $646 = 0, $647 = 0, $648 = 0, $649 = 0, $65 = 0, $650 = 0, $651 = 0, $652 = 0, $653 = 0, $654 = 0, $655 = 0, $656 = 0, $657 = 0, $658 = 0, $659 = 0, $66 = 0;
 var $660 = 0, $661 = 0, $662 = 0, $663 = 0, $664 = 0, $665 = 0, $666 = 0, $667 = 0, $668 = 0, $669 = 0, $67 = 0, $670 = 0, $671 = 0, $672 = 0, $673 = 0, $674 = 0, $675 = 0, $676 = 0, $677 = 0, $678 = 0;
 var $679 = 0, $68 = 0, $680 = 0, $681 = 0, $682 = 0, $683 = 0, $684 = 0, $685 = 0, $686 = 0, $687 = 0, $688 = 0, $689 = 0, $69 = 0, $690 = 0, $691 = 0, $692 = 0, $693 = 0, $694 = 0, $695 = 0, $696 = 0;
 var $697 = 0, $698 = 0, $699 = 0, $7 = 0, $70 = 0, $700 = 0, $701 = 0, $702 = 0, $703 = 0, $704 = 0, $705 = 0, $706 = 0, $707 = 0, $708 = 0, $709 = 0, $71 = 0, $710 = 0, $711 = 0, $712 = 0, $713 = 0;
 var $714 = 0, $715 = 0, $716 = 0, $717 = 0, $718 = 0, $719 = 0, $72 = 0, $720 = 0, $721 = 0, $722 = 0, $723 = 0, $724 = 0, $725 = 0, $726 = 0, $727 = 0, $728 = 0, $729 = 0, $73 = 0, $730 = 0, $731 = 0;
 var $732 = 0, $733 = 0, $734 = 0, $735 = 0, $736 = 0, $737 = 0, $738 = 0, $739 = 0, $74 = 0, $740 = 0, $741 = 0, $742 = 0, $743 = 0, $744 = 0, $745 = 0, $746 = 0, $747 = 0, $748 = 0, $749 = 0, $75 = 0;
 var $750 = 0, $751 = 0, $752 = 0, $753 = 0, $754 = 0, $755 = 0, $756 = 0, $757 = 0, $758 = 0, $759 = 0, $76 = 0, $760 = 0, $761 = 0, $762 = 0, $763 = 0, $764 = 0, $765 = 0, $766 = 0, $767 = 0, $768 = 0;
 var $769 = 0, $77 = 0, $770 = 0, $771 = 0, $772 = 0, $773 = 0, $774 = 0, $775 = 0, $776 = 0, $777 = 0, $778 = 0, $779 = 0, $78 = 0, $780 = 0, $781 = 0, $782 = 0, $783 = 0, $784 = 0, $785 = 0, $786 = 0;
 var $787 = 0, $788 = 0, $789 = 0, $79 = 0, $790 = 0, $791 = 0, $792 = 0, $793 = 0, $794 = 0, $795 = 0, $796 = 0, $797 = 0, $798 = 0, $799 = 0, $8 = 0, $80 = 0, $800 = 0, $801 = 0, $802 = 0, $803 = 0;
 var $804 = 0, $805 = 0, $806 = 0, $807 = 0, $808 = 0, $809 = 0, $81 = 0, $810 = 0, $811 = 0, $812 = 0, $813 = 0, $814 = 0, $815 = 0, $816 = 0, $817 = 0, $818 = 0, $819 = 0, $82 = 0, $820 = 0, $821 = 0;
 var $822 = 0, $823 = 0, $824 = 0, $825 = 0, $826 = 0, $827 = 0, $828 = 0, $829 = 0, $83 = 0, $830 = 0, $831 = 0, $832 = 0, $833 = 0, $834 = 0, $835 = 0, $836 = 0, $837 = 0, $838 = 0, $839 = 0, $84 = 0;
 var $840 = 0, $841 = 0, $842 = 0, $843 = 0, $844 = 0, $845 = 0, $846 = 0, $847 = 0, $848 = 0, $849 = 0, $85 = 0, $850 = 0, $851 = 0, $852 = 0, $853 = 0, $854 = 0, $855 = 0, $856 = 0, $857 = 0, $858 = 0;
 var $859 = 0, $86 = 0, $860 = 0, $861 = 0, $862 = 0, $863 = 0, $864 = 0, $865 = 0, $866 = 0, $867 = 0, $868 = 0, $869 = 0, $87 = 0, $870 = 0, $871 = 0, $872 = 0, $873 = 0, $874 = 0, $875 = 0, $876 = 0;
 var $877 = 0, $878 = 0, $879 = 0, $88 = 0, $880 = 0, $881 = 0, $882 = 0, $883 = 0, $884 = 0, $885 = 0, $886 = 0, $887 = 0, $888 = 0, $889 = 0, $89 = 0, $890 = 0, $891 = 0, $892 = 0, $893 = 0, $894 = 0;
 var $895 = 0, $896 = 0, $897 = 0, $898 = 0, $899 = 0, $9 = 0, $90 = 0, $900 = 0, $901 = 0, $902 = 0, $903 = 0, $904 = 0, $905 = 0, $906 = 0, $907 = 0, $908 = 0, $909 = 0, $91 = 0, $910 = 0, $911 = 0;
 var $912 = 0, $913 = 0, $914 = 0, $915 = 0, $916 = 0, $917 = 0, $918 = 0, $919 = 0, $92 = 0, $920 = 0, $921 = 0, $922 = 0, $923 = 0, $924 = 0, $925 = 0, $926 = 0, $927 = 0, $928 = 0, $929 = 0, $93 = 0;
 var $930 = 0, $931 = 0, $932 = 0, $933 = 0, $934 = 0, $935 = 0, $936 = 0, $937 = 0, $938 = 0, $939 = 0, $94 = 0, $940 = 0, $941 = 0, $942 = 0, $943 = 0, $944 = 0, $945 = 0, $946 = 0, $947 = 0, $948 = 0;
 var $949 = 0, $95 = 0, $950 = 0, $951 = 0, $952 = 0, $953 = 0, $954 = 0, $955 = 0, $956 = 0, $957 = 0, $958 = 0, $959 = 0, $96 = 0, $960 = 0, $961 = 0, $962 = 0, $963 = 0, $964 = 0, $965 = 0, $966 = 0;
 var $967 = 0, $968 = 0, $969 = 0, $97 = 0, $970 = 0, $971 = 0, $972 = 0, $973 = 0, $974 = 0, $975 = 0, $976 = 0, $977 = 0, $978 = 0, $979 = 0, $98 = 0, $980 = 0, $981 = 0, $982 = 0, $983 = 0, $984 = 0;
 var $985 = 0, $986 = 0, $987 = 0, $988 = 0, $989 = 0, $99 = 0, $990 = 0, $991 = 0, $992 = 0, $993 = 0, $994 = 0, $995 = 0, $996 = 0, $997 = 0, $998 = 0, $999 = 0, $F$0$i$i = 0, $F1$0$i = 0, $F4$0 = 0, $F4$0$i$i = 0;
 var $F5$0$i = 0, $I1$0$i$i = 0, $I7$0$i = 0, $I7$0$i$i = 0, $K12$029$i = 0, $K2$07$i$i = 0, $K8$051$i$i = 0, $R$0$i = 0, $R$0$i$i = 0, $R$0$i$i$lcssa = 0, $R$0$i$lcssa = 0, $R$0$i18 = 0, $R$0$i18$lcssa = 0, $R$1$i = 0, $R$1$i$i = 0, $R$1$i20 = 0, $RP$0$i = 0, $RP$0$i$i = 0, $RP$0$i$i$lcssa = 0, $RP$0$i$lcssa = 0;
 var $RP$0$i17 = 0, $RP$0$i17$lcssa = 0, $T$0$lcssa$i = 0, $T$0$lcssa$i$i = 0, $T$0$lcssa$i25$i = 0, $T$028$i = 0, $T$028$i$lcssa = 0, $T$050$i$i = 0, $T$050$i$i$lcssa = 0, $T$06$i$i = 0, $T$06$i$i$lcssa = 0, $br$0$ph$i = 0, $cond$i = 0, $cond$i$i = 0, $cond$i21 = 0, $exitcond$i$i = 0, $i$02$i$i = 0, $idx$0$i = 0, $mem$0 = 0, $nb$0 = 0;
 var $not$$i = 0, $not$$i$i = 0, $not$$i26$i = 0, $oldfirst$0$i$i = 0, $or$cond$i = 0, $or$cond$i30 = 0, $or$cond1$i = 0, $or$cond19$i = 0, $or$cond2$i = 0, $or$cond3$i = 0, $or$cond5$i = 0, $or$cond57$i = 0, $or$cond6$i = 0, $or$cond8$i = 0, $or$cond9$i = 0, $qsize$0$i$i = 0, $rsize$0$i = 0, $rsize$0$i$lcssa = 0, $rsize$0$i15 = 0, $rsize$1$i = 0;
 var $rsize$2$i = 0, $rsize$3$lcssa$i = 0, $rsize$331$i = 0, $rst$0$i = 0, $rst$1$i = 0, $sizebits$0$i = 0, $sp$0$i$i = 0, $sp$0$i$i$i = 0, $sp$084$i = 0, $sp$084$i$lcssa = 0, $sp$183$i = 0, $sp$183$i$lcssa = 0, $ssize$0$$i = 0, $ssize$0$i = 0, $ssize$1$ph$i = 0, $ssize$2$i = 0, $t$0$i = 0, $t$0$i14 = 0, $t$1$i = 0, $t$2$ph$i = 0;
 var $t$2$v$3$i = 0, $t$230$i = 0, $tbase$255$i = 0, $tsize$0$ph$i = 0, $tsize$0323944$i = 0, $tsize$1$i = 0, $tsize$254$i = 0, $v$0$i = 0, $v$0$i$lcssa = 0, $v$0$i16 = 0, $v$1$i = 0, $v$2$i = 0, $v$3$lcssa$i = 0, $v$3$ph$i = 0, $v$332$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($bytes>>>0)<(245);
 do {
  if ($0) {
   $1 = ($bytes>>>0)<(11);
   $2 = (($bytes) + 11)|0;
   $3 = $2 & -8;
   $4 = $1 ? 16 : $3;
   $5 = $4 >>> 3;
   $6 = HEAP32[73184>>2]|0;
   $7 = $6 >>> $5;
   $8 = $7 & 3;
   $9 = ($8|0)==(0);
   if (!($9)) {
    $10 = $7 & 1;
    $11 = $10 ^ 1;
    $12 = (($11) + ($5))|0;
    $13 = $12 << 1;
    $14 = (73224 + ($13<<2)|0);
    $$sum10 = (($13) + 2)|0;
    $15 = (73224 + ($$sum10<<2)|0);
    $16 = HEAP32[$15>>2]|0;
    $17 = ((($16)) + 8|0);
    $18 = HEAP32[$17>>2]|0;
    $19 = ($14|0)==($18|0);
    do {
     if ($19) {
      $20 = 1 << $12;
      $21 = $20 ^ -1;
      $22 = $6 & $21;
      HEAP32[73184>>2] = $22;
     } else {
      $23 = HEAP32[(73200)>>2]|0;
      $24 = ($18>>>0)<($23>>>0);
      if ($24) {
       _abort();
       // unreachable;
      }
      $25 = ((($18)) + 12|0);
      $26 = HEAP32[$25>>2]|0;
      $27 = ($26|0)==($16|0);
      if ($27) {
       HEAP32[$25>>2] = $14;
       HEAP32[$15>>2] = $18;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $28 = $12 << 3;
    $29 = $28 | 3;
    $30 = ((($16)) + 4|0);
    HEAP32[$30>>2] = $29;
    $$sum1112 = $28 | 4;
    $31 = (($16) + ($$sum1112)|0);
    $32 = HEAP32[$31>>2]|0;
    $33 = $32 | 1;
    HEAP32[$31>>2] = $33;
    $mem$0 = $17;
    return ($mem$0|0);
   }
   $34 = HEAP32[(73192)>>2]|0;
   $35 = ($4>>>0)>($34>>>0);
   if ($35) {
    $36 = ($7|0)==(0);
    if (!($36)) {
     $37 = $7 << $5;
     $38 = 2 << $5;
     $39 = (0 - ($38))|0;
     $40 = $38 | $39;
     $41 = $37 & $40;
     $42 = (0 - ($41))|0;
     $43 = $41 & $42;
     $44 = (($43) + -1)|0;
     $45 = $44 >>> 12;
     $46 = $45 & 16;
     $47 = $44 >>> $46;
     $48 = $47 >>> 5;
     $49 = $48 & 8;
     $50 = $49 | $46;
     $51 = $47 >>> $49;
     $52 = $51 >>> 2;
     $53 = $52 & 4;
     $54 = $50 | $53;
     $55 = $51 >>> $53;
     $56 = $55 >>> 1;
     $57 = $56 & 2;
     $58 = $54 | $57;
     $59 = $55 >>> $57;
     $60 = $59 >>> 1;
     $61 = $60 & 1;
     $62 = $58 | $61;
     $63 = $59 >>> $61;
     $64 = (($62) + ($63))|0;
     $65 = $64 << 1;
     $66 = (73224 + ($65<<2)|0);
     $$sum4 = (($65) + 2)|0;
     $67 = (73224 + ($$sum4<<2)|0);
     $68 = HEAP32[$67>>2]|0;
     $69 = ((($68)) + 8|0);
     $70 = HEAP32[$69>>2]|0;
     $71 = ($66|0)==($70|0);
     do {
      if ($71) {
       $72 = 1 << $64;
       $73 = $72 ^ -1;
       $74 = $6 & $73;
       HEAP32[73184>>2] = $74;
       $89 = $34;
      } else {
       $75 = HEAP32[(73200)>>2]|0;
       $76 = ($70>>>0)<($75>>>0);
       if ($76) {
        _abort();
        // unreachable;
       }
       $77 = ((($70)) + 12|0);
       $78 = HEAP32[$77>>2]|0;
       $79 = ($78|0)==($68|0);
       if ($79) {
        HEAP32[$77>>2] = $66;
        HEAP32[$67>>2] = $70;
        $$pre = HEAP32[(73192)>>2]|0;
        $89 = $$pre;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $80 = $64 << 3;
     $81 = (($80) - ($4))|0;
     $82 = $4 | 3;
     $83 = ((($68)) + 4|0);
     HEAP32[$83>>2] = $82;
     $84 = (($68) + ($4)|0);
     $85 = $81 | 1;
     $$sum56 = $4 | 4;
     $86 = (($68) + ($$sum56)|0);
     HEAP32[$86>>2] = $85;
     $87 = (($68) + ($80)|0);
     HEAP32[$87>>2] = $81;
     $88 = ($89|0)==(0);
     if (!($88)) {
      $90 = HEAP32[(73204)>>2]|0;
      $91 = $89 >>> 3;
      $92 = $91 << 1;
      $93 = (73224 + ($92<<2)|0);
      $94 = HEAP32[73184>>2]|0;
      $95 = 1 << $91;
      $96 = $94 & $95;
      $97 = ($96|0)==(0);
      if ($97) {
       $98 = $94 | $95;
       HEAP32[73184>>2] = $98;
       $$pre105 = (($92) + 2)|0;
       $$pre106 = (73224 + ($$pre105<<2)|0);
       $$pre$phiZ2D = $$pre106;$F4$0 = $93;
      } else {
       $$sum9 = (($92) + 2)|0;
       $99 = (73224 + ($$sum9<<2)|0);
       $100 = HEAP32[$99>>2]|0;
       $101 = HEAP32[(73200)>>2]|0;
       $102 = ($100>>>0)<($101>>>0);
       if ($102) {
        _abort();
        // unreachable;
       } else {
        $$pre$phiZ2D = $99;$F4$0 = $100;
       }
      }
      HEAP32[$$pre$phiZ2D>>2] = $90;
      $103 = ((($F4$0)) + 12|0);
      HEAP32[$103>>2] = $90;
      $104 = ((($90)) + 8|0);
      HEAP32[$104>>2] = $F4$0;
      $105 = ((($90)) + 12|0);
      HEAP32[$105>>2] = $93;
     }
     HEAP32[(73192)>>2] = $81;
     HEAP32[(73204)>>2] = $84;
     $mem$0 = $69;
     return ($mem$0|0);
    }
    $106 = HEAP32[(73188)>>2]|0;
    $107 = ($106|0)==(0);
    if ($107) {
     $nb$0 = $4;
    } else {
     $108 = (0 - ($106))|0;
     $109 = $106 & $108;
     $110 = (($109) + -1)|0;
     $111 = $110 >>> 12;
     $112 = $111 & 16;
     $113 = $110 >>> $112;
     $114 = $113 >>> 5;
     $115 = $114 & 8;
     $116 = $115 | $112;
     $117 = $113 >>> $115;
     $118 = $117 >>> 2;
     $119 = $118 & 4;
     $120 = $116 | $119;
     $121 = $117 >>> $119;
     $122 = $121 >>> 1;
     $123 = $122 & 2;
     $124 = $120 | $123;
     $125 = $121 >>> $123;
     $126 = $125 >>> 1;
     $127 = $126 & 1;
     $128 = $124 | $127;
     $129 = $125 >>> $127;
     $130 = (($128) + ($129))|0;
     $131 = (73488 + ($130<<2)|0);
     $132 = HEAP32[$131>>2]|0;
     $133 = ((($132)) + 4|0);
     $134 = HEAP32[$133>>2]|0;
     $135 = $134 & -8;
     $136 = (($135) - ($4))|0;
     $rsize$0$i = $136;$t$0$i = $132;$v$0$i = $132;
     while(1) {
      $137 = ((($t$0$i)) + 16|0);
      $138 = HEAP32[$137>>2]|0;
      $139 = ($138|0)==(0|0);
      if ($139) {
       $140 = ((($t$0$i)) + 20|0);
       $141 = HEAP32[$140>>2]|0;
       $142 = ($141|0)==(0|0);
       if ($142) {
        $rsize$0$i$lcssa = $rsize$0$i;$v$0$i$lcssa = $v$0$i;
        break;
       } else {
        $144 = $141;
       }
      } else {
       $144 = $138;
      }
      $143 = ((($144)) + 4|0);
      $145 = HEAP32[$143>>2]|0;
      $146 = $145 & -8;
      $147 = (($146) - ($4))|0;
      $148 = ($147>>>0)<($rsize$0$i>>>0);
      $$rsize$0$i = $148 ? $147 : $rsize$0$i;
      $$v$0$i = $148 ? $144 : $v$0$i;
      $rsize$0$i = $$rsize$0$i;$t$0$i = $144;$v$0$i = $$v$0$i;
     }
     $149 = HEAP32[(73200)>>2]|0;
     $150 = ($v$0$i$lcssa>>>0)<($149>>>0);
     if ($150) {
      _abort();
      // unreachable;
     }
     $151 = (($v$0$i$lcssa) + ($4)|0);
     $152 = ($v$0$i$lcssa>>>0)<($151>>>0);
     if (!($152)) {
      _abort();
      // unreachable;
     }
     $153 = ((($v$0$i$lcssa)) + 24|0);
     $154 = HEAP32[$153>>2]|0;
     $155 = ((($v$0$i$lcssa)) + 12|0);
     $156 = HEAP32[$155>>2]|0;
     $157 = ($156|0)==($v$0$i$lcssa|0);
     do {
      if ($157) {
       $167 = ((($v$0$i$lcssa)) + 20|0);
       $168 = HEAP32[$167>>2]|0;
       $169 = ($168|0)==(0|0);
       if ($169) {
        $170 = ((($v$0$i$lcssa)) + 16|0);
        $171 = HEAP32[$170>>2]|0;
        $172 = ($171|0)==(0|0);
        if ($172) {
         $R$1$i = 0;
         break;
        } else {
         $R$0$i = $171;$RP$0$i = $170;
        }
       } else {
        $R$0$i = $168;$RP$0$i = $167;
       }
       while(1) {
        $173 = ((($R$0$i)) + 20|0);
        $174 = HEAP32[$173>>2]|0;
        $175 = ($174|0)==(0|0);
        if (!($175)) {
         $R$0$i = $174;$RP$0$i = $173;
         continue;
        }
        $176 = ((($R$0$i)) + 16|0);
        $177 = HEAP32[$176>>2]|0;
        $178 = ($177|0)==(0|0);
        if ($178) {
         $R$0$i$lcssa = $R$0$i;$RP$0$i$lcssa = $RP$0$i;
         break;
        } else {
         $R$0$i = $177;$RP$0$i = $176;
        }
       }
       $179 = ($RP$0$i$lcssa>>>0)<($149>>>0);
       if ($179) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$RP$0$i$lcssa>>2] = 0;
        $R$1$i = $R$0$i$lcssa;
        break;
       }
      } else {
       $158 = ((($v$0$i$lcssa)) + 8|0);
       $159 = HEAP32[$158>>2]|0;
       $160 = ($159>>>0)<($149>>>0);
       if ($160) {
        _abort();
        // unreachable;
       }
       $161 = ((($159)) + 12|0);
       $162 = HEAP32[$161>>2]|0;
       $163 = ($162|0)==($v$0$i$lcssa|0);
       if (!($163)) {
        _abort();
        // unreachable;
       }
       $164 = ((($156)) + 8|0);
       $165 = HEAP32[$164>>2]|0;
       $166 = ($165|0)==($v$0$i$lcssa|0);
       if ($166) {
        HEAP32[$161>>2] = $156;
        HEAP32[$164>>2] = $159;
        $R$1$i = $156;
        break;
       } else {
        _abort();
        // unreachable;
       }
      }
     } while(0);
     $180 = ($154|0)==(0|0);
     do {
      if (!($180)) {
       $181 = ((($v$0$i$lcssa)) + 28|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = (73488 + ($182<<2)|0);
       $184 = HEAP32[$183>>2]|0;
       $185 = ($v$0$i$lcssa|0)==($184|0);
       if ($185) {
        HEAP32[$183>>2] = $R$1$i;
        $cond$i = ($R$1$i|0)==(0|0);
        if ($cond$i) {
         $186 = 1 << $182;
         $187 = $186 ^ -1;
         $188 = HEAP32[(73188)>>2]|0;
         $189 = $188 & $187;
         HEAP32[(73188)>>2] = $189;
         break;
        }
       } else {
        $190 = HEAP32[(73200)>>2]|0;
        $191 = ($154>>>0)<($190>>>0);
        if ($191) {
         _abort();
         // unreachable;
        }
        $192 = ((($154)) + 16|0);
        $193 = HEAP32[$192>>2]|0;
        $194 = ($193|0)==($v$0$i$lcssa|0);
        if ($194) {
         HEAP32[$192>>2] = $R$1$i;
        } else {
         $195 = ((($154)) + 20|0);
         HEAP32[$195>>2] = $R$1$i;
        }
        $196 = ($R$1$i|0)==(0|0);
        if ($196) {
         break;
        }
       }
       $197 = HEAP32[(73200)>>2]|0;
       $198 = ($R$1$i>>>0)<($197>>>0);
       if ($198) {
        _abort();
        // unreachable;
       }
       $199 = ((($R$1$i)) + 24|0);
       HEAP32[$199>>2] = $154;
       $200 = ((($v$0$i$lcssa)) + 16|0);
       $201 = HEAP32[$200>>2]|0;
       $202 = ($201|0)==(0|0);
       do {
        if (!($202)) {
         $203 = ($201>>>0)<($197>>>0);
         if ($203) {
          _abort();
          // unreachable;
         } else {
          $204 = ((($R$1$i)) + 16|0);
          HEAP32[$204>>2] = $201;
          $205 = ((($201)) + 24|0);
          HEAP32[$205>>2] = $R$1$i;
          break;
         }
        }
       } while(0);
       $206 = ((($v$0$i$lcssa)) + 20|0);
       $207 = HEAP32[$206>>2]|0;
       $208 = ($207|0)==(0|0);
       if (!($208)) {
        $209 = HEAP32[(73200)>>2]|0;
        $210 = ($207>>>0)<($209>>>0);
        if ($210) {
         _abort();
         // unreachable;
        } else {
         $211 = ((($R$1$i)) + 20|0);
         HEAP32[$211>>2] = $207;
         $212 = ((($207)) + 24|0);
         HEAP32[$212>>2] = $R$1$i;
         break;
        }
       }
      }
     } while(0);
     $213 = ($rsize$0$i$lcssa>>>0)<(16);
     if ($213) {
      $214 = (($rsize$0$i$lcssa) + ($4))|0;
      $215 = $214 | 3;
      $216 = ((($v$0$i$lcssa)) + 4|0);
      HEAP32[$216>>2] = $215;
      $$sum4$i = (($214) + 4)|0;
      $217 = (($v$0$i$lcssa) + ($$sum4$i)|0);
      $218 = HEAP32[$217>>2]|0;
      $219 = $218 | 1;
      HEAP32[$217>>2] = $219;
     } else {
      $220 = $4 | 3;
      $221 = ((($v$0$i$lcssa)) + 4|0);
      HEAP32[$221>>2] = $220;
      $222 = $rsize$0$i$lcssa | 1;
      $$sum$i35 = $4 | 4;
      $223 = (($v$0$i$lcssa) + ($$sum$i35)|0);
      HEAP32[$223>>2] = $222;
      $$sum1$i = (($rsize$0$i$lcssa) + ($4))|0;
      $224 = (($v$0$i$lcssa) + ($$sum1$i)|0);
      HEAP32[$224>>2] = $rsize$0$i$lcssa;
      $225 = HEAP32[(73192)>>2]|0;
      $226 = ($225|0)==(0);
      if (!($226)) {
       $227 = HEAP32[(73204)>>2]|0;
       $228 = $225 >>> 3;
       $229 = $228 << 1;
       $230 = (73224 + ($229<<2)|0);
       $231 = HEAP32[73184>>2]|0;
       $232 = 1 << $228;
       $233 = $231 & $232;
       $234 = ($233|0)==(0);
       if ($234) {
        $235 = $231 | $232;
        HEAP32[73184>>2] = $235;
        $$pre$i = (($229) + 2)|0;
        $$pre8$i = (73224 + ($$pre$i<<2)|0);
        $$pre$phi$iZ2D = $$pre8$i;$F1$0$i = $230;
       } else {
        $$sum3$i = (($229) + 2)|0;
        $236 = (73224 + ($$sum3$i<<2)|0);
        $237 = HEAP32[$236>>2]|0;
        $238 = HEAP32[(73200)>>2]|0;
        $239 = ($237>>>0)<($238>>>0);
        if ($239) {
         _abort();
         // unreachable;
        } else {
         $$pre$phi$iZ2D = $236;$F1$0$i = $237;
        }
       }
       HEAP32[$$pre$phi$iZ2D>>2] = $227;
       $240 = ((($F1$0$i)) + 12|0);
       HEAP32[$240>>2] = $227;
       $241 = ((($227)) + 8|0);
       HEAP32[$241>>2] = $F1$0$i;
       $242 = ((($227)) + 12|0);
       HEAP32[$242>>2] = $230;
      }
      HEAP32[(73192)>>2] = $rsize$0$i$lcssa;
      HEAP32[(73204)>>2] = $151;
     }
     $243 = ((($v$0$i$lcssa)) + 8|0);
     $mem$0 = $243;
     return ($mem$0|0);
    }
   } else {
    $nb$0 = $4;
   }
  } else {
   $244 = ($bytes>>>0)>(4294967231);
   if ($244) {
    $nb$0 = -1;
   } else {
    $245 = (($bytes) + 11)|0;
    $246 = $245 & -8;
    $247 = HEAP32[(73188)>>2]|0;
    $248 = ($247|0)==(0);
    if ($248) {
     $nb$0 = $246;
    } else {
     $249 = (0 - ($246))|0;
     $250 = $245 >>> 8;
     $251 = ($250|0)==(0);
     if ($251) {
      $idx$0$i = 0;
     } else {
      $252 = ($246>>>0)>(16777215);
      if ($252) {
       $idx$0$i = 31;
      } else {
       $253 = (($250) + 1048320)|0;
       $254 = $253 >>> 16;
       $255 = $254 & 8;
       $256 = $250 << $255;
       $257 = (($256) + 520192)|0;
       $258 = $257 >>> 16;
       $259 = $258 & 4;
       $260 = $259 | $255;
       $261 = $256 << $259;
       $262 = (($261) + 245760)|0;
       $263 = $262 >>> 16;
       $264 = $263 & 2;
       $265 = $260 | $264;
       $266 = (14 - ($265))|0;
       $267 = $261 << $264;
       $268 = $267 >>> 15;
       $269 = (($266) + ($268))|0;
       $270 = $269 << 1;
       $271 = (($269) + 7)|0;
       $272 = $246 >>> $271;
       $273 = $272 & 1;
       $274 = $273 | $270;
       $idx$0$i = $274;
      }
     }
     $275 = (73488 + ($idx$0$i<<2)|0);
     $276 = HEAP32[$275>>2]|0;
     $277 = ($276|0)==(0|0);
     L123: do {
      if ($277) {
       $rsize$2$i = $249;$t$1$i = 0;$v$2$i = 0;
       label = 86;
      } else {
       $278 = ($idx$0$i|0)==(31);
       $279 = $idx$0$i >>> 1;
       $280 = (25 - ($279))|0;
       $281 = $278 ? 0 : $280;
       $282 = $246 << $281;
       $rsize$0$i15 = $249;$rst$0$i = 0;$sizebits$0$i = $282;$t$0$i14 = $276;$v$0$i16 = 0;
       while(1) {
        $283 = ((($t$0$i14)) + 4|0);
        $284 = HEAP32[$283>>2]|0;
        $285 = $284 & -8;
        $286 = (($285) - ($246))|0;
        $287 = ($286>>>0)<($rsize$0$i15>>>0);
        if ($287) {
         $288 = ($285|0)==($246|0);
         if ($288) {
          $rsize$331$i = $286;$t$230$i = $t$0$i14;$v$332$i = $t$0$i14;
          label = 90;
          break L123;
         } else {
          $rsize$1$i = $286;$v$1$i = $t$0$i14;
         }
        } else {
         $rsize$1$i = $rsize$0$i15;$v$1$i = $v$0$i16;
        }
        $289 = ((($t$0$i14)) + 20|0);
        $290 = HEAP32[$289>>2]|0;
        $291 = $sizebits$0$i >>> 31;
        $292 = (((($t$0$i14)) + 16|0) + ($291<<2)|0);
        $293 = HEAP32[$292>>2]|0;
        $294 = ($290|0)==(0|0);
        $295 = ($290|0)==($293|0);
        $or$cond19$i = $294 | $295;
        $rst$1$i = $or$cond19$i ? $rst$0$i : $290;
        $296 = ($293|0)==(0|0);
        $297 = $sizebits$0$i << 1;
        if ($296) {
         $rsize$2$i = $rsize$1$i;$t$1$i = $rst$1$i;$v$2$i = $v$1$i;
         label = 86;
         break;
        } else {
         $rsize$0$i15 = $rsize$1$i;$rst$0$i = $rst$1$i;$sizebits$0$i = $297;$t$0$i14 = $293;$v$0$i16 = $v$1$i;
        }
       }
      }
     } while(0);
     if ((label|0) == 86) {
      $298 = ($t$1$i|0)==(0|0);
      $299 = ($v$2$i|0)==(0|0);
      $or$cond$i = $298 & $299;
      if ($or$cond$i) {
       $300 = 2 << $idx$0$i;
       $301 = (0 - ($300))|0;
       $302 = $300 | $301;
       $303 = $247 & $302;
       $304 = ($303|0)==(0);
       if ($304) {
        $nb$0 = $246;
        break;
       }
       $305 = (0 - ($303))|0;
       $306 = $303 & $305;
       $307 = (($306) + -1)|0;
       $308 = $307 >>> 12;
       $309 = $308 & 16;
       $310 = $307 >>> $309;
       $311 = $310 >>> 5;
       $312 = $311 & 8;
       $313 = $312 | $309;
       $314 = $310 >>> $312;
       $315 = $314 >>> 2;
       $316 = $315 & 4;
       $317 = $313 | $316;
       $318 = $314 >>> $316;
       $319 = $318 >>> 1;
       $320 = $319 & 2;
       $321 = $317 | $320;
       $322 = $318 >>> $320;
       $323 = $322 >>> 1;
       $324 = $323 & 1;
       $325 = $321 | $324;
       $326 = $322 >>> $324;
       $327 = (($325) + ($326))|0;
       $328 = (73488 + ($327<<2)|0);
       $329 = HEAP32[$328>>2]|0;
       $t$2$ph$i = $329;$v$3$ph$i = 0;
      } else {
       $t$2$ph$i = $t$1$i;$v$3$ph$i = $v$2$i;
      }
      $330 = ($t$2$ph$i|0)==(0|0);
      if ($330) {
       $rsize$3$lcssa$i = $rsize$2$i;$v$3$lcssa$i = $v$3$ph$i;
      } else {
       $rsize$331$i = $rsize$2$i;$t$230$i = $t$2$ph$i;$v$332$i = $v$3$ph$i;
       label = 90;
      }
     }
     if ((label|0) == 90) {
      while(1) {
       label = 0;
       $331 = ((($t$230$i)) + 4|0);
       $332 = HEAP32[$331>>2]|0;
       $333 = $332 & -8;
       $334 = (($333) - ($246))|0;
       $335 = ($334>>>0)<($rsize$331$i>>>0);
       $$rsize$3$i = $335 ? $334 : $rsize$331$i;
       $t$2$v$3$i = $335 ? $t$230$i : $v$332$i;
       $336 = ((($t$230$i)) + 16|0);
       $337 = HEAP32[$336>>2]|0;
       $338 = ($337|0)==(0|0);
       if (!($338)) {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $337;$v$332$i = $t$2$v$3$i;
        label = 90;
        continue;
       }
       $339 = ((($t$230$i)) + 20|0);
       $340 = HEAP32[$339>>2]|0;
       $341 = ($340|0)==(0|0);
       if ($341) {
        $rsize$3$lcssa$i = $$rsize$3$i;$v$3$lcssa$i = $t$2$v$3$i;
        break;
       } else {
        $rsize$331$i = $$rsize$3$i;$t$230$i = $340;$v$332$i = $t$2$v$3$i;
        label = 90;
       }
      }
     }
     $342 = ($v$3$lcssa$i|0)==(0|0);
     if ($342) {
      $nb$0 = $246;
     } else {
      $343 = HEAP32[(73192)>>2]|0;
      $344 = (($343) - ($246))|0;
      $345 = ($rsize$3$lcssa$i>>>0)<($344>>>0);
      if ($345) {
       $346 = HEAP32[(73200)>>2]|0;
       $347 = ($v$3$lcssa$i>>>0)<($346>>>0);
       if ($347) {
        _abort();
        // unreachable;
       }
       $348 = (($v$3$lcssa$i) + ($246)|0);
       $349 = ($v$3$lcssa$i>>>0)<($348>>>0);
       if (!($349)) {
        _abort();
        // unreachable;
       }
       $350 = ((($v$3$lcssa$i)) + 24|0);
       $351 = HEAP32[$350>>2]|0;
       $352 = ((($v$3$lcssa$i)) + 12|0);
       $353 = HEAP32[$352>>2]|0;
       $354 = ($353|0)==($v$3$lcssa$i|0);
       do {
        if ($354) {
         $364 = ((($v$3$lcssa$i)) + 20|0);
         $365 = HEAP32[$364>>2]|0;
         $366 = ($365|0)==(0|0);
         if ($366) {
          $367 = ((($v$3$lcssa$i)) + 16|0);
          $368 = HEAP32[$367>>2]|0;
          $369 = ($368|0)==(0|0);
          if ($369) {
           $R$1$i20 = 0;
           break;
          } else {
           $R$0$i18 = $368;$RP$0$i17 = $367;
          }
         } else {
          $R$0$i18 = $365;$RP$0$i17 = $364;
         }
         while(1) {
          $370 = ((($R$0$i18)) + 20|0);
          $371 = HEAP32[$370>>2]|0;
          $372 = ($371|0)==(0|0);
          if (!($372)) {
           $R$0$i18 = $371;$RP$0$i17 = $370;
           continue;
          }
          $373 = ((($R$0$i18)) + 16|0);
          $374 = HEAP32[$373>>2]|0;
          $375 = ($374|0)==(0|0);
          if ($375) {
           $R$0$i18$lcssa = $R$0$i18;$RP$0$i17$lcssa = $RP$0$i17;
           break;
          } else {
           $R$0$i18 = $374;$RP$0$i17 = $373;
          }
         }
         $376 = ($RP$0$i17$lcssa>>>0)<($346>>>0);
         if ($376) {
          _abort();
          // unreachable;
         } else {
          HEAP32[$RP$0$i17$lcssa>>2] = 0;
          $R$1$i20 = $R$0$i18$lcssa;
          break;
         }
        } else {
         $355 = ((($v$3$lcssa$i)) + 8|0);
         $356 = HEAP32[$355>>2]|0;
         $357 = ($356>>>0)<($346>>>0);
         if ($357) {
          _abort();
          // unreachable;
         }
         $358 = ((($356)) + 12|0);
         $359 = HEAP32[$358>>2]|0;
         $360 = ($359|0)==($v$3$lcssa$i|0);
         if (!($360)) {
          _abort();
          // unreachable;
         }
         $361 = ((($353)) + 8|0);
         $362 = HEAP32[$361>>2]|0;
         $363 = ($362|0)==($v$3$lcssa$i|0);
         if ($363) {
          HEAP32[$358>>2] = $353;
          HEAP32[$361>>2] = $356;
          $R$1$i20 = $353;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $377 = ($351|0)==(0|0);
       do {
        if (!($377)) {
         $378 = ((($v$3$lcssa$i)) + 28|0);
         $379 = HEAP32[$378>>2]|0;
         $380 = (73488 + ($379<<2)|0);
         $381 = HEAP32[$380>>2]|0;
         $382 = ($v$3$lcssa$i|0)==($381|0);
         if ($382) {
          HEAP32[$380>>2] = $R$1$i20;
          $cond$i21 = ($R$1$i20|0)==(0|0);
          if ($cond$i21) {
           $383 = 1 << $379;
           $384 = $383 ^ -1;
           $385 = HEAP32[(73188)>>2]|0;
           $386 = $385 & $384;
           HEAP32[(73188)>>2] = $386;
           break;
          }
         } else {
          $387 = HEAP32[(73200)>>2]|0;
          $388 = ($351>>>0)<($387>>>0);
          if ($388) {
           _abort();
           // unreachable;
          }
          $389 = ((($351)) + 16|0);
          $390 = HEAP32[$389>>2]|0;
          $391 = ($390|0)==($v$3$lcssa$i|0);
          if ($391) {
           HEAP32[$389>>2] = $R$1$i20;
          } else {
           $392 = ((($351)) + 20|0);
           HEAP32[$392>>2] = $R$1$i20;
          }
          $393 = ($R$1$i20|0)==(0|0);
          if ($393) {
           break;
          }
         }
         $394 = HEAP32[(73200)>>2]|0;
         $395 = ($R$1$i20>>>0)<($394>>>0);
         if ($395) {
          _abort();
          // unreachable;
         }
         $396 = ((($R$1$i20)) + 24|0);
         HEAP32[$396>>2] = $351;
         $397 = ((($v$3$lcssa$i)) + 16|0);
         $398 = HEAP32[$397>>2]|0;
         $399 = ($398|0)==(0|0);
         do {
          if (!($399)) {
           $400 = ($398>>>0)<($394>>>0);
           if ($400) {
            _abort();
            // unreachable;
           } else {
            $401 = ((($R$1$i20)) + 16|0);
            HEAP32[$401>>2] = $398;
            $402 = ((($398)) + 24|0);
            HEAP32[$402>>2] = $R$1$i20;
            break;
           }
          }
         } while(0);
         $403 = ((($v$3$lcssa$i)) + 20|0);
         $404 = HEAP32[$403>>2]|0;
         $405 = ($404|0)==(0|0);
         if (!($405)) {
          $406 = HEAP32[(73200)>>2]|0;
          $407 = ($404>>>0)<($406>>>0);
          if ($407) {
           _abort();
           // unreachable;
          } else {
           $408 = ((($R$1$i20)) + 20|0);
           HEAP32[$408>>2] = $404;
           $409 = ((($404)) + 24|0);
           HEAP32[$409>>2] = $R$1$i20;
           break;
          }
         }
        }
       } while(0);
       $410 = ($rsize$3$lcssa$i>>>0)<(16);
       L199: do {
        if ($410) {
         $411 = (($rsize$3$lcssa$i) + ($246))|0;
         $412 = $411 | 3;
         $413 = ((($v$3$lcssa$i)) + 4|0);
         HEAP32[$413>>2] = $412;
         $$sum18$i = (($411) + 4)|0;
         $414 = (($v$3$lcssa$i) + ($$sum18$i)|0);
         $415 = HEAP32[$414>>2]|0;
         $416 = $415 | 1;
         HEAP32[$414>>2] = $416;
        } else {
         $417 = $246 | 3;
         $418 = ((($v$3$lcssa$i)) + 4|0);
         HEAP32[$418>>2] = $417;
         $419 = $rsize$3$lcssa$i | 1;
         $$sum$i2334 = $246 | 4;
         $420 = (($v$3$lcssa$i) + ($$sum$i2334)|0);
         HEAP32[$420>>2] = $419;
         $$sum1$i24 = (($rsize$3$lcssa$i) + ($246))|0;
         $421 = (($v$3$lcssa$i) + ($$sum1$i24)|0);
         HEAP32[$421>>2] = $rsize$3$lcssa$i;
         $422 = $rsize$3$lcssa$i >>> 3;
         $423 = ($rsize$3$lcssa$i>>>0)<(256);
         if ($423) {
          $424 = $422 << 1;
          $425 = (73224 + ($424<<2)|0);
          $426 = HEAP32[73184>>2]|0;
          $427 = 1 << $422;
          $428 = $426 & $427;
          $429 = ($428|0)==(0);
          if ($429) {
           $430 = $426 | $427;
           HEAP32[73184>>2] = $430;
           $$pre$i25 = (($424) + 2)|0;
           $$pre43$i = (73224 + ($$pre$i25<<2)|0);
           $$pre$phi$i26Z2D = $$pre43$i;$F5$0$i = $425;
          } else {
           $$sum17$i = (($424) + 2)|0;
           $431 = (73224 + ($$sum17$i<<2)|0);
           $432 = HEAP32[$431>>2]|0;
           $433 = HEAP32[(73200)>>2]|0;
           $434 = ($432>>>0)<($433>>>0);
           if ($434) {
            _abort();
            // unreachable;
           } else {
            $$pre$phi$i26Z2D = $431;$F5$0$i = $432;
           }
          }
          HEAP32[$$pre$phi$i26Z2D>>2] = $348;
          $435 = ((($F5$0$i)) + 12|0);
          HEAP32[$435>>2] = $348;
          $$sum15$i = (($246) + 8)|0;
          $436 = (($v$3$lcssa$i) + ($$sum15$i)|0);
          HEAP32[$436>>2] = $F5$0$i;
          $$sum16$i = (($246) + 12)|0;
          $437 = (($v$3$lcssa$i) + ($$sum16$i)|0);
          HEAP32[$437>>2] = $425;
          break;
         }
         $438 = $rsize$3$lcssa$i >>> 8;
         $439 = ($438|0)==(0);
         if ($439) {
          $I7$0$i = 0;
         } else {
          $440 = ($rsize$3$lcssa$i>>>0)>(16777215);
          if ($440) {
           $I7$0$i = 31;
          } else {
           $441 = (($438) + 1048320)|0;
           $442 = $441 >>> 16;
           $443 = $442 & 8;
           $444 = $438 << $443;
           $445 = (($444) + 520192)|0;
           $446 = $445 >>> 16;
           $447 = $446 & 4;
           $448 = $447 | $443;
           $449 = $444 << $447;
           $450 = (($449) + 245760)|0;
           $451 = $450 >>> 16;
           $452 = $451 & 2;
           $453 = $448 | $452;
           $454 = (14 - ($453))|0;
           $455 = $449 << $452;
           $456 = $455 >>> 15;
           $457 = (($454) + ($456))|0;
           $458 = $457 << 1;
           $459 = (($457) + 7)|0;
           $460 = $rsize$3$lcssa$i >>> $459;
           $461 = $460 & 1;
           $462 = $461 | $458;
           $I7$0$i = $462;
          }
         }
         $463 = (73488 + ($I7$0$i<<2)|0);
         $$sum2$i = (($246) + 28)|0;
         $464 = (($v$3$lcssa$i) + ($$sum2$i)|0);
         HEAP32[$464>>2] = $I7$0$i;
         $$sum3$i27 = (($246) + 16)|0;
         $465 = (($v$3$lcssa$i) + ($$sum3$i27)|0);
         $$sum4$i28 = (($246) + 20)|0;
         $466 = (($v$3$lcssa$i) + ($$sum4$i28)|0);
         HEAP32[$466>>2] = 0;
         HEAP32[$465>>2] = 0;
         $467 = HEAP32[(73188)>>2]|0;
         $468 = 1 << $I7$0$i;
         $469 = $467 & $468;
         $470 = ($469|0)==(0);
         if ($470) {
          $471 = $467 | $468;
          HEAP32[(73188)>>2] = $471;
          HEAP32[$463>>2] = $348;
          $$sum5$i = (($246) + 24)|0;
          $472 = (($v$3$lcssa$i) + ($$sum5$i)|0);
          HEAP32[$472>>2] = $463;
          $$sum6$i = (($246) + 12)|0;
          $473 = (($v$3$lcssa$i) + ($$sum6$i)|0);
          HEAP32[$473>>2] = $348;
          $$sum7$i = (($246) + 8)|0;
          $474 = (($v$3$lcssa$i) + ($$sum7$i)|0);
          HEAP32[$474>>2] = $348;
          break;
         }
         $475 = HEAP32[$463>>2]|0;
         $476 = ((($475)) + 4|0);
         $477 = HEAP32[$476>>2]|0;
         $478 = $477 & -8;
         $479 = ($478|0)==($rsize$3$lcssa$i|0);
         L216: do {
          if ($479) {
           $T$0$lcssa$i = $475;
          } else {
           $480 = ($I7$0$i|0)==(31);
           $481 = $I7$0$i >>> 1;
           $482 = (25 - ($481))|0;
           $483 = $480 ? 0 : $482;
           $484 = $rsize$3$lcssa$i << $483;
           $K12$029$i = $484;$T$028$i = $475;
           while(1) {
            $491 = $K12$029$i >>> 31;
            $492 = (((($T$028$i)) + 16|0) + ($491<<2)|0);
            $487 = HEAP32[$492>>2]|0;
            $493 = ($487|0)==(0|0);
            if ($493) {
             $$lcssa232 = $492;$T$028$i$lcssa = $T$028$i;
             break;
            }
            $485 = $K12$029$i << 1;
            $486 = ((($487)) + 4|0);
            $488 = HEAP32[$486>>2]|0;
            $489 = $488 & -8;
            $490 = ($489|0)==($rsize$3$lcssa$i|0);
            if ($490) {
             $T$0$lcssa$i = $487;
             break L216;
            } else {
             $K12$029$i = $485;$T$028$i = $487;
            }
           }
           $494 = HEAP32[(73200)>>2]|0;
           $495 = ($$lcssa232>>>0)<($494>>>0);
           if ($495) {
            _abort();
            // unreachable;
           } else {
            HEAP32[$$lcssa232>>2] = $348;
            $$sum11$i = (($246) + 24)|0;
            $496 = (($v$3$lcssa$i) + ($$sum11$i)|0);
            HEAP32[$496>>2] = $T$028$i$lcssa;
            $$sum12$i = (($246) + 12)|0;
            $497 = (($v$3$lcssa$i) + ($$sum12$i)|0);
            HEAP32[$497>>2] = $348;
            $$sum13$i = (($246) + 8)|0;
            $498 = (($v$3$lcssa$i) + ($$sum13$i)|0);
            HEAP32[$498>>2] = $348;
            break L199;
           }
          }
         } while(0);
         $499 = ((($T$0$lcssa$i)) + 8|0);
         $500 = HEAP32[$499>>2]|0;
         $501 = HEAP32[(73200)>>2]|0;
         $502 = ($500>>>0)>=($501>>>0);
         $not$$i = ($T$0$lcssa$i>>>0)>=($501>>>0);
         $503 = $502 & $not$$i;
         if ($503) {
          $504 = ((($500)) + 12|0);
          HEAP32[$504>>2] = $348;
          HEAP32[$499>>2] = $348;
          $$sum8$i = (($246) + 8)|0;
          $505 = (($v$3$lcssa$i) + ($$sum8$i)|0);
          HEAP32[$505>>2] = $500;
          $$sum9$i = (($246) + 12)|0;
          $506 = (($v$3$lcssa$i) + ($$sum9$i)|0);
          HEAP32[$506>>2] = $T$0$lcssa$i;
          $$sum10$i = (($246) + 24)|0;
          $507 = (($v$3$lcssa$i) + ($$sum10$i)|0);
          HEAP32[$507>>2] = 0;
          break;
         } else {
          _abort();
          // unreachable;
         }
        }
       } while(0);
       $508 = ((($v$3$lcssa$i)) + 8|0);
       $mem$0 = $508;
       return ($mem$0|0);
      } else {
       $nb$0 = $246;
      }
     }
    }
   }
  }
 } while(0);
 $509 = HEAP32[(73192)>>2]|0;
 $510 = ($509>>>0)<($nb$0>>>0);
 if (!($510)) {
  $511 = (($509) - ($nb$0))|0;
  $512 = HEAP32[(73204)>>2]|0;
  $513 = ($511>>>0)>(15);
  if ($513) {
   $514 = (($512) + ($nb$0)|0);
   HEAP32[(73204)>>2] = $514;
   HEAP32[(73192)>>2] = $511;
   $515 = $511 | 1;
   $$sum2 = (($nb$0) + 4)|0;
   $516 = (($512) + ($$sum2)|0);
   HEAP32[$516>>2] = $515;
   $517 = (($512) + ($509)|0);
   HEAP32[$517>>2] = $511;
   $518 = $nb$0 | 3;
   $519 = ((($512)) + 4|0);
   HEAP32[$519>>2] = $518;
  } else {
   HEAP32[(73192)>>2] = 0;
   HEAP32[(73204)>>2] = 0;
   $520 = $509 | 3;
   $521 = ((($512)) + 4|0);
   HEAP32[$521>>2] = $520;
   $$sum1 = (($509) + 4)|0;
   $522 = (($512) + ($$sum1)|0);
   $523 = HEAP32[$522>>2]|0;
   $524 = $523 | 1;
   HEAP32[$522>>2] = $524;
  }
  $525 = ((($512)) + 8|0);
  $mem$0 = $525;
  return ($mem$0|0);
 }
 $526 = HEAP32[(73196)>>2]|0;
 $527 = ($526>>>0)>($nb$0>>>0);
 if ($527) {
  $528 = (($526) - ($nb$0))|0;
  HEAP32[(73196)>>2] = $528;
  $529 = HEAP32[(73208)>>2]|0;
  $530 = (($529) + ($nb$0)|0);
  HEAP32[(73208)>>2] = $530;
  $531 = $528 | 1;
  $$sum = (($nb$0) + 4)|0;
  $532 = (($529) + ($$sum)|0);
  HEAP32[$532>>2] = $531;
  $533 = $nb$0 | 3;
  $534 = ((($529)) + 4|0);
  HEAP32[$534>>2] = $533;
  $535 = ((($529)) + 8|0);
  $mem$0 = $535;
  return ($mem$0|0);
 }
 $536 = HEAP32[73656>>2]|0;
 $537 = ($536|0)==(0);
 do {
  if ($537) {
   $538 = (_sysconf(30)|0);
   $539 = (($538) + -1)|0;
   $540 = $539 & $538;
   $541 = ($540|0)==(0);
   if ($541) {
    HEAP32[(73664)>>2] = $538;
    HEAP32[(73660)>>2] = $538;
    HEAP32[(73668)>>2] = -1;
    HEAP32[(73672)>>2] = -1;
    HEAP32[(73676)>>2] = 0;
    HEAP32[(73628)>>2] = 0;
    $542 = (_time((0|0))|0);
    $543 = $542 & -16;
    $544 = $543 ^ 1431655768;
    HEAP32[73656>>2] = $544;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $545 = (($nb$0) + 48)|0;
 $546 = HEAP32[(73664)>>2]|0;
 $547 = (($nb$0) + 47)|0;
 $548 = (($546) + ($547))|0;
 $549 = (0 - ($546))|0;
 $550 = $548 & $549;
 $551 = ($550>>>0)>($nb$0>>>0);
 if (!($551)) {
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $552 = HEAP32[(73624)>>2]|0;
 $553 = ($552|0)==(0);
 if (!($553)) {
  $554 = HEAP32[(73616)>>2]|0;
  $555 = (($554) + ($550))|0;
  $556 = ($555>>>0)<=($554>>>0);
  $557 = ($555>>>0)>($552>>>0);
  $or$cond1$i = $556 | $557;
  if ($or$cond1$i) {
   $mem$0 = 0;
   return ($mem$0|0);
  }
 }
 $558 = HEAP32[(73628)>>2]|0;
 $559 = $558 & 4;
 $560 = ($559|0)==(0);
 L258: do {
  if ($560) {
   $561 = HEAP32[(73208)>>2]|0;
   $562 = ($561|0)==(0|0);
   L260: do {
    if ($562) {
     label = 174;
    } else {
     $sp$0$i$i = (73632);
     while(1) {
      $563 = HEAP32[$sp$0$i$i>>2]|0;
      $564 = ($563>>>0)>($561>>>0);
      if (!($564)) {
       $565 = ((($sp$0$i$i)) + 4|0);
       $566 = HEAP32[$565>>2]|0;
       $567 = (($563) + ($566)|0);
       $568 = ($567>>>0)>($561>>>0);
       if ($568) {
        $$lcssa228 = $sp$0$i$i;$$lcssa230 = $565;
        break;
       }
      }
      $569 = ((($sp$0$i$i)) + 8|0);
      $570 = HEAP32[$569>>2]|0;
      $571 = ($570|0)==(0|0);
      if ($571) {
       label = 174;
       break L260;
      } else {
       $sp$0$i$i = $570;
      }
     }
     $594 = HEAP32[(73196)>>2]|0;
     $595 = (($548) - ($594))|0;
     $596 = $595 & $549;
     $597 = ($596>>>0)<(2147483647);
     if ($597) {
      $598 = (_sbrk(($596|0))|0);
      $599 = HEAP32[$$lcssa228>>2]|0;
      $600 = HEAP32[$$lcssa230>>2]|0;
      $601 = (($599) + ($600)|0);
      $602 = ($598|0)==($601|0);
      $$3$i = $602 ? $596 : 0;
      if ($602) {
       $603 = ($598|0)==((-1)|0);
       if ($603) {
        $tsize$0323944$i = $$3$i;
       } else {
        $tbase$255$i = $598;$tsize$254$i = $$3$i;
        label = 194;
        break L258;
       }
      } else {
       $br$0$ph$i = $598;$ssize$1$ph$i = $596;$tsize$0$ph$i = $$3$i;
       label = 184;
      }
     } else {
      $tsize$0323944$i = 0;
     }
    }
   } while(0);
   do {
    if ((label|0) == 174) {
     $572 = (_sbrk(0)|0);
     $573 = ($572|0)==((-1)|0);
     if ($573) {
      $tsize$0323944$i = 0;
     } else {
      $574 = $572;
      $575 = HEAP32[(73660)>>2]|0;
      $576 = (($575) + -1)|0;
      $577 = $576 & $574;
      $578 = ($577|0)==(0);
      if ($578) {
       $ssize$0$i = $550;
      } else {
       $579 = (($576) + ($574))|0;
       $580 = (0 - ($575))|0;
       $581 = $579 & $580;
       $582 = (($550) - ($574))|0;
       $583 = (($582) + ($581))|0;
       $ssize$0$i = $583;
      }
      $584 = HEAP32[(73616)>>2]|0;
      $585 = (($584) + ($ssize$0$i))|0;
      $586 = ($ssize$0$i>>>0)>($nb$0>>>0);
      $587 = ($ssize$0$i>>>0)<(2147483647);
      $or$cond$i30 = $586 & $587;
      if ($or$cond$i30) {
       $588 = HEAP32[(73624)>>2]|0;
       $589 = ($588|0)==(0);
       if (!($589)) {
        $590 = ($585>>>0)<=($584>>>0);
        $591 = ($585>>>0)>($588>>>0);
        $or$cond2$i = $590 | $591;
        if ($or$cond2$i) {
         $tsize$0323944$i = 0;
         break;
        }
       }
       $592 = (_sbrk(($ssize$0$i|0))|0);
       $593 = ($592|0)==($572|0);
       $ssize$0$$i = $593 ? $ssize$0$i : 0;
       if ($593) {
        $tbase$255$i = $572;$tsize$254$i = $ssize$0$$i;
        label = 194;
        break L258;
       } else {
        $br$0$ph$i = $592;$ssize$1$ph$i = $ssize$0$i;$tsize$0$ph$i = $ssize$0$$i;
        label = 184;
       }
      } else {
       $tsize$0323944$i = 0;
      }
     }
    }
   } while(0);
   L280: do {
    if ((label|0) == 184) {
     $604 = (0 - ($ssize$1$ph$i))|0;
     $605 = ($br$0$ph$i|0)!=((-1)|0);
     $606 = ($ssize$1$ph$i>>>0)<(2147483647);
     $or$cond5$i = $606 & $605;
     $607 = ($545>>>0)>($ssize$1$ph$i>>>0);
     $or$cond6$i = $607 & $or$cond5$i;
     do {
      if ($or$cond6$i) {
       $608 = HEAP32[(73664)>>2]|0;
       $609 = (($547) - ($ssize$1$ph$i))|0;
       $610 = (($609) + ($608))|0;
       $611 = (0 - ($608))|0;
       $612 = $610 & $611;
       $613 = ($612>>>0)<(2147483647);
       if ($613) {
        $614 = (_sbrk(($612|0))|0);
        $615 = ($614|0)==((-1)|0);
        if ($615) {
         (_sbrk(($604|0))|0);
         $tsize$0323944$i = $tsize$0$ph$i;
         break L280;
        } else {
         $616 = (($612) + ($ssize$1$ph$i))|0;
         $ssize$2$i = $616;
         break;
        }
       } else {
        $ssize$2$i = $ssize$1$ph$i;
       }
      } else {
       $ssize$2$i = $ssize$1$ph$i;
      }
     } while(0);
     $617 = ($br$0$ph$i|0)==((-1)|0);
     if ($617) {
      $tsize$0323944$i = $tsize$0$ph$i;
     } else {
      $tbase$255$i = $br$0$ph$i;$tsize$254$i = $ssize$2$i;
      label = 194;
      break L258;
     }
    }
   } while(0);
   $618 = HEAP32[(73628)>>2]|0;
   $619 = $618 | 4;
   HEAP32[(73628)>>2] = $619;
   $tsize$1$i = $tsize$0323944$i;
   label = 191;
  } else {
   $tsize$1$i = 0;
   label = 191;
  }
 } while(0);
 if ((label|0) == 191) {
  $620 = ($550>>>0)<(2147483647);
  if ($620) {
   $621 = (_sbrk(($550|0))|0);
   $622 = (_sbrk(0)|0);
   $623 = ($621|0)!=((-1)|0);
   $624 = ($622|0)!=((-1)|0);
   $or$cond3$i = $623 & $624;
   $625 = ($621>>>0)<($622>>>0);
   $or$cond8$i = $625 & $or$cond3$i;
   if ($or$cond8$i) {
    $626 = $622;
    $627 = $621;
    $628 = (($626) - ($627))|0;
    $629 = (($nb$0) + 40)|0;
    $630 = ($628>>>0)>($629>>>0);
    $$tsize$1$i = $630 ? $628 : $tsize$1$i;
    if ($630) {
     $tbase$255$i = $621;$tsize$254$i = $$tsize$1$i;
     label = 194;
    }
   }
  }
 }
 if ((label|0) == 194) {
  $631 = HEAP32[(73616)>>2]|0;
  $632 = (($631) + ($tsize$254$i))|0;
  HEAP32[(73616)>>2] = $632;
  $633 = HEAP32[(73620)>>2]|0;
  $634 = ($632>>>0)>($633>>>0);
  if ($634) {
   HEAP32[(73620)>>2] = $632;
  }
  $635 = HEAP32[(73208)>>2]|0;
  $636 = ($635|0)==(0|0);
  L299: do {
   if ($636) {
    $637 = HEAP32[(73200)>>2]|0;
    $638 = ($637|0)==(0|0);
    $639 = ($tbase$255$i>>>0)<($637>>>0);
    $or$cond9$i = $638 | $639;
    if ($or$cond9$i) {
     HEAP32[(73200)>>2] = $tbase$255$i;
    }
    HEAP32[(73632)>>2] = $tbase$255$i;
    HEAP32[(73636)>>2] = $tsize$254$i;
    HEAP32[(73644)>>2] = 0;
    $640 = HEAP32[73656>>2]|0;
    HEAP32[(73220)>>2] = $640;
    HEAP32[(73216)>>2] = -1;
    $i$02$i$i = 0;
    while(1) {
     $641 = $i$02$i$i << 1;
     $642 = (73224 + ($641<<2)|0);
     $$sum$i$i = (($641) + 3)|0;
     $643 = (73224 + ($$sum$i$i<<2)|0);
     HEAP32[$643>>2] = $642;
     $$sum1$i$i = (($641) + 2)|0;
     $644 = (73224 + ($$sum1$i$i<<2)|0);
     HEAP32[$644>>2] = $642;
     $645 = (($i$02$i$i) + 1)|0;
     $exitcond$i$i = ($645|0)==(32);
     if ($exitcond$i$i) {
      break;
     } else {
      $i$02$i$i = $645;
     }
    }
    $646 = (($tsize$254$i) + -40)|0;
    $647 = ((($tbase$255$i)) + 8|0);
    $648 = $647;
    $649 = $648 & 7;
    $650 = ($649|0)==(0);
    $651 = (0 - ($648))|0;
    $652 = $651 & 7;
    $653 = $650 ? 0 : $652;
    $654 = (($tbase$255$i) + ($653)|0);
    $655 = (($646) - ($653))|0;
    HEAP32[(73208)>>2] = $654;
    HEAP32[(73196)>>2] = $655;
    $656 = $655 | 1;
    $$sum$i13$i = (($653) + 4)|0;
    $657 = (($tbase$255$i) + ($$sum$i13$i)|0);
    HEAP32[$657>>2] = $656;
    $$sum2$i$i = (($tsize$254$i) + -36)|0;
    $658 = (($tbase$255$i) + ($$sum2$i$i)|0);
    HEAP32[$658>>2] = 40;
    $659 = HEAP32[(73672)>>2]|0;
    HEAP32[(73212)>>2] = $659;
   } else {
    $sp$084$i = (73632);
    while(1) {
     $660 = HEAP32[$sp$084$i>>2]|0;
     $661 = ((($sp$084$i)) + 4|0);
     $662 = HEAP32[$661>>2]|0;
     $663 = (($660) + ($662)|0);
     $664 = ($tbase$255$i|0)==($663|0);
     if ($664) {
      $$lcssa222 = $660;$$lcssa224 = $661;$$lcssa226 = $662;$sp$084$i$lcssa = $sp$084$i;
      label = 204;
      break;
     }
     $665 = ((($sp$084$i)) + 8|0);
     $666 = HEAP32[$665>>2]|0;
     $667 = ($666|0)==(0|0);
     if ($667) {
      break;
     } else {
      $sp$084$i = $666;
     }
    }
    if ((label|0) == 204) {
     $668 = ((($sp$084$i$lcssa)) + 12|0);
     $669 = HEAP32[$668>>2]|0;
     $670 = $669 & 8;
     $671 = ($670|0)==(0);
     if ($671) {
      $672 = ($635>>>0)>=($$lcssa222>>>0);
      $673 = ($635>>>0)<($tbase$255$i>>>0);
      $or$cond57$i = $673 & $672;
      if ($or$cond57$i) {
       $674 = (($$lcssa226) + ($tsize$254$i))|0;
       HEAP32[$$lcssa224>>2] = $674;
       $675 = HEAP32[(73196)>>2]|0;
       $676 = (($675) + ($tsize$254$i))|0;
       $677 = ((($635)) + 8|0);
       $678 = $677;
       $679 = $678 & 7;
       $680 = ($679|0)==(0);
       $681 = (0 - ($678))|0;
       $682 = $681 & 7;
       $683 = $680 ? 0 : $682;
       $684 = (($635) + ($683)|0);
       $685 = (($676) - ($683))|0;
       HEAP32[(73208)>>2] = $684;
       HEAP32[(73196)>>2] = $685;
       $686 = $685 | 1;
       $$sum$i17$i = (($683) + 4)|0;
       $687 = (($635) + ($$sum$i17$i)|0);
       HEAP32[$687>>2] = $686;
       $$sum2$i18$i = (($676) + 4)|0;
       $688 = (($635) + ($$sum2$i18$i)|0);
       HEAP32[$688>>2] = 40;
       $689 = HEAP32[(73672)>>2]|0;
       HEAP32[(73212)>>2] = $689;
       break;
      }
     }
    }
    $690 = HEAP32[(73200)>>2]|0;
    $691 = ($tbase$255$i>>>0)<($690>>>0);
    if ($691) {
     HEAP32[(73200)>>2] = $tbase$255$i;
     $755 = $tbase$255$i;
    } else {
     $755 = $690;
    }
    $692 = (($tbase$255$i) + ($tsize$254$i)|0);
    $sp$183$i = (73632);
    while(1) {
     $693 = HEAP32[$sp$183$i>>2]|0;
     $694 = ($693|0)==($692|0);
     if ($694) {
      $$lcssa219 = $sp$183$i;$sp$183$i$lcssa = $sp$183$i;
      label = 212;
      break;
     }
     $695 = ((($sp$183$i)) + 8|0);
     $696 = HEAP32[$695>>2]|0;
     $697 = ($696|0)==(0|0);
     if ($697) {
      $sp$0$i$i$i = (73632);
      break;
     } else {
      $sp$183$i = $696;
     }
    }
    if ((label|0) == 212) {
     $698 = ((($sp$183$i$lcssa)) + 12|0);
     $699 = HEAP32[$698>>2]|0;
     $700 = $699 & 8;
     $701 = ($700|0)==(0);
     if ($701) {
      HEAP32[$$lcssa219>>2] = $tbase$255$i;
      $702 = ((($sp$183$i$lcssa)) + 4|0);
      $703 = HEAP32[$702>>2]|0;
      $704 = (($703) + ($tsize$254$i))|0;
      HEAP32[$702>>2] = $704;
      $705 = ((($tbase$255$i)) + 8|0);
      $706 = $705;
      $707 = $706 & 7;
      $708 = ($707|0)==(0);
      $709 = (0 - ($706))|0;
      $710 = $709 & 7;
      $711 = $708 ? 0 : $710;
      $712 = (($tbase$255$i) + ($711)|0);
      $$sum112$i = (($tsize$254$i) + 8)|0;
      $713 = (($tbase$255$i) + ($$sum112$i)|0);
      $714 = $713;
      $715 = $714 & 7;
      $716 = ($715|0)==(0);
      $717 = (0 - ($714))|0;
      $718 = $717 & 7;
      $719 = $716 ? 0 : $718;
      $$sum113$i = (($719) + ($tsize$254$i))|0;
      $720 = (($tbase$255$i) + ($$sum113$i)|0);
      $721 = $720;
      $722 = $712;
      $723 = (($721) - ($722))|0;
      $$sum$i19$i = (($711) + ($nb$0))|0;
      $724 = (($tbase$255$i) + ($$sum$i19$i)|0);
      $725 = (($723) - ($nb$0))|0;
      $726 = $nb$0 | 3;
      $$sum1$i20$i = (($711) + 4)|0;
      $727 = (($tbase$255$i) + ($$sum1$i20$i)|0);
      HEAP32[$727>>2] = $726;
      $728 = ($720|0)==($635|0);
      L324: do {
       if ($728) {
        $729 = HEAP32[(73196)>>2]|0;
        $730 = (($729) + ($725))|0;
        HEAP32[(73196)>>2] = $730;
        HEAP32[(73208)>>2] = $724;
        $731 = $730 | 1;
        $$sum42$i$i = (($$sum$i19$i) + 4)|0;
        $732 = (($tbase$255$i) + ($$sum42$i$i)|0);
        HEAP32[$732>>2] = $731;
       } else {
        $733 = HEAP32[(73204)>>2]|0;
        $734 = ($720|0)==($733|0);
        if ($734) {
         $735 = HEAP32[(73192)>>2]|0;
         $736 = (($735) + ($725))|0;
         HEAP32[(73192)>>2] = $736;
         HEAP32[(73204)>>2] = $724;
         $737 = $736 | 1;
         $$sum40$i$i = (($$sum$i19$i) + 4)|0;
         $738 = (($tbase$255$i) + ($$sum40$i$i)|0);
         HEAP32[$738>>2] = $737;
         $$sum41$i$i = (($736) + ($$sum$i19$i))|0;
         $739 = (($tbase$255$i) + ($$sum41$i$i)|0);
         HEAP32[$739>>2] = $736;
         break;
        }
        $$sum2$i21$i = (($tsize$254$i) + 4)|0;
        $$sum114$i = (($$sum2$i21$i) + ($719))|0;
        $740 = (($tbase$255$i) + ($$sum114$i)|0);
        $741 = HEAP32[$740>>2]|0;
        $742 = $741 & 3;
        $743 = ($742|0)==(1);
        if ($743) {
         $744 = $741 & -8;
         $745 = $741 >>> 3;
         $746 = ($741>>>0)<(256);
         L332: do {
          if ($746) {
           $$sum3738$i$i = $719 | 8;
           $$sum124$i = (($$sum3738$i$i) + ($tsize$254$i))|0;
           $747 = (($tbase$255$i) + ($$sum124$i)|0);
           $748 = HEAP32[$747>>2]|0;
           $$sum39$i$i = (($tsize$254$i) + 12)|0;
           $$sum125$i = (($$sum39$i$i) + ($719))|0;
           $749 = (($tbase$255$i) + ($$sum125$i)|0);
           $750 = HEAP32[$749>>2]|0;
           $751 = $745 << 1;
           $752 = (73224 + ($751<<2)|0);
           $753 = ($748|0)==($752|0);
           do {
            if (!($753)) {
             $754 = ($748>>>0)<($755>>>0);
             if ($754) {
              _abort();
              // unreachable;
             }
             $756 = ((($748)) + 12|0);
             $757 = HEAP32[$756>>2]|0;
             $758 = ($757|0)==($720|0);
             if ($758) {
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $759 = ($750|0)==($748|0);
           if ($759) {
            $760 = 1 << $745;
            $761 = $760 ^ -1;
            $762 = HEAP32[73184>>2]|0;
            $763 = $762 & $761;
            HEAP32[73184>>2] = $763;
            break;
           }
           $764 = ($750|0)==($752|0);
           do {
            if ($764) {
             $$pre57$i$i = ((($750)) + 8|0);
             $$pre$phi58$i$iZ2D = $$pre57$i$i;
            } else {
             $765 = ($750>>>0)<($755>>>0);
             if ($765) {
              _abort();
              // unreachable;
             }
             $766 = ((($750)) + 8|0);
             $767 = HEAP32[$766>>2]|0;
             $768 = ($767|0)==($720|0);
             if ($768) {
              $$pre$phi58$i$iZ2D = $766;
              break;
             }
             _abort();
             // unreachable;
            }
           } while(0);
           $769 = ((($748)) + 12|0);
           HEAP32[$769>>2] = $750;
           HEAP32[$$pre$phi58$i$iZ2D>>2] = $748;
          } else {
           $$sum34$i$i = $719 | 24;
           $$sum115$i = (($$sum34$i$i) + ($tsize$254$i))|0;
           $770 = (($tbase$255$i) + ($$sum115$i)|0);
           $771 = HEAP32[$770>>2]|0;
           $$sum5$i$i = (($tsize$254$i) + 12)|0;
           $$sum116$i = (($$sum5$i$i) + ($719))|0;
           $772 = (($tbase$255$i) + ($$sum116$i)|0);
           $773 = HEAP32[$772>>2]|0;
           $774 = ($773|0)==($720|0);
           do {
            if ($774) {
             $$sum67$i$i = $719 | 16;
             $$sum122$i = (($$sum2$i21$i) + ($$sum67$i$i))|0;
             $784 = (($tbase$255$i) + ($$sum122$i)|0);
             $785 = HEAP32[$784>>2]|0;
             $786 = ($785|0)==(0|0);
             if ($786) {
              $$sum123$i = (($$sum67$i$i) + ($tsize$254$i))|0;
              $787 = (($tbase$255$i) + ($$sum123$i)|0);
              $788 = HEAP32[$787>>2]|0;
              $789 = ($788|0)==(0|0);
              if ($789) {
               $R$1$i$i = 0;
               break;
              } else {
               $R$0$i$i = $788;$RP$0$i$i = $787;
              }
             } else {
              $R$0$i$i = $785;$RP$0$i$i = $784;
             }
             while(1) {
              $790 = ((($R$0$i$i)) + 20|0);
              $791 = HEAP32[$790>>2]|0;
              $792 = ($791|0)==(0|0);
              if (!($792)) {
               $R$0$i$i = $791;$RP$0$i$i = $790;
               continue;
              }
              $793 = ((($R$0$i$i)) + 16|0);
              $794 = HEAP32[$793>>2]|0;
              $795 = ($794|0)==(0|0);
              if ($795) {
               $R$0$i$i$lcssa = $R$0$i$i;$RP$0$i$i$lcssa = $RP$0$i$i;
               break;
              } else {
               $R$0$i$i = $794;$RP$0$i$i = $793;
              }
             }
             $796 = ($RP$0$i$i$lcssa>>>0)<($755>>>0);
             if ($796) {
              _abort();
              // unreachable;
             } else {
              HEAP32[$RP$0$i$i$lcssa>>2] = 0;
              $R$1$i$i = $R$0$i$i$lcssa;
              break;
             }
            } else {
             $$sum3536$i$i = $719 | 8;
             $$sum117$i = (($$sum3536$i$i) + ($tsize$254$i))|0;
             $775 = (($tbase$255$i) + ($$sum117$i)|0);
             $776 = HEAP32[$775>>2]|0;
             $777 = ($776>>>0)<($755>>>0);
             if ($777) {
              _abort();
              // unreachable;
             }
             $778 = ((($776)) + 12|0);
             $779 = HEAP32[$778>>2]|0;
             $780 = ($779|0)==($720|0);
             if (!($780)) {
              _abort();
              // unreachable;
             }
             $781 = ((($773)) + 8|0);
             $782 = HEAP32[$781>>2]|0;
             $783 = ($782|0)==($720|0);
             if ($783) {
              HEAP32[$778>>2] = $773;
              HEAP32[$781>>2] = $776;
              $R$1$i$i = $773;
              break;
             } else {
              _abort();
              // unreachable;
             }
            }
           } while(0);
           $797 = ($771|0)==(0|0);
           if ($797) {
            break;
           }
           $$sum30$i$i = (($tsize$254$i) + 28)|0;
           $$sum118$i = (($$sum30$i$i) + ($719))|0;
           $798 = (($tbase$255$i) + ($$sum118$i)|0);
           $799 = HEAP32[$798>>2]|0;
           $800 = (73488 + ($799<<2)|0);
           $801 = HEAP32[$800>>2]|0;
           $802 = ($720|0)==($801|0);
           do {
            if ($802) {
             HEAP32[$800>>2] = $R$1$i$i;
             $cond$i$i = ($R$1$i$i|0)==(0|0);
             if (!($cond$i$i)) {
              break;
             }
             $803 = 1 << $799;
             $804 = $803 ^ -1;
             $805 = HEAP32[(73188)>>2]|0;
             $806 = $805 & $804;
             HEAP32[(73188)>>2] = $806;
             break L332;
            } else {
             $807 = HEAP32[(73200)>>2]|0;
             $808 = ($771>>>0)<($807>>>0);
             if ($808) {
              _abort();
              // unreachable;
             }
             $809 = ((($771)) + 16|0);
             $810 = HEAP32[$809>>2]|0;
             $811 = ($810|0)==($720|0);
             if ($811) {
              HEAP32[$809>>2] = $R$1$i$i;
             } else {
              $812 = ((($771)) + 20|0);
              HEAP32[$812>>2] = $R$1$i$i;
             }
             $813 = ($R$1$i$i|0)==(0|0);
             if ($813) {
              break L332;
             }
            }
           } while(0);
           $814 = HEAP32[(73200)>>2]|0;
           $815 = ($R$1$i$i>>>0)<($814>>>0);
           if ($815) {
            _abort();
            // unreachable;
           }
           $816 = ((($R$1$i$i)) + 24|0);
           HEAP32[$816>>2] = $771;
           $$sum3132$i$i = $719 | 16;
           $$sum119$i = (($$sum3132$i$i) + ($tsize$254$i))|0;
           $817 = (($tbase$255$i) + ($$sum119$i)|0);
           $818 = HEAP32[$817>>2]|0;
           $819 = ($818|0)==(0|0);
           do {
            if (!($819)) {
             $820 = ($818>>>0)<($814>>>0);
             if ($820) {
              _abort();
              // unreachable;
             } else {
              $821 = ((($R$1$i$i)) + 16|0);
              HEAP32[$821>>2] = $818;
              $822 = ((($818)) + 24|0);
              HEAP32[$822>>2] = $R$1$i$i;
              break;
             }
            }
           } while(0);
           $$sum120$i = (($$sum2$i21$i) + ($$sum3132$i$i))|0;
           $823 = (($tbase$255$i) + ($$sum120$i)|0);
           $824 = HEAP32[$823>>2]|0;
           $825 = ($824|0)==(0|0);
           if ($825) {
            break;
           }
           $826 = HEAP32[(73200)>>2]|0;
           $827 = ($824>>>0)<($826>>>0);
           if ($827) {
            _abort();
            // unreachable;
           } else {
            $828 = ((($R$1$i$i)) + 20|0);
            HEAP32[$828>>2] = $824;
            $829 = ((($824)) + 24|0);
            HEAP32[$829>>2] = $R$1$i$i;
            break;
           }
          }
         } while(0);
         $$sum9$i$i = $744 | $719;
         $$sum121$i = (($$sum9$i$i) + ($tsize$254$i))|0;
         $830 = (($tbase$255$i) + ($$sum121$i)|0);
         $831 = (($744) + ($725))|0;
         $oldfirst$0$i$i = $830;$qsize$0$i$i = $831;
        } else {
         $oldfirst$0$i$i = $720;$qsize$0$i$i = $725;
        }
        $832 = ((($oldfirst$0$i$i)) + 4|0);
        $833 = HEAP32[$832>>2]|0;
        $834 = $833 & -2;
        HEAP32[$832>>2] = $834;
        $835 = $qsize$0$i$i | 1;
        $$sum10$i$i = (($$sum$i19$i) + 4)|0;
        $836 = (($tbase$255$i) + ($$sum10$i$i)|0);
        HEAP32[$836>>2] = $835;
        $$sum11$i$i = (($qsize$0$i$i) + ($$sum$i19$i))|0;
        $837 = (($tbase$255$i) + ($$sum11$i$i)|0);
        HEAP32[$837>>2] = $qsize$0$i$i;
        $838 = $qsize$0$i$i >>> 3;
        $839 = ($qsize$0$i$i>>>0)<(256);
        if ($839) {
         $840 = $838 << 1;
         $841 = (73224 + ($840<<2)|0);
         $842 = HEAP32[73184>>2]|0;
         $843 = 1 << $838;
         $844 = $842 & $843;
         $845 = ($844|0)==(0);
         do {
          if ($845) {
           $846 = $842 | $843;
           HEAP32[73184>>2] = $846;
           $$pre$i22$i = (($840) + 2)|0;
           $$pre56$i$i = (73224 + ($$pre$i22$i<<2)|0);
           $$pre$phi$i23$iZ2D = $$pre56$i$i;$F4$0$i$i = $841;
          } else {
           $$sum29$i$i = (($840) + 2)|0;
           $847 = (73224 + ($$sum29$i$i<<2)|0);
           $848 = HEAP32[$847>>2]|0;
           $849 = HEAP32[(73200)>>2]|0;
           $850 = ($848>>>0)<($849>>>0);
           if (!($850)) {
            $$pre$phi$i23$iZ2D = $847;$F4$0$i$i = $848;
            break;
           }
           _abort();
           // unreachable;
          }
         } while(0);
         HEAP32[$$pre$phi$i23$iZ2D>>2] = $724;
         $851 = ((($F4$0$i$i)) + 12|0);
         HEAP32[$851>>2] = $724;
         $$sum27$i$i = (($$sum$i19$i) + 8)|0;
         $852 = (($tbase$255$i) + ($$sum27$i$i)|0);
         HEAP32[$852>>2] = $F4$0$i$i;
         $$sum28$i$i = (($$sum$i19$i) + 12)|0;
         $853 = (($tbase$255$i) + ($$sum28$i$i)|0);
         HEAP32[$853>>2] = $841;
         break;
        }
        $854 = $qsize$0$i$i >>> 8;
        $855 = ($854|0)==(0);
        do {
         if ($855) {
          $I7$0$i$i = 0;
         } else {
          $856 = ($qsize$0$i$i>>>0)>(16777215);
          if ($856) {
           $I7$0$i$i = 31;
           break;
          }
          $857 = (($854) + 1048320)|0;
          $858 = $857 >>> 16;
          $859 = $858 & 8;
          $860 = $854 << $859;
          $861 = (($860) + 520192)|0;
          $862 = $861 >>> 16;
          $863 = $862 & 4;
          $864 = $863 | $859;
          $865 = $860 << $863;
          $866 = (($865) + 245760)|0;
          $867 = $866 >>> 16;
          $868 = $867 & 2;
          $869 = $864 | $868;
          $870 = (14 - ($869))|0;
          $871 = $865 << $868;
          $872 = $871 >>> 15;
          $873 = (($870) + ($872))|0;
          $874 = $873 << 1;
          $875 = (($873) + 7)|0;
          $876 = $qsize$0$i$i >>> $875;
          $877 = $876 & 1;
          $878 = $877 | $874;
          $I7$0$i$i = $878;
         }
        } while(0);
        $879 = (73488 + ($I7$0$i$i<<2)|0);
        $$sum12$i$i = (($$sum$i19$i) + 28)|0;
        $880 = (($tbase$255$i) + ($$sum12$i$i)|0);
        HEAP32[$880>>2] = $I7$0$i$i;
        $$sum13$i$i = (($$sum$i19$i) + 16)|0;
        $881 = (($tbase$255$i) + ($$sum13$i$i)|0);
        $$sum14$i$i = (($$sum$i19$i) + 20)|0;
        $882 = (($tbase$255$i) + ($$sum14$i$i)|0);
        HEAP32[$882>>2] = 0;
        HEAP32[$881>>2] = 0;
        $883 = HEAP32[(73188)>>2]|0;
        $884 = 1 << $I7$0$i$i;
        $885 = $883 & $884;
        $886 = ($885|0)==(0);
        if ($886) {
         $887 = $883 | $884;
         HEAP32[(73188)>>2] = $887;
         HEAP32[$879>>2] = $724;
         $$sum15$i$i = (($$sum$i19$i) + 24)|0;
         $888 = (($tbase$255$i) + ($$sum15$i$i)|0);
         HEAP32[$888>>2] = $879;
         $$sum16$i$i = (($$sum$i19$i) + 12)|0;
         $889 = (($tbase$255$i) + ($$sum16$i$i)|0);
         HEAP32[$889>>2] = $724;
         $$sum17$i$i = (($$sum$i19$i) + 8)|0;
         $890 = (($tbase$255$i) + ($$sum17$i$i)|0);
         HEAP32[$890>>2] = $724;
         break;
        }
        $891 = HEAP32[$879>>2]|0;
        $892 = ((($891)) + 4|0);
        $893 = HEAP32[$892>>2]|0;
        $894 = $893 & -8;
        $895 = ($894|0)==($qsize$0$i$i|0);
        L418: do {
         if ($895) {
          $T$0$lcssa$i25$i = $891;
         } else {
          $896 = ($I7$0$i$i|0)==(31);
          $897 = $I7$0$i$i >>> 1;
          $898 = (25 - ($897))|0;
          $899 = $896 ? 0 : $898;
          $900 = $qsize$0$i$i << $899;
          $K8$051$i$i = $900;$T$050$i$i = $891;
          while(1) {
           $907 = $K8$051$i$i >>> 31;
           $908 = (((($T$050$i$i)) + 16|0) + ($907<<2)|0);
           $903 = HEAP32[$908>>2]|0;
           $909 = ($903|0)==(0|0);
           if ($909) {
            $$lcssa = $908;$T$050$i$i$lcssa = $T$050$i$i;
            break;
           }
           $901 = $K8$051$i$i << 1;
           $902 = ((($903)) + 4|0);
           $904 = HEAP32[$902>>2]|0;
           $905 = $904 & -8;
           $906 = ($905|0)==($qsize$0$i$i|0);
           if ($906) {
            $T$0$lcssa$i25$i = $903;
            break L418;
           } else {
            $K8$051$i$i = $901;$T$050$i$i = $903;
           }
          }
          $910 = HEAP32[(73200)>>2]|0;
          $911 = ($$lcssa>>>0)<($910>>>0);
          if ($911) {
           _abort();
           // unreachable;
          } else {
           HEAP32[$$lcssa>>2] = $724;
           $$sum23$i$i = (($$sum$i19$i) + 24)|0;
           $912 = (($tbase$255$i) + ($$sum23$i$i)|0);
           HEAP32[$912>>2] = $T$050$i$i$lcssa;
           $$sum24$i$i = (($$sum$i19$i) + 12)|0;
           $913 = (($tbase$255$i) + ($$sum24$i$i)|0);
           HEAP32[$913>>2] = $724;
           $$sum25$i$i = (($$sum$i19$i) + 8)|0;
           $914 = (($tbase$255$i) + ($$sum25$i$i)|0);
           HEAP32[$914>>2] = $724;
           break L324;
          }
         }
        } while(0);
        $915 = ((($T$0$lcssa$i25$i)) + 8|0);
        $916 = HEAP32[$915>>2]|0;
        $917 = HEAP32[(73200)>>2]|0;
        $918 = ($916>>>0)>=($917>>>0);
        $not$$i26$i = ($T$0$lcssa$i25$i>>>0)>=($917>>>0);
        $919 = $918 & $not$$i26$i;
        if ($919) {
         $920 = ((($916)) + 12|0);
         HEAP32[$920>>2] = $724;
         HEAP32[$915>>2] = $724;
         $$sum20$i$i = (($$sum$i19$i) + 8)|0;
         $921 = (($tbase$255$i) + ($$sum20$i$i)|0);
         HEAP32[$921>>2] = $916;
         $$sum21$i$i = (($$sum$i19$i) + 12)|0;
         $922 = (($tbase$255$i) + ($$sum21$i$i)|0);
         HEAP32[$922>>2] = $T$0$lcssa$i25$i;
         $$sum22$i$i = (($$sum$i19$i) + 24)|0;
         $923 = (($tbase$255$i) + ($$sum22$i$i)|0);
         HEAP32[$923>>2] = 0;
         break;
        } else {
         _abort();
         // unreachable;
        }
       }
      } while(0);
      $$sum1819$i$i = $711 | 8;
      $924 = (($tbase$255$i) + ($$sum1819$i$i)|0);
      $mem$0 = $924;
      return ($mem$0|0);
     } else {
      $sp$0$i$i$i = (73632);
     }
    }
    while(1) {
     $925 = HEAP32[$sp$0$i$i$i>>2]|0;
     $926 = ($925>>>0)>($635>>>0);
     if (!($926)) {
      $927 = ((($sp$0$i$i$i)) + 4|0);
      $928 = HEAP32[$927>>2]|0;
      $929 = (($925) + ($928)|0);
      $930 = ($929>>>0)>($635>>>0);
      if ($930) {
       $$lcssa215 = $925;$$lcssa216 = $928;$$lcssa217 = $929;
       break;
      }
     }
     $931 = ((($sp$0$i$i$i)) + 8|0);
     $932 = HEAP32[$931>>2]|0;
     $sp$0$i$i$i = $932;
    }
    $$sum$i14$i = (($$lcssa216) + -47)|0;
    $$sum1$i15$i = (($$lcssa216) + -39)|0;
    $933 = (($$lcssa215) + ($$sum1$i15$i)|0);
    $934 = $933;
    $935 = $934 & 7;
    $936 = ($935|0)==(0);
    $937 = (0 - ($934))|0;
    $938 = $937 & 7;
    $939 = $936 ? 0 : $938;
    $$sum2$i16$i = (($$sum$i14$i) + ($939))|0;
    $940 = (($$lcssa215) + ($$sum2$i16$i)|0);
    $941 = ((($635)) + 16|0);
    $942 = ($940>>>0)<($941>>>0);
    $943 = $942 ? $635 : $940;
    $944 = ((($943)) + 8|0);
    $945 = (($tsize$254$i) + -40)|0;
    $946 = ((($tbase$255$i)) + 8|0);
    $947 = $946;
    $948 = $947 & 7;
    $949 = ($948|0)==(0);
    $950 = (0 - ($947))|0;
    $951 = $950 & 7;
    $952 = $949 ? 0 : $951;
    $953 = (($tbase$255$i) + ($952)|0);
    $954 = (($945) - ($952))|0;
    HEAP32[(73208)>>2] = $953;
    HEAP32[(73196)>>2] = $954;
    $955 = $954 | 1;
    $$sum$i$i$i = (($952) + 4)|0;
    $956 = (($tbase$255$i) + ($$sum$i$i$i)|0);
    HEAP32[$956>>2] = $955;
    $$sum2$i$i$i = (($tsize$254$i) + -36)|0;
    $957 = (($tbase$255$i) + ($$sum2$i$i$i)|0);
    HEAP32[$957>>2] = 40;
    $958 = HEAP32[(73672)>>2]|0;
    HEAP32[(73212)>>2] = $958;
    $959 = ((($943)) + 4|0);
    HEAP32[$959>>2] = 27;
    ;HEAP32[$944>>2]=HEAP32[(73632)>>2]|0;HEAP32[$944+4>>2]=HEAP32[(73632)+4>>2]|0;HEAP32[$944+8>>2]=HEAP32[(73632)+8>>2]|0;HEAP32[$944+12>>2]=HEAP32[(73632)+12>>2]|0;
    HEAP32[(73632)>>2] = $tbase$255$i;
    HEAP32[(73636)>>2] = $tsize$254$i;
    HEAP32[(73644)>>2] = 0;
    HEAP32[(73640)>>2] = $944;
    $960 = ((($943)) + 28|0);
    HEAP32[$960>>2] = 7;
    $961 = ((($943)) + 32|0);
    $962 = ($961>>>0)<($$lcssa217>>>0);
    if ($962) {
     $964 = $960;
     while(1) {
      $963 = ((($964)) + 4|0);
      HEAP32[$963>>2] = 7;
      $965 = ((($964)) + 8|0);
      $966 = ($965>>>0)<($$lcssa217>>>0);
      if ($966) {
       $964 = $963;
      } else {
       break;
      }
     }
    }
    $967 = ($943|0)==($635|0);
    if (!($967)) {
     $968 = $943;
     $969 = $635;
     $970 = (($968) - ($969))|0;
     $971 = HEAP32[$959>>2]|0;
     $972 = $971 & -2;
     HEAP32[$959>>2] = $972;
     $973 = $970 | 1;
     $974 = ((($635)) + 4|0);
     HEAP32[$974>>2] = $973;
     HEAP32[$943>>2] = $970;
     $975 = $970 >>> 3;
     $976 = ($970>>>0)<(256);
     if ($976) {
      $977 = $975 << 1;
      $978 = (73224 + ($977<<2)|0);
      $979 = HEAP32[73184>>2]|0;
      $980 = 1 << $975;
      $981 = $979 & $980;
      $982 = ($981|0)==(0);
      if ($982) {
       $983 = $979 | $980;
       HEAP32[73184>>2] = $983;
       $$pre$i$i = (($977) + 2)|0;
       $$pre14$i$i = (73224 + ($$pre$i$i<<2)|0);
       $$pre$phi$i$iZ2D = $$pre14$i$i;$F$0$i$i = $978;
      } else {
       $$sum4$i$i = (($977) + 2)|0;
       $984 = (73224 + ($$sum4$i$i<<2)|0);
       $985 = HEAP32[$984>>2]|0;
       $986 = HEAP32[(73200)>>2]|0;
       $987 = ($985>>>0)<($986>>>0);
       if ($987) {
        _abort();
        // unreachable;
       } else {
        $$pre$phi$i$iZ2D = $984;$F$0$i$i = $985;
       }
      }
      HEAP32[$$pre$phi$i$iZ2D>>2] = $635;
      $988 = ((($F$0$i$i)) + 12|0);
      HEAP32[$988>>2] = $635;
      $989 = ((($635)) + 8|0);
      HEAP32[$989>>2] = $F$0$i$i;
      $990 = ((($635)) + 12|0);
      HEAP32[$990>>2] = $978;
      break;
     }
     $991 = $970 >>> 8;
     $992 = ($991|0)==(0);
     if ($992) {
      $I1$0$i$i = 0;
     } else {
      $993 = ($970>>>0)>(16777215);
      if ($993) {
       $I1$0$i$i = 31;
      } else {
       $994 = (($991) + 1048320)|0;
       $995 = $994 >>> 16;
       $996 = $995 & 8;
       $997 = $991 << $996;
       $998 = (($997) + 520192)|0;
       $999 = $998 >>> 16;
       $1000 = $999 & 4;
       $1001 = $1000 | $996;
       $1002 = $997 << $1000;
       $1003 = (($1002) + 245760)|0;
       $1004 = $1003 >>> 16;
       $1005 = $1004 & 2;
       $1006 = $1001 | $1005;
       $1007 = (14 - ($1006))|0;
       $1008 = $1002 << $1005;
       $1009 = $1008 >>> 15;
       $1010 = (($1007) + ($1009))|0;
       $1011 = $1010 << 1;
       $1012 = (($1010) + 7)|0;
       $1013 = $970 >>> $1012;
       $1014 = $1013 & 1;
       $1015 = $1014 | $1011;
       $I1$0$i$i = $1015;
      }
     }
     $1016 = (73488 + ($I1$0$i$i<<2)|0);
     $1017 = ((($635)) + 28|0);
     HEAP32[$1017>>2] = $I1$0$i$i;
     $1018 = ((($635)) + 20|0);
     HEAP32[$1018>>2] = 0;
     HEAP32[$941>>2] = 0;
     $1019 = HEAP32[(73188)>>2]|0;
     $1020 = 1 << $I1$0$i$i;
     $1021 = $1019 & $1020;
     $1022 = ($1021|0)==(0);
     if ($1022) {
      $1023 = $1019 | $1020;
      HEAP32[(73188)>>2] = $1023;
      HEAP32[$1016>>2] = $635;
      $1024 = ((($635)) + 24|0);
      HEAP32[$1024>>2] = $1016;
      $1025 = ((($635)) + 12|0);
      HEAP32[$1025>>2] = $635;
      $1026 = ((($635)) + 8|0);
      HEAP32[$1026>>2] = $635;
      break;
     }
     $1027 = HEAP32[$1016>>2]|0;
     $1028 = ((($1027)) + 4|0);
     $1029 = HEAP32[$1028>>2]|0;
     $1030 = $1029 & -8;
     $1031 = ($1030|0)==($970|0);
     L459: do {
      if ($1031) {
       $T$0$lcssa$i$i = $1027;
      } else {
       $1032 = ($I1$0$i$i|0)==(31);
       $1033 = $I1$0$i$i >>> 1;
       $1034 = (25 - ($1033))|0;
       $1035 = $1032 ? 0 : $1034;
       $1036 = $970 << $1035;
       $K2$07$i$i = $1036;$T$06$i$i = $1027;
       while(1) {
        $1043 = $K2$07$i$i >>> 31;
        $1044 = (((($T$06$i$i)) + 16|0) + ($1043<<2)|0);
        $1039 = HEAP32[$1044>>2]|0;
        $1045 = ($1039|0)==(0|0);
        if ($1045) {
         $$lcssa211 = $1044;$T$06$i$i$lcssa = $T$06$i$i;
         break;
        }
        $1037 = $K2$07$i$i << 1;
        $1038 = ((($1039)) + 4|0);
        $1040 = HEAP32[$1038>>2]|0;
        $1041 = $1040 & -8;
        $1042 = ($1041|0)==($970|0);
        if ($1042) {
         $T$0$lcssa$i$i = $1039;
         break L459;
        } else {
         $K2$07$i$i = $1037;$T$06$i$i = $1039;
        }
       }
       $1046 = HEAP32[(73200)>>2]|0;
       $1047 = ($$lcssa211>>>0)<($1046>>>0);
       if ($1047) {
        _abort();
        // unreachable;
       } else {
        HEAP32[$$lcssa211>>2] = $635;
        $1048 = ((($635)) + 24|0);
        HEAP32[$1048>>2] = $T$06$i$i$lcssa;
        $1049 = ((($635)) + 12|0);
        HEAP32[$1049>>2] = $635;
        $1050 = ((($635)) + 8|0);
        HEAP32[$1050>>2] = $635;
        break L299;
       }
      }
     } while(0);
     $1051 = ((($T$0$lcssa$i$i)) + 8|0);
     $1052 = HEAP32[$1051>>2]|0;
     $1053 = HEAP32[(73200)>>2]|0;
     $1054 = ($1052>>>0)>=($1053>>>0);
     $not$$i$i = ($T$0$lcssa$i$i>>>0)>=($1053>>>0);
     $1055 = $1054 & $not$$i$i;
     if ($1055) {
      $1056 = ((($1052)) + 12|0);
      HEAP32[$1056>>2] = $635;
      HEAP32[$1051>>2] = $635;
      $1057 = ((($635)) + 8|0);
      HEAP32[$1057>>2] = $1052;
      $1058 = ((($635)) + 12|0);
      HEAP32[$1058>>2] = $T$0$lcssa$i$i;
      $1059 = ((($635)) + 24|0);
      HEAP32[$1059>>2] = 0;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   }
  } while(0);
  $1060 = HEAP32[(73196)>>2]|0;
  $1061 = ($1060>>>0)>($nb$0>>>0);
  if ($1061) {
   $1062 = (($1060) - ($nb$0))|0;
   HEAP32[(73196)>>2] = $1062;
   $1063 = HEAP32[(73208)>>2]|0;
   $1064 = (($1063) + ($nb$0)|0);
   HEAP32[(73208)>>2] = $1064;
   $1065 = $1062 | 1;
   $$sum$i32 = (($nb$0) + 4)|0;
   $1066 = (($1063) + ($$sum$i32)|0);
   HEAP32[$1066>>2] = $1065;
   $1067 = $nb$0 | 3;
   $1068 = ((($1063)) + 4|0);
   HEAP32[$1068>>2] = $1067;
   $1069 = ((($1063)) + 8|0);
   $mem$0 = $1069;
   return ($mem$0|0);
  }
 }
 $1070 = (___errno_location()|0);
 HEAP32[$1070>>2] = 12;
 $mem$0 = 0;
 return ($mem$0|0);
}
function _free($mem) {
 $mem = $mem|0;
 var $$lcssa = 0, $$pre = 0, $$pre$phi59Z2D = 0, $$pre$phi61Z2D = 0, $$pre$phiZ2D = 0, $$pre57 = 0, $$pre58 = 0, $$pre60 = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum1718 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0;
 var $$sum25 = 0, $$sum26 = 0, $$sum27 = 0, $$sum28 = 0, $$sum29 = 0, $$sum3 = 0, $$sum30 = 0, $$sum31 = 0, $$sum5 = 0, $$sum67 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0;
 var $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0;
 var $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0;
 var $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0;
 var $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0, $175 = 0, $176 = 0, $177 = 0;
 var $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0, $193 = 0, $194 = 0, $195 = 0;
 var $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0, $210 = 0, $211 = 0, $212 = 0;
 var $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0, $229 = 0, $23 = 0, $230 = 0;
 var $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0, $247 = 0, $248 = 0, $249 = 0;
 var $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0, $265 = 0, $266 = 0, $267 = 0;
 var $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0, $283 = 0, $284 = 0, $285 = 0;
 var $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0, $300 = 0, $301 = 0, $302 = 0;
 var $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $308 = 0, $309 = 0, $31 = 0, $310 = 0, $311 = 0, $312 = 0, $313 = 0, $314 = 0, $315 = 0, $316 = 0, $317 = 0, $318 = 0, $319 = 0, $32 = 0, $320 = 0;
 var $321 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0;
 var $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0;
 var $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0;
 var $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I18$0 = 0, $K19$052 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0;
 var $R7$0 = 0, $R7$0$lcssa = 0, $R7$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $RP9$0 = 0, $RP9$0$lcssa = 0, $T$0$lcssa = 0, $T$051 = 0, $T$051$lcssa = 0, $cond = 0, $cond47 = 0, $not$ = 0, $p$0 = 0, $psize$0 = 0, $psize$1 = 0, $sp$0$i = 0, $sp$0$in$i = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($mem|0)==(0|0);
 if ($0) {
  return;
 }
 $1 = ((($mem)) + -8|0);
 $2 = HEAP32[(73200)>>2]|0;
 $3 = ($1>>>0)<($2>>>0);
 if ($3) {
  _abort();
  // unreachable;
 }
 $4 = ((($mem)) + -4|0);
 $5 = HEAP32[$4>>2]|0;
 $6 = $5 & 3;
 $7 = ($6|0)==(1);
 if ($7) {
  _abort();
  // unreachable;
 }
 $8 = $5 & -8;
 $$sum = (($8) + -8)|0;
 $9 = (($mem) + ($$sum)|0);
 $10 = $5 & 1;
 $11 = ($10|0)==(0);
 do {
  if ($11) {
   $12 = HEAP32[$1>>2]|0;
   $13 = ($6|0)==(0);
   if ($13) {
    return;
   }
   $$sum2 = (-8 - ($12))|0;
   $14 = (($mem) + ($$sum2)|0);
   $15 = (($12) + ($8))|0;
   $16 = ($14>>>0)<($2>>>0);
   if ($16) {
    _abort();
    // unreachable;
   }
   $17 = HEAP32[(73204)>>2]|0;
   $18 = ($14|0)==($17|0);
   if ($18) {
    $$sum3 = (($8) + -4)|0;
    $103 = (($mem) + ($$sum3)|0);
    $104 = HEAP32[$103>>2]|0;
    $105 = $104 & 3;
    $106 = ($105|0)==(3);
    if (!($106)) {
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    HEAP32[(73192)>>2] = $15;
    $107 = $104 & -2;
    HEAP32[$103>>2] = $107;
    $108 = $15 | 1;
    $$sum20 = (($$sum2) + 4)|0;
    $109 = (($mem) + ($$sum20)|0);
    HEAP32[$109>>2] = $108;
    HEAP32[$9>>2] = $15;
    return;
   }
   $19 = $12 >>> 3;
   $20 = ($12>>>0)<(256);
   if ($20) {
    $$sum30 = (($$sum2) + 8)|0;
    $21 = (($mem) + ($$sum30)|0);
    $22 = HEAP32[$21>>2]|0;
    $$sum31 = (($$sum2) + 12)|0;
    $23 = (($mem) + ($$sum31)|0);
    $24 = HEAP32[$23>>2]|0;
    $25 = $19 << 1;
    $26 = (73224 + ($25<<2)|0);
    $27 = ($22|0)==($26|0);
    if (!($27)) {
     $28 = ($22>>>0)<($2>>>0);
     if ($28) {
      _abort();
      // unreachable;
     }
     $29 = ((($22)) + 12|0);
     $30 = HEAP32[$29>>2]|0;
     $31 = ($30|0)==($14|0);
     if (!($31)) {
      _abort();
      // unreachable;
     }
    }
    $32 = ($24|0)==($22|0);
    if ($32) {
     $33 = 1 << $19;
     $34 = $33 ^ -1;
     $35 = HEAP32[73184>>2]|0;
     $36 = $35 & $34;
     HEAP32[73184>>2] = $36;
     $p$0 = $14;$psize$0 = $15;
     break;
    }
    $37 = ($24|0)==($26|0);
    if ($37) {
     $$pre60 = ((($24)) + 8|0);
     $$pre$phi61Z2D = $$pre60;
    } else {
     $38 = ($24>>>0)<($2>>>0);
     if ($38) {
      _abort();
      // unreachable;
     }
     $39 = ((($24)) + 8|0);
     $40 = HEAP32[$39>>2]|0;
     $41 = ($40|0)==($14|0);
     if ($41) {
      $$pre$phi61Z2D = $39;
     } else {
      _abort();
      // unreachable;
     }
    }
    $42 = ((($22)) + 12|0);
    HEAP32[$42>>2] = $24;
    HEAP32[$$pre$phi61Z2D>>2] = $22;
    $p$0 = $14;$psize$0 = $15;
    break;
   }
   $$sum22 = (($$sum2) + 24)|0;
   $43 = (($mem) + ($$sum22)|0);
   $44 = HEAP32[$43>>2]|0;
   $$sum23 = (($$sum2) + 12)|0;
   $45 = (($mem) + ($$sum23)|0);
   $46 = HEAP32[$45>>2]|0;
   $47 = ($46|0)==($14|0);
   do {
    if ($47) {
     $$sum25 = (($$sum2) + 20)|0;
     $57 = (($mem) + ($$sum25)|0);
     $58 = HEAP32[$57>>2]|0;
     $59 = ($58|0)==(0|0);
     if ($59) {
      $$sum24 = (($$sum2) + 16)|0;
      $60 = (($mem) + ($$sum24)|0);
      $61 = HEAP32[$60>>2]|0;
      $62 = ($61|0)==(0|0);
      if ($62) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $61;$RP$0 = $60;
      }
     } else {
      $R$0 = $58;$RP$0 = $57;
     }
     while(1) {
      $63 = ((($R$0)) + 20|0);
      $64 = HEAP32[$63>>2]|0;
      $65 = ($64|0)==(0|0);
      if (!($65)) {
       $R$0 = $64;$RP$0 = $63;
       continue;
      }
      $66 = ((($R$0)) + 16|0);
      $67 = HEAP32[$66>>2]|0;
      $68 = ($67|0)==(0|0);
      if ($68) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $67;$RP$0 = $66;
      }
     }
     $69 = ($RP$0$lcssa>>>0)<($2>>>0);
     if ($69) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum29 = (($$sum2) + 8)|0;
     $48 = (($mem) + ($$sum29)|0);
     $49 = HEAP32[$48>>2]|0;
     $50 = ($49>>>0)<($2>>>0);
     if ($50) {
      _abort();
      // unreachable;
     }
     $51 = ((($49)) + 12|0);
     $52 = HEAP32[$51>>2]|0;
     $53 = ($52|0)==($14|0);
     if (!($53)) {
      _abort();
      // unreachable;
     }
     $54 = ((($46)) + 8|0);
     $55 = HEAP32[$54>>2]|0;
     $56 = ($55|0)==($14|0);
     if ($56) {
      HEAP32[$51>>2] = $46;
      HEAP32[$54>>2] = $49;
      $R$1 = $46;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $70 = ($44|0)==(0|0);
   if ($70) {
    $p$0 = $14;$psize$0 = $15;
   } else {
    $$sum26 = (($$sum2) + 28)|0;
    $71 = (($mem) + ($$sum26)|0);
    $72 = HEAP32[$71>>2]|0;
    $73 = (73488 + ($72<<2)|0);
    $74 = HEAP32[$73>>2]|0;
    $75 = ($14|0)==($74|0);
    if ($75) {
     HEAP32[$73>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $76 = 1 << $72;
      $77 = $76 ^ -1;
      $78 = HEAP32[(73188)>>2]|0;
      $79 = $78 & $77;
      HEAP32[(73188)>>2] = $79;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    } else {
     $80 = HEAP32[(73200)>>2]|0;
     $81 = ($44>>>0)<($80>>>0);
     if ($81) {
      _abort();
      // unreachable;
     }
     $82 = ((($44)) + 16|0);
     $83 = HEAP32[$82>>2]|0;
     $84 = ($83|0)==($14|0);
     if ($84) {
      HEAP32[$82>>2] = $R$1;
     } else {
      $85 = ((($44)) + 20|0);
      HEAP32[$85>>2] = $R$1;
     }
     $86 = ($R$1|0)==(0|0);
     if ($86) {
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
    $87 = HEAP32[(73200)>>2]|0;
    $88 = ($R$1>>>0)<($87>>>0);
    if ($88) {
     _abort();
     // unreachable;
    }
    $89 = ((($R$1)) + 24|0);
    HEAP32[$89>>2] = $44;
    $$sum27 = (($$sum2) + 16)|0;
    $90 = (($mem) + ($$sum27)|0);
    $91 = HEAP32[$90>>2]|0;
    $92 = ($91|0)==(0|0);
    do {
     if (!($92)) {
      $93 = ($91>>>0)<($87>>>0);
      if ($93) {
       _abort();
       // unreachable;
      } else {
       $94 = ((($R$1)) + 16|0);
       HEAP32[$94>>2] = $91;
       $95 = ((($91)) + 24|0);
       HEAP32[$95>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum28 = (($$sum2) + 20)|0;
    $96 = (($mem) + ($$sum28)|0);
    $97 = HEAP32[$96>>2]|0;
    $98 = ($97|0)==(0|0);
    if ($98) {
     $p$0 = $14;$psize$0 = $15;
    } else {
     $99 = HEAP32[(73200)>>2]|0;
     $100 = ($97>>>0)<($99>>>0);
     if ($100) {
      _abort();
      // unreachable;
     } else {
      $101 = ((($R$1)) + 20|0);
      HEAP32[$101>>2] = $97;
      $102 = ((($97)) + 24|0);
      HEAP32[$102>>2] = $R$1;
      $p$0 = $14;$psize$0 = $15;
      break;
     }
    }
   }
  } else {
   $p$0 = $1;$psize$0 = $8;
  }
 } while(0);
 $110 = ($p$0>>>0)<($9>>>0);
 if (!($110)) {
  _abort();
  // unreachable;
 }
 $$sum19 = (($8) + -4)|0;
 $111 = (($mem) + ($$sum19)|0);
 $112 = HEAP32[$111>>2]|0;
 $113 = $112 & 1;
 $114 = ($113|0)==(0);
 if ($114) {
  _abort();
  // unreachable;
 }
 $115 = $112 & 2;
 $116 = ($115|0)==(0);
 if ($116) {
  $117 = HEAP32[(73208)>>2]|0;
  $118 = ($9|0)==($117|0);
  if ($118) {
   $119 = HEAP32[(73196)>>2]|0;
   $120 = (($119) + ($psize$0))|0;
   HEAP32[(73196)>>2] = $120;
   HEAP32[(73208)>>2] = $p$0;
   $121 = $120 | 1;
   $122 = ((($p$0)) + 4|0);
   HEAP32[$122>>2] = $121;
   $123 = HEAP32[(73204)>>2]|0;
   $124 = ($p$0|0)==($123|0);
   if (!($124)) {
    return;
   }
   HEAP32[(73204)>>2] = 0;
   HEAP32[(73192)>>2] = 0;
   return;
  }
  $125 = HEAP32[(73204)>>2]|0;
  $126 = ($9|0)==($125|0);
  if ($126) {
   $127 = HEAP32[(73192)>>2]|0;
   $128 = (($127) + ($psize$0))|0;
   HEAP32[(73192)>>2] = $128;
   HEAP32[(73204)>>2] = $p$0;
   $129 = $128 | 1;
   $130 = ((($p$0)) + 4|0);
   HEAP32[$130>>2] = $129;
   $131 = (($p$0) + ($128)|0);
   HEAP32[$131>>2] = $128;
   return;
  }
  $132 = $112 & -8;
  $133 = (($132) + ($psize$0))|0;
  $134 = $112 >>> 3;
  $135 = ($112>>>0)<(256);
  do {
   if ($135) {
    $136 = (($mem) + ($8)|0);
    $137 = HEAP32[$136>>2]|0;
    $$sum1718 = $8 | 4;
    $138 = (($mem) + ($$sum1718)|0);
    $139 = HEAP32[$138>>2]|0;
    $140 = $134 << 1;
    $141 = (73224 + ($140<<2)|0);
    $142 = ($137|0)==($141|0);
    if (!($142)) {
     $143 = HEAP32[(73200)>>2]|0;
     $144 = ($137>>>0)<($143>>>0);
     if ($144) {
      _abort();
      // unreachable;
     }
     $145 = ((($137)) + 12|0);
     $146 = HEAP32[$145>>2]|0;
     $147 = ($146|0)==($9|0);
     if (!($147)) {
      _abort();
      // unreachable;
     }
    }
    $148 = ($139|0)==($137|0);
    if ($148) {
     $149 = 1 << $134;
     $150 = $149 ^ -1;
     $151 = HEAP32[73184>>2]|0;
     $152 = $151 & $150;
     HEAP32[73184>>2] = $152;
     break;
    }
    $153 = ($139|0)==($141|0);
    if ($153) {
     $$pre58 = ((($139)) + 8|0);
     $$pre$phi59Z2D = $$pre58;
    } else {
     $154 = HEAP32[(73200)>>2]|0;
     $155 = ($139>>>0)<($154>>>0);
     if ($155) {
      _abort();
      // unreachable;
     }
     $156 = ((($139)) + 8|0);
     $157 = HEAP32[$156>>2]|0;
     $158 = ($157|0)==($9|0);
     if ($158) {
      $$pre$phi59Z2D = $156;
     } else {
      _abort();
      // unreachable;
     }
    }
    $159 = ((($137)) + 12|0);
    HEAP32[$159>>2] = $139;
    HEAP32[$$pre$phi59Z2D>>2] = $137;
   } else {
    $$sum5 = (($8) + 16)|0;
    $160 = (($mem) + ($$sum5)|0);
    $161 = HEAP32[$160>>2]|0;
    $$sum67 = $8 | 4;
    $162 = (($mem) + ($$sum67)|0);
    $163 = HEAP32[$162>>2]|0;
    $164 = ($163|0)==($9|0);
    do {
     if ($164) {
      $$sum9 = (($8) + 12)|0;
      $175 = (($mem) + ($$sum9)|0);
      $176 = HEAP32[$175>>2]|0;
      $177 = ($176|0)==(0|0);
      if ($177) {
       $$sum8 = (($8) + 8)|0;
       $178 = (($mem) + ($$sum8)|0);
       $179 = HEAP32[$178>>2]|0;
       $180 = ($179|0)==(0|0);
       if ($180) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $179;$RP9$0 = $178;
       }
      } else {
       $R7$0 = $176;$RP9$0 = $175;
      }
      while(1) {
       $181 = ((($R7$0)) + 20|0);
       $182 = HEAP32[$181>>2]|0;
       $183 = ($182|0)==(0|0);
       if (!($183)) {
        $R7$0 = $182;$RP9$0 = $181;
        continue;
       }
       $184 = ((($R7$0)) + 16|0);
       $185 = HEAP32[$184>>2]|0;
       $186 = ($185|0)==(0|0);
       if ($186) {
        $R7$0$lcssa = $R7$0;$RP9$0$lcssa = $RP9$0;
        break;
       } else {
        $R7$0 = $185;$RP9$0 = $184;
       }
      }
      $187 = HEAP32[(73200)>>2]|0;
      $188 = ($RP9$0$lcssa>>>0)<($187>>>0);
      if ($188) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0$lcssa>>2] = 0;
       $R7$1 = $R7$0$lcssa;
       break;
      }
     } else {
      $165 = (($mem) + ($8)|0);
      $166 = HEAP32[$165>>2]|0;
      $167 = HEAP32[(73200)>>2]|0;
      $168 = ($166>>>0)<($167>>>0);
      if ($168) {
       _abort();
       // unreachable;
      }
      $169 = ((($166)) + 12|0);
      $170 = HEAP32[$169>>2]|0;
      $171 = ($170|0)==($9|0);
      if (!($171)) {
       _abort();
       // unreachable;
      }
      $172 = ((($163)) + 8|0);
      $173 = HEAP32[$172>>2]|0;
      $174 = ($173|0)==($9|0);
      if ($174) {
       HEAP32[$169>>2] = $163;
       HEAP32[$172>>2] = $166;
       $R7$1 = $163;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $189 = ($161|0)==(0|0);
    if (!($189)) {
     $$sum12 = (($8) + 20)|0;
     $190 = (($mem) + ($$sum12)|0);
     $191 = HEAP32[$190>>2]|0;
     $192 = (73488 + ($191<<2)|0);
     $193 = HEAP32[$192>>2]|0;
     $194 = ($9|0)==($193|0);
     if ($194) {
      HEAP32[$192>>2] = $R7$1;
      $cond47 = ($R7$1|0)==(0|0);
      if ($cond47) {
       $195 = 1 << $191;
       $196 = $195 ^ -1;
       $197 = HEAP32[(73188)>>2]|0;
       $198 = $197 & $196;
       HEAP32[(73188)>>2] = $198;
       break;
      }
     } else {
      $199 = HEAP32[(73200)>>2]|0;
      $200 = ($161>>>0)<($199>>>0);
      if ($200) {
       _abort();
       // unreachable;
      }
      $201 = ((($161)) + 16|0);
      $202 = HEAP32[$201>>2]|0;
      $203 = ($202|0)==($9|0);
      if ($203) {
       HEAP32[$201>>2] = $R7$1;
      } else {
       $204 = ((($161)) + 20|0);
       HEAP32[$204>>2] = $R7$1;
      }
      $205 = ($R7$1|0)==(0|0);
      if ($205) {
       break;
      }
     }
     $206 = HEAP32[(73200)>>2]|0;
     $207 = ($R7$1>>>0)<($206>>>0);
     if ($207) {
      _abort();
      // unreachable;
     }
     $208 = ((($R7$1)) + 24|0);
     HEAP32[$208>>2] = $161;
     $$sum13 = (($8) + 8)|0;
     $209 = (($mem) + ($$sum13)|0);
     $210 = HEAP32[$209>>2]|0;
     $211 = ($210|0)==(0|0);
     do {
      if (!($211)) {
       $212 = ($210>>>0)<($206>>>0);
       if ($212) {
        _abort();
        // unreachable;
       } else {
        $213 = ((($R7$1)) + 16|0);
        HEAP32[$213>>2] = $210;
        $214 = ((($210)) + 24|0);
        HEAP32[$214>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum14 = (($8) + 12)|0;
     $215 = (($mem) + ($$sum14)|0);
     $216 = HEAP32[$215>>2]|0;
     $217 = ($216|0)==(0|0);
     if (!($217)) {
      $218 = HEAP32[(73200)>>2]|0;
      $219 = ($216>>>0)<($218>>>0);
      if ($219) {
       _abort();
       // unreachable;
      } else {
       $220 = ((($R7$1)) + 20|0);
       HEAP32[$220>>2] = $216;
       $221 = ((($216)) + 24|0);
       HEAP32[$221>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $222 = $133 | 1;
  $223 = ((($p$0)) + 4|0);
  HEAP32[$223>>2] = $222;
  $224 = (($p$0) + ($133)|0);
  HEAP32[$224>>2] = $133;
  $225 = HEAP32[(73204)>>2]|0;
  $226 = ($p$0|0)==($225|0);
  if ($226) {
   HEAP32[(73192)>>2] = $133;
   return;
  } else {
   $psize$1 = $133;
  }
 } else {
  $227 = $112 & -2;
  HEAP32[$111>>2] = $227;
  $228 = $psize$0 | 1;
  $229 = ((($p$0)) + 4|0);
  HEAP32[$229>>2] = $228;
  $230 = (($p$0) + ($psize$0)|0);
  HEAP32[$230>>2] = $psize$0;
  $psize$1 = $psize$0;
 }
 $231 = $psize$1 >>> 3;
 $232 = ($psize$1>>>0)<(256);
 if ($232) {
  $233 = $231 << 1;
  $234 = (73224 + ($233<<2)|0);
  $235 = HEAP32[73184>>2]|0;
  $236 = 1 << $231;
  $237 = $235 & $236;
  $238 = ($237|0)==(0);
  if ($238) {
   $239 = $235 | $236;
   HEAP32[73184>>2] = $239;
   $$pre = (($233) + 2)|0;
   $$pre57 = (73224 + ($$pre<<2)|0);
   $$pre$phiZ2D = $$pre57;$F16$0 = $234;
  } else {
   $$sum11 = (($233) + 2)|0;
   $240 = (73224 + ($$sum11<<2)|0);
   $241 = HEAP32[$240>>2]|0;
   $242 = HEAP32[(73200)>>2]|0;
   $243 = ($241>>>0)<($242>>>0);
   if ($243) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $240;$F16$0 = $241;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $p$0;
  $244 = ((($F16$0)) + 12|0);
  HEAP32[$244>>2] = $p$0;
  $245 = ((($p$0)) + 8|0);
  HEAP32[$245>>2] = $F16$0;
  $246 = ((($p$0)) + 12|0);
  HEAP32[$246>>2] = $234;
  return;
 }
 $247 = $psize$1 >>> 8;
 $248 = ($247|0)==(0);
 if ($248) {
  $I18$0 = 0;
 } else {
  $249 = ($psize$1>>>0)>(16777215);
  if ($249) {
   $I18$0 = 31;
  } else {
   $250 = (($247) + 1048320)|0;
   $251 = $250 >>> 16;
   $252 = $251 & 8;
   $253 = $247 << $252;
   $254 = (($253) + 520192)|0;
   $255 = $254 >>> 16;
   $256 = $255 & 4;
   $257 = $256 | $252;
   $258 = $253 << $256;
   $259 = (($258) + 245760)|0;
   $260 = $259 >>> 16;
   $261 = $260 & 2;
   $262 = $257 | $261;
   $263 = (14 - ($262))|0;
   $264 = $258 << $261;
   $265 = $264 >>> 15;
   $266 = (($263) + ($265))|0;
   $267 = $266 << 1;
   $268 = (($266) + 7)|0;
   $269 = $psize$1 >>> $268;
   $270 = $269 & 1;
   $271 = $270 | $267;
   $I18$0 = $271;
  }
 }
 $272 = (73488 + ($I18$0<<2)|0);
 $273 = ((($p$0)) + 28|0);
 HEAP32[$273>>2] = $I18$0;
 $274 = ((($p$0)) + 16|0);
 $275 = ((($p$0)) + 20|0);
 HEAP32[$275>>2] = 0;
 HEAP32[$274>>2] = 0;
 $276 = HEAP32[(73188)>>2]|0;
 $277 = 1 << $I18$0;
 $278 = $276 & $277;
 $279 = ($278|0)==(0);
 L199: do {
  if ($279) {
   $280 = $276 | $277;
   HEAP32[(73188)>>2] = $280;
   HEAP32[$272>>2] = $p$0;
   $281 = ((($p$0)) + 24|0);
   HEAP32[$281>>2] = $272;
   $282 = ((($p$0)) + 12|0);
   HEAP32[$282>>2] = $p$0;
   $283 = ((($p$0)) + 8|0);
   HEAP32[$283>>2] = $p$0;
  } else {
   $284 = HEAP32[$272>>2]|0;
   $285 = ((($284)) + 4|0);
   $286 = HEAP32[$285>>2]|0;
   $287 = $286 & -8;
   $288 = ($287|0)==($psize$1|0);
   L202: do {
    if ($288) {
     $T$0$lcssa = $284;
    } else {
     $289 = ($I18$0|0)==(31);
     $290 = $I18$0 >>> 1;
     $291 = (25 - ($290))|0;
     $292 = $289 ? 0 : $291;
     $293 = $psize$1 << $292;
     $K19$052 = $293;$T$051 = $284;
     while(1) {
      $300 = $K19$052 >>> 31;
      $301 = (((($T$051)) + 16|0) + ($300<<2)|0);
      $296 = HEAP32[$301>>2]|0;
      $302 = ($296|0)==(0|0);
      if ($302) {
       $$lcssa = $301;$T$051$lcssa = $T$051;
       break;
      }
      $294 = $K19$052 << 1;
      $295 = ((($296)) + 4|0);
      $297 = HEAP32[$295>>2]|0;
      $298 = $297 & -8;
      $299 = ($298|0)==($psize$1|0);
      if ($299) {
       $T$0$lcssa = $296;
       break L202;
      } else {
       $K19$052 = $294;$T$051 = $296;
      }
     }
     $303 = HEAP32[(73200)>>2]|0;
     $304 = ($$lcssa>>>0)<($303>>>0);
     if ($304) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$$lcssa>>2] = $p$0;
      $305 = ((($p$0)) + 24|0);
      HEAP32[$305>>2] = $T$051$lcssa;
      $306 = ((($p$0)) + 12|0);
      HEAP32[$306>>2] = $p$0;
      $307 = ((($p$0)) + 8|0);
      HEAP32[$307>>2] = $p$0;
      break L199;
     }
    }
   } while(0);
   $308 = ((($T$0$lcssa)) + 8|0);
   $309 = HEAP32[$308>>2]|0;
   $310 = HEAP32[(73200)>>2]|0;
   $311 = ($309>>>0)>=($310>>>0);
   $not$ = ($T$0$lcssa>>>0)>=($310>>>0);
   $312 = $311 & $not$;
   if ($312) {
    $313 = ((($309)) + 12|0);
    HEAP32[$313>>2] = $p$0;
    HEAP32[$308>>2] = $p$0;
    $314 = ((($p$0)) + 8|0);
    HEAP32[$314>>2] = $309;
    $315 = ((($p$0)) + 12|0);
    HEAP32[$315>>2] = $T$0$lcssa;
    $316 = ((($p$0)) + 24|0);
    HEAP32[$316>>2] = 0;
    break;
   } else {
    _abort();
    // unreachable;
   }
  }
 } while(0);
 $317 = HEAP32[(73216)>>2]|0;
 $318 = (($317) + -1)|0;
 HEAP32[(73216)>>2] = $318;
 $319 = ($318|0)==(0);
 if ($319) {
  $sp$0$in$i = (73640);
 } else {
  return;
 }
 while(1) {
  $sp$0$i = HEAP32[$sp$0$in$i>>2]|0;
  $320 = ($sp$0$i|0)==(0|0);
  $321 = ((($sp$0$i)) + 8|0);
  if ($320) {
   break;
  } else {
   $sp$0$in$i = $321;
  }
 }
 HEAP32[(73216)>>2] = -1;
 return;
}
function _calloc($n_elements,$elem_size) {
 $n_elements = $n_elements|0;
 $elem_size = $elem_size|0;
 var $$ = 0, $0 = 0, $1 = 0, $10 = 0, $11 = 0, $2 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0, $7 = 0, $8 = 0, $9 = 0, $req$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($n_elements|0)==(0);
 if ($0) {
  $req$0 = 0;
 } else {
  $1 = Math_imul($elem_size, $n_elements)|0;
  $2 = $elem_size | $n_elements;
  $3 = ($2>>>0)>(65535);
  if ($3) {
   $4 = (($1>>>0) / ($n_elements>>>0))&-1;
   $5 = ($4|0)==($elem_size|0);
   $$ = $5 ? $1 : -1;
   $req$0 = $$;
  } else {
   $req$0 = $1;
  }
 }
 $6 = (_malloc($req$0)|0);
 $7 = ($6|0)==(0|0);
 if ($7) {
  return ($6|0);
 }
 $8 = ((($6)) + -4|0);
 $9 = HEAP32[$8>>2]|0;
 $10 = $9 & 3;
 $11 = ($10|0)==(0);
 if ($11) {
  return ($6|0);
 }
 _memset(($6|0),0,($req$0|0))|0;
 return ($6|0);
}
function _realloc($oldmem,$bytes) {
 $oldmem = $oldmem|0;
 $bytes = $bytes|0;
 var $0 = 0, $1 = 0, $10 = 0, $11 = 0, $12 = 0, $13 = 0, $14 = 0, $15 = 0, $16 = 0, $17 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $3 = 0, $4 = 0, $5 = 0, $6 = 0;
 var $7 = 0, $8 = 0, $9 = 0, $mem$0 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ($oldmem|0)==(0|0);
 if ($0) {
  $1 = (_malloc($bytes)|0);
  $mem$0 = $1;
  return ($mem$0|0);
 }
 $2 = ($bytes>>>0)>(4294967231);
 if ($2) {
  $3 = (___errno_location()|0);
  HEAP32[$3>>2] = 12;
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $4 = ($bytes>>>0)<(11);
 $5 = (($bytes) + 11)|0;
 $6 = $5 & -8;
 $7 = $4 ? 16 : $6;
 $8 = ((($oldmem)) + -8|0);
 $9 = (_try_realloc_chunk($8,$7)|0);
 $10 = ($9|0)==(0|0);
 if (!($10)) {
  $11 = ((($9)) + 8|0);
  $mem$0 = $11;
  return ($mem$0|0);
 }
 $12 = (_malloc($bytes)|0);
 $13 = ($12|0)==(0|0);
 if ($13) {
  $mem$0 = 0;
  return ($mem$0|0);
 }
 $14 = ((($oldmem)) + -4|0);
 $15 = HEAP32[$14>>2]|0;
 $16 = $15 & -8;
 $17 = $15 & 3;
 $18 = ($17|0)==(0);
 $19 = $18 ? 8 : 4;
 $20 = (($16) - ($19))|0;
 $21 = ($20>>>0)<($bytes>>>0);
 $22 = $21 ? $20 : $bytes;
 _memcpy(($12|0),($oldmem|0),($22|0))|0;
 _free($oldmem);
 $mem$0 = $12;
 return ($mem$0|0);
}
function _try_realloc_chunk($p,$nb) {
 $p = $p|0;
 $nb = $nb|0;
 var $$pre = 0, $$pre$phiZ2D = 0, $$sum = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum15 = 0, $$sum16 = 0, $$sum17 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum22 = 0, $$sum23 = 0, $$sum2728 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum78 = 0;
 var $$sum910 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0, $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0;
 var $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0, $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0;
 var $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0, $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0;
 var $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0, $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0;
 var $17 = 0, $170 = 0, $18 = 0, $19 = 0, $2 = 0, $20 = 0, $21 = 0, $22 = 0, $23 = 0, $24 = 0, $25 = 0, $26 = 0, $27 = 0, $28 = 0, $29 = 0, $3 = 0, $30 = 0, $31 = 0, $32 = 0, $33 = 0;
 var $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0, $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0;
 var $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0, $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0;
 var $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0, $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0;
 var $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0, $97 = 0, $98 = 0, $99 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $cond = 0, $newp$0 = 0, $notlhs = 0;
 var $notrhs = 0, $or$cond$not = 0, $or$cond30 = 0, $storemerge = 0, $storemerge21 = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = ((($p)) + 4|0);
 $1 = HEAP32[$0>>2]|0;
 $2 = $1 & -8;
 $3 = (($p) + ($2)|0);
 $4 = HEAP32[(73200)>>2]|0;
 $5 = $1 & 3;
 $notlhs = ($p>>>0)>=($4>>>0);
 $notrhs = ($5|0)!=(1);
 $or$cond$not = $notrhs & $notlhs;
 $6 = ($p>>>0)<($3>>>0);
 $or$cond30 = $or$cond$not & $6;
 if (!($or$cond30)) {
  _abort();
  // unreachable;
 }
 $$sum2728 = $2 | 4;
 $7 = (($p) + ($$sum2728)|0);
 $8 = HEAP32[$7>>2]|0;
 $9 = $8 & 1;
 $10 = ($9|0)==(0);
 if ($10) {
  _abort();
  // unreachable;
 }
 $11 = ($5|0)==(0);
 if ($11) {
  $12 = ($nb>>>0)<(256);
  if ($12) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $13 = (($nb) + 4)|0;
  $14 = ($2>>>0)<($13>>>0);
  if (!($14)) {
   $15 = (($2) - ($nb))|0;
   $16 = HEAP32[(73664)>>2]|0;
   $17 = $16 << 1;
   $18 = ($15>>>0)>($17>>>0);
   if (!($18)) {
    $newp$0 = $p;
    return ($newp$0|0);
   }
  }
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $19 = ($2>>>0)<($nb>>>0);
 if (!($19)) {
  $20 = (($2) - ($nb))|0;
  $21 = ($20>>>0)>(15);
  if (!($21)) {
   $newp$0 = $p;
   return ($newp$0|0);
  }
  $22 = (($p) + ($nb)|0);
  $23 = $1 & 1;
  $24 = $23 | $nb;
  $25 = $24 | 2;
  HEAP32[$0>>2] = $25;
  $$sum23 = (($nb) + 4)|0;
  $26 = (($p) + ($$sum23)|0);
  $27 = $20 | 3;
  HEAP32[$26>>2] = $27;
  $28 = HEAP32[$7>>2]|0;
  $29 = $28 | 1;
  HEAP32[$7>>2] = $29;
  _dispose_chunk($22,$20);
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $30 = HEAP32[(73208)>>2]|0;
 $31 = ($3|0)==($30|0);
 if ($31) {
  $32 = HEAP32[(73196)>>2]|0;
  $33 = (($32) + ($2))|0;
  $34 = ($33>>>0)>($nb>>>0);
  if (!($34)) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $35 = (($33) - ($nb))|0;
  $36 = (($p) + ($nb)|0);
  $37 = $1 & 1;
  $38 = $37 | $nb;
  $39 = $38 | 2;
  HEAP32[$0>>2] = $39;
  $$sum22 = (($nb) + 4)|0;
  $40 = (($p) + ($$sum22)|0);
  $41 = $35 | 1;
  HEAP32[$40>>2] = $41;
  HEAP32[(73208)>>2] = $36;
  HEAP32[(73196)>>2] = $35;
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $42 = HEAP32[(73204)>>2]|0;
 $43 = ($3|0)==($42|0);
 if ($43) {
  $44 = HEAP32[(73192)>>2]|0;
  $45 = (($44) + ($2))|0;
  $46 = ($45>>>0)<($nb>>>0);
  if ($46) {
   $newp$0 = 0;
   return ($newp$0|0);
  }
  $47 = (($45) - ($nb))|0;
  $48 = ($47>>>0)>(15);
  if ($48) {
   $49 = (($p) + ($nb)|0);
   $50 = (($p) + ($45)|0);
   $51 = $1 & 1;
   $52 = $51 | $nb;
   $53 = $52 | 2;
   HEAP32[$0>>2] = $53;
   $$sum19 = (($nb) + 4)|0;
   $54 = (($p) + ($$sum19)|0);
   $55 = $47 | 1;
   HEAP32[$54>>2] = $55;
   HEAP32[$50>>2] = $47;
   $$sum20 = (($45) + 4)|0;
   $56 = (($p) + ($$sum20)|0);
   $57 = HEAP32[$56>>2]|0;
   $58 = $57 & -2;
   HEAP32[$56>>2] = $58;
   $storemerge = $49;$storemerge21 = $47;
  } else {
   $59 = $1 & 1;
   $60 = $59 | $45;
   $61 = $60 | 2;
   HEAP32[$0>>2] = $61;
   $$sum17 = (($45) + 4)|0;
   $62 = (($p) + ($$sum17)|0);
   $63 = HEAP32[$62>>2]|0;
   $64 = $63 | 1;
   HEAP32[$62>>2] = $64;
   $storemerge = 0;$storemerge21 = 0;
  }
  HEAP32[(73192)>>2] = $storemerge21;
  HEAP32[(73204)>>2] = $storemerge;
  $newp$0 = $p;
  return ($newp$0|0);
 }
 $65 = $8 & 2;
 $66 = ($65|0)==(0);
 if (!($66)) {
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $67 = $8 & -8;
 $68 = (($67) + ($2))|0;
 $69 = ($68>>>0)<($nb>>>0);
 if ($69) {
  $newp$0 = 0;
  return ($newp$0|0);
 }
 $70 = (($68) - ($nb))|0;
 $71 = $8 >>> 3;
 $72 = ($8>>>0)<(256);
 do {
  if ($72) {
   $$sum15 = (($2) + 8)|0;
   $73 = (($p) + ($$sum15)|0);
   $74 = HEAP32[$73>>2]|0;
   $$sum16 = (($2) + 12)|0;
   $75 = (($p) + ($$sum16)|0);
   $76 = HEAP32[$75>>2]|0;
   $77 = $71 << 1;
   $78 = (73224 + ($77<<2)|0);
   $79 = ($74|0)==($78|0);
   if (!($79)) {
    $80 = ($74>>>0)<($4>>>0);
    if ($80) {
     _abort();
     // unreachable;
    }
    $81 = ((($74)) + 12|0);
    $82 = HEAP32[$81>>2]|0;
    $83 = ($82|0)==($3|0);
    if (!($83)) {
     _abort();
     // unreachable;
    }
   }
   $84 = ($76|0)==($74|0);
   if ($84) {
    $85 = 1 << $71;
    $86 = $85 ^ -1;
    $87 = HEAP32[73184>>2]|0;
    $88 = $87 & $86;
    HEAP32[73184>>2] = $88;
    break;
   }
   $89 = ($76|0)==($78|0);
   if ($89) {
    $$pre = ((($76)) + 8|0);
    $$pre$phiZ2D = $$pre;
   } else {
    $90 = ($76>>>0)<($4>>>0);
    if ($90) {
     _abort();
     // unreachable;
    }
    $91 = ((($76)) + 8|0);
    $92 = HEAP32[$91>>2]|0;
    $93 = ($92|0)==($3|0);
    if ($93) {
     $$pre$phiZ2D = $91;
    } else {
     _abort();
     // unreachable;
    }
   }
   $94 = ((($74)) + 12|0);
   HEAP32[$94>>2] = $76;
   HEAP32[$$pre$phiZ2D>>2] = $74;
  } else {
   $$sum = (($2) + 24)|0;
   $95 = (($p) + ($$sum)|0);
   $96 = HEAP32[$95>>2]|0;
   $$sum2 = (($2) + 12)|0;
   $97 = (($p) + ($$sum2)|0);
   $98 = HEAP32[$97>>2]|0;
   $99 = ($98|0)==($3|0);
   do {
    if ($99) {
     $$sum4 = (($2) + 20)|0;
     $109 = (($p) + ($$sum4)|0);
     $110 = HEAP32[$109>>2]|0;
     $111 = ($110|0)==(0|0);
     if ($111) {
      $$sum3 = (($2) + 16)|0;
      $112 = (($p) + ($$sum3)|0);
      $113 = HEAP32[$112>>2]|0;
      $114 = ($113|0)==(0|0);
      if ($114) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $113;$RP$0 = $112;
      }
     } else {
      $R$0 = $110;$RP$0 = $109;
     }
     while(1) {
      $115 = ((($R$0)) + 20|0);
      $116 = HEAP32[$115>>2]|0;
      $117 = ($116|0)==(0|0);
      if (!($117)) {
       $R$0 = $116;$RP$0 = $115;
       continue;
      }
      $118 = ((($R$0)) + 16|0);
      $119 = HEAP32[$118>>2]|0;
      $120 = ($119|0)==(0|0);
      if ($120) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $119;$RP$0 = $118;
      }
     }
     $121 = ($RP$0$lcssa>>>0)<($4>>>0);
     if ($121) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum14 = (($2) + 8)|0;
     $100 = (($p) + ($$sum14)|0);
     $101 = HEAP32[$100>>2]|0;
     $102 = ($101>>>0)<($4>>>0);
     if ($102) {
      _abort();
      // unreachable;
     }
     $103 = ((($101)) + 12|0);
     $104 = HEAP32[$103>>2]|0;
     $105 = ($104|0)==($3|0);
     if (!($105)) {
      _abort();
      // unreachable;
     }
     $106 = ((($98)) + 8|0);
     $107 = HEAP32[$106>>2]|0;
     $108 = ($107|0)==($3|0);
     if ($108) {
      HEAP32[$103>>2] = $98;
      HEAP32[$106>>2] = $101;
      $R$1 = $98;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $122 = ($96|0)==(0|0);
   if (!($122)) {
    $$sum11 = (($2) + 28)|0;
    $123 = (($p) + ($$sum11)|0);
    $124 = HEAP32[$123>>2]|0;
    $125 = (73488 + ($124<<2)|0);
    $126 = HEAP32[$125>>2]|0;
    $127 = ($3|0)==($126|0);
    if ($127) {
     HEAP32[$125>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $128 = 1 << $124;
      $129 = $128 ^ -1;
      $130 = HEAP32[(73188)>>2]|0;
      $131 = $130 & $129;
      HEAP32[(73188)>>2] = $131;
      break;
     }
    } else {
     $132 = HEAP32[(73200)>>2]|0;
     $133 = ($96>>>0)<($132>>>0);
     if ($133) {
      _abort();
      // unreachable;
     }
     $134 = ((($96)) + 16|0);
     $135 = HEAP32[$134>>2]|0;
     $136 = ($135|0)==($3|0);
     if ($136) {
      HEAP32[$134>>2] = $R$1;
     } else {
      $137 = ((($96)) + 20|0);
      HEAP32[$137>>2] = $R$1;
     }
     $138 = ($R$1|0)==(0|0);
     if ($138) {
      break;
     }
    }
    $139 = HEAP32[(73200)>>2]|0;
    $140 = ($R$1>>>0)<($139>>>0);
    if ($140) {
     _abort();
     // unreachable;
    }
    $141 = ((($R$1)) + 24|0);
    HEAP32[$141>>2] = $96;
    $$sum12 = (($2) + 16)|0;
    $142 = (($p) + ($$sum12)|0);
    $143 = HEAP32[$142>>2]|0;
    $144 = ($143|0)==(0|0);
    do {
     if (!($144)) {
      $145 = ($143>>>0)<($139>>>0);
      if ($145) {
       _abort();
       // unreachable;
      } else {
       $146 = ((($R$1)) + 16|0);
       HEAP32[$146>>2] = $143;
       $147 = ((($143)) + 24|0);
       HEAP32[$147>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum13 = (($2) + 20)|0;
    $148 = (($p) + ($$sum13)|0);
    $149 = HEAP32[$148>>2]|0;
    $150 = ($149|0)==(0|0);
    if (!($150)) {
     $151 = HEAP32[(73200)>>2]|0;
     $152 = ($149>>>0)<($151>>>0);
     if ($152) {
      _abort();
      // unreachable;
     } else {
      $153 = ((($R$1)) + 20|0);
      HEAP32[$153>>2] = $149;
      $154 = ((($149)) + 24|0);
      HEAP32[$154>>2] = $R$1;
      break;
     }
    }
   }
  }
 } while(0);
 $155 = ($70>>>0)<(16);
 if ($155) {
  $156 = $1 & 1;
  $157 = $68 | $156;
  $158 = $157 | 2;
  HEAP32[$0>>2] = $158;
  $$sum910 = $68 | 4;
  $159 = (($p) + ($$sum910)|0);
  $160 = HEAP32[$159>>2]|0;
  $161 = $160 | 1;
  HEAP32[$159>>2] = $161;
  $newp$0 = $p;
  return ($newp$0|0);
 } else {
  $162 = (($p) + ($nb)|0);
  $163 = $1 & 1;
  $164 = $163 | $nb;
  $165 = $164 | 2;
  HEAP32[$0>>2] = $165;
  $$sum5 = (($nb) + 4)|0;
  $166 = (($p) + ($$sum5)|0);
  $167 = $70 | 3;
  HEAP32[$166>>2] = $167;
  $$sum78 = $68 | 4;
  $168 = (($p) + ($$sum78)|0);
  $169 = HEAP32[$168>>2]|0;
  $170 = $169 | 1;
  HEAP32[$168>>2] = $170;
  _dispose_chunk($162,$70);
  $newp$0 = $p;
  return ($newp$0|0);
 }
 return (0)|0;
}
function _dispose_chunk($p,$psize) {
 $p = $p|0;
 $psize = $psize|0;
 var $$0 = 0, $$02 = 0, $$1 = 0, $$lcssa = 0, $$pre = 0, $$pre$phi50Z2D = 0, $$pre$phi52Z2D = 0, $$pre$phiZ2D = 0, $$pre48 = 0, $$pre49 = 0, $$pre51 = 0, $$sum = 0, $$sum1 = 0, $$sum10 = 0, $$sum11 = 0, $$sum12 = 0, $$sum13 = 0, $$sum14 = 0, $$sum16 = 0, $$sum17 = 0;
 var $$sum18 = 0, $$sum19 = 0, $$sum2 = 0, $$sum20 = 0, $$sum21 = 0, $$sum22 = 0, $$sum23 = 0, $$sum24 = 0, $$sum25 = 0, $$sum3 = 0, $$sum4 = 0, $$sum5 = 0, $$sum7 = 0, $$sum8 = 0, $$sum9 = 0, $0 = 0, $1 = 0, $10 = 0, $100 = 0, $101 = 0;
 var $102 = 0, $103 = 0, $104 = 0, $105 = 0, $106 = 0, $107 = 0, $108 = 0, $109 = 0, $11 = 0, $110 = 0, $111 = 0, $112 = 0, $113 = 0, $114 = 0, $115 = 0, $116 = 0, $117 = 0, $118 = 0, $119 = 0, $12 = 0;
 var $120 = 0, $121 = 0, $122 = 0, $123 = 0, $124 = 0, $125 = 0, $126 = 0, $127 = 0, $128 = 0, $129 = 0, $13 = 0, $130 = 0, $131 = 0, $132 = 0, $133 = 0, $134 = 0, $135 = 0, $136 = 0, $137 = 0, $138 = 0;
 var $139 = 0, $14 = 0, $140 = 0, $141 = 0, $142 = 0, $143 = 0, $144 = 0, $145 = 0, $146 = 0, $147 = 0, $148 = 0, $149 = 0, $15 = 0, $150 = 0, $151 = 0, $152 = 0, $153 = 0, $154 = 0, $155 = 0, $156 = 0;
 var $157 = 0, $158 = 0, $159 = 0, $16 = 0, $160 = 0, $161 = 0, $162 = 0, $163 = 0, $164 = 0, $165 = 0, $166 = 0, $167 = 0, $168 = 0, $169 = 0, $17 = 0, $170 = 0, $171 = 0, $172 = 0, $173 = 0, $174 = 0;
 var $175 = 0, $176 = 0, $177 = 0, $178 = 0, $179 = 0, $18 = 0, $180 = 0, $181 = 0, $182 = 0, $183 = 0, $184 = 0, $185 = 0, $186 = 0, $187 = 0, $188 = 0, $189 = 0, $19 = 0, $190 = 0, $191 = 0, $192 = 0;
 var $193 = 0, $194 = 0, $195 = 0, $196 = 0, $197 = 0, $198 = 0, $199 = 0, $2 = 0, $20 = 0, $200 = 0, $201 = 0, $202 = 0, $203 = 0, $204 = 0, $205 = 0, $206 = 0, $207 = 0, $208 = 0, $209 = 0, $21 = 0;
 var $210 = 0, $211 = 0, $212 = 0, $213 = 0, $214 = 0, $215 = 0, $216 = 0, $217 = 0, $218 = 0, $219 = 0, $22 = 0, $220 = 0, $221 = 0, $222 = 0, $223 = 0, $224 = 0, $225 = 0, $226 = 0, $227 = 0, $228 = 0;
 var $229 = 0, $23 = 0, $230 = 0, $231 = 0, $232 = 0, $233 = 0, $234 = 0, $235 = 0, $236 = 0, $237 = 0, $238 = 0, $239 = 0, $24 = 0, $240 = 0, $241 = 0, $242 = 0, $243 = 0, $244 = 0, $245 = 0, $246 = 0;
 var $247 = 0, $248 = 0, $249 = 0, $25 = 0, $250 = 0, $251 = 0, $252 = 0, $253 = 0, $254 = 0, $255 = 0, $256 = 0, $257 = 0, $258 = 0, $259 = 0, $26 = 0, $260 = 0, $261 = 0, $262 = 0, $263 = 0, $264 = 0;
 var $265 = 0, $266 = 0, $267 = 0, $268 = 0, $269 = 0, $27 = 0, $270 = 0, $271 = 0, $272 = 0, $273 = 0, $274 = 0, $275 = 0, $276 = 0, $277 = 0, $278 = 0, $279 = 0, $28 = 0, $280 = 0, $281 = 0, $282 = 0;
 var $283 = 0, $284 = 0, $285 = 0, $286 = 0, $287 = 0, $288 = 0, $289 = 0, $29 = 0, $290 = 0, $291 = 0, $292 = 0, $293 = 0, $294 = 0, $295 = 0, $296 = 0, $297 = 0, $298 = 0, $299 = 0, $3 = 0, $30 = 0;
 var $300 = 0, $301 = 0, $302 = 0, $303 = 0, $304 = 0, $305 = 0, $306 = 0, $307 = 0, $31 = 0, $32 = 0, $33 = 0, $34 = 0, $35 = 0, $36 = 0, $37 = 0, $38 = 0, $39 = 0, $4 = 0, $40 = 0, $41 = 0;
 var $42 = 0, $43 = 0, $44 = 0, $45 = 0, $46 = 0, $47 = 0, $48 = 0, $49 = 0, $5 = 0, $50 = 0, $51 = 0, $52 = 0, $53 = 0, $54 = 0, $55 = 0, $56 = 0, $57 = 0, $58 = 0, $59 = 0, $6 = 0;
 var $60 = 0, $61 = 0, $62 = 0, $63 = 0, $64 = 0, $65 = 0, $66 = 0, $67 = 0, $68 = 0, $69 = 0, $7 = 0, $70 = 0, $71 = 0, $72 = 0, $73 = 0, $74 = 0, $75 = 0, $76 = 0, $77 = 0, $78 = 0;
 var $79 = 0, $8 = 0, $80 = 0, $81 = 0, $82 = 0, $83 = 0, $84 = 0, $85 = 0, $86 = 0, $87 = 0, $88 = 0, $89 = 0, $9 = 0, $90 = 0, $91 = 0, $92 = 0, $93 = 0, $94 = 0, $95 = 0, $96 = 0;
 var $97 = 0, $98 = 0, $99 = 0, $F16$0 = 0, $I19$0 = 0, $K20$043 = 0, $R$0 = 0, $R$0$lcssa = 0, $R$1 = 0, $R7$0 = 0, $R7$0$lcssa = 0, $R7$1 = 0, $RP$0 = 0, $RP$0$lcssa = 0, $RP9$0 = 0, $RP9$0$lcssa = 0, $T$0$lcssa = 0, $T$042 = 0, $T$042$lcssa = 0, $cond = 0;
 var $cond39 = 0, $not$ = 0, label = 0, sp = 0;
 sp = STACKTOP;
 $0 = (($p) + ($psize)|0);
 $1 = ((($p)) + 4|0);
 $2 = HEAP32[$1>>2]|0;
 $3 = $2 & 1;
 $4 = ($3|0)==(0);
 do {
  if ($4) {
   $5 = HEAP32[$p>>2]|0;
   $6 = $2 & 3;
   $7 = ($6|0)==(0);
   if ($7) {
    return;
   }
   $8 = (0 - ($5))|0;
   $9 = (($p) + ($8)|0);
   $10 = (($5) + ($psize))|0;
   $11 = HEAP32[(73200)>>2]|0;
   $12 = ($9>>>0)<($11>>>0);
   if ($12) {
    _abort();
    // unreachable;
   }
   $13 = HEAP32[(73204)>>2]|0;
   $14 = ($9|0)==($13|0);
   if ($14) {
    $$sum = (($psize) + 4)|0;
    $99 = (($p) + ($$sum)|0);
    $100 = HEAP32[$99>>2]|0;
    $101 = $100 & 3;
    $102 = ($101|0)==(3);
    if (!($102)) {
     $$0 = $9;$$02 = $10;
     break;
    }
    HEAP32[(73192)>>2] = $10;
    $103 = $100 & -2;
    HEAP32[$99>>2] = $103;
    $104 = $10 | 1;
    $$sum14 = (4 - ($5))|0;
    $105 = (($p) + ($$sum14)|0);
    HEAP32[$105>>2] = $104;
    HEAP32[$0>>2] = $10;
    return;
   }
   $15 = $5 >>> 3;
   $16 = ($5>>>0)<(256);
   if ($16) {
    $$sum24 = (8 - ($5))|0;
    $17 = (($p) + ($$sum24)|0);
    $18 = HEAP32[$17>>2]|0;
    $$sum25 = (12 - ($5))|0;
    $19 = (($p) + ($$sum25)|0);
    $20 = HEAP32[$19>>2]|0;
    $21 = $15 << 1;
    $22 = (73224 + ($21<<2)|0);
    $23 = ($18|0)==($22|0);
    if (!($23)) {
     $24 = ($18>>>0)<($11>>>0);
     if ($24) {
      _abort();
      // unreachable;
     }
     $25 = ((($18)) + 12|0);
     $26 = HEAP32[$25>>2]|0;
     $27 = ($26|0)==($9|0);
     if (!($27)) {
      _abort();
      // unreachable;
     }
    }
    $28 = ($20|0)==($18|0);
    if ($28) {
     $29 = 1 << $15;
     $30 = $29 ^ -1;
     $31 = HEAP32[73184>>2]|0;
     $32 = $31 & $30;
     HEAP32[73184>>2] = $32;
     $$0 = $9;$$02 = $10;
     break;
    }
    $33 = ($20|0)==($22|0);
    if ($33) {
     $$pre51 = ((($20)) + 8|0);
     $$pre$phi52Z2D = $$pre51;
    } else {
     $34 = ($20>>>0)<($11>>>0);
     if ($34) {
      _abort();
      // unreachable;
     }
     $35 = ((($20)) + 8|0);
     $36 = HEAP32[$35>>2]|0;
     $37 = ($36|0)==($9|0);
     if ($37) {
      $$pre$phi52Z2D = $35;
     } else {
      _abort();
      // unreachable;
     }
    }
    $38 = ((($18)) + 12|0);
    HEAP32[$38>>2] = $20;
    HEAP32[$$pre$phi52Z2D>>2] = $18;
    $$0 = $9;$$02 = $10;
    break;
   }
   $$sum16 = (24 - ($5))|0;
   $39 = (($p) + ($$sum16)|0);
   $40 = HEAP32[$39>>2]|0;
   $$sum17 = (12 - ($5))|0;
   $41 = (($p) + ($$sum17)|0);
   $42 = HEAP32[$41>>2]|0;
   $43 = ($42|0)==($9|0);
   do {
    if ($43) {
     $$sum18 = (16 - ($5))|0;
     $$sum19 = (($$sum18) + 4)|0;
     $53 = (($p) + ($$sum19)|0);
     $54 = HEAP32[$53>>2]|0;
     $55 = ($54|0)==(0|0);
     if ($55) {
      $56 = (($p) + ($$sum18)|0);
      $57 = HEAP32[$56>>2]|0;
      $58 = ($57|0)==(0|0);
      if ($58) {
       $R$1 = 0;
       break;
      } else {
       $R$0 = $57;$RP$0 = $56;
      }
     } else {
      $R$0 = $54;$RP$0 = $53;
     }
     while(1) {
      $59 = ((($R$0)) + 20|0);
      $60 = HEAP32[$59>>2]|0;
      $61 = ($60|0)==(0|0);
      if (!($61)) {
       $R$0 = $60;$RP$0 = $59;
       continue;
      }
      $62 = ((($R$0)) + 16|0);
      $63 = HEAP32[$62>>2]|0;
      $64 = ($63|0)==(0|0);
      if ($64) {
       $R$0$lcssa = $R$0;$RP$0$lcssa = $RP$0;
       break;
      } else {
       $R$0 = $63;$RP$0 = $62;
      }
     }
     $65 = ($RP$0$lcssa>>>0)<($11>>>0);
     if ($65) {
      _abort();
      // unreachable;
     } else {
      HEAP32[$RP$0$lcssa>>2] = 0;
      $R$1 = $R$0$lcssa;
      break;
     }
    } else {
     $$sum23 = (8 - ($5))|0;
     $44 = (($p) + ($$sum23)|0);
     $45 = HEAP32[$44>>2]|0;
     $46 = ($45>>>0)<($11>>>0);
     if ($46) {
      _abort();
      // unreachable;
     }
     $47 = ((($45)) + 12|0);
     $48 = HEAP32[$47>>2]|0;
     $49 = ($48|0)==($9|0);
     if (!($49)) {
      _abort();
      // unreachable;
     }
     $50 = ((($42)) + 8|0);
     $51 = HEAP32[$50>>2]|0;
     $52 = ($51|0)==($9|0);
     if ($52) {
      HEAP32[$47>>2] = $42;
      HEAP32[$50>>2] = $45;
      $R$1 = $42;
      break;
     } else {
      _abort();
      // unreachable;
     }
    }
   } while(0);
   $66 = ($40|0)==(0|0);
   if ($66) {
    $$0 = $9;$$02 = $10;
   } else {
    $$sum20 = (28 - ($5))|0;
    $67 = (($p) + ($$sum20)|0);
    $68 = HEAP32[$67>>2]|0;
    $69 = (73488 + ($68<<2)|0);
    $70 = HEAP32[$69>>2]|0;
    $71 = ($9|0)==($70|0);
    if ($71) {
     HEAP32[$69>>2] = $R$1;
     $cond = ($R$1|0)==(0|0);
     if ($cond) {
      $72 = 1 << $68;
      $73 = $72 ^ -1;
      $74 = HEAP32[(73188)>>2]|0;
      $75 = $74 & $73;
      HEAP32[(73188)>>2] = $75;
      $$0 = $9;$$02 = $10;
      break;
     }
    } else {
     $76 = HEAP32[(73200)>>2]|0;
     $77 = ($40>>>0)<($76>>>0);
     if ($77) {
      _abort();
      // unreachable;
     }
     $78 = ((($40)) + 16|0);
     $79 = HEAP32[$78>>2]|0;
     $80 = ($79|0)==($9|0);
     if ($80) {
      HEAP32[$78>>2] = $R$1;
     } else {
      $81 = ((($40)) + 20|0);
      HEAP32[$81>>2] = $R$1;
     }
     $82 = ($R$1|0)==(0|0);
     if ($82) {
      $$0 = $9;$$02 = $10;
      break;
     }
    }
    $83 = HEAP32[(73200)>>2]|0;
    $84 = ($R$1>>>0)<($83>>>0);
    if ($84) {
     _abort();
     // unreachable;
    }
    $85 = ((($R$1)) + 24|0);
    HEAP32[$85>>2] = $40;
    $$sum21 = (16 - ($5))|0;
    $86 = (($p) + ($$sum21)|0);
    $87 = HEAP32[$86>>2]|0;
    $88 = ($87|0)==(0|0);
    do {
     if (!($88)) {
      $89 = ($87>>>0)<($83>>>0);
      if ($89) {
       _abort();
       // unreachable;
      } else {
       $90 = ((($R$1)) + 16|0);
       HEAP32[$90>>2] = $87;
       $91 = ((($87)) + 24|0);
       HEAP32[$91>>2] = $R$1;
       break;
      }
     }
    } while(0);
    $$sum22 = (($$sum21) + 4)|0;
    $92 = (($p) + ($$sum22)|0);
    $93 = HEAP32[$92>>2]|0;
    $94 = ($93|0)==(0|0);
    if ($94) {
     $$0 = $9;$$02 = $10;
    } else {
     $95 = HEAP32[(73200)>>2]|0;
     $96 = ($93>>>0)<($95>>>0);
     if ($96) {
      _abort();
      // unreachable;
     } else {
      $97 = ((($R$1)) + 20|0);
      HEAP32[$97>>2] = $93;
      $98 = ((($93)) + 24|0);
      HEAP32[$98>>2] = $R$1;
      $$0 = $9;$$02 = $10;
      break;
     }
    }
   }
  } else {
   $$0 = $p;$$02 = $psize;
  }
 } while(0);
 $106 = HEAP32[(73200)>>2]|0;
 $107 = ($0>>>0)<($106>>>0);
 if ($107) {
  _abort();
  // unreachable;
 }
 $$sum1 = (($psize) + 4)|0;
 $108 = (($p) + ($$sum1)|0);
 $109 = HEAP32[$108>>2]|0;
 $110 = $109 & 2;
 $111 = ($110|0)==(0);
 if ($111) {
  $112 = HEAP32[(73208)>>2]|0;
  $113 = ($0|0)==($112|0);
  if ($113) {
   $114 = HEAP32[(73196)>>2]|0;
   $115 = (($114) + ($$02))|0;
   HEAP32[(73196)>>2] = $115;
   HEAP32[(73208)>>2] = $$0;
   $116 = $115 | 1;
   $117 = ((($$0)) + 4|0);
   HEAP32[$117>>2] = $116;
   $118 = HEAP32[(73204)>>2]|0;
   $119 = ($$0|0)==($118|0);
   if (!($119)) {
    return;
   }
   HEAP32[(73204)>>2] = 0;
   HEAP32[(73192)>>2] = 0;
   return;
  }
  $120 = HEAP32[(73204)>>2]|0;
  $121 = ($0|0)==($120|0);
  if ($121) {
   $122 = HEAP32[(73192)>>2]|0;
   $123 = (($122) + ($$02))|0;
   HEAP32[(73192)>>2] = $123;
   HEAP32[(73204)>>2] = $$0;
   $124 = $123 | 1;
   $125 = ((($$0)) + 4|0);
   HEAP32[$125>>2] = $124;
   $126 = (($$0) + ($123)|0);
   HEAP32[$126>>2] = $123;
   return;
  }
  $127 = $109 & -8;
  $128 = (($127) + ($$02))|0;
  $129 = $109 >>> 3;
  $130 = ($109>>>0)<(256);
  do {
   if ($130) {
    $$sum12 = (($psize) + 8)|0;
    $131 = (($p) + ($$sum12)|0);
    $132 = HEAP32[$131>>2]|0;
    $$sum13 = (($psize) + 12)|0;
    $133 = (($p) + ($$sum13)|0);
    $134 = HEAP32[$133>>2]|0;
    $135 = $129 << 1;
    $136 = (73224 + ($135<<2)|0);
    $137 = ($132|0)==($136|0);
    if (!($137)) {
     $138 = ($132>>>0)<($106>>>0);
     if ($138) {
      _abort();
      // unreachable;
     }
     $139 = ((($132)) + 12|0);
     $140 = HEAP32[$139>>2]|0;
     $141 = ($140|0)==($0|0);
     if (!($141)) {
      _abort();
      // unreachable;
     }
    }
    $142 = ($134|0)==($132|0);
    if ($142) {
     $143 = 1 << $129;
     $144 = $143 ^ -1;
     $145 = HEAP32[73184>>2]|0;
     $146 = $145 & $144;
     HEAP32[73184>>2] = $146;
     break;
    }
    $147 = ($134|0)==($136|0);
    if ($147) {
     $$pre49 = ((($134)) + 8|0);
     $$pre$phi50Z2D = $$pre49;
    } else {
     $148 = ($134>>>0)<($106>>>0);
     if ($148) {
      _abort();
      // unreachable;
     }
     $149 = ((($134)) + 8|0);
     $150 = HEAP32[$149>>2]|0;
     $151 = ($150|0)==($0|0);
     if ($151) {
      $$pre$phi50Z2D = $149;
     } else {
      _abort();
      // unreachable;
     }
    }
    $152 = ((($132)) + 12|0);
    HEAP32[$152>>2] = $134;
    HEAP32[$$pre$phi50Z2D>>2] = $132;
   } else {
    $$sum2 = (($psize) + 24)|0;
    $153 = (($p) + ($$sum2)|0);
    $154 = HEAP32[$153>>2]|0;
    $$sum3 = (($psize) + 12)|0;
    $155 = (($p) + ($$sum3)|0);
    $156 = HEAP32[$155>>2]|0;
    $157 = ($156|0)==($0|0);
    do {
     if ($157) {
      $$sum5 = (($psize) + 20)|0;
      $167 = (($p) + ($$sum5)|0);
      $168 = HEAP32[$167>>2]|0;
      $169 = ($168|0)==(0|0);
      if ($169) {
       $$sum4 = (($psize) + 16)|0;
       $170 = (($p) + ($$sum4)|0);
       $171 = HEAP32[$170>>2]|0;
       $172 = ($171|0)==(0|0);
       if ($172) {
        $R7$1 = 0;
        break;
       } else {
        $R7$0 = $171;$RP9$0 = $170;
       }
      } else {
       $R7$0 = $168;$RP9$0 = $167;
      }
      while(1) {
       $173 = ((($R7$0)) + 20|0);
       $174 = HEAP32[$173>>2]|0;
       $175 = ($174|0)==(0|0);
       if (!($175)) {
        $R7$0 = $174;$RP9$0 = $173;
        continue;
       }
       $176 = ((($R7$0)) + 16|0);
       $177 = HEAP32[$176>>2]|0;
       $178 = ($177|0)==(0|0);
       if ($178) {
        $R7$0$lcssa = $R7$0;$RP9$0$lcssa = $RP9$0;
        break;
       } else {
        $R7$0 = $177;$RP9$0 = $176;
       }
      }
      $179 = ($RP9$0$lcssa>>>0)<($106>>>0);
      if ($179) {
       _abort();
       // unreachable;
      } else {
       HEAP32[$RP9$0$lcssa>>2] = 0;
       $R7$1 = $R7$0$lcssa;
       break;
      }
     } else {
      $$sum11 = (($psize) + 8)|0;
      $158 = (($p) + ($$sum11)|0);
      $159 = HEAP32[$158>>2]|0;
      $160 = ($159>>>0)<($106>>>0);
      if ($160) {
       _abort();
       // unreachable;
      }
      $161 = ((($159)) + 12|0);
      $162 = HEAP32[$161>>2]|0;
      $163 = ($162|0)==($0|0);
      if (!($163)) {
       _abort();
       // unreachable;
      }
      $164 = ((($156)) + 8|0);
      $165 = HEAP32[$164>>2]|0;
      $166 = ($165|0)==($0|0);
      if ($166) {
       HEAP32[$161>>2] = $156;
       HEAP32[$164>>2] = $159;
       $R7$1 = $156;
       break;
      } else {
       _abort();
       // unreachable;
      }
     }
    } while(0);
    $180 = ($154|0)==(0|0);
    if (!($180)) {
     $$sum8 = (($psize) + 28)|0;
     $181 = (($p) + ($$sum8)|0);
     $182 = HEAP32[$181>>2]|0;
     $183 = (73488 + ($182<<2)|0);
     $184 = HEAP32[$183>>2]|0;
     $185 = ($0|0)==($184|0);
     if ($185) {
      HEAP32[$183>>2] = $R7$1;
      $cond39 = ($R7$1|0)==(0|0);
      if ($cond39) {
       $186 = 1 << $182;
       $187 = $186 ^ -1;
       $188 = HEAP32[(73188)>>2]|0;
       $189 = $188 & $187;
       HEAP32[(73188)>>2] = $189;
       break;
      }
     } else {
      $190 = HEAP32[(73200)>>2]|0;
      $191 = ($154>>>0)<($190>>>0);
      if ($191) {
       _abort();
       // unreachable;
      }
      $192 = ((($154)) + 16|0);
      $193 = HEAP32[$192>>2]|0;
      $194 = ($193|0)==($0|0);
      if ($194) {
       HEAP32[$192>>2] = $R7$1;
      } else {
       $195 = ((($154)) + 20|0);
       HEAP32[$195>>2] = $R7$1;
      }
      $196 = ($R7$1|0)==(0|0);
      if ($196) {
       break;
      }
     }
     $197 = HEAP32[(73200)>>2]|0;
     $198 = ($R7$1>>>0)<($197>>>0);
     if ($198) {
      _abort();
      // unreachable;
     }
     $199 = ((($R7$1)) + 24|0);
     HEAP32[$199>>2] = $154;
     $$sum9 = (($psize) + 16)|0;
     $200 = (($p) + ($$sum9)|0);
     $201 = HEAP32[$200>>2]|0;
     $202 = ($201|0)==(0|0);
     do {
      if (!($202)) {
       $203 = ($201>>>0)<($197>>>0);
       if ($203) {
        _abort();
        // unreachable;
       } else {
        $204 = ((($R7$1)) + 16|0);
        HEAP32[$204>>2] = $201;
        $205 = ((($201)) + 24|0);
        HEAP32[$205>>2] = $R7$1;
        break;
       }
      }
     } while(0);
     $$sum10 = (($psize) + 20)|0;
     $206 = (($p) + ($$sum10)|0);
     $207 = HEAP32[$206>>2]|0;
     $208 = ($207|0)==(0|0);
     if (!($208)) {
      $209 = HEAP32[(73200)>>2]|0;
      $210 = ($207>>>0)<($209>>>0);
      if ($210) {
       _abort();
       // unreachable;
      } else {
       $211 = ((($R7$1)) + 20|0);
       HEAP32[$211>>2] = $207;
       $212 = ((($207)) + 24|0);
       HEAP32[$212>>2] = $R7$1;
       break;
      }
     }
    }
   }
  } while(0);
  $213 = $128 | 1;
  $214 = ((($$0)) + 4|0);
  HEAP32[$214>>2] = $213;
  $215 = (($$0) + ($128)|0);
  HEAP32[$215>>2] = $128;
  $216 = HEAP32[(73204)>>2]|0;
  $217 = ($$0|0)==($216|0);
  if ($217) {
   HEAP32[(73192)>>2] = $128;
   return;
  } else {
   $$1 = $128;
  }
 } else {
  $218 = $109 & -2;
  HEAP32[$108>>2] = $218;
  $219 = $$02 | 1;
  $220 = ((($$0)) + 4|0);
  HEAP32[$220>>2] = $219;
  $221 = (($$0) + ($$02)|0);
  HEAP32[$221>>2] = $$02;
  $$1 = $$02;
 }
 $222 = $$1 >>> 3;
 $223 = ($$1>>>0)<(256);
 if ($223) {
  $224 = $222 << 1;
  $225 = (73224 + ($224<<2)|0);
  $226 = HEAP32[73184>>2]|0;
  $227 = 1 << $222;
  $228 = $226 & $227;
  $229 = ($228|0)==(0);
  if ($229) {
   $230 = $226 | $227;
   HEAP32[73184>>2] = $230;
   $$pre = (($224) + 2)|0;
   $$pre48 = (73224 + ($$pre<<2)|0);
   $$pre$phiZ2D = $$pre48;$F16$0 = $225;
  } else {
   $$sum7 = (($224) + 2)|0;
   $231 = (73224 + ($$sum7<<2)|0);
   $232 = HEAP32[$231>>2]|0;
   $233 = HEAP32[(73200)>>2]|0;
   $234 = ($232>>>0)<($233>>>0);
   if ($234) {
    _abort();
    // unreachable;
   } else {
    $$pre$phiZ2D = $231;$F16$0 = $232;
   }
  }
  HEAP32[$$pre$phiZ2D>>2] = $$0;
  $235 = ((($F16$0)) + 12|0);
  HEAP32[$235>>2] = $$0;
  $236 = ((($$0)) + 8|0);
  HEAP32[$236>>2] = $F16$0;
  $237 = ((($$0)) + 12|0);
  HEAP32[$237>>2] = $225;
  return;
 }
 $238 = $$1 >>> 8;
 $239 = ($238|0)==(0);
 if ($239) {
  $I19$0 = 0;
 } else {
  $240 = ($$1>>>0)>(16777215);
  if ($240) {
   $I19$0 = 31;
  } else {
   $241 = (($238) + 1048320)|0;
   $242 = $241 >>> 16;
   $243 = $242 & 8;
   $244 = $238 << $243;
   $245 = (($244) + 520192)|0;
   $246 = $245 >>> 16;
   $247 = $246 & 4;
   $248 = $247 | $243;
   $249 = $244 << $247;
   $250 = (($249) + 245760)|0;
   $251 = $250 >>> 16;
   $252 = $251 & 2;
   $253 = $248 | $252;
   $254 = (14 - ($253))|0;
   $255 = $249 << $252;
   $256 = $255 >>> 15;
   $257 = (($254) + ($256))|0;
   $258 = $257 << 1;
   $259 = (($257) + 7)|0;
   $260 = $$1 >>> $259;
   $261 = $260 & 1;
   $262 = $261 | $258;
   $I19$0 = $262;
  }
 }
 $263 = (73488 + ($I19$0<<2)|0);
 $264 = ((($$0)) + 28|0);
 HEAP32[$264>>2] = $I19$0;
 $265 = ((($$0)) + 16|0);
 $266 = ((($$0)) + 20|0);
 HEAP32[$266>>2] = 0;
 HEAP32[$265>>2] = 0;
 $267 = HEAP32[(73188)>>2]|0;
 $268 = 1 << $I19$0;
 $269 = $267 & $268;
 $270 = ($269|0)==(0);
 if ($270) {
  $271 = $267 | $268;
  HEAP32[(73188)>>2] = $271;
  HEAP32[$263>>2] = $$0;
  $272 = ((($$0)) + 24|0);
  HEAP32[$272>>2] = $263;
  $273 = ((($$0)) + 12|0);
  HEAP32[$273>>2] = $$0;
  $274 = ((($$0)) + 8|0);
  HEAP32[$274>>2] = $$0;
  return;
 }
 $275 = HEAP32[$263>>2]|0;
 $276 = ((($275)) + 4|0);
 $277 = HEAP32[$276>>2]|0;
 $278 = $277 & -8;
 $279 = ($278|0)==($$1|0);
 L191: do {
  if ($279) {
   $T$0$lcssa = $275;
  } else {
   $280 = ($I19$0|0)==(31);
   $281 = $I19$0 >>> 1;
   $282 = (25 - ($281))|0;
   $283 = $280 ? 0 : $282;
   $284 = $$1 << $283;
   $K20$043 = $284;$T$042 = $275;
   while(1) {
    $291 = $K20$043 >>> 31;
    $292 = (((($T$042)) + 16|0) + ($291<<2)|0);
    $287 = HEAP32[$292>>2]|0;
    $293 = ($287|0)==(0|0);
    if ($293) {
     $$lcssa = $292;$T$042$lcssa = $T$042;
     break;
    }
    $285 = $K20$043 << 1;
    $286 = ((($287)) + 4|0);
    $288 = HEAP32[$286>>2]|0;
    $289 = $288 & -8;
    $290 = ($289|0)==($$1|0);
    if ($290) {
     $T$0$lcssa = $287;
     break L191;
    } else {
     $K20$043 = $285;$T$042 = $287;
    }
   }
   $294 = HEAP32[(73200)>>2]|0;
   $295 = ($$lcssa>>>0)<($294>>>0);
   if ($295) {
    _abort();
    // unreachable;
   }
   HEAP32[$$lcssa>>2] = $$0;
   $296 = ((($$0)) + 24|0);
   HEAP32[$296>>2] = $T$042$lcssa;
   $297 = ((($$0)) + 12|0);
   HEAP32[$297>>2] = $$0;
   $298 = ((($$0)) + 8|0);
   HEAP32[$298>>2] = $$0;
   return;
  }
 } while(0);
 $299 = ((($T$0$lcssa)) + 8|0);
 $300 = HEAP32[$299>>2]|0;
 $301 = HEAP32[(73200)>>2]|0;
 $302 = ($300>>>0)>=($301>>>0);
 $not$ = ($T$0$lcssa>>>0)>=($301>>>0);
 $303 = $302 & $not$;
 if (!($303)) {
  _abort();
  // unreachable;
 }
 $304 = ((($300)) + 12|0);
 HEAP32[$304>>2] = $$0;
 HEAP32[$299>>2] = $$0;
 $305 = ((($$0)) + 8|0);
 HEAP32[$305>>2] = $300;
 $306 = ((($$0)) + 12|0);
 HEAP32[$306>>2] = $T$0$lcssa;
 $307 = ((($$0)) + 24|0);
 HEAP32[$307>>2] = 0;
 return;
}
function runPostSets() {

}
function _i64Subtract(a, b, c, d) {
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a - c)>>>0;
    h = (b - d)>>>0;
    h = (b - d - (((c>>>0) > (a>>>0))|0))>>>0; // Borrow one from high word to low word on underflow.
    return ((tempRet0 = h,l|0)|0);
}
function _i64Add(a, b, c, d) {
    /*
      x = a + b*2^32
      y = c + d*2^32
      result = l + h*2^32
    */
    a = a|0; b = b|0; c = c|0; d = d|0;
    var l = 0, h = 0;
    l = (a + c)>>>0;
    h = (b + d + (((l>>>0) < (a>>>0))|0))>>>0; // Add carry from low word to high word on overflow.
    return ((tempRet0 = h,l|0)|0);
}
function _strlen(ptr) {
    ptr = ptr|0;
    var curr = 0;
    curr = ptr;
    while (((HEAP8[((curr)>>0)])|0)) {
      curr = (curr + 1)|0;
    }
    return (curr - ptr)|0;
}
function _strncpy(pdest, psrc, num) {
    pdest = pdest|0; psrc = psrc|0; num = num|0;
    var padding = 0, curr = 0, i = 0;
    while ((i|0) < (num|0)) {
      curr = padding ? 0 : ((HEAP8[(((psrc)+(i))>>0)])|0);
      HEAP8[(((pdest)+(i))>>0)]=curr;
      padding = padding ? 1 : (((HEAP8[(((psrc)+(i))>>0)])|0) == 0);
      i = (i+1)|0;
    }
    return pdest|0;
}
function _memcpy(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if ((num|0) >= 4096) return _emscripten_memcpy_big(dest|0, src|0, num|0)|0;
    ret = dest|0;
    if ((dest&3) == (src&3)) {
      while (dest & 3) {
        if ((num|0) == 0) return ret|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
        dest = (dest+1)|0;
        src = (src+1)|0;
        num = (num-1)|0;
      }
      while ((num|0) >= 4) {
        HEAP32[((dest)>>2)]=((HEAP32[((src)>>2)])|0);
        dest = (dest+4)|0;
        src = (src+4)|0;
        num = (num-4)|0;
      }
    }
    while ((num|0) > 0) {
      HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      dest = (dest+1)|0;
      src = (src+1)|0;
      num = (num-1)|0;
    }
    return ret|0;
}
function _saveSetjmp(env, label, table, size) {
    // Not particularly fast: slow table lookup of setjmpId to label. But setjmp
    // prevents relooping anyhow, so slowness is to be expected. And typical case
    // is 1 setjmp per invocation, or less.
    env = env|0;
    label = label|0;
    table = table|0;
    size = size|0;
    var i = 0;
    setjmpId = (setjmpId+1)|0;
    HEAP32[((env)>>2)]=setjmpId;
    while ((i|0) < (size|0)) {
      if (((HEAP32[(((table)+((i<<3)))>>2)])|0) == 0) {
        HEAP32[(((table)+((i<<3)))>>2)]=setjmpId;
        HEAP32[(((table)+((i<<3)+4))>>2)]=label;
        // prepare next slot
        HEAP32[(((table)+((i<<3)+8))>>2)]=0;
        tempRet0 = size;
        return table | 0;
      }
      i = i+1|0;
    }
    // grow the table
    size = (size*2)|0;
    table = _realloc(table|0, 8*(size+1|0)|0) | 0;
    table = _saveSetjmp(env|0, label|0, table|0, size|0) | 0;
    tempRet0 = size;
    return table | 0;
}
function _bitshift64Lshr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >>> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = 0;
    return (high >>> (bits - 32))|0;
}
function _testSetjmp(id, table, size) {
    id = id|0;
    table = table|0;
    size = size|0;
    var i = 0, curr = 0;
    while ((i|0) < (size|0)) {
      curr = ((HEAP32[(((table)+((i<<3)))>>2)])|0);
      if ((curr|0) == 0) break;
      if ((curr|0) == (id|0)) {
        return ((HEAP32[(((table)+((i<<3)+4))>>2)])|0);
      }
      i = i+1|0;
    }
    return 0;
}
function _memmove(dest, src, num) {
    dest = dest|0; src = src|0; num = num|0;
    var ret = 0;
    if (((src|0) < (dest|0)) & ((dest|0) < ((src + num)|0))) {
      // Unlikely case: Copy backwards in a safe manner
      ret = dest;
      src = (src + num)|0;
      dest = (dest + num)|0;
      while ((num|0) > 0) {
        dest = (dest - 1)|0;
        src = (src - 1)|0;
        num = (num - 1)|0;
        HEAP8[((dest)>>0)]=((HEAP8[((src)>>0)])|0);
      }
      dest = ret;
    } else {
      _memcpy(dest, src, num) | 0;
    }
    return dest | 0;
}
function _memset(ptr, value, num) {
    ptr = ptr|0; value = value|0; num = num|0;
    var stop = 0, value4 = 0, stop4 = 0, unaligned = 0;
    stop = (ptr + num)|0;
    if ((num|0) >= 20) {
      // This is unaligned, but quite large, so work hard to get to aligned settings
      value = value & 0xff;
      unaligned = ptr & 3;
      value4 = value | (value << 8) | (value << 16) | (value << 24);
      stop4 = stop & ~3;
      if (unaligned) {
        unaligned = (ptr + 4 - unaligned)|0;
        while ((ptr|0) < (unaligned|0)) { // no need to check for stop, since we have large num
          HEAP8[((ptr)>>0)]=value;
          ptr = (ptr+1)|0;
        }
      }
      while ((ptr|0) < (stop4|0)) {
        HEAP32[((ptr)>>2)]=value4;
        ptr = (ptr+4)|0;
      }
    }
    while ((ptr|0) < (stop|0)) {
      HEAP8[((ptr)>>0)]=value;
      ptr = (ptr+1)|0;
    }
    return (ptr-num)|0;
}
function _strcat(pdest, psrc) {
    pdest = pdest|0; psrc = psrc|0;
    var i = 0;
    var pdestEnd = 0;
    pdestEnd = (pdest + (_strlen(pdest)|0))|0;
    do {
      HEAP8[((pdestEnd+i)>>0)]=HEAP8[((psrc+i)>>0)];
      i = (i+1)|0;
    } while (((HEAP8[(((psrc)+(i-1))>>0)])|0));
    return pdest|0;
}
function _bitshift64Shl(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = (high << bits) | ((low&(ander << (32 - bits))) >>> (32 - bits));
      return low << bits;
    }
    tempRet0 = low << (bits - 32);
    return 0;
}
function _strcpy(pdest, psrc) {
    pdest = pdest|0; psrc = psrc|0;
    var i = 0;
    do {
      HEAP8[(((pdest+i)|0)>>0)]=HEAP8[(((psrc+i)|0)>>0)];
      i = (i+1)|0;
    } while (((HEAP8[(((psrc)+(i-1))>>0)])|0));
    return pdest|0;
}
function _bitshift64Ashr(low, high, bits) {
    low = low|0; high = high|0; bits = bits|0;
    var ander = 0;
    if ((bits|0) < 32) {
      ander = ((1 << bits) - 1)|0;
      tempRet0 = high >> bits;
      return (low >>> bits) | ((high&ander) << (32 - bits));
    }
    tempRet0 = (high|0) < 0 ? -1 : 0;
    return (high >> (bits - 32))|0;
  }
function _llvm_cttz_i32(x) {
    x = x|0;
    var ret = 0;
    ret = ((HEAP8[(((cttz_i8)+(x & 0xff))>>0)])|0);
    if ((ret|0) < 8) return ret|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 8)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 8)|0;
    ret = ((HEAP8[(((cttz_i8)+((x >> 16)&0xff))>>0)])|0);
    if ((ret|0) < 8) return (ret + 16)|0;
    return (((HEAP8[(((cttz_i8)+(x >>> 24))>>0)])|0) + 24)|0;
  }

// ======== compiled code from system/lib/compiler-rt , see readme therein
function ___muldsi3($a, $b) {
  $a = $a | 0;
  $b = $b | 0;
  var $1 = 0, $2 = 0, $3 = 0, $6 = 0, $8 = 0, $11 = 0, $12 = 0;
  $1 = $a & 65535;
  $2 = $b & 65535;
  $3 = Math_imul($2, $1) | 0;
  $6 = $a >>> 16;
  $8 = ($3 >>> 16) + (Math_imul($2, $6) | 0) | 0;
  $11 = $b >>> 16;
  $12 = Math_imul($11, $1) | 0;
  return (tempRet0 = (($8 >>> 16) + (Math_imul($11, $6) | 0) | 0) + ((($8 & 65535) + $12 | 0) >>> 16) | 0, 0 | ($8 + $12 << 16 | $3 & 65535)) | 0;
}
function ___divdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $7$0 = 0, $7$1 = 0, $8$0 = 0, $10$0 = 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  $7$0 = $2$0 ^ $1$0;
  $7$1 = $2$1 ^ $1$1;
  $8$0 = ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, 0) | 0;
  $10$0 = _i64Subtract($8$0 ^ $7$0, tempRet0 ^ $7$1, $7$0, $7$1) | 0;
  return $10$0 | 0;
}
function ___remdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, $1$0 = 0, $1$1 = 0, $2$0 = 0, $2$1 = 0, $4$0 = 0, $4$1 = 0, $6$0 = 0, $10$0 = 0, $10$1 = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  $1$0 = $a$1 >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $1$1 = (($a$1 | 0) < 0 ? -1 : 0) >> 31 | (($a$1 | 0) < 0 ? -1 : 0) << 1;
  $2$0 = $b$1 >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $2$1 = (($b$1 | 0) < 0 ? -1 : 0) >> 31 | (($b$1 | 0) < 0 ? -1 : 0) << 1;
  $4$0 = _i64Subtract($1$0 ^ $a$0, $1$1 ^ $a$1, $1$0, $1$1) | 0;
  $4$1 = tempRet0;
  $6$0 = _i64Subtract($2$0 ^ $b$0, $2$1 ^ $b$1, $2$0, $2$1) | 0;
  ___udivmoddi4($4$0, $4$1, $6$0, tempRet0, $rem) | 0;
  $10$0 = _i64Subtract(HEAP32[$rem >> 2] ^ $1$0, HEAP32[$rem + 4 >> 2] ^ $1$1, $1$0, $1$1) | 0;
  $10$1 = tempRet0;
  STACKTOP = __stackBase__;
  return (tempRet0 = $10$1, $10$0) | 0;
}
function ___muldi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $x_sroa_0_0_extract_trunc = 0, $y_sroa_0_0_extract_trunc = 0, $1$0 = 0, $1$1 = 0, $2 = 0;
  $x_sroa_0_0_extract_trunc = $a$0;
  $y_sroa_0_0_extract_trunc = $b$0;
  $1$0 = ___muldsi3($x_sroa_0_0_extract_trunc, $y_sroa_0_0_extract_trunc) | 0;
  $1$1 = tempRet0;
  $2 = Math_imul($a$1, $y_sroa_0_0_extract_trunc) | 0;
  return (tempRet0 = ((Math_imul($b$1, $x_sroa_0_0_extract_trunc) | 0) + $2 | 0) + $1$1 | $1$1 & 0, 0 | $1$0 & -1) | 0;
}
function ___udivdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $1$0 = 0;
  $1$0 = ___udivmoddi4($a$0, $a$1, $b$0, $b$1, 0) | 0;
  return $1$0 | 0;
}
function ___uremdi3($a$0, $a$1, $b$0, $b$1) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  var $rem = 0, __stackBase__ = 0;
  __stackBase__ = STACKTOP;
  STACKTOP = STACKTOP + 8 | 0;
  $rem = __stackBase__ | 0;
  ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) | 0;
  STACKTOP = __stackBase__;
  return (tempRet0 = HEAP32[$rem + 4 >> 2] | 0, HEAP32[$rem >> 2] | 0) | 0;
}
function ___udivmoddi4($a$0, $a$1, $b$0, $b$1, $rem) {
  $a$0 = $a$0 | 0;
  $a$1 = $a$1 | 0;
  $b$0 = $b$0 | 0;
  $b$1 = $b$1 | 0;
  $rem = $rem | 0;
  var $n_sroa_0_0_extract_trunc = 0, $n_sroa_1_4_extract_shift$0 = 0, $n_sroa_1_4_extract_trunc = 0, $d_sroa_0_0_extract_trunc = 0, $d_sroa_1_4_extract_shift$0 = 0, $d_sroa_1_4_extract_trunc = 0, $4 = 0, $17 = 0, $37 = 0, $49 = 0, $51 = 0, $57 = 0, $58 = 0, $66 = 0, $78 = 0, $86 = 0, $88 = 0, $89 = 0, $91 = 0, $92 = 0, $95 = 0, $105 = 0, $117 = 0, $119 = 0, $125 = 0, $126 = 0, $130 = 0, $q_sroa_1_1_ph = 0, $q_sroa_0_1_ph = 0, $r_sroa_1_1_ph = 0, $r_sroa_0_1_ph = 0, $sr_1_ph = 0, $d_sroa_0_0_insert_insert99$0 = 0, $d_sroa_0_0_insert_insert99$1 = 0, $137$0 = 0, $137$1 = 0, $carry_0203 = 0, $sr_1202 = 0, $r_sroa_0_1201 = 0, $r_sroa_1_1200 = 0, $q_sroa_0_1199 = 0, $q_sroa_1_1198 = 0, $147 = 0, $149 = 0, $r_sroa_0_0_insert_insert42$0 = 0, $r_sroa_0_0_insert_insert42$1 = 0, $150$1 = 0, $151$0 = 0, $152 = 0, $154$0 = 0, $r_sroa_0_0_extract_trunc = 0, $r_sroa_1_4_extract_trunc = 0, $155 = 0, $carry_0_lcssa$0 = 0, $carry_0_lcssa$1 = 0, $r_sroa_0_1_lcssa = 0, $r_sroa_1_1_lcssa = 0, $q_sroa_0_1_lcssa = 0, $q_sroa_1_1_lcssa = 0, $q_sroa_0_0_insert_ext75$0 = 0, $q_sroa_0_0_insert_ext75$1 = 0, $q_sroa_0_0_insert_insert77$1 = 0, $_0$0 = 0, $_0$1 = 0;
  $n_sroa_0_0_extract_trunc = $a$0;
  $n_sroa_1_4_extract_shift$0 = $a$1;
  $n_sroa_1_4_extract_trunc = $n_sroa_1_4_extract_shift$0;
  $d_sroa_0_0_extract_trunc = $b$0;
  $d_sroa_1_4_extract_shift$0 = $b$1;
  $d_sroa_1_4_extract_trunc = $d_sroa_1_4_extract_shift$0;
  if (($n_sroa_1_4_extract_trunc | 0) == 0) {
    $4 = ($rem | 0) != 0;
    if (($d_sroa_1_4_extract_trunc | 0) == 0) {
      if ($4) {
        HEAP32[$rem >> 2] = ($n_sroa_0_0_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
        HEAP32[$rem + 4 >> 2] = 0;
      }
      $_0$1 = 0;
      $_0$0 = ($n_sroa_0_0_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$4) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    }
  }
  $17 = ($d_sroa_1_4_extract_trunc | 0) == 0;
  do {
    if (($d_sroa_0_0_extract_trunc | 0) == 0) {
      if ($17) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_0_0_extract_trunc >>> 0);
          HEAP32[$rem + 4 >> 2] = 0;
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_0_0_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      if (($n_sroa_0_0_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0;
          HEAP32[$rem + 4 >> 2] = ($n_sroa_1_4_extract_trunc >>> 0) % ($d_sroa_1_4_extract_trunc >>> 0);
        }
        $_0$1 = 0;
        $_0$0 = ($n_sroa_1_4_extract_trunc >>> 0) / ($d_sroa_1_4_extract_trunc >>> 0) >>> 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $37 = $d_sroa_1_4_extract_trunc - 1 | 0;
      if (($37 & $d_sroa_1_4_extract_trunc | 0) == 0) {
        if (($rem | 0) != 0) {
          HEAP32[$rem >> 2] = 0 | $a$0 & -1;
          HEAP32[$rem + 4 >> 2] = $37 & $n_sroa_1_4_extract_trunc | $a$1 & 0;
        }
        $_0$1 = 0;
        $_0$0 = $n_sroa_1_4_extract_trunc >>> ((_llvm_cttz_i32($d_sroa_1_4_extract_trunc | 0) | 0) >>> 0);
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $49 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
      $51 = $49 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
      if ($51 >>> 0 <= 30) {
        $57 = $51 + 1 | 0;
        $58 = 31 - $51 | 0;
        $sr_1_ph = $57;
        $r_sroa_0_1_ph = $n_sroa_1_4_extract_trunc << $58 | $n_sroa_0_0_extract_trunc >>> ($57 >>> 0);
        $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($57 >>> 0);
        $q_sroa_0_1_ph = 0;
        $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $58;
        break;
      }
      if (($rem | 0) == 0) {
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      HEAP32[$rem >> 2] = 0 | $a$0 & -1;
      HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
      $_0$1 = 0;
      $_0$0 = 0;
      return (tempRet0 = $_0$1, $_0$0) | 0;
    } else {
      if (!$17) {
        $117 = Math_clz32($d_sroa_1_4_extract_trunc | 0) | 0;
        $119 = $117 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        if ($119 >>> 0 <= 31) {
          $125 = $119 + 1 | 0;
          $126 = 31 - $119 | 0;
          $130 = $119 - 31 >> 31;
          $sr_1_ph = $125;
          $r_sroa_0_1_ph = $n_sroa_0_0_extract_trunc >>> ($125 >>> 0) & $130 | $n_sroa_1_4_extract_trunc << $126;
          $r_sroa_1_1_ph = $n_sroa_1_4_extract_trunc >>> ($125 >>> 0) & $130;
          $q_sroa_0_1_ph = 0;
          $q_sroa_1_1_ph = $n_sroa_0_0_extract_trunc << $126;
          break;
        }
        if (($rem | 0) == 0) {
          $_0$1 = 0;
          $_0$0 = 0;
          return (tempRet0 = $_0$1, $_0$0) | 0;
        }
        HEAP32[$rem >> 2] = 0 | $a$0 & -1;
        HEAP32[$rem + 4 >> 2] = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$1 = 0;
        $_0$0 = 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
      $66 = $d_sroa_0_0_extract_trunc - 1 | 0;
      if (($66 & $d_sroa_0_0_extract_trunc | 0) != 0) {
        $86 = (Math_clz32($d_sroa_0_0_extract_trunc | 0) | 0) + 33 | 0;
        $88 = $86 - (Math_clz32($n_sroa_1_4_extract_trunc | 0) | 0) | 0;
        $89 = 64 - $88 | 0;
        $91 = 32 - $88 | 0;
        $92 = $91 >> 31;
        $95 = $88 - 32 | 0;
        $105 = $95 >> 31;
        $sr_1_ph = $88;
        $r_sroa_0_1_ph = $91 - 1 >> 31 & $n_sroa_1_4_extract_trunc >>> ($95 >>> 0) | ($n_sroa_1_4_extract_trunc << $91 | $n_sroa_0_0_extract_trunc >>> ($88 >>> 0)) & $105;
        $r_sroa_1_1_ph = $105 & $n_sroa_1_4_extract_trunc >>> ($88 >>> 0);
        $q_sroa_0_1_ph = $n_sroa_0_0_extract_trunc << $89 & $92;
        $q_sroa_1_1_ph = ($n_sroa_1_4_extract_trunc << $89 | $n_sroa_0_0_extract_trunc >>> ($95 >>> 0)) & $92 | $n_sroa_0_0_extract_trunc << $91 & $88 - 33 >> 31;
        break;
      }
      if (($rem | 0) != 0) {
        HEAP32[$rem >> 2] = $66 & $n_sroa_0_0_extract_trunc;
        HEAP32[$rem + 4 >> 2] = 0;
      }
      if (($d_sroa_0_0_extract_trunc | 0) == 1) {
        $_0$1 = $n_sroa_1_4_extract_shift$0 | $a$1 & 0;
        $_0$0 = 0 | $a$0 & -1;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      } else {
        $78 = _llvm_cttz_i32($d_sroa_0_0_extract_trunc | 0) | 0;
        $_0$1 = 0 | $n_sroa_1_4_extract_trunc >>> ($78 >>> 0);
        $_0$0 = $n_sroa_1_4_extract_trunc << 32 - $78 | $n_sroa_0_0_extract_trunc >>> ($78 >>> 0) | 0;
        return (tempRet0 = $_0$1, $_0$0) | 0;
      }
    }
  } while (0);
  if (($sr_1_ph | 0) == 0) {
    $q_sroa_1_1_lcssa = $q_sroa_1_1_ph;
    $q_sroa_0_1_lcssa = $q_sroa_0_1_ph;
    $r_sroa_1_1_lcssa = $r_sroa_1_1_ph;
    $r_sroa_0_1_lcssa = $r_sroa_0_1_ph;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = 0;
  } else {
    $d_sroa_0_0_insert_insert99$0 = 0 | $b$0 & -1;
    $d_sroa_0_0_insert_insert99$1 = $d_sroa_1_4_extract_shift$0 | $b$1 & 0;
    $137$0 = _i64Add($d_sroa_0_0_insert_insert99$0 | 0, $d_sroa_0_0_insert_insert99$1 | 0, -1, -1) | 0;
    $137$1 = tempRet0;
    $q_sroa_1_1198 = $q_sroa_1_1_ph;
    $q_sroa_0_1199 = $q_sroa_0_1_ph;
    $r_sroa_1_1200 = $r_sroa_1_1_ph;
    $r_sroa_0_1201 = $r_sroa_0_1_ph;
    $sr_1202 = $sr_1_ph;
    $carry_0203 = 0;
    while (1) {
      $147 = $q_sroa_0_1199 >>> 31 | $q_sroa_1_1198 << 1;
      $149 = $carry_0203 | $q_sroa_0_1199 << 1;
      $r_sroa_0_0_insert_insert42$0 = 0 | ($r_sroa_0_1201 << 1 | $q_sroa_1_1198 >>> 31);
      $r_sroa_0_0_insert_insert42$1 = $r_sroa_0_1201 >>> 31 | $r_sroa_1_1200 << 1 | 0;
      _i64Subtract($137$0, $137$1, $r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1) | 0;
      $150$1 = tempRet0;
      $151$0 = $150$1 >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1;
      $152 = $151$0 & 1;
      $154$0 = _i64Subtract($r_sroa_0_0_insert_insert42$0, $r_sroa_0_0_insert_insert42$1, $151$0 & $d_sroa_0_0_insert_insert99$0, ((($150$1 | 0) < 0 ? -1 : 0) >> 31 | (($150$1 | 0) < 0 ? -1 : 0) << 1) & $d_sroa_0_0_insert_insert99$1) | 0;
      $r_sroa_0_0_extract_trunc = $154$0;
      $r_sroa_1_4_extract_trunc = tempRet0;
      $155 = $sr_1202 - 1 | 0;
      if (($155 | 0) == 0) {
        break;
      } else {
        $q_sroa_1_1198 = $147;
        $q_sroa_0_1199 = $149;
        $r_sroa_1_1200 = $r_sroa_1_4_extract_trunc;
        $r_sroa_0_1201 = $r_sroa_0_0_extract_trunc;
        $sr_1202 = $155;
        $carry_0203 = $152;
      }
    }
    $q_sroa_1_1_lcssa = $147;
    $q_sroa_0_1_lcssa = $149;
    $r_sroa_1_1_lcssa = $r_sroa_1_4_extract_trunc;
    $r_sroa_0_1_lcssa = $r_sroa_0_0_extract_trunc;
    $carry_0_lcssa$1 = 0;
    $carry_0_lcssa$0 = $152;
  }
  $q_sroa_0_0_insert_ext75$0 = $q_sroa_0_1_lcssa;
  $q_sroa_0_0_insert_ext75$1 = 0;
  $q_sroa_0_0_insert_insert77$1 = $q_sroa_1_1_lcssa | $q_sroa_0_0_insert_ext75$1;
  if (($rem | 0) != 0) {
    HEAP32[$rem >> 2] = 0 | $r_sroa_0_1_lcssa;
    HEAP32[$rem + 4 >> 2] = $r_sroa_1_1_lcssa | 0;
  }
  $_0$1 = (0 | $q_sroa_0_0_insert_ext75$0) >>> 31 | $q_sroa_0_0_insert_insert77$1 << 1 | ($q_sroa_0_0_insert_ext75$1 << 1 | $q_sroa_0_0_insert_ext75$0 >>> 31) & 0 | $carry_0_lcssa$1;
  $_0$0 = ($q_sroa_0_0_insert_ext75$0 << 1 | 0 >>> 31) & -2 | $carry_0_lcssa$0;
  return (tempRet0 = $_0$1, $_0$0) | 0;
}
// =======================================================================



  
function dynCall_iiii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  return FUNCTION_TABLE_iiii[index&511](a1|0,a2|0,a3|0)|0;
}


function dynCall_i(index) {
  index = index|0;
  
  return FUNCTION_TABLE_i[index&511]()|0;
}


function dynCall_vi(index,a1) {
  index = index|0;
  a1=a1|0;
  FUNCTION_TABLE_vi[index&511](a1|0);
}


function dynCall_vii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  FUNCTION_TABLE_vii[index&511](a1|0,a2|0);
}


function dynCall_ii(index,a1) {
  index = index|0;
  a1=a1|0;
  return FUNCTION_TABLE_ii[index&511](a1|0)|0;
}


function dynCall_viii(index,a1,a2,a3) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0;
  FUNCTION_TABLE_viii[index&0](a1|0,a2|0,a3|0);
}


function dynCall_v(index) {
  index = index|0;
  
  FUNCTION_TABLE_v[index&511]();
}


function dynCall_iiiii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
  return FUNCTION_TABLE_iiiii[index&511](a1|0,a2|0,a3|0,a4|0)|0;
}


function dynCall_iii(index,a1,a2) {
  index = index|0;
  a1=a1|0; a2=a2|0;
  return FUNCTION_TABLE_iii[index&511](a1|0,a2|0)|0;
}


function dynCall_viiii(index,a1,a2,a3,a4) {
  index = index|0;
  a1=a1|0; a2=a2|0; a3=a3|0; a4=a4|0;
  FUNCTION_TABLE_viiii[index&511](a1|0,a2|0,a3|0,a4|0);
}

function b0(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_iiii(0);return 0; }
function b1() { ; nullFunc_i(1);return 0; }
function b2(p0) { p0 = p0|0; nullFunc_vi(2); }
function b3(p0,p1) { p0 = p0|0;p1 = p1|0; nullFunc_vii(3); }
function b4(p0) { p0 = p0|0; nullFunc_ii(4);return 0; }
function b5(p0,p1,p2) { p0 = p0|0;p1 = p1|0;p2 = p2|0; nullFunc_viii(5); }
function b6() { ; nullFunc_v(6); }
function b7(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_iiiii(7);return 0; }
function b8(p0,p1) { p0 = p0|0;p1 = p1|0; nullFunc_iii(8);return 0; }
function b9(p0,p1,p2,p3) { p0 = p0|0;p1 = p1|0;p2 = p2|0;p3 = p3|0; nullFunc_viiii(9); }

// EMSCRIPTEN_END_FUNCS
var FUNCTION_TABLE_iiii = [b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,_rl_quote_filename,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,_sn_write,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,_getF,_getS,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,_dofilecont,b0,b0,_generic_reader,_finishpcall,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,__rl_dispatch_subseq,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0,b0
,b0,b0,b0];
var FUNCTION_TABLE_i = [b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,_rl_read_key,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1,b1
,b1,b1,b1];
var FUNCTION_TABLE_vi = [b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,_rl_prep_terminal,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,_laction,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,__rl_signal_handler
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,_rl_signal_handler,_rl_sigwinch_handler,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2,b2
,b2,b2,b2];
var FUNCTION_TABLE_vii = [b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,_lstop,_growstack,_f_call,_resume,_unroll,_f_parser,_dothecall,b3,_f_luaopen,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,_hookf,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,__rl_complete_sigcleanup,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3,b3
,b3,b3,b3];
var FUNCTION_TABLE_ii = [b4,_luaB_assert,_luaB_collectgarbage,_luaB_dofile,_luaB_error,_luaB_getmetatable,_luaB_ipairs,_luaB_loadfile,_luaB_load,_luaB_next,_luaB_pairs,_luaB_pcall,_luaB_print,_luaB_rawequal,_luaB_rawlen,_luaB_rawget,_luaB_rawset,_luaB_select,_luaB_setmetatable,_luaB_tonumber,_luaB_tostring,_luaB_xpcall,_b_arshift,_b_and,_b_not,_b_or,_b_xor,_b_test,_b_extract
,_b_lrot,_b_lshift,_b_replace,_b_rrot,_b_rshift,_luaB_cocreate,_luaB_coresume,_luaB_corunning,_luaB_costatus,_luaB_cowrap,_luaB_yield,_luaB_yieldable,_db_debug,_db_getuservalue,_db_gethook,_db_getinfo,_db_getlocal,_db_getregistry,_db_getmetatable,_db_getupvalue,_db_upvaluejoin,_db_upvalueid,_db_setuservalue,_db_sethook,_db_setlocal,_db_setmetatable,_db_setupvalue,_db_traceback,_io_close,_io_flush
,_io_input,_io_lines,_io_open,_io_output,_io_popen,_io_read,_io_tmpfile,_io_type,_io_write,_f_flush,_f_lines,_f_read,_f_seek,_f_setvbuf,_f_write,_f_gc,_f_tostring,_math_abs,_math_acos,_math_asin,_math_atan,_math_ceil,_math_cos,_math_deg,_math_exp,_math_toint,_math_floor,_math_fmod,_math_ult,_math_log
,_math_max,_math_min,_math_modf,_math_rad,_math_random,_math_randomseed,_math_sin,_math_sqrt,_math_tan,_math_type,_math_cosh,_math_sinh,_math_tanh,_math_pow,_math_frexp,_math_ldexp,_math_log10,_os_clock,_os_date,_os_difftime,_os_execute,_os_exit,_os_getenv,_os_remove,_os_rename,_os_setlocale,_os_time,_os_tmpname,_str_byte,_str_char
,_str_dump,_str_find,_str_format,_gmatch,_str_gsub,_str_len,_str_lower,_str_match,_str_rep,_str_reverse,_str_sub,_str_upper,_str_pack,_str_packsize,_str_unpack,_tconcat,_tinsert,_pack,_unpack,_tremove,_tmove,_sort,_byteoffset,_codepoint,_utfchar,_utflen,_iter_codes,_ll_loadlib,_ll_searchpath,_ll_require
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,_parser_if,_parser_endif,_parser_else,_parser_include,_sv_bell_style,_sv_combegin,_sv_compwidth,_sv_dispprefix,_sv_compquery,_sv_editmode,_sv_histsize,_sv_isrchterm,_sv_keymap,_sv_seqtimeout,b4,_rl_getc,__nc_outch
,_info_hash,b4,_tcap_hash,b4,b4,_pmain,_msghandler,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,_panic,_luaopen_base,_luaopen_package,_luaopen_coroutine,_luaopen_table,_luaopen_io,_luaopen_os,_luaopen_string,_luaopen_math,_luaopen_utf8
,_luaopen_debug,_luaopen_bit32,_luaB_type,b4,_ipairsaux,_ipairsaux_raw,b4,b4,_luaB_auxwrap,b4,_io_noclose,_io_readline,_io_fclose,_io_pclose,b4,_gmatch_aux,b4,b4,b4,b4,_iter_aux,_gctm,_searcher_preload,_searcher_Lua,_searcher_C,_searcher_Croot,b4,b4,b4,b4
,b4,__rl_vi_callback_char_search,__rl_vi_callback_change_char,__rl_vi_callback_set_mark,__rl_vi_callback_goto_mark,b4,b4,b4,b4,__rl_output_character_function,b4,b4,__rl_insert_next_callback,__rl_char_search_callback,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4,b4
,b4,b4,b4];
var FUNCTION_TABLE_viii = [b5];
var FUNCTION_TABLE_v = [b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_rl_deprep_terminal,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,_rl_redisplay,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,__rl_reset_argument,b6,b6,b6
,__rl_internal_char_cleanup,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6,b6
,b6,b6,b6];
var FUNCTION_TABLE_iiiii = [b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,_l_alloc,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,_writer,b7,_lua_geti,_lua_rawgeti,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7,b7
,b7,b7,b7];
var FUNCTION_TABLE_iii = [b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,_rl_abort,_rl_newline,_rl_arrow_keys,_rl_backward_byte,_rl_backward_char,_rl_rubout,_rl_backward_kill_line,_rl_backward_kill_word,_rl_backward_word,_rl_beginning_of_history,_rl_beg_of_line,_rl_call_last_kbd_macro,_rl_capitalize_word,_rl_char_search,_rl_backward_char_search,_rl_clear_screen,_rl_complete,_rl_copy_backward_word,_rl_copy_forward_word,_rl_copy_region_to_kill,_rl_delete,_rl_delete_or_show_completions,_rl_delete_horizontal_space,_rl_digit_argument,_rl_do_lowercase_version,_rl_downcase_word,_rl_dump_functions,_rl_dump_macros,_rl_dump_variables,_rl_emacs_editing_mode
,_rl_end_kbd_macro,_rl_end_of_history,_rl_end_of_line,_rl_exchange_point_and_mark,_rl_rubout_or_delete,_rl_forward_byte,_rl_forward_char,_rl_forward_search_history,_rl_forward_word,_rl_history_search_backward,_rl_history_search_forward,_rl_history_substr_search_backward,_rl_history_substr_search_forward,_rl_insert_comment,_rl_insert_completions,_rl_kill_full_line,_rl_kill_line,_rl_kill_region,_rl_kill_word,_rl_menu_complete,_rl_backward_menu_complete,_rl_get_next_history,_rl_noninc_forward_search,_rl_noninc_reverse_search,_rl_noninc_forward_search_again,_rl_noninc_reverse_search_again,_rl_old_menu_complete,_rl_overwrite_mode,_rl_possible_completions,_rl_get_previous_history
,_rl_print_last_kbd_macro,_rl_quoted_insert,_rl_re_read_init_file,_rl_refresh_line,_rl_reverse_search_history,_rl_revert_line,_rl_insert,_rl_set_mark,_rl_skip_csi_sequence,_rl_start_kbd_macro,_rl_tab_insert,_rl_tilde_expand,_rl_transpose_chars,_rl_transpose_words,_rl_tty_status,_rl_undo_command,_rl_universal_argument,_rl_unix_filename_rubout,_rl_unix_line_discard,_rl_unix_word_rubout,_rl_upcase_word,_rl_yank,_rl_yank_last_arg,_rl_yank_nth_arg,_rl_yank_pop,_rl_vi_append_eol,_rl_vi_append_mode,_rl_vi_arg_digit,_rl_vi_back_to_indent,_rl_vi_bWord
,_rl_vi_bword,_rl_vi_change_case,_rl_vi_change_char,_rl_vi_change_to,_rl_vi_char_search,_rl_vi_column,_rl_vi_complete,_rl_vi_delete,_rl_vi_delete_to,_rl_vi_eWord,_rl_vi_editing_mode,_rl_vi_end_word,_rl_vi_eof_maybe,_rl_vi_eword,_rl_vi_fWord,_rl_vi_fetch_history,_rl_vi_first_print,_rl_vi_fword,_rl_vi_goto_mark,_rl_vi_insert_beg,_rl_vi_insertion_mode,_rl_vi_match,_rl_vi_movement_mode,_rl_vi_next_word,_rl_vi_overstrike,_rl_vi_overstrike_delete,_rl_vi_prev_word,_rl_vi_put,_rl_vi_redo,_rl_vi_replace
,_rl_vi_rubout,_rl_vi_search,_rl_vi_search_again,_rl_vi_set_mark,_rl_vi_subst,_rl_vi_tilde_expand,_rl_vi_yank_arg,_rl_vi_yank_to,_rl_vi_undo,_rl_vi_insert_mode,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,_compare_info_names,b8,_compare_tcap_names,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,_lua_newstate,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,__rl_qsort_string_compare,_rl_filename_completion_function,b8,__rl_null_function,b8,b8,b8,b8,b8,_rl_insert_close,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8,b8
,b8,b8,b8];
var FUNCTION_TABLE_viiii = [b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,_lua_seti,_lua_rawseti,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9,b9
,b9,b9,b9];

  return { _testSetjmp: _testSetjmp, _i64Subtract: _i64Subtract, _strcat: _strcat, _free: _free, _main: _main, _i64Add: _i64Add, _memmove: _memmove, _saveSetjmp: _saveSetjmp, _memset: _memset, _malloc: _malloc, _strncpy: _strncpy, _memcpy: _memcpy, _strlen: _strlen, _bitshift64Lshr: _bitshift64Lshr, _strcpy: _strcpy, _bitshift64Shl: _bitshift64Shl, runPostSets: runPostSets, stackAlloc: stackAlloc, stackSave: stackSave, stackRestore: stackRestore, establishStackSpace: establishStackSpace, setThrew: setThrew, setTempRet0: setTempRet0, getTempRet0: getTempRet0, dynCall_iiii: dynCall_iiii, dynCall_i: dynCall_i, dynCall_vi: dynCall_vi, dynCall_vii: dynCall_vii, dynCall_ii: dynCall_ii, dynCall_viii: dynCall_viii, dynCall_v: dynCall_v, dynCall_iiiii: dynCall_iiiii, dynCall_iii: dynCall_iii, dynCall_viiii: dynCall_viiii };
})
// EMSCRIPTEN_END_ASM
(Module.asmGlobalArg, Module.asmLibraryArg, buffer);
var real__testSetjmp = asm["_testSetjmp"]; asm["_testSetjmp"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__testSetjmp.apply(null, arguments);
};

var real__i64Subtract = asm["_i64Subtract"]; asm["_i64Subtract"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Subtract.apply(null, arguments);
};

var real__strcat = asm["_strcat"]; asm["_strcat"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__strcat.apply(null, arguments);
};

var real__free = asm["_free"]; asm["_free"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__free.apply(null, arguments);
};

var real__main = asm["_main"]; asm["_main"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__main.apply(null, arguments);
};

var real__i64Add = asm["_i64Add"]; asm["_i64Add"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__i64Add.apply(null, arguments);
};

var real__memmove = asm["_memmove"]; asm["_memmove"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__memmove.apply(null, arguments);
};

var real__saveSetjmp = asm["_saveSetjmp"]; asm["_saveSetjmp"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__saveSetjmp.apply(null, arguments);
};

var real__malloc = asm["_malloc"]; asm["_malloc"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__malloc.apply(null, arguments);
};

var real__strncpy = asm["_strncpy"]; asm["_strncpy"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__strncpy.apply(null, arguments);
};

var real__strlen = asm["_strlen"]; asm["_strlen"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__strlen.apply(null, arguments);
};

var real__bitshift64Lshr = asm["_bitshift64Lshr"]; asm["_bitshift64Lshr"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Lshr.apply(null, arguments);
};

var real__strcpy = asm["_strcpy"]; asm["_strcpy"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__strcpy.apply(null, arguments);
};

var real__bitshift64Shl = asm["_bitshift64Shl"]; asm["_bitshift64Shl"] = function() {
assert(runtimeInitialized, 'you need to wait for the runtime to be ready (e.g. wait for main() to be called)');
assert(!runtimeExited, 'the runtime was exited (use NO_EXIT_RUNTIME to keep it alive after main() exits)');
return real__bitshift64Shl.apply(null, arguments);
};
var _testSetjmp = Module["_testSetjmp"] = asm["_testSetjmp"];
var _i64Subtract = Module["_i64Subtract"] = asm["_i64Subtract"];
var _strcat = Module["_strcat"] = asm["_strcat"];
var _free = Module["_free"] = asm["_free"];
var _main = Module["_main"] = asm["_main"];
var _i64Add = Module["_i64Add"] = asm["_i64Add"];
var _memmove = Module["_memmove"] = asm["_memmove"];
var _saveSetjmp = Module["_saveSetjmp"] = asm["_saveSetjmp"];
var _memset = Module["_memset"] = asm["_memset"];
var _malloc = Module["_malloc"] = asm["_malloc"];
var _strncpy = Module["_strncpy"] = asm["_strncpy"];
var _memcpy = Module["_memcpy"] = asm["_memcpy"];
var _strlen = Module["_strlen"] = asm["_strlen"];
var runPostSets = Module["runPostSets"] = asm["runPostSets"];
var _bitshift64Lshr = Module["_bitshift64Lshr"] = asm["_bitshift64Lshr"];
var _strcpy = Module["_strcpy"] = asm["_strcpy"];
var _bitshift64Shl = Module["_bitshift64Shl"] = asm["_bitshift64Shl"];
var dynCall_iiii = Module["dynCall_iiii"] = asm["dynCall_iiii"];
var dynCall_i = Module["dynCall_i"] = asm["dynCall_i"];
var dynCall_vi = Module["dynCall_vi"] = asm["dynCall_vi"];
var dynCall_vii = Module["dynCall_vii"] = asm["dynCall_vii"];
var dynCall_ii = Module["dynCall_ii"] = asm["dynCall_ii"];
var dynCall_viii = Module["dynCall_viii"] = asm["dynCall_viii"];
var dynCall_v = Module["dynCall_v"] = asm["dynCall_v"];
var dynCall_iiiii = Module["dynCall_iiiii"] = asm["dynCall_iiiii"];
var dynCall_iii = Module["dynCall_iii"] = asm["dynCall_iii"];
var dynCall_viiii = Module["dynCall_viiii"] = asm["dynCall_viiii"];
;

Runtime.stackAlloc = asm['stackAlloc'];
Runtime.stackSave = asm['stackSave'];
Runtime.stackRestore = asm['stackRestore'];
Runtime.establishStackSpace = asm['establishStackSpace'];

Runtime.setTempRet0 = asm['setTempRet0'];
Runtime.getTempRet0 = asm['getTempRet0'];


// TODO: strip out parts of this we do not need

//======= begin closure i64 code =======

// Copyright 2009 The Closure Library Authors. All Rights Reserved.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//      http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS-IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

/**
 * @fileoverview Defines a Long class for representing a 64-bit two's-complement
 * integer value, which faithfully simulates the behavior of a Java "long". This
 * implementation is derived from LongLib in GWT.
 *
 */

var i64Math = (function() { // Emscripten wrapper
  var goog = { math: {} };


  /**
   * Constructs a 64-bit two's-complement integer, given its low and high 32-bit
   * values as *signed* integers.  See the from* functions below for more
   * convenient ways of constructing Longs.
   *
   * The internal representation of a long is the two given signed, 32-bit values.
   * We use 32-bit pieces because these are the size of integers on which
   * Javascript performs bit-operations.  For operations like addition and
   * multiplication, we split each number into 16-bit pieces, which can easily be
   * multiplied within Javascript's floating-point representation without overflow
   * or change in sign.
   *
   * In the algorithms below, we frequently reduce the negative case to the
   * positive case by negating the input(s) and then post-processing the result.
   * Note that we must ALWAYS check specially whether those values are MIN_VALUE
   * (-2^63) because -MIN_VALUE == MIN_VALUE (since 2^63 cannot be represented as
   * a positive number, it overflows back into a negative).  Not handling this
   * case would often result in infinite recursion.
   *
   * @param {number} low  The low (signed) 32 bits of the long.
   * @param {number} high  The high (signed) 32 bits of the long.
   * @constructor
   */
  goog.math.Long = function(low, high) {
    /**
     * @type {number}
     * @private
     */
    this.low_ = low | 0;  // force into 32 signed bits.

    /**
     * @type {number}
     * @private
     */
    this.high_ = high | 0;  // force into 32 signed bits.
  };


  // NOTE: Common constant values ZERO, ONE, NEG_ONE, etc. are defined below the
  // from* methods on which they depend.


  /**
   * A cache of the Long representations of small integer values.
   * @type {!Object}
   * @private
   */
  goog.math.Long.IntCache_ = {};


  /**
   * Returns a Long representing the given (32-bit) integer value.
   * @param {number} value The 32-bit integer in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromInt = function(value) {
    if (-128 <= value && value < 128) {
      var cachedObj = goog.math.Long.IntCache_[value];
      if (cachedObj) {
        return cachedObj;
      }
    }

    var obj = new goog.math.Long(value | 0, value < 0 ? -1 : 0);
    if (-128 <= value && value < 128) {
      goog.math.Long.IntCache_[value] = obj;
    }
    return obj;
  };


  /**
   * Returns a Long representing the given value, provided that it is a finite
   * number.  Otherwise, zero is returned.
   * @param {number} value The number in question.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromNumber = function(value) {
    if (isNaN(value) || !isFinite(value)) {
      return goog.math.Long.ZERO;
    } else if (value <= -goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MIN_VALUE;
    } else if (value + 1 >= goog.math.Long.TWO_PWR_63_DBL_) {
      return goog.math.Long.MAX_VALUE;
    } else if (value < 0) {
      return goog.math.Long.fromNumber(-value).negate();
    } else {
      return new goog.math.Long(
          (value % goog.math.Long.TWO_PWR_32_DBL_) | 0,
          (value / goog.math.Long.TWO_PWR_32_DBL_) | 0);
    }
  };


  /**
   * Returns a Long representing the 64-bit integer that comes by concatenating
   * the given high and low bits.  Each is assumed to use 32 bits.
   * @param {number} lowBits The low 32-bits.
   * @param {number} highBits The high 32-bits.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromBits = function(lowBits, highBits) {
    return new goog.math.Long(lowBits, highBits);
  };


  /**
   * Returns a Long representation of the given string, written using the given
   * radix.
   * @param {string} str The textual representation of the Long.
   * @param {number=} opt_radix The radix in which the text is written.
   * @return {!goog.math.Long} The corresponding Long value.
   */
  goog.math.Long.fromString = function(str, opt_radix) {
    if (str.length == 0) {
      throw Error('number format error: empty string');
    }

    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (str.charAt(0) == '-') {
      return goog.math.Long.fromString(str.substring(1), radix).negate();
    } else if (str.indexOf('-') >= 0) {
      throw Error('number format error: interior "-" character: ' + str);
    }

    // Do several (8) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 8));

    var result = goog.math.Long.ZERO;
    for (var i = 0; i < str.length; i += 8) {
      var size = Math.min(8, str.length - i);
      var value = parseInt(str.substring(i, i + size), radix);
      if (size < 8) {
        var power = goog.math.Long.fromNumber(Math.pow(radix, size));
        result = result.multiply(power).add(goog.math.Long.fromNumber(value));
      } else {
        result = result.multiply(radixToPower);
        result = result.add(goog.math.Long.fromNumber(value));
      }
    }
    return result;
  };


  // NOTE: the compiler should inline these constant values below and then remove
  // these variables, so there should be no runtime penalty for these.


  /**
   * Number used repeated below in calculations.  This must appear before the
   * first call to any from* function below.
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_16_DBL_ = 1 << 16;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_24_DBL_ = 1 << 24;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_32_DBL_ =
      goog.math.Long.TWO_PWR_16_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_31_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ / 2;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_48_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_16_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_64_DBL_ =
      goog.math.Long.TWO_PWR_32_DBL_ * goog.math.Long.TWO_PWR_32_DBL_;


  /**
   * @type {number}
   * @private
   */
  goog.math.Long.TWO_PWR_63_DBL_ =
      goog.math.Long.TWO_PWR_64_DBL_ / 2;


  /** @type {!goog.math.Long} */
  goog.math.Long.ZERO = goog.math.Long.fromInt(0);


  /** @type {!goog.math.Long} */
  goog.math.Long.ONE = goog.math.Long.fromInt(1);


  /** @type {!goog.math.Long} */
  goog.math.Long.NEG_ONE = goog.math.Long.fromInt(-1);


  /** @type {!goog.math.Long} */
  goog.math.Long.MAX_VALUE =
      goog.math.Long.fromBits(0xFFFFFFFF | 0, 0x7FFFFFFF | 0);


  /** @type {!goog.math.Long} */
  goog.math.Long.MIN_VALUE = goog.math.Long.fromBits(0, 0x80000000 | 0);


  /**
   * @type {!goog.math.Long}
   * @private
   */
  goog.math.Long.TWO_PWR_24_ = goog.math.Long.fromInt(1 << 24);


  /** @return {number} The value, assuming it is a 32-bit integer. */
  goog.math.Long.prototype.toInt = function() {
    return this.low_;
  };


  /** @return {number} The closest floating-point representation to this value. */
  goog.math.Long.prototype.toNumber = function() {
    return this.high_ * goog.math.Long.TWO_PWR_32_DBL_ +
           this.getLowBitsUnsigned();
  };


  /**
   * @param {number=} opt_radix The radix in which the text should be written.
   * @return {string} The textual representation of this value.
   */
  goog.math.Long.prototype.toString = function(opt_radix) {
    var radix = opt_radix || 10;
    if (radix < 2 || 36 < radix) {
      throw Error('radix out of range: ' + radix);
    }

    if (this.isZero()) {
      return '0';
    }

    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        // We need to change the Long value before it can be negated, so we remove
        // the bottom-most digit in this base and then recurse to do the rest.
        var radixLong = goog.math.Long.fromNumber(radix);
        var div = this.div(radixLong);
        var rem = div.multiply(radixLong).subtract(this);
        return div.toString(radix) + rem.toInt().toString(radix);
      } else {
        return '-' + this.negate().toString(radix);
      }
    }

    // Do several (6) digits each time through the loop, so as to
    // minimize the calls to the very expensive emulated div.
    var radixToPower = goog.math.Long.fromNumber(Math.pow(radix, 6));

    var rem = this;
    var result = '';
    while (true) {
      var remDiv = rem.div(radixToPower);
      var intval = rem.subtract(remDiv.multiply(radixToPower)).toInt();
      var digits = intval.toString(radix);

      rem = remDiv;
      if (rem.isZero()) {
        return digits + result;
      } else {
        while (digits.length < 6) {
          digits = '0' + digits;
        }
        result = '' + digits + result;
      }
    }
  };


  /** @return {number} The high 32-bits as a signed value. */
  goog.math.Long.prototype.getHighBits = function() {
    return this.high_;
  };


  /** @return {number} The low 32-bits as a signed value. */
  goog.math.Long.prototype.getLowBits = function() {
    return this.low_;
  };


  /** @return {number} The low 32-bits as an unsigned value. */
  goog.math.Long.prototype.getLowBitsUnsigned = function() {
    return (this.low_ >= 0) ?
        this.low_ : goog.math.Long.TWO_PWR_32_DBL_ + this.low_;
  };


  /**
   * @return {number} Returns the number of bits needed to represent the absolute
   *     value of this Long.
   */
  goog.math.Long.prototype.getNumBitsAbs = function() {
    if (this.isNegative()) {
      if (this.equals(goog.math.Long.MIN_VALUE)) {
        return 64;
      } else {
        return this.negate().getNumBitsAbs();
      }
    } else {
      var val = this.high_ != 0 ? this.high_ : this.low_;
      for (var bit = 31; bit > 0; bit--) {
        if ((val & (1 << bit)) != 0) {
          break;
        }
      }
      return this.high_ != 0 ? bit + 33 : bit + 1;
    }
  };


  /** @return {boolean} Whether this value is zero. */
  goog.math.Long.prototype.isZero = function() {
    return this.high_ == 0 && this.low_ == 0;
  };


  /** @return {boolean} Whether this value is negative. */
  goog.math.Long.prototype.isNegative = function() {
    return this.high_ < 0;
  };


  /** @return {boolean} Whether this value is odd. */
  goog.math.Long.prototype.isOdd = function() {
    return (this.low_ & 1) == 1;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long equals the other.
   */
  goog.math.Long.prototype.equals = function(other) {
    return (this.high_ == other.high_) && (this.low_ == other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long does not equal the other.
   */
  goog.math.Long.prototype.notEquals = function(other) {
    return (this.high_ != other.high_) || (this.low_ != other.low_);
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than the other.
   */
  goog.math.Long.prototype.lessThan = function(other) {
    return this.compare(other) < 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is less than or equal to the other.
   */
  goog.math.Long.prototype.lessThanOrEqual = function(other) {
    return this.compare(other) <= 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than the other.
   */
  goog.math.Long.prototype.greaterThan = function(other) {
    return this.compare(other) > 0;
  };


  /**
   * @param {goog.math.Long} other Long to compare against.
   * @return {boolean} Whether this Long is greater than or equal to the other.
   */
  goog.math.Long.prototype.greaterThanOrEqual = function(other) {
    return this.compare(other) >= 0;
  };


  /**
   * Compares this Long with the given one.
   * @param {goog.math.Long} other Long to compare against.
   * @return {number} 0 if they are the same, 1 if the this is greater, and -1
   *     if the given one is greater.
   */
  goog.math.Long.prototype.compare = function(other) {
    if (this.equals(other)) {
      return 0;
    }

    var thisNeg = this.isNegative();
    var otherNeg = other.isNegative();
    if (thisNeg && !otherNeg) {
      return -1;
    }
    if (!thisNeg && otherNeg) {
      return 1;
    }

    // at this point, the signs are the same, so subtraction will not overflow
    if (this.subtract(other).isNegative()) {
      return -1;
    } else {
      return 1;
    }
  };


  /** @return {!goog.math.Long} The negation of this value. */
  goog.math.Long.prototype.negate = function() {
    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.MIN_VALUE;
    } else {
      return this.not().add(goog.math.Long.ONE);
    }
  };


  /**
   * Returns the sum of this and the given Long.
   * @param {goog.math.Long} other Long to add to this one.
   * @return {!goog.math.Long} The sum of this and the given Long.
   */
  goog.math.Long.prototype.add = function(other) {
    // Divide each number into 4 chunks of 16 bits, and then sum the chunks.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 + b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 + b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 + b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 + b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns the difference of this and the given Long.
   * @param {goog.math.Long} other Long to subtract from this.
   * @return {!goog.math.Long} The difference of this and the given Long.
   */
  goog.math.Long.prototype.subtract = function(other) {
    return this.add(other.negate());
  };


  /**
   * Returns the product of this and the given long.
   * @param {goog.math.Long} other Long to multiply with this.
   * @return {!goog.math.Long} The product of this and the other.
   */
  goog.math.Long.prototype.multiply = function(other) {
    if (this.isZero()) {
      return goog.math.Long.ZERO;
    } else if (other.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      return other.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return this.isOdd() ? goog.math.Long.MIN_VALUE : goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().multiply(other.negate());
      } else {
        return this.negate().multiply(other).negate();
      }
    } else if (other.isNegative()) {
      return this.multiply(other.negate()).negate();
    }

    // If both longs are small, use float multiplication
    if (this.lessThan(goog.math.Long.TWO_PWR_24_) &&
        other.lessThan(goog.math.Long.TWO_PWR_24_)) {
      return goog.math.Long.fromNumber(this.toNumber() * other.toNumber());
    }

    // Divide each long into 4 chunks of 16 bits, and then add up 4x4 products.
    // We can skip products that would overflow.

    var a48 = this.high_ >>> 16;
    var a32 = this.high_ & 0xFFFF;
    var a16 = this.low_ >>> 16;
    var a00 = this.low_ & 0xFFFF;

    var b48 = other.high_ >>> 16;
    var b32 = other.high_ & 0xFFFF;
    var b16 = other.low_ >>> 16;
    var b00 = other.low_ & 0xFFFF;

    var c48 = 0, c32 = 0, c16 = 0, c00 = 0;
    c00 += a00 * b00;
    c16 += c00 >>> 16;
    c00 &= 0xFFFF;
    c16 += a16 * b00;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c16 += a00 * b16;
    c32 += c16 >>> 16;
    c16 &= 0xFFFF;
    c32 += a32 * b00;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a16 * b16;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c32 += a00 * b32;
    c48 += c32 >>> 16;
    c32 &= 0xFFFF;
    c48 += a48 * b00 + a32 * b16 + a16 * b32 + a00 * b48;
    c48 &= 0xFFFF;
    return goog.math.Long.fromBits((c16 << 16) | c00, (c48 << 16) | c32);
  };


  /**
   * Returns this Long divided by the given one.
   * @param {goog.math.Long} other Long by which to divide.
   * @return {!goog.math.Long} This Long divided by the given one.
   */
  goog.math.Long.prototype.div = function(other) {
    if (other.isZero()) {
      throw Error('division by zero');
    } else if (this.isZero()) {
      return goog.math.Long.ZERO;
    }

    if (this.equals(goog.math.Long.MIN_VALUE)) {
      if (other.equals(goog.math.Long.ONE) ||
          other.equals(goog.math.Long.NEG_ONE)) {
        return goog.math.Long.MIN_VALUE;  // recall that -MIN_VALUE == MIN_VALUE
      } else if (other.equals(goog.math.Long.MIN_VALUE)) {
        return goog.math.Long.ONE;
      } else {
        // At this point, we have |other| >= 2, so |this/other| < |MIN_VALUE|.
        var halfThis = this.shiftRight(1);
        var approx = halfThis.div(other).shiftLeft(1);
        if (approx.equals(goog.math.Long.ZERO)) {
          return other.isNegative() ? goog.math.Long.ONE : goog.math.Long.NEG_ONE;
        } else {
          var rem = this.subtract(other.multiply(approx));
          var result = approx.add(rem.div(other));
          return result;
        }
      }
    } else if (other.equals(goog.math.Long.MIN_VALUE)) {
      return goog.math.Long.ZERO;
    }

    if (this.isNegative()) {
      if (other.isNegative()) {
        return this.negate().div(other.negate());
      } else {
        return this.negate().div(other).negate();
      }
    } else if (other.isNegative()) {
      return this.div(other.negate()).negate();
    }

    // Repeat the following until the remainder is less than other:  find a
    // floating-point that approximates remainder / other *from below*, add this
    // into the result, and subtract it from the remainder.  It is critical that
    // the approximate value is less than or equal to the real value so that the
    // remainder never becomes negative.
    var res = goog.math.Long.ZERO;
    var rem = this;
    while (rem.greaterThanOrEqual(other)) {
      // Approximate the result of division. This may be a little greater or
      // smaller than the actual value.
      var approx = Math.max(1, Math.floor(rem.toNumber() / other.toNumber()));

      // We will tweak the approximate result by changing it in the 48-th digit or
      // the smallest non-fractional digit, whichever is larger.
      var log2 = Math.ceil(Math.log(approx) / Math.LN2);
      var delta = (log2 <= 48) ? 1 : Math.pow(2, log2 - 48);

      // Decrease the approximation until it is smaller than the remainder.  Note
      // that if it is too large, the product overflows and is negative.
      var approxRes = goog.math.Long.fromNumber(approx);
      var approxRem = approxRes.multiply(other);
      while (approxRem.isNegative() || approxRem.greaterThan(rem)) {
        approx -= delta;
        approxRes = goog.math.Long.fromNumber(approx);
        approxRem = approxRes.multiply(other);
      }

      // We know the answer can't be zero... and actually, zero would cause
      // infinite recursion since we would make no progress.
      if (approxRes.isZero()) {
        approxRes = goog.math.Long.ONE;
      }

      res = res.add(approxRes);
      rem = rem.subtract(approxRem);
    }
    return res;
  };


  /**
   * Returns this Long modulo the given one.
   * @param {goog.math.Long} other Long by which to mod.
   * @return {!goog.math.Long} This Long modulo the given one.
   */
  goog.math.Long.prototype.modulo = function(other) {
    return this.subtract(this.div(other).multiply(other));
  };


  /** @return {!goog.math.Long} The bitwise-NOT of this value. */
  goog.math.Long.prototype.not = function() {
    return goog.math.Long.fromBits(~this.low_, ~this.high_);
  };


  /**
   * Returns the bitwise-AND of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to AND.
   * @return {!goog.math.Long} The bitwise-AND of this and the other.
   */
  goog.math.Long.prototype.and = function(other) {
    return goog.math.Long.fromBits(this.low_ & other.low_,
                                   this.high_ & other.high_);
  };


  /**
   * Returns the bitwise-OR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to OR.
   * @return {!goog.math.Long} The bitwise-OR of this and the other.
   */
  goog.math.Long.prototype.or = function(other) {
    return goog.math.Long.fromBits(this.low_ | other.low_,
                                   this.high_ | other.high_);
  };


  /**
   * Returns the bitwise-XOR of this Long and the given one.
   * @param {goog.math.Long} other The Long with which to XOR.
   * @return {!goog.math.Long} The bitwise-XOR of this and the other.
   */
  goog.math.Long.prototype.xor = function(other) {
    return goog.math.Long.fromBits(this.low_ ^ other.low_,
                                   this.high_ ^ other.high_);
  };


  /**
   * Returns this Long with bits shifted to the left by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the left by the given amount.
   */
  goog.math.Long.prototype.shiftLeft = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var low = this.low_;
      if (numBits < 32) {
        var high = this.high_;
        return goog.math.Long.fromBits(
            low << numBits,
            (high << numBits) | (low >>> (32 - numBits)));
      } else {
        return goog.math.Long.fromBits(0, low << (numBits - 32));
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount.
   */
  goog.math.Long.prototype.shiftRight = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >> numBits);
      } else {
        return goog.math.Long.fromBits(
            high >> (numBits - 32),
            high >= 0 ? 0 : -1);
      }
    }
  };


  /**
   * Returns this Long with bits shifted to the right by the given amount, with
   * the new top bits matching the current sign bit.
   * @param {number} numBits The number of bits by which to shift.
   * @return {!goog.math.Long} This shifted to the right by the given amount, with
   *     zeros placed into the new leading bits.
   */
  goog.math.Long.prototype.shiftRightUnsigned = function(numBits) {
    numBits &= 63;
    if (numBits == 0) {
      return this;
    } else {
      var high = this.high_;
      if (numBits < 32) {
        var low = this.low_;
        return goog.math.Long.fromBits(
            (low >>> numBits) | (high << (32 - numBits)),
            high >>> numBits);
      } else if (numBits == 32) {
        return goog.math.Long.fromBits(high, 0);
      } else {
        return goog.math.Long.fromBits(high >>> (numBits - 32), 0);
      }
    }
  };

  //======= begin jsbn =======

  var navigator = { appName: 'Modern Browser' }; // polyfill a little

  // Copyright (c) 2005  Tom Wu
  // All Rights Reserved.
  // http://www-cs-students.stanford.edu/~tjw/jsbn/

  /*
   * Copyright (c) 2003-2005  Tom Wu
   * All Rights Reserved.
   *
   * Permission is hereby granted, free of charge, to any person obtaining
   * a copy of this software and associated documentation files (the
   * "Software"), to deal in the Software without restriction, including
   * without limitation the rights to use, copy, modify, merge, publish,
   * distribute, sublicense, and/or sell copies of the Software, and to
   * permit persons to whom the Software is furnished to do so, subject to
   * the following conditions:
   *
   * The above copyright notice and this permission notice shall be
   * included in all copies or substantial portions of the Software.
   *
   * THE SOFTWARE IS PROVIDED "AS-IS" AND WITHOUT WARRANTY OF ANY KIND, 
   * EXPRESS, IMPLIED OR OTHERWISE, INCLUDING WITHOUT LIMITATION, ANY 
   * WARRANTY OF MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.  
   *
   * IN NO EVENT SHALL TOM WU BE LIABLE FOR ANY SPECIAL, INCIDENTAL,
   * INDIRECT OR CONSEQUENTIAL DAMAGES OF ANY KIND, OR ANY DAMAGES WHATSOEVER
   * RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER OR NOT ADVISED OF
   * THE POSSIBILITY OF DAMAGE, AND ON ANY THEORY OF LIABILITY, ARISING OUT
   * OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
   *
   * In addition, the following condition applies:
   *
   * All redistributions must retain an intact copy of this copyright notice
   * and disclaimer.
   */

  // Basic JavaScript BN library - subset useful for RSA encryption.

  // Bits per digit
  var dbits;

  // JavaScript engine analysis
  var canary = 0xdeadbeefcafe;
  var j_lm = ((canary&0xffffff)==0xefcafe);

  // (public) Constructor
  function BigInteger(a,b,c) {
    if(a != null)
      if("number" == typeof a) this.fromNumber(a,b,c);
      else if(b == null && "string" != typeof a) this.fromString(a,256);
      else this.fromString(a,b);
  }

  // return new, unset BigInteger
  function nbi() { return new BigInteger(null); }

  // am: Compute w_j += (x*this_i), propagate carries,
  // c is initial carry, returns final carry.
  // c < 3*dvalue, x < 2*dvalue, this_i < dvalue
  // We need to select the fastest one that works in this environment.

  // am1: use a single mult and divide to get the high bits,
  // max digit bits should be 26 because
  // max internal value = 2*dvalue^2-2*dvalue (< 2^53)
  function am1(i,x,w,j,c,n) {
    while(--n >= 0) {
      var v = x*this[i++]+w[j]+c;
      c = Math.floor(v/0x4000000);
      w[j++] = v&0x3ffffff;
    }
    return c;
  }
  // am2 avoids a big mult-and-extract completely.
  // Max digit bits should be <= 30 because we do bitwise ops
  // on values up to 2*hdvalue^2-hdvalue-1 (< 2^31)
  function am2(i,x,w,j,c,n) {
    var xl = x&0x7fff, xh = x>>15;
    while(--n >= 0) {
      var l = this[i]&0x7fff;
      var h = this[i++]>>15;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x7fff)<<15)+w[j]+(c&0x3fffffff);
      c = (l>>>30)+(m>>>15)+xh*h+(c>>>30);
      w[j++] = l&0x3fffffff;
    }
    return c;
  }
  // Alternately, set max digit bits to 28 since some
  // browsers slow down when dealing with 32-bit numbers.
  function am3(i,x,w,j,c,n) {
    var xl = x&0x3fff, xh = x>>14;
    while(--n >= 0) {
      var l = this[i]&0x3fff;
      var h = this[i++]>>14;
      var m = xh*l+h*xl;
      l = xl*l+((m&0x3fff)<<14)+w[j]+c;
      c = (l>>28)+(m>>14)+xh*h;
      w[j++] = l&0xfffffff;
    }
    return c;
  }
  if(j_lm && (navigator.appName == "Microsoft Internet Explorer")) {
    BigInteger.prototype.am = am2;
    dbits = 30;
  }
  else if(j_lm && (navigator.appName != "Netscape")) {
    BigInteger.prototype.am = am1;
    dbits = 26;
  }
  else { // Mozilla/Netscape seems to prefer am3
    BigInteger.prototype.am = am3;
    dbits = 28;
  }

  BigInteger.prototype.DB = dbits;
  BigInteger.prototype.DM = ((1<<dbits)-1);
  BigInteger.prototype.DV = (1<<dbits);

  var BI_FP = 52;
  BigInteger.prototype.FV = Math.pow(2,BI_FP);
  BigInteger.prototype.F1 = BI_FP-dbits;
  BigInteger.prototype.F2 = 2*dbits-BI_FP;

  // Digit conversions
  var BI_RM = "0123456789abcdefghijklmnopqrstuvwxyz";
  var BI_RC = new Array();
  var rr,vv;
  rr = "0".charCodeAt(0);
  for(vv = 0; vv <= 9; ++vv) BI_RC[rr++] = vv;
  rr = "a".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;
  rr = "A".charCodeAt(0);
  for(vv = 10; vv < 36; ++vv) BI_RC[rr++] = vv;

  function int2char(n) { return BI_RM.charAt(n); }
  function intAt(s,i) {
    var c = BI_RC[s.charCodeAt(i)];
    return (c==null)?-1:c;
  }

  // (protected) copy this to r
  function bnpCopyTo(r) {
    for(var i = this.t-1; i >= 0; --i) r[i] = this[i];
    r.t = this.t;
    r.s = this.s;
  }

  // (protected) set from integer value x, -DV <= x < DV
  function bnpFromInt(x) {
    this.t = 1;
    this.s = (x<0)?-1:0;
    if(x > 0) this[0] = x;
    else if(x < -1) this[0] = x+DV;
    else this.t = 0;
  }

  // return bigint initialized to value
  function nbv(i) { var r = nbi(); r.fromInt(i); return r; }

  // (protected) set from string and radix
  function bnpFromString(s,b) {
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 256) k = 8; // byte array
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else { this.fromRadix(s,b); return; }
    this.t = 0;
    this.s = 0;
    var i = s.length, mi = false, sh = 0;
    while(--i >= 0) {
      var x = (k==8)?s[i]&0xff:intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-") mi = true;
        continue;
      }
      mi = false;
      if(sh == 0)
        this[this.t++] = x;
      else if(sh+k > this.DB) {
        this[this.t-1] |= (x&((1<<(this.DB-sh))-1))<<sh;
        this[this.t++] = (x>>(this.DB-sh));
      }
      else
        this[this.t-1] |= x<<sh;
      sh += k;
      if(sh >= this.DB) sh -= this.DB;
    }
    if(k == 8 && (s[0]&0x80) != 0) {
      this.s = -1;
      if(sh > 0) this[this.t-1] |= ((1<<(this.DB-sh))-1)<<sh;
    }
    this.clamp();
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) clamp off excess high words
  function bnpClamp() {
    var c = this.s&this.DM;
    while(this.t > 0 && this[this.t-1] == c) --this.t;
  }

  // (public) return string representation in given radix
  function bnToString(b) {
    if(this.s < 0) return "-"+this.negate().toString(b);
    var k;
    if(b == 16) k = 4;
    else if(b == 8) k = 3;
    else if(b == 2) k = 1;
    else if(b == 32) k = 5;
    else if(b == 4) k = 2;
    else return this.toRadix(b);
    var km = (1<<k)-1, d, m = false, r = "", i = this.t;
    var p = this.DB-(i*this.DB)%k;
    if(i-- > 0) {
      if(p < this.DB && (d = this[i]>>p) > 0) { m = true; r = int2char(d); }
      while(i >= 0) {
        if(p < k) {
          d = (this[i]&((1<<p)-1))<<(k-p);
          d |= this[--i]>>(p+=this.DB-k);
        }
        else {
          d = (this[i]>>(p-=k))&km;
          if(p <= 0) { p += this.DB; --i; }
        }
        if(d > 0) m = true;
        if(m) r += int2char(d);
      }
    }
    return m?r:"0";
  }

  // (public) -this
  function bnNegate() { var r = nbi(); BigInteger.ZERO.subTo(this,r); return r; }

  // (public) |this|
  function bnAbs() { return (this.s<0)?this.negate():this; }

  // (public) return + if this > a, - if this < a, 0 if equal
  function bnCompareTo(a) {
    var r = this.s-a.s;
    if(r != 0) return r;
    var i = this.t;
    r = i-a.t;
    if(r != 0) return (this.s<0)?-r:r;
    while(--i >= 0) if((r=this[i]-a[i]) != 0) return r;
    return 0;
  }

  // returns bit length of the integer x
  function nbits(x) {
    var r = 1, t;
    if((t=x>>>16) != 0) { x = t; r += 16; }
    if((t=x>>8) != 0) { x = t; r += 8; }
    if((t=x>>4) != 0) { x = t; r += 4; }
    if((t=x>>2) != 0) { x = t; r += 2; }
    if((t=x>>1) != 0) { x = t; r += 1; }
    return r;
  }

  // (public) return the number of bits in "this"
  function bnBitLength() {
    if(this.t <= 0) return 0;
    return this.DB*(this.t-1)+nbits(this[this.t-1]^(this.s&this.DM));
  }

  // (protected) r = this << n*DB
  function bnpDLShiftTo(n,r) {
    var i;
    for(i = this.t-1; i >= 0; --i) r[i+n] = this[i];
    for(i = n-1; i >= 0; --i) r[i] = 0;
    r.t = this.t+n;
    r.s = this.s;
  }

  // (protected) r = this >> n*DB
  function bnpDRShiftTo(n,r) {
    for(var i = n; i < this.t; ++i) r[i-n] = this[i];
    r.t = Math.max(this.t-n,0);
    r.s = this.s;
  }

  // (protected) r = this << n
  function bnpLShiftTo(n,r) {
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<cbs)-1;
    var ds = Math.floor(n/this.DB), c = (this.s<<bs)&this.DM, i;
    for(i = this.t-1; i >= 0; --i) {
      r[i+ds+1] = (this[i]>>cbs)|c;
      c = (this[i]&bm)<<bs;
    }
    for(i = ds-1; i >= 0; --i) r[i] = 0;
    r[ds] = c;
    r.t = this.t+ds+1;
    r.s = this.s;
    r.clamp();
  }

  // (protected) r = this >> n
  function bnpRShiftTo(n,r) {
    r.s = this.s;
    var ds = Math.floor(n/this.DB);
    if(ds >= this.t) { r.t = 0; return; }
    var bs = n%this.DB;
    var cbs = this.DB-bs;
    var bm = (1<<bs)-1;
    r[0] = this[ds]>>bs;
    for(var i = ds+1; i < this.t; ++i) {
      r[i-ds-1] |= (this[i]&bm)<<cbs;
      r[i-ds] = this[i]>>bs;
    }
    if(bs > 0) r[this.t-ds-1] |= (this.s&bm)<<cbs;
    r.t = this.t-ds;
    r.clamp();
  }

  // (protected) r = this - a
  function bnpSubTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]-a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c -= a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c -= a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c -= a.s;
    }
    r.s = (c<0)?-1:0;
    if(c < -1) r[i++] = this.DV+c;
    else if(c > 0) r[i++] = c;
    r.t = i;
    r.clamp();
  }

  // (protected) r = this * a, r != this,a (HAC 14.12)
  // "this" should be the larger one if appropriate.
  function bnpMultiplyTo(a,r) {
    var x = this.abs(), y = a.abs();
    var i = x.t;
    r.t = i+y.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < y.t; ++i) r[i+x.t] = x.am(0,y[i],r,i,0,x.t);
    r.s = 0;
    r.clamp();
    if(this.s != a.s) BigInteger.ZERO.subTo(r,r);
  }

  // (protected) r = this^2, r != this (HAC 14.16)
  function bnpSquareTo(r) {
    var x = this.abs();
    var i = r.t = 2*x.t;
    while(--i >= 0) r[i] = 0;
    for(i = 0; i < x.t-1; ++i) {
      var c = x.am(i,x[i],r,2*i,0,1);
      if((r[i+x.t]+=x.am(i+1,2*x[i],r,2*i+1,c,x.t-i-1)) >= x.DV) {
        r[i+x.t] -= x.DV;
        r[i+x.t+1] = 1;
      }
    }
    if(r.t > 0) r[r.t-1] += x.am(i,x[i],r,2*i,0,1);
    r.s = 0;
    r.clamp();
  }

  // (protected) divide this by m, quotient and remainder to q, r (HAC 14.20)
  // r != q, this != m.  q or r may be null.
  function bnpDivRemTo(m,q,r) {
    var pm = m.abs();
    if(pm.t <= 0) return;
    var pt = this.abs();
    if(pt.t < pm.t) {
      if(q != null) q.fromInt(0);
      if(r != null) this.copyTo(r);
      return;
    }
    if(r == null) r = nbi();
    var y = nbi(), ts = this.s, ms = m.s;
    var nsh = this.DB-nbits(pm[pm.t-1]);	// normalize modulus
    if(nsh > 0) { pm.lShiftTo(nsh,y); pt.lShiftTo(nsh,r); }
    else { pm.copyTo(y); pt.copyTo(r); }
    var ys = y.t;
    var y0 = y[ys-1];
    if(y0 == 0) return;
    var yt = y0*(1<<this.F1)+((ys>1)?y[ys-2]>>this.F2:0);
    var d1 = this.FV/yt, d2 = (1<<this.F1)/yt, e = 1<<this.F2;
    var i = r.t, j = i-ys, t = (q==null)?nbi():q;
    y.dlShiftTo(j,t);
    if(r.compareTo(t) >= 0) {
      r[r.t++] = 1;
      r.subTo(t,r);
    }
    BigInteger.ONE.dlShiftTo(ys,t);
    t.subTo(y,y);	// "negative" y so we can replace sub with am later
    while(y.t < ys) y[y.t++] = 0;
    while(--j >= 0) {
      // Estimate quotient digit
      var qd = (r[--i]==y0)?this.DM:Math.floor(r[i]*d1+(r[i-1]+e)*d2);
      if((r[i]+=y.am(0,qd,r,j,0,ys)) < qd) {	// Try it out
        y.dlShiftTo(j,t);
        r.subTo(t,r);
        while(r[i] < --qd) r.subTo(t,r);
      }
    }
    if(q != null) {
      r.drShiftTo(ys,q);
      if(ts != ms) BigInteger.ZERO.subTo(q,q);
    }
    r.t = ys;
    r.clamp();
    if(nsh > 0) r.rShiftTo(nsh,r);	// Denormalize remainder
    if(ts < 0) BigInteger.ZERO.subTo(r,r);
  }

  // (public) this mod a
  function bnMod(a) {
    var r = nbi();
    this.abs().divRemTo(a,null,r);
    if(this.s < 0 && r.compareTo(BigInteger.ZERO) > 0) a.subTo(r,r);
    return r;
  }

  // Modular reduction using "classic" algorithm
  function Classic(m) { this.m = m; }
  function cConvert(x) {
    if(x.s < 0 || x.compareTo(this.m) >= 0) return x.mod(this.m);
    else return x;
  }
  function cRevert(x) { return x; }
  function cReduce(x) { x.divRemTo(this.m,null,x); }
  function cMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }
  function cSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  Classic.prototype.convert = cConvert;
  Classic.prototype.revert = cRevert;
  Classic.prototype.reduce = cReduce;
  Classic.prototype.mulTo = cMulTo;
  Classic.prototype.sqrTo = cSqrTo;

  // (protected) return "-1/this % 2^DB"; useful for Mont. reduction
  // justification:
  //         xy == 1 (mod m)
  //         xy =  1+km
  //   xy(2-xy) = (1+km)(1-km)
  // x[y(2-xy)] = 1-k^2m^2
  // x[y(2-xy)] == 1 (mod m^2)
  // if y is 1/x mod m, then y(2-xy) is 1/x mod m^2
  // should reduce x and y(2-xy) by m^2 at each step to keep size bounded.
  // JS multiply "overflows" differently from C/C++, so care is needed here.
  function bnpInvDigit() {
    if(this.t < 1) return 0;
    var x = this[0];
    if((x&1) == 0) return 0;
    var y = x&3;		// y == 1/x mod 2^2
    y = (y*(2-(x&0xf)*y))&0xf;	// y == 1/x mod 2^4
    y = (y*(2-(x&0xff)*y))&0xff;	// y == 1/x mod 2^8
    y = (y*(2-(((x&0xffff)*y)&0xffff)))&0xffff;	// y == 1/x mod 2^16
    // last step - calculate inverse mod DV directly;
    // assumes 16 < DB <= 32 and assumes ability to handle 48-bit ints
    y = (y*(2-x*y%this.DV))%this.DV;		// y == 1/x mod 2^dbits
    // we really want the negative inverse, and -DV < y < DV
    return (y>0)?this.DV-y:-y;
  }

  // Montgomery reduction
  function Montgomery(m) {
    this.m = m;
    this.mp = m.invDigit();
    this.mpl = this.mp&0x7fff;
    this.mph = this.mp>>15;
    this.um = (1<<(m.DB-15))-1;
    this.mt2 = 2*m.t;
  }

  // xR mod m
  function montConvert(x) {
    var r = nbi();
    x.abs().dlShiftTo(this.m.t,r);
    r.divRemTo(this.m,null,r);
    if(x.s < 0 && r.compareTo(BigInteger.ZERO) > 0) this.m.subTo(r,r);
    return r;
  }

  // x/R mod m
  function montRevert(x) {
    var r = nbi();
    x.copyTo(r);
    this.reduce(r);
    return r;
  }

  // x = x/R mod m (HAC 14.32)
  function montReduce(x) {
    while(x.t <= this.mt2)	// pad x so am has enough room later
      x[x.t++] = 0;
    for(var i = 0; i < this.m.t; ++i) {
      // faster way of calculating u0 = x[i]*mp mod DV
      var j = x[i]&0x7fff;
      var u0 = (j*this.mpl+(((j*this.mph+(x[i]>>15)*this.mpl)&this.um)<<15))&x.DM;
      // use am to combine the multiply-shift-add into one call
      j = i+this.m.t;
      x[j] += this.m.am(0,u0,x,i,0,this.m.t);
      // propagate carry
      while(x[j] >= x.DV) { x[j] -= x.DV; x[++j]++; }
    }
    x.clamp();
    x.drShiftTo(this.m.t,x);
    if(x.compareTo(this.m) >= 0) x.subTo(this.m,x);
  }

  // r = "x^2/R mod m"; x != r
  function montSqrTo(x,r) { x.squareTo(r); this.reduce(r); }

  // r = "xy/R mod m"; x,y != r
  function montMulTo(x,y,r) { x.multiplyTo(y,r); this.reduce(r); }

  Montgomery.prototype.convert = montConvert;
  Montgomery.prototype.revert = montRevert;
  Montgomery.prototype.reduce = montReduce;
  Montgomery.prototype.mulTo = montMulTo;
  Montgomery.prototype.sqrTo = montSqrTo;

  // (protected) true iff this is even
  function bnpIsEven() { return ((this.t>0)?(this[0]&1):this.s) == 0; }

  // (protected) this^e, e < 2^32, doing sqr and mul with "r" (HAC 14.79)
  function bnpExp(e,z) {
    if(e > 0xffffffff || e < 1) return BigInteger.ONE;
    var r = nbi(), r2 = nbi(), g = z.convert(this), i = nbits(e)-1;
    g.copyTo(r);
    while(--i >= 0) {
      z.sqrTo(r,r2);
      if((e&(1<<i)) > 0) z.mulTo(r2,g,r);
      else { var t = r; r = r2; r2 = t; }
    }
    return z.revert(r);
  }

  // (public) this^e % m, 0 <= e < 2^32
  function bnModPowInt(e,m) {
    var z;
    if(e < 256 || m.isEven()) z = new Classic(m); else z = new Montgomery(m);
    return this.exp(e,z);
  }

  // protected
  BigInteger.prototype.copyTo = bnpCopyTo;
  BigInteger.prototype.fromInt = bnpFromInt;
  BigInteger.prototype.fromString = bnpFromString;
  BigInteger.prototype.clamp = bnpClamp;
  BigInteger.prototype.dlShiftTo = bnpDLShiftTo;
  BigInteger.prototype.drShiftTo = bnpDRShiftTo;
  BigInteger.prototype.lShiftTo = bnpLShiftTo;
  BigInteger.prototype.rShiftTo = bnpRShiftTo;
  BigInteger.prototype.subTo = bnpSubTo;
  BigInteger.prototype.multiplyTo = bnpMultiplyTo;
  BigInteger.prototype.squareTo = bnpSquareTo;
  BigInteger.prototype.divRemTo = bnpDivRemTo;
  BigInteger.prototype.invDigit = bnpInvDigit;
  BigInteger.prototype.isEven = bnpIsEven;
  BigInteger.prototype.exp = bnpExp;

  // public
  BigInteger.prototype.toString = bnToString;
  BigInteger.prototype.negate = bnNegate;
  BigInteger.prototype.abs = bnAbs;
  BigInteger.prototype.compareTo = bnCompareTo;
  BigInteger.prototype.bitLength = bnBitLength;
  BigInteger.prototype.mod = bnMod;
  BigInteger.prototype.modPowInt = bnModPowInt;

  // "constants"
  BigInteger.ZERO = nbv(0);
  BigInteger.ONE = nbv(1);

  // jsbn2 stuff

  // (protected) convert from radix string
  function bnpFromRadix(s,b) {
    this.fromInt(0);
    if(b == null) b = 10;
    var cs = this.chunkSize(b);
    var d = Math.pow(b,cs), mi = false, j = 0, w = 0;
    for(var i = 0; i < s.length; ++i) {
      var x = intAt(s,i);
      if(x < 0) {
        if(s.charAt(i) == "-" && this.signum() == 0) mi = true;
        continue;
      }
      w = b*w+x;
      if(++j >= cs) {
        this.dMultiply(d);
        this.dAddOffset(w,0);
        j = 0;
        w = 0;
      }
    }
    if(j > 0) {
      this.dMultiply(Math.pow(b,j));
      this.dAddOffset(w,0);
    }
    if(mi) BigInteger.ZERO.subTo(this,this);
  }

  // (protected) return x s.t. r^x < DV
  function bnpChunkSize(r) { return Math.floor(Math.LN2*this.DB/Math.log(r)); }

  // (public) 0 if this == 0, 1 if this > 0
  function bnSigNum() {
    if(this.s < 0) return -1;
    else if(this.t <= 0 || (this.t == 1 && this[0] <= 0)) return 0;
    else return 1;
  }

  // (protected) this *= n, this >= 0, 1 < n < DV
  function bnpDMultiply(n) {
    this[this.t] = this.am(0,n-1,this,0,0,this.t);
    ++this.t;
    this.clamp();
  }

  // (protected) this += n << w words, this >= 0
  function bnpDAddOffset(n,w) {
    if(n == 0) return;
    while(this.t <= w) this[this.t++] = 0;
    this[w] += n;
    while(this[w] >= this.DV) {
      this[w] -= this.DV;
      if(++w >= this.t) this[this.t++] = 0;
      ++this[w];
    }
  }

  // (protected) convert to radix string
  function bnpToRadix(b) {
    if(b == null) b = 10;
    if(this.signum() == 0 || b < 2 || b > 36) return "0";
    var cs = this.chunkSize(b);
    var a = Math.pow(b,cs);
    var d = nbv(a), y = nbi(), z = nbi(), r = "";
    this.divRemTo(d,y,z);
    while(y.signum() > 0) {
      r = (a+z.intValue()).toString(b).substr(1) + r;
      y.divRemTo(d,y,z);
    }
    return z.intValue().toString(b) + r;
  }

  // (public) return value as integer
  function bnIntValue() {
    if(this.s < 0) {
      if(this.t == 1) return this[0]-this.DV;
      else if(this.t == 0) return -1;
    }
    else if(this.t == 1) return this[0];
    else if(this.t == 0) return 0;
    // assumes 16 < DB < 32
    return ((this[1]&((1<<(32-this.DB))-1))<<this.DB)|this[0];
  }

  // (protected) r = this + a
  function bnpAddTo(a,r) {
    var i = 0, c = 0, m = Math.min(a.t,this.t);
    while(i < m) {
      c += this[i]+a[i];
      r[i++] = c&this.DM;
      c >>= this.DB;
    }
    if(a.t < this.t) {
      c += a.s;
      while(i < this.t) {
        c += this[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += this.s;
    }
    else {
      c += this.s;
      while(i < a.t) {
        c += a[i];
        r[i++] = c&this.DM;
        c >>= this.DB;
      }
      c += a.s;
    }
    r.s = (c<0)?-1:0;
    if(c > 0) r[i++] = c;
    else if(c < -1) r[i++] = this.DV+c;
    r.t = i;
    r.clamp();
  }

  BigInteger.prototype.fromRadix = bnpFromRadix;
  BigInteger.prototype.chunkSize = bnpChunkSize;
  BigInteger.prototype.signum = bnSigNum;
  BigInteger.prototype.dMultiply = bnpDMultiply;
  BigInteger.prototype.dAddOffset = bnpDAddOffset;
  BigInteger.prototype.toRadix = bnpToRadix;
  BigInteger.prototype.intValue = bnIntValue;
  BigInteger.prototype.addTo = bnpAddTo;

  //======= end jsbn =======

  // Emscripten wrapper
  var Wrapper = {
    abs: function(l, h) {
      var x = new goog.math.Long(l, h);
      var ret;
      if (x.isNegative()) {
        ret = x.negate();
      } else {
        ret = x;
      }
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
    },
    ensureTemps: function() {
      if (Wrapper.ensuredTemps) return;
      Wrapper.ensuredTemps = true;
      Wrapper.two32 = new BigInteger();
      Wrapper.two32.fromString('4294967296', 10);
      Wrapper.two64 = new BigInteger();
      Wrapper.two64.fromString('18446744073709551616', 10);
      Wrapper.temp1 = new BigInteger();
      Wrapper.temp2 = new BigInteger();
    },
    lh2bignum: function(l, h) {
      var a = new BigInteger();
      a.fromString(h.toString(), 10);
      var b = new BigInteger();
      a.multiplyTo(Wrapper.two32, b);
      var c = new BigInteger();
      c.fromString(l.toString(), 10);
      var d = new BigInteger();
      c.addTo(b, d);
      return d;
    },
    stringify: function(l, h, unsigned) {
      var ret = new goog.math.Long(l, h).toString();
      if (unsigned && ret[0] == '-') {
        // unsign slowly using jsbn bignums
        Wrapper.ensureTemps();
        var bignum = new BigInteger();
        bignum.fromString(ret, 10);
        ret = new BigInteger();
        Wrapper.two64.addTo(bignum, ret);
        ret = ret.toString(10);
      }
      return ret;
    },
    fromString: function(str, base, min, max, unsigned) {
      Wrapper.ensureTemps();
      var bignum = new BigInteger();
      bignum.fromString(str, base);
      var bigmin = new BigInteger();
      bigmin.fromString(min, 10);
      var bigmax = new BigInteger();
      bigmax.fromString(max, 10);
      if (unsigned && bignum.compareTo(BigInteger.ZERO) < 0) {
        var temp = new BigInteger();
        bignum.addTo(Wrapper.two64, temp);
        bignum = temp;
      }
      var error = false;
      if (bignum.compareTo(bigmin) < 0) {
        bignum = bigmin;
        error = true;
      } else if (bignum.compareTo(bigmax) > 0) {
        bignum = bigmax;
        error = true;
      }
      var ret = goog.math.Long.fromString(bignum.toString()); // min-max checks should have clamped this to a range goog.math.Long can handle well
      HEAP32[tempDoublePtr>>2] = ret.low_;
      HEAP32[tempDoublePtr+4>>2] = ret.high_;
      if (error) throw 'range error';
    }
  };
  return Wrapper;
})();

//======= end closure i64 code =======



// === Auto-generated postamble setup entry stuff ===


function ExitStatus(status) {
  this.name = "ExitStatus";
  this.message = "Program terminated with exit(" + status + ")";
  this.status = status;
};
ExitStatus.prototype = new Error();
ExitStatus.prototype.constructor = ExitStatus;

var initialStackTop;
var preloadStartTime = null;
var calledMain = false;

dependenciesFulfilled = function runCaller() {
  // If run has never been called, and we should call run (INVOKE_RUN is true, and Module.noInitialRun is not false)
  if (!Module['calledRun']) run();
  if (!Module['calledRun']) dependenciesFulfilled = runCaller; // try this again later, after new deps are fulfilled
}

Module['callMain'] = Module.callMain = function callMain(args) {
  assert(runDependencies == 0, 'cannot call main when async dependencies remain! (listen on __ATMAIN__)');
  assert(__ATPRERUN__.length == 0, 'cannot call main when preRun functions remain to be called');

  args = args || [];

  ensureInitRuntime();

  var argc = args.length+1;
  function pad() {
    for (var i = 0; i < 4-1; i++) {
      argv.push(0);
    }
  }
  var argv = [allocate(intArrayFromString(Module['thisProgram']), 'i8', ALLOC_NORMAL) ];
  pad();
  for (var i = 0; i < argc-1; i = i + 1) {
    argv.push(allocate(intArrayFromString(args[i]), 'i8', ALLOC_NORMAL));
    pad();
  }
  argv.push(0);
  argv = allocate(argv, 'i32', ALLOC_NORMAL);

  initialStackTop = STACKTOP;

  try {

    var ret = Module['_main'](argc, argv, 0);


    // if we're not running an evented main loop, it's time to exit
    exit(ret, /* implicit = */ true);
  }
  catch(e) {
    if (e instanceof ExitStatus) {
      // exit() throws this once it's done to make sure execution
      // has been stopped completely
      return;
    } else if (e == 'SimulateInfiniteLoop') {
      // running an evented main loop, don't immediately exit
      Module['noExitRuntime'] = true;
      return;
    } else {
      if (e && typeof e === 'object' && e.stack) Module.printErr('exception thrown: ' + [e, e.stack]);
      throw e;
    }
  } finally {
    calledMain = true;
  }
}




function run(args) {
  args = args || Module['arguments'];

  if (preloadStartTime === null) preloadStartTime = Date.now();

  if (runDependencies > 0) {
    Module.printErr('run() called, but dependencies remain, so not running');
    return;
  }

  preRun();

  if (runDependencies > 0) return; // a preRun added a dependency, run will be called later
  if (Module['calledRun']) return; // run may have just been called through dependencies being fulfilled just in this very frame

  function doRun() {
    if (Module['calledRun']) return; // run may have just been called while the async setStatus time below was happening
    Module['calledRun'] = true;

    if (ABORT) return; 

    ensureInitRuntime();

    preMain();

    if (ENVIRONMENT_IS_WEB && preloadStartTime !== null) {
      Module.printErr('pre-main prep time: ' + (Date.now() - preloadStartTime) + ' ms');
    }

    if (Module['onRuntimeInitialized']) Module['onRuntimeInitialized']();

    if (Module['_main'] && shouldRunNow) Module['callMain'](args);

    postRun();
  }

  if (Module['setStatus']) {
    Module['setStatus']('Running...');
    setTimeout(function() {
      setTimeout(function() {
        Module['setStatus']('');
      }, 1);
      doRun();
    }, 1);
  } else {
    doRun();
  }
}
Module['run'] = Module.run = run;

function exit(status, implicit) {
  if (implicit && Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') implicitly called by end of main(), but noExitRuntime, so not exiting the runtime (you can use emscripten_force_exit, if you want to force a true shutdown)');
    return;
  }

  if (Module['noExitRuntime']) {
    Module.printErr('exit(' + status + ') called, but noExitRuntime, so halting execution but not exiting the runtime or preventing further async execution (you can use emscripten_force_exit, if you want to force a true shutdown)');
  } else {

    ABORT = true;
    EXITSTATUS = status;
    STACKTOP = initialStackTop;

    exitRuntime();

    if (Module['onExit']) Module['onExit'](status);
  }

  if (ENVIRONMENT_IS_NODE) {
    // Work around a node.js bug where stdout buffer is not flushed at process exit:
    // Instead of process.exit() directly, wait for stdout flush event.
    // See https://github.com/joyent/node/issues/1669 and https://github.com/kripken/emscripten/issues/2582
    // Workaround is based on https://github.com/RReverser/acorn/commit/50ab143cecc9ed71a2d66f78b4aec3bb2e9844f6
    process['stdout']['once']('drain', function () {
      process['exit'](status);
    });
    console.log(' '); // Make sure to print something to force the drain event to occur, in case the stdout buffer was empty.
    // Work around another node bug where sometimes 'drain' is never fired - make another effort
    // to emit the exit status, after a significant delay (if node hasn't fired drain by then, give up)
    setTimeout(function() {
      process['exit'](status);
    }, 500);
  } else
  if (ENVIRONMENT_IS_SHELL && typeof quit === 'function') {
    quit(status);
  }
  // if we reach here, we must throw an exception to halt the current execution
  throw new ExitStatus(status);
}
Module['exit'] = Module.exit = exit;

var abortDecorators = [];

function abort(what) {
  if (what !== undefined) {
    Module.print(what);
    Module.printErr(what);
    what = JSON.stringify(what)
  } else {
    what = '';
  }

  ABORT = true;
  EXITSTATUS = 1;

  var extra = '';

  var output = 'abort(' + what + ') at ' + stackTrace() + extra;
  if (abortDecorators) {
    abortDecorators.forEach(function(decorator) {
      output = decorator(output, what);
    });
  }
  throw output;
}
Module['abort'] = Module.abort = abort;

// {{PRE_RUN_ADDITIONS}}

if (Module['preInit']) {
  if (typeof Module['preInit'] == 'function') Module['preInit'] = [Module['preInit']];
  while (Module['preInit'].length > 0) {
    Module['preInit'].pop()();
  }
}

// shouldRunNow refers to calling main(), not run().
var shouldRunNow = true;
if (Module['noInitialRun']) {
  shouldRunNow = false;
}


run();

// {{POST_RUN_ADDITIONS}}






// {{MODULE_ADDITIONS}}



